@@ -62,7 +62,7 @@ static KEYWORD layconopt[] =
 	TERMKEY
 };
 COMCOMP cla_layconp = {layconopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "layout constraint system option", 0};
+	0, " \t", M_("layout constraint system option"), 0};
 
 INTBIG cla_changeclock;
 #ifdef DEBUG
@@ -96,13 +96,13 @@ void cla_layconsetmode(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputerr("Usage: constraint tell layout OPTION");
+		ttyputusage("constraint tell layout OPTION");
 		return;
 	}
 
 	if (el_curconstraint != cla_constraint)
 	{
-		ttyputerr("Must first switch to this solver with 'constraint use'");
+		ttyputerr(_("Must first switch to this solver with 'constraint use'"));
 		return;
 	}
 
@@ -113,14 +113,14 @@ void cla_layconsetmode(INTSML count, char *par[])
 	{
 #ifdef DEBUG
 		cla_conlaydebug = 1 - cla_conlaydebug;
-		if (cla_conlaydebug != 0) ttyputmsg("Layout constraint debugging on"); else
-			ttyputmsg("Layout constraint debugging off");
+		if (cla_conlaydebug != 0) ttyputmsg(_("Layout constraint debugging on")); else
+			ttyputmsg(_("Layout constraint debugging off"));
 #else
-		ttyputmsg("Sorry, constraint debugging code has been compiled out");
+		ttyputmsg(_("Sorry, constraint debugging code has been compiled out"));
 #endif
 		return;
 	}
-	ttyputerr("Bad layout constraint option: %s", pp);
+	ttyputbadusage("constraint tell layout");
 }
 
 /*
@@ -312,7 +312,7 @@ void cla_layconmodifydescript(INTBIG addr, INTBIG type, VARIABLE *var, INTBIG ol
  * "announce" is nonzero, report "start" and "end" changes on the node.
  * If the nodeinst is a portproto of the current facet and has any arcs
  * connected to it, the routine returns nonzero to indicate that the outer
- * facet has ports that moved (the nodeinst has exported ports).
+ * facet has ports that moved (the nodeinst has exports).
  */
 INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG deltahx,
 	INTBIG deltahy, INTSML dangle, INTSML dtrans, INTSML announce)
@@ -347,7 +347,7 @@ INTSML cla_modifynodeinst(NODEINST *ni, INTBIG deltalx, INTBIG deltaly, INTBIG d
 
 #ifdef DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg("Change node %s by X(%s %s) Y(%s %s) r=%d t=%d",
+		ttyputmsg(_("Change node %s by X(%s %s) Y(%s %s) r=%d t=%d"),
 			describenodeinst(ni), latoa(deltalx), latoa(deltahx), latoa(deltaly),
 				latoa(deltahy), dangle, dtrans);
 #endif
@@ -459,7 +459,7 @@ void cla_modwithin(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		xform(ai->end[1].xpos-ox, ai->end[1].ypos-oy, &onox, &onoy, trans);
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Internal arc %s moves 0:%s,%s  1:%s,%s",
+			ttyputmsg(_("Internal arc %s moves 0:%s,%s  1:%s,%s"),
 				describearcinst(ai), latoa(nox), latoa(noy), latoa(onox), latoa(onoy));
 #endif
 		/* move the arcinst */
@@ -553,7 +553,7 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		opt = ai->end[thatend].portarcinst->proto;
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Modify rigid arc %s from %s to %s",
+			ttyputmsg(_("Modify rigid arc %s from %s to %s"),
 				describearcinst(ai), describenodeinst(ni), describenodeinst(ono));
 #endif
 
@@ -562,7 +562,7 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 			&ay[thatend], trans);
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Other end of arc moves to (%s,%s)",
+			ttyputmsg(_("Other end of arc moves to (%s,%s)"),
 				latoa(ax[thatend]), latoa(ay[thatend]));
 #endif
 
@@ -608,7 +608,7 @@ INTSML cla_modrigid(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		/* move the arcinst */
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Now arc runs from (%s,%s) to (%s,%s)",
+			ttyputmsg(_("Now arc runs from (%s,%s) to (%s,%s)"),
 				latoa(ax[0]), latoa(ay[0]), latoa(ax[1]), latoa(ay[1]));
 #endif
 		cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 0);
@@ -652,7 +652,8 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 	XARRAY trans;
 	REGISTER INTBIG odx, ody;
 	REGISTER INTSML i, total;
-	INTBIG ax[2], ay[2], dx, dy;
+	INTBIG ax[2], ay[2], dx, dy, lx, hx, ly, hy;
+	static POLYGON *poly = NOPOLYGON;
 
 	/* build a list of the flexible arcs on this nodeinst */
 	total = 0;
@@ -697,7 +698,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 #ifdef	DEBUG
 		if (cla_conlaydebug)
 		{
-			ttyputmsg("Considering arc %s (clock=%d, curclock=%d)",
+			ttyputmsg(_("Considering arc %s (clock=%d, curclock=%d)"),
 				describearcinst(ai), ai->changed, cla_changeclock+1);
 		}
 #endif
@@ -729,6 +730,34 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		xform(ai->end[thisend].xpos-ox, ai->end[thisend].ypos-oy,
 			&ax[thisend], &ay[thisend], trans);
 
+#if 1
+		/* make sure the arc end is still in the port */
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
+		shapeportpoly(ai->end[thisend].nodeinst, ai->end[thisend].portarcinst->proto,
+			poly, 0);
+		reduceportpoly(poly, ai->end[thisend].nodeinst, ai->end[thisend].portarcinst->proto,
+			ai->width - arcwidthoffset(ai));
+		if (isinside(ax[thisend], ay[thisend], poly) == 0)
+		{
+			getbbox(poly, &lx, &hx, &ly, &hy);
+			if (ay[thisend] >= ly && ay[thisend] <= hy)
+			{
+				/* extend arc horizontally to fit in port */
+				if (ax[thisend] < lx) ax[thisend] = lx; else
+					if (ax[thisend] > hx) ax[thisend] = hx;
+			} else if (ax[thisend] >= lx && ax[thisend] <= hx)
+			{
+				/* extend arc vertically to fit in port */
+				if (ay[thisend] < ly) ay[thisend] = ly; else
+					if (ay[thisend] > hy) ay[thisend] = hy;
+			} else
+			{
+				/* extend arc arbitrarily to fit in port */
+				closestpoint(poly, &ax[thisend], &ay[thisend]);
+			}
+		}
+#endif
+
 		/* get other end of arcinst and its position */
 		ono = ai->end[thatend].nodeinst;
 		opt = ai->end[thatend].portarcinst->proto;
@@ -737,7 +766,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 #ifdef	DEBUG
 		if (cla_conlaydebug)
 		{
-			ttyputmsg("Modify flexible arc %s from %s to %s",
+			ttyputmsg(_("Modify flexible arc %s from %s to %s"),
 				describearcinst(ai), describenodeinst(ni), describenodeinst(ono));
 		}
 #endif
@@ -787,7 +816,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 #ifdef	DEBUG
 					if (cla_conlaydebug)
-						ttyputmsg("  Moving other end of arc to (%s,%s), other node by (%s,0)",
+						ttyputmsg(_("  Moving other end of arc to (%s,%s), other node by (%s,0)"),
 							latoa(ax[thatend]), latoa(ay[thatend]), latoa(dx-odx));
 #endif
 					if (dx != odx)
@@ -818,7 +847,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 
 #ifdef	DEBUG
 				if (cla_conlaydebug)
-					ttyputmsg("  Moving other end of arc to (%s,%s), other node by (0,%s)",
+					ttyputmsg(_("  Moving other end of arc to (%s,%s), other node by (0,%s)"),
 						latoa(ax[thatend]), latoa(ay[thatend]), latoa(dy-ody));
 #endif
 				if (dy != ody)
@@ -854,7 +883,7 @@ INTSML cla_modflex(NODEINST *ni, INTSML dangle, INTSML dtrans)
 		/* other node has changed or arc is funny, just use its position */
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("  ! Moving arc %s to (%s,%s)-(%s,%s)", describearcinst(ai),
+			ttyputmsg(_("  ! Moving arc %s to (%s,%s)-(%s,%s)"), describearcinst(ai),
 				latoa(ax[0]), latoa(ay[0]), latoa(ax[1]), latoa(ay[1]));
 #endif
 		cla_domovearcinst(ai, ax[0],ay[0], ax[1],ay[1], 1);
@@ -943,7 +972,7 @@ void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
 		getcenter(poly1, &tx, &ty);
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Ensuring rigid arc %s", describearcinst(ai));
+			ttyputmsg(_("Ensuring rigid arc %s"), describearcinst(ai));
 #endif
 		cla_domovearcinst(ai, fx, fy, tx, ty, arctyp);
 		return;
@@ -963,7 +992,7 @@ void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
 		closestpoint(poly1, &tx, &ty);
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Ensuring manhattan arc %s", describearcinst(ai));
+			ttyputmsg(_("Ensuring manhattan arc %s"), describearcinst(ai));
 #endif
 		cla_domovearcinst(ai, fx, fy, tx, ty, arctyp);
 		return;
@@ -977,7 +1006,7 @@ void cla_ensurearcinst(ARCINST *ai, INTSML arctyp)
 		closestpoint(poly1, &tx, &ty);
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("Ensuring manhattan arc %s", describearcinst(ai));
+			ttyputmsg(_("Ensuring manhattan arc %s"), describearcinst(ai));
 #endif
 		cla_domovearcinst(ai, fx, fy, tx, ty, arctyp);
 		return;
@@ -1007,7 +1036,7 @@ void cla_updatearc(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTS
 	/* set the proper arcinst position */
 #ifdef DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg("Change arc %s from (%s,%s)-(%s,%s) to (%s,%s)-(%s,%s)",
+		ttyputmsg(_("Change arc %s from (%s,%s)-(%s,%s) to (%s,%s)-(%s,%s)"),
 			describearcinst(ai), latoa(ai->end[0].xpos), latoa(ai->end[0].ypos),
 				latoa(ai->end[1].xpos), latoa(ai->end[1].ypos),
 					latoa(fx), latoa(fy), latoa(tx), latoa(ty));
@@ -1063,7 +1092,7 @@ void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
 #ifdef	DEBUG
 	if (cla_conlaydebug)
 	{
-		ttyputmsg("Jogging arc %s (0%o) to run from (%s,%s) to (%s,%s)",
+		ttyputmsg(_("Jogging arc %s (0%o) to run from (%s,%s) to (%s,%s)"),
 			describearcinst(ai), ai, latoa(fx), latoa(fy), latoa(tx), latoa(ty));
 	}
 #endif
@@ -1104,7 +1133,7 @@ void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
 	}
 	if (no1 == NONODEINST || no2 == NONODEINST)
 	{
-		ttyputerr("Problem creating jog pins");
+		ttyputerr(_("Problem creating jog pins"));
 		return;
 	}
 	(void)db_change((INTBIG)no1, OBJECTEND, VNODEINST, 0, 0, 0, 0, 0);
@@ -1116,7 +1145,7 @@ void cla_domovearcinst(ARCINST *ai, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty,
 	ar3 = db_newarcinst(ap, wid, oldbits, no1, pp, oldxB,oldyB, tno, tpt, tx,ty, pnt);
 	if (ar1 == NOARCINST || ar2 == NOARCINST || ar3 == NOARCINST)
 	{
-		ttyputerr("Problem creating jog arcs");
+		ttyputerr(_("Problem creating jog arcs"));
 		return;
 	}
 	(void)copyvars((INTBIG)ai, VARCINST, (INTBIG)ar2, VARCINST);
@@ -1174,9 +1203,9 @@ void cla_adjustmatrix(NODEINST *ni, PORTPROTO *pp, XARRAY trans)
 #ifdef	DEBUG
 		if (cla_conlaydebug)
 		{
-			ttyputmsg("Node %s port %s was at (%s,%s), is at (%s,%s)", describenodeinst(ni),
+			ttyputmsg(_("Node %s port %s was at (%s,%s), is at (%s,%s)"), describenodeinst(ni),
 				pp->protoname, latoa(onox), latoa(onoy), latoa(dx), latoa(dy));
-			ttyputmsg("    Node moved (%s,%s)", latoa(ox), latoa(oy));
+			ttyputmsg(_("    Node moved (%s,%s)"), latoa(ox), latoa(oy));
 		}
 #endif
 		trans[2][0] = dx - onox + ox;   trans[2][1] = dy - onoy + oy;
@@ -1341,7 +1370,7 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 
 #ifdef	DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg("In computefacet on facet %s (fl=%d)",
+		ttyputmsg(_("In computefacet on facet %s (fl=%d)"),
 			facet->cell->cellname, forcedlook);
 #endif
 	/* get current boundary of facet */
@@ -1389,7 +1418,7 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 	{
 #ifdef	DEBUG
 		if (cla_conlaydebug)
-			ttyputmsg("   Recomputing uniform parents of facet %s",
+			ttyputmsg(_("   Recomputing uniform parents of facet %s"),
 				describenodeproto(facet));
 #endif
 		dlx = facet->lowx - flx;   dhx = facet->highx - fhx;
@@ -1414,13 +1443,14 @@ void cla_computefacet(NODEPROTO *facet, INTSML forcedlook)
 	 */
 #ifdef	DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg("   Performing complex tree examination");
+		ttyputmsg(_("   Performing complex tree examination"));
 #endif
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
 		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 			np->userbits &= ~(FACETMOD|FACETNOMOD);
 	facet->userbits |= FACETMOD;
-	for(np = facet->cell->lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
+		for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		/* only want facets with no instances as roots of trees */
 		if (np->firstinst != NONODEINST) continue;
@@ -1484,7 +1514,7 @@ INTSML cla_lookdown(NODEPROTO *start)
 	}
 #ifdef	DEBUG
 	if (cla_conlaydebug)
-		ttyputmsg("      Complex tree search at facet %s", describenodeproto(start));
+		ttyputmsg(_("      Complex tree search at facet %s"), describenodeproto(start));
 #endif
 	/* modify the nodes in this facet that changed */
 	forcedlook = 0;
