@@ -33,7 +33,7 @@
 
 /* command completion table for this constraint solver */
 static COMCOMP cli_linconsp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "facet to solve for linear inequalities", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("facet to solve for linear inequalities"), 0};
 static KEYWORD linconiopt[] =
 {
 	{"on",                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -41,7 +41,7 @@ static KEYWORD linconiopt[] =
 	TERMKEY
 };
 static COMCOMP cli_linconip = {linconiopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "mode that assumes manhattan wires", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("mode that assumes manhattan wires"), 0};
 static KEYWORD lincontopt[] =
 {
 	{"go",                   0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -50,7 +50,7 @@ static KEYWORD lincontopt[] =
 	TERMKEY
 };
 static COMCOMP cli_lincontp = {lincontopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "text-equivalent mode", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("text-equivalent mode"), 0};
 static KEYWORD linconopt[] =
 {
 	{"solve",                1,{&cli_linconsp,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -60,7 +60,7 @@ static KEYWORD linconopt[] =
 	TERMKEY
 };
 COMCOMP cli_linconp = {linconopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "linear constraint system option", 0};
+	0, " \t", M_("linear constraint system option"), 0};
 
 /* global data in linear constraints */
 CONSTRAINT *cli_constraint;	/* the constraint object for this solver */
@@ -208,17 +208,16 @@ void cli_linconsetmode(INTSML count, char *par[])
 	REGISTER char *pp;
 	REGISTER NODEPROTO *np;
 	REGISTER GEOM *geom;
-	extern AIDENTRY *us_aid;
 
 	if (count == 0)
 	{
-		ttyputerr("Usage: constraint tell linear OPTION");
+		ttyputusage("constraint tell linear OPTION");
 		return;
 	}
 
 	if (el_curconstraint != cli_constraint)
 	{
-		ttyputerr("Must first switch to this solver with 'constraint use'");
+		ttyputerr(_("Must first switch to this solver with 'constraint use'"));
 		return;
 	}
 
@@ -227,8 +226,8 @@ void cli_linconsetmode(INTSML count, char *par[])
 	if (namesamen(pp, "debug-toggle", l) == 0 && l >= 1)
 	{
 		cli_conlindebug = 1 - cli_conlindebug;
-		if (cli_conlindebug != 0) ttyputverbose("Linear constraint debugging on"); else
-			ttyputverbose("Linear constraint debugging off");
+		if (cli_conlindebug != 0) ttyputverbose(_("Linear constraint debugging on")); else
+			ttyputverbose(_("Linear constraint debugging off"));
 		return;
 	}
 
@@ -236,7 +235,7 @@ void cli_linconsetmode(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputerr("Usage: constraint tell linear text-equivalence OPTION");
+			ttyputusage("constraint tell linear text-equivalence OPTION");
 			return;
 		}
 		l = strlen(pp = par[1]);
@@ -245,7 +244,7 @@ void cli_linconsetmode(INTSML count, char *par[])
 			np = getcurfacet();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("Must have a current facet to generate names");
+				ttyputerr(_("Must have a current facet to generate names"));
 				return;
 			}
 			cli_nameallnodes(np);
@@ -254,14 +253,14 @@ void cli_linconsetmode(INTSML count, char *par[])
 		if (namesamen(pp, "go", l) == 0 && l >= 1)
 		{
 			np = getcurfacet();
-			if (np == NONODEPROTO) ttyputverbose("Enabling text/graphics association"); else
+			if (np == NONODEPROTO) ttyputverbose(_("Enabling text/graphics association")); else
 			{
 				if (cli_texton != 0)
 				{
 					if (np == cli_curfacet)
-						ttyputverbose("Reevaluating textual description"); else
-							ttyputverbose("Switching association to facet %s", describenodeproto(np));
-				} else ttyputverbose("Text window will mirror facet %s", describenodeproto(np));
+						ttyputverbose(_("Reevaluating textual description")); else
+							ttyputverbose(_("Switching association to facet %s"), describenodeproto(np));
+				} else ttyputverbose(_("Text window will mirror facet %s"), describenodeproto(np));
 			}
 			cli_maketextfacet(np);
 			return;
@@ -271,13 +270,13 @@ void cli_linconsetmode(INTSML count, char *par[])
 			geom = (GEOM *)askaid(us_aid, "get-object");
 			if (geom == NOGEOM)
 			{
-				ttyputerr("Find a single object first");
+				ttyputerr(_("Find a single object first"));
 				return;
 			}
 			cli_highlightequivalent(geom);
 			return;
 		}
-		ttyputerr("Bad constraint TELL LINEAR TEXT-EQUIVALENCE option");
+		ttyputbadusage("constraint tell linear text-equivalence");
 		return;
 	}
 
@@ -287,16 +286,16 @@ void cli_linconsetmode(INTSML count, char *par[])
 		if (namesame(pp, "on") == 0)
 		{
 			cli_manhattan = 1;
-			ttyputverbose("Manhattan arcs will be kept that way");
+			ttyputverbose(_("Manhattan arcs will be kept that way"));
 			return;
 		}
 		if (namesamen(pp, "off", l) == 0 && l >= 2)
 		{
 			cli_manhattan = 0;
-			ttyputverbose("No assumptions will be made about Manhattan arcs");
+			ttyputverbose(_("No assumptions will be made about Manhattan arcs"));
 			return;
 		}
-		ttyputerr("Usage: constraint tell linear implicit-manhattan (on|off)");
+		ttyputusage("constraint tell linear implicit-manhattan (on|off)");
 		return;
 	}
 
@@ -307,7 +306,7 @@ void cli_linconsetmode(INTSML count, char *par[])
 			np = getcurfacet();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No facet specified and no current facet");
+				ttyputerr(_("No facet specified and no current facet"));
 				return;
 			}
 		} else
@@ -315,12 +314,12 @@ void cli_linconsetmode(INTSML count, char *par[])
 			np = getnodeproto(par[1]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No facet named %s", par[1]);
+				ttyputerr(_("No facet named %s"), par[1]);
 				return;
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr("Must solve facets, not primitives");
+				ttyputerr(_("Must solve facets, not primitives"));
 				return;
 			}
 		}
@@ -330,7 +329,7 @@ void cli_linconsetmode(INTSML count, char *par[])
 		cli_didsolve = 1;
 		return;
 	}
-	ttyputerr("Bad linear constraint option: %s", pp);
+	ttyputbadusage("constraint tell linear");
 }
 
 /*
@@ -393,7 +392,7 @@ void cli_dosolve(NODEPROTO *facet)
 	REGISTER INTBIG dlx, dhx, dly, dhy;
 
 	if (cli_conlindebug != 0)
-		ttyputmsg("Re-checking linear constraints for facet %s", describenodeproto(facet));
+		ttyputmsg(_("Re-checking linear constraints for facet %s"), describenodeproto(facet));
 	if (cli_didsolve == 0) cli_solvefacet(facet, 0, 0);
 
 	/* get current boundary of facet */
@@ -588,14 +587,14 @@ INTSML cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG c
 	if (changetype == 3)
 	{
 		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties);
-		if (var == NOVARIABLE) ttyputmsg("No linear constraint properties"); else
+		if (var == NOVARIABLE) ttyputmsg(_("No linear constraint properties")); else
 		{
 			len = getlength(var) / LINCONSIZE;
-			ttyputmsg("%d %s on this arc:", len, makeplural("constraint", len));
+			ttyputmsg(_("%d %s on this arc:"), len, makeplural(_("constraint"), len));
 			for(i=0; i<len; i++)
 			{
 				conptr = &((LINCON *)var->addr)[i];
-				ttyputmsg("Constraint %d: %s %s %s", i+1, (conptr->variable<=1 ? "x" : "y"),
+				ttyputmsg(_("Constraint %d: %s %s %s"), i+1, (conptr->variable<=1 ? "x" : "y"),
 					cli_linconops[conptr->oper], frtoa(conptr->value));
 			}
 		}
@@ -608,7 +607,7 @@ INTSML cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG c
 		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER|VISARRAY, cli_properties);
 		if (var == NOVARIABLE)
 		{
-			ttyputerr("No constraints on this arc");
+			ttyputerr(_("No constraints on this arc"));
 			return(1);
 		}
 		len = getlength(var) / LINCONSIZE;
@@ -641,7 +640,7 @@ INTSML cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG c
 			variable = 2;
 	} else
 	{
-		ttyputerr("Cannot parse variable (should be 'X' or 'Y')");
+		ttyputerr(_("Cannot parse variable (should be 'X' or 'Y')"));
 		error++;
 	}
 	pt++;
@@ -656,7 +655,7 @@ INTSML cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG c
 		pt += strlen(cli_linconops[i]);
 	} else
 	{
-		ttyputerr("Cannot parse operator (must be '>=', '==', or '<=')");
+		ttyputerr(_("Cannot parse operator (must be '>=', '==', or '<=')"));
 		error++;
 	}
 
@@ -666,26 +665,26 @@ INTSML cli_linconsetobject(INTBIG addr, INTBIG type, INTBIG changetype, INTBIG c
 		value = atofr(pt);
 		if (value < 0)
 		{
-			ttyputerr("Values must be positive");
+			ttyputerr(_("Values must be positive"));
 			error++;
 		}
 	} else
 	{
-		ttyputerr("Invalid number on right (%s)", pt);
+		ttyputerr(_("Invalid number on right (%s)"), pt);
 		error++;
 	}
 
 	if (error != 0)
 	{
-		ttyputmsg("Cannot accept linear constraint '%s'", str);
+		ttyputmsg(_("Cannot accept linear constraint '%s'"), str);
 		return(1);
 	}
 
 	db_setchangefacet(ai->parent);
 	db_forcehierarchicalanalysis(ai->parent);
 	if (cli_addarcconstraint(ai, (INTSML)variable, oper, value, (INTSML)changetype) != 0) return(1);
-	if (changetype == 0) ttyputverbose("Constraint set"); else
-		ttyputverbose("Constraint added");
+	if (changetype == 0) ttyputverbose(_("Constraint set")); else
+		ttyputverbose(_("Constraint added"));
 	return(0);
 }
 
@@ -720,7 +719,7 @@ INTSML cli_addarcconstraint(ARCINST *ai, INTSML variable, INTSML oper, INTBIG va
 	conlist = (LINCON *)emalloc(((len+1) * (sizeof (LINCON))), el_tempcluster);
 	if (conlist == 0)
 	{
-		ttyputerr("Out of memory");
+		ttyputnomemory();
 		return(1);
 	}
 	for(i=0; i<len; i++)
@@ -777,7 +776,7 @@ void cli_deletearcconstraint(ARCINST *ai, INTSML variable, INTSML oper, INTBIG v
 	conlist = (LINCON *)emalloc(((len-1) * (sizeof (LINCON))), el_tempcluster);
 	if (conlist == 0)
 	{
-		ttyputerr("Out of memory");
+		ttyputnomemory();
 		return;
 	}
 	k = 0;
@@ -878,7 +877,7 @@ void cli_solvefacet(NODEPROTO *np, INTSML minimum, INTSML noanchors)
 	/* quit now if all constraints are solved */
 	if (xnotsolved == 0 && ynotsolved == 0 && minimum == 0)
 	{
-		if (cli_conlindebug != 0) ttyputmsg("All constraints are met");
+		if (cli_conlindebug != 0) ttyputmsg(_("All constraints are met"));
 		cli_deleteconstraints(firstx);
 		cli_deleteconstraints(firsty);
 		return;
@@ -890,29 +889,29 @@ void cli_solvefacet(NODEPROTO *np, INTSML minimum, INTSML noanchors)
 
 	if (cli_conlindebug != 0)
 	{
-		cli_printconstraints(firstx, "Horizontal constraints:", "X");
-		if (xnotsolved == 0) ttyputmsg("HORIZONTAL CONSTRAINTS ARE ALL MET");
-		cli_printconstraints(firsty, "Vertical constraints:", "Y");
-		if (ynotsolved == 0) ttyputmsg("VERTICAL CONSTRAINTS ARE ALL MET");
+		cli_printconstraints(firstx, _("Horizontal constraints:"), "X");
+		if (xnotsolved == 0) ttyputmsg(_("HORIZONTAL CONSTRAINTS ARE ALL MET"));
+		cli_printconstraints(firsty, _("Vertical constraints:"), "Y");
+		if (ynotsolved == 0) ttyputmsg(_("VERTICAL CONSTRAINTS ARE ALL MET"));
 	}
 
 	/* solve the networks and determine the success */
 	failure = 0;
 	if (xnotsolved != 0 || minimum != 0)
 	{
-		if (cli_conlindebug != 0) ttyputmsg("Solving X constraints:");
+		if (cli_conlindebug != 0) ttyputmsg(_("Solving X constraints:"));
 		if (cli_solveconstraints(firstx, minimum) != 0)
 		{
-			ttyputmsg("X constraint network cannot be solved!");
+			ttyputmsg(_("X constraint network cannot be solved!"));
 			failure = 1;
 		}
 	}
 	if (ynotsolved != 0 || minimum != 0)
 	{
-		if (cli_conlindebug != 0) ttyputmsg("Solving Y constraints:");
+		if (cli_conlindebug != 0) ttyputmsg(_("Solving Y constraints:"));
 		if (cli_solveconstraints(firsty, minimum) != 0)
 		{
-			ttyputmsg("Y constraint network cannot be solved!");
+			ttyputmsg(_("Y constraint network cannot be solved!"));
 			failure = 1;
 		}
 	}
@@ -948,7 +947,7 @@ INTSML cli_buildconstraints(NODEPROTO *np, CONNODE **first, INTSML axis, INTSML
 	REGISTER CONNODE *cn;
 
 	/* get the value of lambda */
-	lambda = whattech(np)->deflambda;
+	lambda = lambdaoffacet(np);
 
 	/* mark all real nodes as un-converted to constraint nodes */
 	for(ni = np->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -1122,7 +1121,7 @@ void cli_addconstraint(ARCINST *ai, CONNODE **first, INTBIG opf, INTBIG vaf, INT
 	cat = cli_allocconarc();
 	if (caf == NOCONARC || cat == NOCONARC)
 	{
-		ttyputerr("Linear constraints: out of arc space");
+		ttyputnomemory();
 		return;
 	}
 
@@ -1136,7 +1135,7 @@ void cli_addconstraint(ARCINST *ai, CONNODE **first, INTBIG opf, INTBIG vaf, INT
 		cnf = cli_allocconnode();
 		if (cnf == NOCONNODE)
 		{
-			ttyputerr("Linear constraints: out of node space");
+			ttyputnomemory();
 			return;
 		}
 		cnf->realn = ai->end[0].nodeinst;
@@ -1161,7 +1160,7 @@ void cli_addconstraint(ARCINST *ai, CONNODE **first, INTBIG opf, INTBIG vaf, INT
 		cnt = cli_allocconnode();
 		if (cnt == NOCONNODE)
 		{
-			ttyputerr("Linear constraints: out of node space");
+			ttyputnomemory();
 			return;
 		}
 		cnt->realn = ai->end[1].nodeinst;
@@ -1291,7 +1290,7 @@ INTSML cli_solveconstraints(CONNODE *first, INTSML minimum)
 			cn->solved = 1;
 		}
 
-		if (cli_conlindebug != 0) ttyputmsg("  Working from node %s at %ld",
+		if (cli_conlindebug != 0) ttyputmsg(_("  Working from node %s at %ld"),
 			describenodeinst(cn->realn), cn->value);
 
 		/* check all constraint arcs to other nodes */
@@ -1316,7 +1315,7 @@ INTSML cli_solveconstraints(CONNODE *first, INTSML minimum)
 			if (ca->other->value == cn->value + ca->value)
 			{
 				if (cli_conlindebug != 0)
-					ttyputmsg("    Constraint to %s is met perfectly",
+					ttyputmsg(_("    Constraint to %s is met perfectly"),
 						describenodeinst(ca->other->realn));
 				ca->other->solved = 1;
 				continue;
@@ -1326,7 +1325,7 @@ INTSML cli_solveconstraints(CONNODE *first, INTSML minimum)
 			if (satisfied != 0 && minimum == 0)
 			{
 				if (cli_conlindebug != 0)
-					ttyputmsg("    Constraint to %s is met adequately",
+					ttyputmsg(_("    Constraint to %s is met adequately"),
 						describenodeinst(ca->other->realn));
 				ca->other->solved = 1;
 				continue;
@@ -1337,7 +1336,7 @@ INTSML cli_solveconstraints(CONNODE *first, INTSML minimum)
 			{
 				ca->other->value = cn->value + ca->value;
 				if (cli_conlindebug != 0)
-					ttyputmsg("    Constraint to unsolved %s adjusts it to %ld",
+					ttyputmsg(_("    Constraint to unsolved %s adjusts it to %ld"),
 						describenodeinst(ca->other->realn), ca->other->value);
 				ca->other->solved = 1;
 				continue;
@@ -1348,7 +1347,7 @@ INTSML cli_solveconstraints(CONNODE *first, INTSML minimum)
 				cno->loopflag = 0;
 			cn->loopflag = 1;
 			if (cli_conlindebug != 0)
-				ttyputmsg("    Constraint to solved %s takes some work:",
+				ttyputmsg(_("    Constraint to solved %s takes some work:"),
 					describenodeinst(ca->other->realn));
 			if (cli_satisfy(cn, ca) != 0) return(1);
 		}
@@ -1372,7 +1371,7 @@ INTSML cli_satisfy(CONNODE *cn, CONARC *ca)
 
 	/* set new value for that constraint node */
 	cno->value = cn->value + ca->value;
-	if (cli_conlindebug != 0) ttyputmsg("      Setting %s to %ld",
+	if (cli_conlindebug != 0) ttyputmsg(_("      Setting %s to %ld"),
 		describenodeinst(cno->realn), cno->value);
 
 	/* see if that constraint node is now satisfied */
@@ -1507,10 +1506,10 @@ void cli_printconstraints(CONNODE *first, char *message, char *axis)
 	ttyputmsg("%s", message);
 	for(cn = first; cn != NOCONNODE; cn = cn->nextconnode)
 	{
-		ttyputmsg("  Node %s at %ld anchored=%d has these constraints:",
+		ttyputmsg(_("  Node %s at %ld anchored=%d has these constraints:"),
 			describenodeinst(cn->realn), cn->value, cn->solved);
 		for(ca = cn->firstconarc; ca != NOCONARC; ca = ca->nextconarc)
-			ttyputmsg("    to node %s (%s %s %ld)", describenodeinst(ca->other->realn), axis,
+			ttyputmsg(_("    to node %s (%s %s %ld)"), describenodeinst(ca->other->realn), axis,
 				cli_linconops[ca->oper], ca->value);
 	}
 }
@@ -1547,7 +1546,7 @@ void cli_nameallnodes(NODEPROTO *np)
 		/* if the name is null, assign a name */
 		if (strlen(pt) == 0)
 		{
-			if (ni->proto->primindex == 0) pt = "FACET"; else pt = "node";
+			if (ni->proto->primindex == 0) pt = _("FACET"); else pt = _("node");
 		}
 
 		/* find an abbreviation module for this */
