@@ -31,7 +31,6 @@
 #include "database.h"
 #include "conlin.h"
 
-extern AIDENTRY *us_aid;
 INTSML (*cli_realcharhandler)(WINDOWPART*, INTSML);
 void (*cli_oldttermhandler)(WINDOWPART*);	/* former text editor termination routine */
 
@@ -103,7 +102,7 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 	/* M(=) typed: highlight the equivalent line */
 	if (cli_curfacet == NONODEPROTO)
 	{
-		ttyputmsg("No valid facet to associate");
+		ttyputmsg(_("No valid facet to associate"));
 		return(0);
 	}
 	line = (char *)askaid(us_aid, "edit-getline", (INTBIG)win, -1);
@@ -112,26 +111,26 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 	switch (type)
 	{
 		case LINECOMM:
-			ttyputmsg("No graphic equivalent of comment line");
+			ttyputmsg(_("No graphic equivalent of comment line"));
 			break;
 		case LINEBEGIN:
-			ttyputmsg("No graphic equivalent of BEGINFACET line");
+			ttyputmsg(_("No graphic equivalent of BEGINFACET line"));
 			break;
 		case LINEEND:
-			ttyputmsg("No graphic equivalent of ENDFACET line");
+			ttyputmsg(_("No graphic equivalent of ENDFACET line"));
 			break;
 		case LINEEXPORT:
-			ttyputmsg("No graphic equivalent of EXPORT line");
+			ttyputmsg(_("No graphic equivalent of EXPORT line"));
 			break;
 		case LINEUNKN:
-			ttyputmsg("No graphic equivalent of this line");
+			ttyputmsg(_("No graphic equivalent of this line"));
 			break;
 
 		case LINECONN:
 			ai = cli_findarcname(line);
 			if (ai == NOARCINST)
 			{
-				ttyputmsg("Cannot find equivalent arc for this line");
+				ttyputmsg(_("Cannot find equivalent arc for this line"));
 				return(0);
 			}
 			(void)askaid(us_aid, "clear");
@@ -142,7 +141,7 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 			comd = cli_parsecomp(line, 1);
 			if (comd == NOCOMPONENTDEC)
 			{
-				ttyputmsg("Cannot parse this declaration line");
+				ttyputmsg(_("Cannot parse this declaration line"));
 				return(0);
 			}
 			count = 0;
@@ -156,7 +155,7 @@ INTSML cli_charhandler(WINDOWPART *win, INTSML i)
 			}
 			if (count == 0)
 			{
-				ttyputmsg("Cannot find equivalent node(s) for this line");
+				ttyputmsg(_("Cannot find equivalent node(s) for this line"));
 				return(0);
 			}
 			break;
@@ -208,7 +207,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 	/* comment out an unknown line type */
 	if (ntype == LINEUNKN)
 	{
-		ttyputerr("Unrecognized line '%s' commented out", newline);
+		ttyputerr(_("Unrecognized line '%s' commented out"), newline);
 		if (otype == LINEUNKN || otype == LINECOMM) cli_commentline((INTSML)changed, win); else
 			cli_restoreline(oldline, (INTSML)changed, win);
 		return;
@@ -238,13 +237,13 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				{
 					if (namesame(oldname, newname) != 0)
 					{
-						ttyputmsg("Facet name changed from %s to %s", oldname, newname);
+						ttyputmsg(_("Facet name changed from %s to %s"), oldname, newname);
 						(void)reallocstring(&cli_curfacet->cell->cellname,
 							newname, cli_curfacet->cell->cluster);
 					}
 				} else if (newname == NOSTRING)
 				{
-					ttyputmsg("Erroneous BEGINFACET line");
+					ttyputmsg(_("Erroneous BEGINFACET line"));
 					cli_restoreline(oldline, (INTSML)changed, win);
 				}
 				if (oldname != NOSTRING) efree(oldname);
@@ -312,7 +311,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				/* must be the first line entered */
 				if (cli_textlines > 0)
 				{
-					ttyputmsg("Already a valid facet definition");
+					ttyputmsg(_("Already a valid facet definition"));
 					cli_commentline((INTSML)changed, win);
 					return;
 				}
@@ -321,7 +320,7 @@ void cli_changehandler(WINDOWPART *win, INTSML nature, char *oldline, char *newl
 				newname = cli_parsebeginfacet(newline, 0);
 				if (newname == NOSTRING)
 				{
-					ttyputmsg("Erroneous BEGINFACET line removed");
+					ttyputmsg(_("Erroneous BEGINFACET line removed"));
 					cli_commentline((INTSML)changed, win);
 					return;
 				}
@@ -402,7 +401,7 @@ void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *
 	oldpp = getportproto(cli_curfacet, olde->portname);
 	if (oldpp == NOPORTPROTO)
 	{
-		ttyputerr("Cannot parse old port name");
+		ttyputerr(_("Cannot parse old port name"));
 		cli_restoreline(oldline, changed, win);
 		cli_deleteexport(olde);   cli_deleteexport(newe);
 		return;
@@ -413,7 +412,7 @@ void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *
 	newni = cli_findnodename(newe->component);
 	if (oldni == NONODEINST || newni == NONODEINST)
 	{
-		ttyputerr("Cannot parse subnode name");
+		ttyputerr(_("Cannot parse subnode name"));
 		cli_restoreline(oldline, changed, win);
 		cli_deleteexport(olde);   cli_deleteexport(newe);
 		return;
@@ -424,7 +423,7 @@ void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *
 	newsubpp = cli_getexportsubport(newe, newni);
 	if (oldsubpp == NOPORTPROTO || newsubpp == NOPORTPROTO)
 	{
-		ttyputerr("Cannot parse subport name");
+		ttyputerr(_("Cannot parse subport name"));
 		cli_restoreline(oldline, changed, win);
 		cli_deleteexport(olde);   cli_deleteexport(newe);
 		return;
@@ -445,7 +444,7 @@ void cli_changeexport(char *oldline, char *newline, INTSML changed, WINDOWPART *
 	{
 		if (getportproto(cli_curfacet, newe->portname) != NOPORTPROTO)
 		{
-			ttyputerr("New port name not unique");
+			ttyputerr(_("New port name not unique"));
 			cli_restoreline(oldline, changed, win);
 			cli_deleteexport(olde);   cli_deleteexport(newe);
 			return;
@@ -501,7 +500,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 	newnp = getnodeproto(newcd->protoname);
 	if (newnp == NONODEPROTO)
 	{
-		ttyputerr("Unknown component: %s", newcd->protoname);
+		ttyputerr(_("Unknown component: %s"), newcd->protoname);
 		cli_restoreline(oldline, changed, win);
 		cli_deletecomponentdec(oldcd);   cli_deletecomponentdec(newcd);
 		return;
@@ -509,7 +508,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 	oldnp = getnodeproto(oldcd->protoname);
 	if (oldnp == NONODEPROTO)
 	{
-		ttyputerr("Unknown old component: %s", oldcd->protoname);
+		ttyputerr(_("Unknown old component: %s"), oldcd->protoname);
 		cli_restoreline(oldline, changed, win);
 		cli_deletecomponentdec(oldcd);   cli_deletecomponentdec(newcd);
 		return;
@@ -618,7 +617,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		ni = cli_findnodename(newcomp->name);
 		if (ni != NONODEINST)
 		{
-			ttyputerr("Already a component called '%s'", newcomp->name);
+			ttyputerr(_("Already a component called '%s'"), newcomp->name);
 			cli_restoreline(oldline, changed, win);
 			cli_deletecomponentdec(oldcd);   cli_deletecomponentdec(newcd);
 			return;
@@ -653,7 +652,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		{
 			cli_ownchanges = 1;
 			startobjectchange((INTBIG)ni, VNODEINST);
-			ni = replacenodeinst(ni, newnp);
+			ni = replacenodeinst(ni, newnp, 0);
 			endobjectchange((INTBIG)ni, VNODEINST);
 			cli_ownchanges = 0;
 			if (ni == NONODEINST)
@@ -663,7 +662,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 				 * worked and this one failed.  Then the replacement of the
 				 * original line will not be correct!!!
 				 */
-				ttyputerr("New component type cannot be replaced");
+				ttyputerr(_("New component type cannot be replaced"));
 				cli_deletecomponentdec(oldcd);   cli_deletecomponentdec(newcd);
 				cli_restoreline(oldline, changed, win);
 				return;
@@ -675,7 +674,7 @@ void cli_changedeclaration(char *oldline, char *newline, INTSML changed,
 		{
 			if (cli_findnodename(newcomp->name) != NONODEINST)
 			{
-				ttyputerr("Already a component called '%s'", newcomp->name);
+				ttyputerr(_("Already a component called '%s'"), newcomp->name);
 				cli_deletecomponentdec(oldcd);   cli_deletecomponentdec(newcd);
 				cli_restoreline(oldline, changed, win);
 				return;
@@ -725,7 +724,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	ARCPROTO *newap, *oldap;
 	NODEINST *oldend1, *oldend2, *newend1, *newend2;
 	PORTPROTO *oldport1, *oldport2, *newport1, *newport2;
-	REGISTER INTBIG newxoff, newyoff;
+	REGISTER INTBIG newxoff, newyoff, lambda;
 	REGISTER INTSML resolve, variable, varx, vary, offchanged;
 	INTBIG x1, y1, x2, y2, widnew, widold;
 	INTSML ret;
@@ -750,7 +749,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	ai = cli_findarcname(oldline);
 	if (ai == NOARCINST)
 	{
-		ttyputerr("Cannot figure out which wire changed");
+		ttyputerr(_("Cannot figure out which wire changed"));
 		cli_restoreline(oldline, changed, win);
 		cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 		return;
@@ -820,7 +819,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	{
 		if (cli_findnodename(newcon->end1) != NONODEINST)
 		{
-			ttyputerr("Already a component called '%s'", newcon->end1);
+			ttyputerr(_("Already a component called '%s'"), newcon->end1);
 			cli_restoreline(oldline, changed, win);
 			cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 			return;
@@ -841,7 +840,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 	{
 		if (cli_findnodename(newcon->end2) != NONODEINST)
 		{
-			ttyputerr("Already a component called '%s'", newcon->end2);
+			ttyputerr(_("Already a component called '%s'"), newcon->end2);
 			cli_restoreline(oldline, changed, win);
 			cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 			return;
@@ -870,7 +869,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		cli_ownchanges = 0;
 		if (newai == NOARCINST)
 		{
-			ttyputerr("Cannot create this new wire");
+			ttyputerr(_("Cannot create this new wire"));
 			cli_restoreline(oldline, changed, win);
 			cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 			return;
@@ -907,7 +906,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		cli_ownchanges = 0;
 		if (ai == NOARCINST)
 		{
-			ttyputerr("Cannot change the type of this wire");
+			ttyputerr(_("Cannot change the type of this wire"));
 			cli_restoreline(oldline, changed, win);
 			cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 			return;
@@ -928,7 +927,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 		cli_ownchanges = 0;
 		if (ret != 0)
 		{
-			ttyputerr("Cannot change the width of this wire");
+			ttyputerr(_("Cannot change the width of this wire"));
 			cli_restoreline(oldline, changed, win);
 			cli_deleteconnection(oldcon);   cli_deleteconnection(newcon);
 			return;
@@ -980,7 +979,8 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 			newxoff = -newxoff;
 			varx = CLLEFT;
 		}
-		newxoff = newxoff * WHOLE / ai->proto->tech->deflambda;
+		lambda = lambdaofarc(ai);
+		newxoff = newxoff * WHOLE / lambda;
 
 		/* compute the constraint in Y */
 		if (newyoff >= 0) vary = CLUP; else
@@ -988,7 +988,7 @@ void cli_changeconnection(char *oldline, char *newline, INTSML changed, WINDOWPA
 			newyoff = -newyoff;
 			vary = CLDOWN;
 		}
-		newyoff = newyoff * WHOLE / ai->proto->tech->deflambda;
+		newyoff = newyoff * WHOLE / lambda;
 
 		/* set the new constraints */
 		(void)cli_addarcconstraint(ai, varx, CLEQUALS, newxoff, 1);
@@ -1092,7 +1092,7 @@ void cli_deletedeclaration(char *oldline)
 	np = getnodeproto(dec->protoname);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Unknown component type: %s", dec->protoname);
+		ttyputerr(_("Unknown component type: %s"), dec->protoname);
 		cli_deletecomponentdec(dec);
 		return;
 	}
@@ -1142,7 +1142,7 @@ void cli_deleteexportline(char *oldline)
 	pp = getportproto(cli_curfacet, e->portname);
 	if (pp == NOPORTPROTO)
 	{
-		ttyputerr("Unknown port: %s", e->portname);
+		ttyputerr(_("Unknown port: %s"), e->portname);
 		cli_deleteexport(e);
 		return;
 	}
@@ -1182,7 +1182,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 	np = getnodeproto(dec->protoname);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Unknown component type: %s", dec->protoname);
+		ttyputerr(_("Unknown component type: %s"), dec->protoname);
 		cli_commentline(changed, win);
 		cli_deletecomponentdec(dec);
 		return(1);
@@ -1195,7 +1195,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 		ni = cli_findnodename(compo->name);
 		if (ni != NONODEINST)
 		{
-			ttyputerr("Already a component called '%s'", compo->name);
+			ttyputerr(_("Already a component called '%s'"), compo->name);
 			cli_commentline(changed, win);
 			cli_deletecomponentdec(dec);
 			return(1);
@@ -1206,7 +1206,7 @@ INTSML cli_adddeclaration(char *newline, INTSML changed, WINDOWPART *win)
 		{
 			if (namesame(compo->name, ocomp->name) == 0)
 			{
-				ttyputerr("Duplicate component name '%s'", compo->name);
+				ttyputerr(_("Duplicate component name '%s'"), compo->name);
 				cli_commentline(changed, win);
 				cli_deletecomponentdec(dec);
 				return(1);
@@ -1273,7 +1273,7 @@ INTSML cli_addwire(char *newline, INTSML changed, WINDOWPART *win)
 	cli_ownchanges = 0;
 	if (ai == NOARCINST)
 	{
-		ttyputerr("Cannot make the wire");
+		ttyputerr(_("Cannot make the wire"));
 		cli_commentline(changed, win);
 		cli_deleteconnection(dcl);
 		return(1);
@@ -1341,11 +1341,11 @@ void cli_addexport(char *newline, INTSML changed, WINDOWPART *win)
 		return;
 	}
 
-	/* make sure the exported port is unique */
+	/* make sure the export is unique */
 	pp = getportproto(cli_curfacet, e->portname);
 	if (pp != NOPORTPROTO)
 	{
-		ttyputerr("Already an exported port called %s", pp->protoname);
+		ttyputerr(_("Already an export called %s"), pp->protoname);
 		cli_commentline(changed, win);
 		cli_deleteexport(e);
 		return;
@@ -1355,7 +1355,7 @@ void cli_addexport(char *newline, INTSML changed, WINDOWPART *win)
 	ni = cli_findnodename(e->component);
 	if (ni == NONODEINST)
 	{
-		ttyputerr("Cannot find node %s", e->component);
+		ttyputerr(_("Cannot find node %s"), e->component);
 		cli_commentline(changed, win);
 		cli_deleteexport(e);
 		return;
@@ -1376,7 +1376,7 @@ void cli_addexport(char *newline, INTSML changed, WINDOWPART *win)
 	cli_ownchanges = 0;
 	if (newpp == NOPORTPROTO)
 	{
-		ttyputerr("Could not create the port");
+		ttyputerr(_("Could not create the port"));
 		cli_commentline(changed, win);
 		cli_deleteexport(e);
 		return;
@@ -1391,13 +1391,13 @@ PORTPROTO *cli_getexportsubport(EXPORT *e, NODEINST *ni)
 	{
 		pp = getportproto(ni->proto, e->subport);
 		if (pp == NOPORTPROTO)
-			ttyputerr("No such port %s on node %s", e->subport, e->component);
+			ttyputerr(_("No such port %s on node %s"), e->subport, e->component);
 	} else
 	{
 		pp = ni->proto->firstportproto;
 		if (cli_uniqueport(ni, pp) == 0)
 		{
-			ttyputerr("Ambiguous port on node %s", e->component);
+			ttyputerr(_("Ambiguous port on node %s"), e->component);
 			pp = NOPORTPROTO;
 		}
 	}
