@@ -85,9 +85,11 @@ CONSTRAINT  *el_curconstraint;		/* current constraint solver */
 
 char        *el_libdir;				/* pointer to library directory */
 
+INTBIG       el_filetypetext;		/* Plain text disk file descriptor */
+
 XARRAY       el_matid;				/* identity matrix */
 INTSML       el_pleasestop;			/* nonzero if abort is requested */
-INTSML       el_units;				/* display and internal units */
+INTBIG       el_units;				/* display and internal units */
 
 /******************************* GRAPHICS *******************************/
 
