@@ -498,7 +498,8 @@ INTSML db_addtortnode(UINTBIG object, RTNODE *rtn, NODEPROTO *facet)
 
 		/* sensibility check */
 		if (oldcount != rtn->total + newrtn->total)
-			ttyputerr("R-trees: %d nodes split to %d and %d!", oldcount, rtn->total, newrtn->total);
+			ttyputerr(_("R-trees: %d nodes split to %d and %d!"),
+				oldcount, rtn->total, newrtn->total);
 
 		/* now recursively insert this new element up the tree */
 		if (rtn->parent == NORTNODE)
@@ -570,11 +571,12 @@ void undogeom(GEOM *geom, NODEPROTO *parnt)
 	{
 		if (db_findgeomanywhere(parnt->rtree, geom, &whichrtn, &whichind) == 0)
 		{
-			ttyputerr("Internal warning: cannot find %s in R-Tree of %s", geomname(geom),
-				describenodeproto(parnt));
+			ttyputerr(_("Internal warning: cannot find %s in R-Tree of %s"),
+				geomname(geom), describenodeproto(parnt));
 			return;
 		}
-		ttyputmsg("Internal warning: %s not in proper R-Tree location", geomname(geom));
+		ttyputmsg(_("Internal warning: %s not in proper R-Tree location"),
+			geomname(geom));
 	}
 
 	/* delete geom from this R-tree node */
@@ -627,7 +629,7 @@ void db_removertnode(RTNODE *rtn, INTSML ind, NODEPROTO *facet)
 		/* node has too few entries, must delete it and reinsert members */
 		for(i=0; i<prtn->total; i++)
 			if (prtn->pointers[i] == (UINTBIG)rtn) break;
-		if (i >= prtn->total) ttyputerr("R-trees: cannot find entry in parent");
+		if (i >= prtn->total) ttyputerr(_("R-trees: cannot find entry in parent"));
 
 		/* remove this entry from its parent */
 		db_removertnode(prtn, i, facet);
@@ -759,15 +761,15 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTSML indent)
 
 	(void)initinfstr();
 	for(i=0; i<indent; i++) (void)addtoinfstr(' ');
-	(void)sprintf(line, "Node X(%s-%s) Y(%s-%s) has %d children:",
+	(void)sprintf(line, _("Node X(%s-%s) Y(%s-%s) has %d children:"),
 		latoa(rtn->lowx), latoa(rtn->highx), latoa(rtn->lowy), latoa(rtn->highy), rtn->total);
 	(void)addstringtoinfstr(line);
 
 	/* sensibility check of this R-tree node */
-	if (rtn->parent != expectedparent) (void)addstringtoinfstr(" WRONG-PARENT");
-	if (rtn->total > db_maxrtnodesize) (void)addstringtoinfstr(" TOO-MANY");
+	if (rtn->parent != expectedparent) (void)addstringtoinfstr(_(" WRONG-PARENT"));
+	if (rtn->total > db_maxrtnodesize) (void)addstringtoinfstr(_(" TOO-MANY"));
 	if (rtn->total < db_minrtnodesize && rtn->parent != NORTNODE)
-		(void)addstringtoinfstr(" TOO-FEW");
+		(void)addstringtoinfstr(_(" TOO-FEW"));
 	if (rtn->total != 0)
 	{
 		db_rtnbbox(rtn, 0, &lowestxv, &highestxv, &lowestyv, &highestyv);
@@ -781,7 +783,7 @@ void db_printrtree(RTNODE *expectedparent, RTNODE *rtn, INTSML indent)
 		}
 		if (rtn->lowx != lowestxv || rtn->highx != highestxv ||
 			rtn->lowy != lowestyv || rtn->highy != highestyv)
-				(void)addstringtoinfstr(" WRONG-BOUNDS");
+				(void)addstringtoinfstr(_(" WRONG-BOUNDS"));
 		rtn->lowx = lowestxv;
 		rtn->highx = highestxv;
 		rtn->lowy = lowestyv;
@@ -1033,10 +1035,10 @@ void boundobj(GEOM *geom, INTBIG *lx, INTBIG *hx, INTBIG *ly, INTBIG *hy)
 				if (var != NOVARIABLE)
 				{
 					makerot(ni, trans);
-					num = nodepolys(ni);
+					num = nodepolys(ni, 0);
 					for(j=0; j<num; j++)
 					{
-						shapenodepoly(ni, (INTSML)j, poly);
+						shapenodepoly(ni, j, poly);
 						xformpoly(poly, trans);
 						getbbox(poly, &plx, &phx, &ply, &phy);
 						if (j == 0)
@@ -1206,7 +1208,7 @@ GEOM *nextobject(INTBIG rsin)
 			/* look down the hierarchy */
 			if (rs->depth >= MAXDEPTH-1)
 			{
-				ttyputerr("R-trees: search too deep");
+				ttyputerr(_("R-trees: search too deep"));
 				continue;
 			}
 			rs->depth++;
