@@ -89,7 +89,7 @@ INTSML loadcode(char *program, INTBIG language)
 
 #if LANGJAVA
 		case VJAVA:
-			ttyputerr("Unable to load code into Java");
+			ttyputerr(_("Unable to load code into Java"));
 			break;
 #endif
 	}
@@ -321,30 +321,30 @@ INTSML languageconverse(INTBIG language)
 		{
 			case VLISP:
 #if LANGLISP
-				ttyputmsg("ELK Lisp 3.0, type %s to quit", getmessageseofkey());
+				ttyputmsg(_("ELK Lisp 3.0, type %s to quit"), getmessageseofkey());
 				lsp_init();
 #else
-				ttyputerr("LISP Interpreter is not installed");
+				ttyputerr(_("LISP Interpreter is not installed"));
 				return(1);
 #endif
 				break;
 
 			case VTCL:
 #if LANGTCL
-				ttyputmsg("TCL Interpreter, type %s to quit", getmessageseofkey());
+				ttyputmsg(_("TCL Interpreter, type %s to quit"), getmessageseofkey());
 				Tcl_DStringInit(&command);
 #else
-				ttyputerr("TCL Interpreter is not installed");
+				ttyputerr(_("TCL Interpreter is not installed"));
 				return(1);
 #endif
 				break;
 
 			case VJAVA:
 #if LANGJAVA
-				ttyputmsg("JAVA Interpreter, type %s to quit", getmessageseofkey());
+				ttyputmsg(_("JAVA Interpreter, type %s to quit"), getmessageseofkey());
 				java_init();
 #else
-				ttyputerr("JAVA Interpreter is not installed");
+				ttyputerr(_("JAVA Interpreter is not installed"));
 				return(1);
 #endif
 				break;
@@ -352,7 +352,7 @@ INTSML languageconverse(INTBIG language)
 #if LANGMM
 			case VMATHEMATICA:
 				if (db_mathematicainit() != 0) return(1);
-				ttyputmsg("Mathematica reader, type %s to quit", getmessageseofkey());
+				ttyputmsg(_("Mathematica reader, type %s to quit"), getmessageseofkey());
 				break;
 #endif
 		}
@@ -435,7 +435,7 @@ INTSML languageconverse(INTBIG language)
 
 			if (MLError(db_mathematicalink) != MLEOK)
 			{
-				ttyputerr("Mathematica error: %s", MLErrorMessage(db_mathematicalink));
+				ttyputerr(_("Mathematica error: %s"), MLErrorMessage(db_mathematicalink));
 				return(1);
 			}
 
