@@ -44,13 +44,7 @@ JDK1_1InitArgs  java_vmargs;					/* JDK 1.1 VM initialization arguments */
 jclass          java_electricclass;
 jclass          java_electriceoutclass;
 jfieldID        java_addressID;
-jfieldID        java_polygonXVID;
-jfieldID        java_polygonYVID;
-jfieldID        java_polygonCountID;
-jfieldID        java_polygonStyleID;
-jfieldID        java_polygonTechID;
-jfieldID        java_polygonLayerID;
-jfieldID        java_polygonPortID;
+jfieldID        java_xarrayVID;
 jobject         java_nullobject;
 char           *java_arraybuffer;
 INTBIG          java_arraybuffersize = 0;
@@ -85,6 +79,7 @@ jclass          java_classwindowframe;
 jclass          java_classgraphics;
 jclass          java_classconstraint;
 jclass          java_classpolygon;
+jclass          java_classxarray;
 
 extern "C"
 {
@@ -128,6 +123,8 @@ extern "C"
 		jobject object, jstring qual);
 	JNIEXPORT jobject JNICALL Java_Electric_getValConstraint(JNIEnv *env, jobject obj,
 		jobject object, jstring qual);
+	JNIEXPORT jobject JNICALL Java_Electric_getValPolygon(JNIEnv *env, jobject obj,
+		jobject object, jstring qual);
 	JNIEXPORT void JNICALL Java_Electric_setVal(JNIEnv *env, jobject obj,
 		jobject jobj, jstring jqual, jobject jattr, jint jbits);
 	JNIEXPORT void JNICALL Java_Electric_setInd(JNIEnv *env, jobject obj,
@@ -138,6 +135,8 @@ extern "C"
 		jint lx, jint hx, jint ly, jint hy, jobject facet);
 	JNIEXPORT jobject JNICALL Java_Electric_nextObject(JNIEnv *env, jobject obj,
 		jint sea);
+	JNIEXPORT void JNICALL Java_Electric_termSearch(JNIEnv *env, jobject obj,
+		jint sea);
 	JNIEXPORT jobject JNICALL Java_Electric_getAid(JNIEnv *env, jobject obj,
 		jstring name);
 	JNIEXPORT jint JNICALL Java_Electric_maxAid(JNIEnv *env, jobject obj);
@@ -185,6 +184,14 @@ extern "C"
 		jobject node);
 	JNIEXPORT jobject JNICALL Java_Electric_shapeNodePoly(JNIEnv *env, jobject obj,
 		jobject node, jint jindex);
+	JNIEXPORT jint JNICALL Java_Electric_nodeEPolys(JNIEnv *env, jobject obj,
+		jobject node);
+	JNIEXPORT jobject JNICALL Java_Electric_shapeENodePoly(JNIEnv *env, jobject obj,
+		jobject node, jint jindex);
+	JNIEXPORT jobject JNICALL Java_Electric_makeRot(JNIEnv *env, jobject obj,
+		jobject node);
+	JNIEXPORT jobject JNICALL Java_Electric_makeTrans(JNIEnv *env, jobject obj,
+		jobject node);
 	JNIEXPORT jobject JNICALL Java_Electric_newArcInst(JNIEnv *env, jobject obj,
 		jobject proto, jint wid, jint bits, jobject node1, jobject port1, jint x1, jint y1,
 		jobject node2, jobject port2, jint x2, jint y2, jobject facet);
@@ -216,8 +223,6 @@ extern "C"
 		jstring name, jstring sname);
 	JNIEXPORT jint JNICALL Java_Electric_killView(JNIEnv *env, jobject obj,
 		jobject view);
-	JNIEXPORT void JNICALL Java_Electric_changeLambda(JNIEnv *env, jobject obj,
-		jint oldlambda, jint newlambda, jobject tech);
 	JNIEXPORT jobject JNICALL Java_Electric_getArcProto(JNIEnv *env, jobject obj,
 		jstring name);
 	JNIEXPORT jobject JNICALL Java_Electric_getCell(JNIEnv *env, jobject obj,
@@ -232,6 +237,18 @@ extern "C"
 		jobject jtech, jint jlayer);
 	JNIEXPORT jint JNICALL Java_Electric_layerFunction(JNIEnv *env, jobject obj,
 		jobject jtech, jint jlayer);
+	JNIEXPORT jint JNICALL Java_Electric_maxDRCSurround(JNIEnv *env, jobject obj,
+		jobject jtech, jobject jlib, jint jlayer);
+	JNIEXPORT jint JNICALL Java_Electric_DRCMinDistance(JNIEnv *env, jobject obj,
+		jobject jtech, jobject jlib, jint jlayer1, jint jlayer2, jint jconnected);
+	JNIEXPORT jint JNICALL Java_Electric_DRCMinWidth(JNIEnv *env, jobject obj,
+		jobject jtech, jobject jlib, jint jlayer);
+	JNIEXPORT void JNICALL Java_Electric_xformPoly(JNIEnv *env, jobject obj,
+		jobject jpoly, jobject jtrans);
+	JNIEXPORT void JNICALL Java_Electric_freePolygon(JNIEnv *env, jobject obj,
+		jobject jpoly);
+	JNIEXPORT jobject JNICALL Java_Electric_getTraversalPath(JNIEnv *env, jobject obj);
+
 	JNIEXPORT void JNICALL Java_Electric_eoutWriteOne(JNIEnv *env, jobject obj,
 		jint byte);
 	JNIEXPORT void JNICALL Java_Electric_eoutWriteString(JNIEnv *env, jobject obj,
@@ -304,6 +321,9 @@ static JNINativeMethod electricmethods[] =
 	{"getVal",
 		"(LCOM/staticfreesoft/electric$constraint;Ljava/lang/String;)Ljava/lang/Object;",
 		(void *)Java_Electric_getValConstraint},
+	{"getVal",
+		"(LCOM/staticfreesoft/electric$polygon;Ljava/lang/String;)Ljava/lang/Object;",
+		(void *)Java_Electric_getValPolygon},
 	{"setVal",
 		"(Ljava/lang/Object;Ljava/lang/String;Ljava/lang/Object;I)V",
 		(void *)Java_Electric_setVal},
@@ -319,6 +339,9 @@ static JNINativeMethod electricmethods[] =
 	{"nextObject",
 		"(I)Ljava/lang/Object;",
 		(void *)Java_Electric_nextObject},
+	{"termSearch",
+		"(I)V",
+		(void *)Java_Electric_termSearch},
 
 	/***************** AID ROUTINES *****************/
 	{"getAid",
@@ -397,8 +420,20 @@ static JNINativeMethod electricmethods[] =
 		"(LCOM/staticfreesoft/electric$nodeinst;)I",
 		(void *)Java_Electric_nodePolys},
 	{"shapeNodePoly",
-		"(LCOM/staticfreesoft/electric$nodeinst;I)LCOM/staticfreesoft/electric$epolygon;",
+		"(LCOM/staticfreesoft/electric$nodeinst;I)LCOM/staticfreesoft/electric$polygon;",
 		(void *)Java_Electric_shapeNodePoly},
+	{"nodeEPolys",
+		"(LCOM/staticfreesoft/electric$nodeinst;)I",
+		(void *)Java_Electric_nodeEPolys},
+	{"shapeENodePoly",
+		"(LCOM/staticfreesoft/electric$nodeinst;I)LCOM/staticfreesoft/electric$polygon;",
+		(void *)Java_Electric_shapeENodePoly},
+	{"makeRot",
+		"(LCOM/staticfreesoft/electric$nodeinst;)LCOM/staticfreesoft/electric$xarray;",
+		(void *)Java_Electric_makeRot},
+	{"makeTrans",
+		"(LCOM/staticfreesoft/electric$nodeinst;)LCOM/staticfreesoft/electric$xarray;",
+		(void *)Java_Electric_makeTrans},
 
 	/***************** ARCINST ROUTINES *****************/
 	{"newArcInst",
@@ -417,7 +452,7 @@ static JNINativeMethod electricmethods[] =
 		"(LCOM/staticfreesoft/electric$arcinst;)I",
 		(void *)Java_Electric_arcPolys},
 	{"shapeArcPoly",
-		"(LCOM/staticfreesoft/electric$arcinst;I)LCOM/staticfreesoft/electric$epolygon;",
+		"(LCOM/staticfreesoft/electric$arcinst;I)LCOM/staticfreesoft/electric$polygon;",
 		(void *)Java_Electric_shapeArcPoly},
 
 	/***************** PORTPROTO ROUTINES *****************/
@@ -457,9 +492,6 @@ static JNINativeMethod electricmethods[] =
 		(void *)Java_Electric_killView},
 
 	/***************** MISCELLANEOUS ROUTINES *****************/
-	{"changeLambda",
-		"(IILCOM/staticfreesoft/electric$technology;)V",
-		(void *)Java_Electric_changeLambda},
 	{"getArcProto",
 		"(Ljava/lang/String;)LCOM/staticfreesoft/electric$arcproto;",
 		(void *)Java_Electric_getArcProto},
@@ -480,7 +512,25 @@ static JNINativeMethod electricmethods[] =
 		(void *)Java_Electric_layerName},
 	{"layerFunction",
 		"(LCOM/staticfreesoft/electric$technology;I)I",
-		(void *)Java_Electric_layerFunction}
+		(void *)Java_Electric_layerFunction},
+	{"maxDRCSurround",
+		"(LCOM/staticfreesoft/electric$technology;LCOM/staticfreesoft/electric$library;I)I",
+		(void *)Java_Electric_maxDRCSurround},
+	{"DRCMinDistance",
+		"(LCOM/staticfreesoft/electric$technology;LCOM/staticfreesoft/electric$library;III)I",
+		(void *)Java_Electric_DRCMinDistance},
+	{"DRCMinWidth",
+		"(LCOM/staticfreesoft/electric$technology;LCOM/staticfreesoft/electric$library;I)I",
+		(void *)Java_Electric_DRCMinWidth},
+	{"xformPoly",
+		"(LCOM/staticfreesoft/electric$polygon;LCOM/staticfreesoft/electric$xarray;)V",
+		(void *)Java_Electric_xformPoly},
+	{"freePolygon",
+		"(LCOM/staticfreesoft/electric$polygon;)V",
+		(void *)Java_Electric_freePolygon},
+	{"getTraversalPath",
+		"()[LCOM/staticfreesoft/electric$nodeinst;",
+		(void *)Java_Electric_getTraversalPath}
 };
 
 static JNINativeMethod electriceoutmethods[] =
@@ -518,7 +568,8 @@ void java_freememory(void)
 
 void java_init(void)
 {
-	char *userclasspath, pathsep;
+	char *userclasspath, *usersettings, pathsep, *properties[10];
+	INTBIG ac;
 
 	if (java_inited != 0) return;
 	java_inited = 1;
@@ -527,7 +578,7 @@ void java_init(void)
 	java_vmargs.version = 0x00010001;
 	if (JNI_GetDefaultJavaVMInitArgs(&java_vmargs) != 0)
 	{
-		ttyputerr("Cannot initialize Java VM");
+		ttyputerr(_("Cannot initialize Java VM"));
 		return;
 	}
 
@@ -541,17 +592,37 @@ void java_init(void)
 	(void)addstringtoinfstr(java_vmargs.classpath);
 	(void)addtoinfstr(pathsep);
 	(void)addtoinfstr('.');
-	(void)addtoinfstr(pathsep);
-	(void)addstringtoinfstr(el_libdir);
-	(void)addstringtoinfstr("java");
 	userclasspath = egetenv("CLASSPATH");
 	if (userclasspath != 0)
 	{
 		(void)addtoinfstr(pathsep);
 		(void)addstringtoinfstr(userclasspath);
 	}
+	(void)addtoinfstr(pathsep);
+	(void)addstringtoinfstr(el_libdir);
+	(void)addstringtoinfstr("java");
 	(void)allocstring(&java_vmargs.classpath, returninfstr(), db_cluster);
 
+	/* set java properties */
+	ac = 0;
+	properties[ac++] = "java.compiler=NONE";
+
+	/* special case for PAR router */
+	usersettings = egetenv("ELECTRIC_PARDIR");
+	if (usersettings != 0)
+	{
+		properties[ac++] = usersettings;
+	} else
+	{
+		(void)initinfstr();
+		(void)addstringtoinfstr("config.dir=");
+		(void)addstringtoinfstr(el_libdir);
+		(void)addstringtoinfstr("prouter");
+		properties[ac++] = returninfstr();
+	}
+	properties[ac] = 0;
+	java_vmargs.properties = properties;
+
 	/* set overrides */
 	java_vmargs.vfprintf = java_vfprintf;
 	java_vmargs.exit = java_exit;
@@ -559,7 +630,7 @@ void java_init(void)
 	/* load and initialize a Java VM, return a JNI interface pointer in env */
 	if (JNI_CreateJavaVM(&java_virtualmachine, (void **)&java_environment, &java_vmargs) != 0)
 	{
-		ttyputerr("Cannot create Java VM");
+		ttyputerr(_("Cannot create Java VM"));
 		return;
 	}
 
@@ -568,13 +639,13 @@ void java_init(void)
 	if (java_electricclass == 0) return;
 	if (java_environment->RegisterNatives(java_electricclass, electricmethods,
 		sizeof(electricmethods)/sizeof(JNINativeMethod)) < 0)
-			ttyputerr("Failed to register native interfaces");
+			ttyputerr(_("Failed to register native interfaces"));
 
 	/* override the "write" method of out "eout" class */
 	java_electriceoutclass = java_environment->FindClass("COM/staticfreesoft/electric$eout");
 	if (java_electriceoutclass == 0) return;
 	if (java_environment->RegisterNatives(java_electriceoutclass, electriceoutmethods, 2) < 0)
-		ttyputerr("Failed to register output interface");
+		ttyputerr(_("Failed to register output interface"));
 	jobject object = java_environment->AllocObject(java_electriceoutclass);
 	jmethodID mid = java_environment->GetMethodID(java_electriceoutclass, "takeover", "()V");
 	java_environment->CallVoidMethod(object, mid);
@@ -642,17 +713,13 @@ void java_init(void)
 	if (java_classgraphics == 0) return;
 	java_classconstraint = java_environment->FindClass("COM/staticfreesoft/electric$constraint");
 	if (java_classconstraint == 0) return;
-	java_classpolygon = java_environment->FindClass("COM/staticfreesoft/electric$epolygon");
+	java_classpolygon = java_environment->FindClass("COM/staticfreesoft/electric$polygon");
 	if (java_classpolygon == 0) return;
+	java_classxarray = java_environment->FindClass("COM/staticfreesoft/electric$xarray");
+	if (java_classxarray == 0) return;
 
-	/* get the attribute pointer to the fields on the Polygon class */
-	java_polygonXVID = java_environment->GetFieldID(java_classpolygon, "xv", "[I");
-	java_polygonYVID = java_environment->GetFieldID(java_classpolygon, "yv", "[I");
-	java_polygonCountID = java_environment->GetFieldID(java_classpolygon, "count", "I");
-	java_polygonStyleID = java_environment->GetFieldID(java_classpolygon, "style", "I");
-	java_polygonTechID = java_environment->GetFieldID(java_classpolygon, "tech", "LCOM/staticfreesoft/electric$technology;");
-	java_polygonLayerID = java_environment->GetFieldID(java_classpolygon, "layer", "I");
-	java_polygonPortID = java_environment->GetFieldID(java_classpolygon, "port", "LCOM/staticfreesoft/electric$portproto;");
+	/* get the attribute pointer to the fields on the XARRAY class */
+	java_xarrayVID = java_environment->GetFieldID(java_classxarray, "v", "[I");
 }
 
 void java_evaluate(char *str)
@@ -726,7 +793,7 @@ char *java_query(char *str, INTBIG *methodreturntype)
 		if (className[i] == '.') break;
 	if (i == 0)
 	{
-		ttyputerr("Cannot determine class and method of '%s'", str);
+		ttyputerr(_("Cannot determine class and method of '%s'"), str);
 		return(0);
 	}
 	methodName = &className[i+1];
@@ -737,7 +804,7 @@ char *java_query(char *str, INTBIG *methodreturntype)
 	theClass = java_environment->FindClass(className);
 	if (theClass == 0)
 	{
-		ttyputerr("Cannot find class '%s'", className);
+		ttyputerr(_("Cannot find class '%s'"), className);
 		className[i] = '.';
 		return(0);
 	}
@@ -837,7 +904,7 @@ char *java_query(char *str, INTBIG *methodreturntype)
 			*methodreturntype = METHODRETURNSDOUBLE;
 		} else
 		{
-			ttyputerr("%s returns unrecognized type '%s'", str, returnClassName);
+			ttyputerr(_("%s returns unrecognized type '%s'"), str, returnClassName);
 			return(0);
 		}
 		*sigpt = 0;
@@ -847,7 +914,7 @@ char *java_query(char *str, INTBIG *methodreturntype)
 		mid = java_environment->GetStaticMethodID(theClass, methodName, sig);
 		if (mid == 0)
 		{
-			ttyputerr("Error getting method pointer to %s (signature '%s')", str, sig);
+			ttyputerr(_("Error getting method pointer to %s (signature '%s')"), str, sig);
 			return(0);
 		}
 
@@ -865,7 +932,7 @@ char *java_query(char *str, INTBIG *methodreturntype)
 			case METHODRETURNSBOOLEAN:
 				bvalue = java_environment->CallStaticBooleanMethod(theClass, mid);
 				if (java_reportexceptions() != 0) return(0);
-				sprintf(resultString, "%s", bvalue ? "True" : "False");
+				sprintf(resultString, "%s", bvalue ? _("True") : _("False"));
 				return(resultString);
 			case METHODRETURNSBYTE:
 				i = java_environment->CallStaticByteMethod(theClass, mid);
@@ -904,7 +971,7 @@ char *java_query(char *str, INTBIG *methodreturntype)
 				return(resultString);
 		}
 	}
-	ttyputerr("Cannot find static method '%s' that takes no parameters", str);
+	ttyputerr(_("Cannot find static method '%s' that takes no parameters"), str);
 	return(0);
 }
 
@@ -1050,6 +1117,12 @@ JNIEXPORT jobject JNICALL Java_Electric_getValConstraint(JNIEnv *env, jobject ob
 	return(java_getval(jobj, VCONSTRAINT, jname));
 }
 
+JNIEXPORT jobject JNICALL Java_Electric_getValPolygon(JNIEnv *env, jobject obj,
+	jobject jobj, jstring jname)
+{
+	return(java_getval(jobj, VPOLYGON, jname));
+}
+
 jobject java_getval(jobject jobj, INTBIG type, jstring jname)
 {
 	const char *name;
@@ -1170,6 +1243,19 @@ JNIEXPORT jobject JNICALL Java_Electric_nextObject(JNIEnv *env, jobject obj,
 	return(jgeom);
 }
 
+JNIEXPORT void JNICALL Java_Electric_termSearch(JNIEnv *env, jobject obj,
+	jint jsea)
+{
+	INTBIG sea;
+
+	/* convert Java parameters to C */
+	if (jsea == 0) return;
+	sea = jsea;
+
+	/* make the Electric call */
+	termsearch(sea);
+}
+
 /****************************** ELECTRIC AID ROUTINES ******************************/
 
 JNIEXPORT jobject JNICALL Java_Electric_getAid(JNIEnv *env, jobject obj,
@@ -1577,7 +1663,7 @@ JNIEXPORT jobject JNICALL Java_Electric_replaceNodeInst(JNIEnv *env, jobject obj
 
 	/* make the Electric call */
 	startobjectchange((INTBIG)ni, VNODEINST);
-	newni = replacenodeinst(ni, proto);
+	newni = replacenodeinst(ni, proto, 0);
 	if (newni != NONODEINST) endobjectchange((INTBIG)newni, VNODEINST);
 
 	/* convert C result to Java */
@@ -1609,7 +1695,7 @@ JNIEXPORT jint JNICALL Java_Electric_nodePolys(JNIEnv *env, jobject obj,
 	jobject jni)
 {
 	NODEINST *ni;
-	INTSML count;
+	INTBIG count;
 	jint jcount;
 
 	/* convert Java parameters to C */
@@ -1617,7 +1703,7 @@ JNIEXPORT jint JNICALL Java_Electric_nodePolys(JNIEnv *env, jobject obj,
 	ni = (NODEINST *)java_environment->GetIntField(jni, java_addressID);
 
 	/* make the Electric call */
-	count = nodepolys(ni);
+	count = nodepolys(ni, 0);
 
 	/* convert C result to Java */
 	jcount = count;
@@ -1629,12 +1715,8 @@ JNIEXPORT jobject JNICALL Java_Electric_shapeNodePoly(JNIEnv *env, jobject obj,
 {
 	NODEINST *ni;
 	INTSML index;
-	jobject object;
-	jintArray xArray, yArray;
-	static POLYGON *poly = NOPOLYGON;
-
-	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
+	jobject jpoly;
+	POLYGON *poly;
 
 	/* convert Java parameters to C */
 	if (jni == 0) return(java_nullobject);
@@ -1642,23 +1724,98 @@ JNIEXPORT jobject JNICALL Java_Electric_shapeNodePoly(JNIEnv *env, jobject obj,
 	index = (INTSML)jindex;
 
 	/* make the Electric call */
+	poly = allocpolygon(4, db_cluster);
 	shapenodepoly(ni, index, poly);
 
 	/* convert C result to Java */
-	object = java_environment->AllocObject(java_classpolygon);
-	xArray = java_environment->NewIntArray(poly->count);
-	yArray = java_environment->NewIntArray(poly->count);
-	java_environment->SetIntArrayRegion(xArray, 0, poly->count, poly->xv);
-	java_environment->SetIntArrayRegion(yArray, 0, poly->count, poly->yv);
-	java_environment->SetObjectField(object, java_polygonXVID, (jobject)xArray);
-	java_environment->SetObjectField(object, java_polygonYVID, (jobject)yArray);
-	java_environment->SetIntField(object, java_polygonCountID, poly->count);
-	java_environment->SetIntField(object, java_polygonStyleID, poly->style);
-	java_environment->SetObjectField(object, java_polygonTechID,
-		java_makeobject((INTBIG)poly->tech, VTECHNOLOGY));
-	java_environment->SetIntField(object, java_polygonLayerID, poly->layer);
-	java_environment->SetObjectField(object, java_polygonPortID,
-		java_makeobject((INTBIG)poly->portproto, VPORTPROTO));
+	jpoly = java_makeobject((INTBIG)poly, VPOLYGON);
+	return(jpoly);
+}
+
+JNIEXPORT jint JNICALL Java_Electric_nodeEPolys(JNIEnv *env, jobject obj,
+	jobject jni)
+{
+	NODEINST *ni;
+	INTBIG count;
+	jint jcount;
+
+	/* convert Java parameters to C */
+	if (jni == 0) return(0);
+	ni = (NODEINST *)java_environment->GetIntField(jni, java_addressID);
+
+	/* make the Electric call */
+	count = nodeEpolys(ni, 0);
+
+	/* convert C result to Java */
+	jcount = count;
+	return(jcount);
+}
+
+JNIEXPORT jobject JNICALL Java_Electric_shapeENodePoly(JNIEnv *env, jobject obj,
+	jobject jni, jint jindex)
+{
+	NODEINST *ni;
+	INTSML index;
+	jobject jpoly;
+	POLYGON *poly;
+
+	/* convert Java parameters to C */
+	if (jni == 0) return(java_nullobject);
+	ni = (NODEINST *)java_environment->GetIntField(jni, java_addressID);
+	index = (INTSML)jindex;
+
+	/* make the Electric call */
+	poly = allocpolygon(4, db_cluster);
+	shapeEnodepoly(ni, index, poly);
+
+	/* convert C result to Java */
+	jpoly = java_makeobject((INTBIG)poly, VPOLYGON);
+	return(jpoly);
+}
+
+JNIEXPORT jobject JNICALL Java_Electric_makeRot(JNIEnv *env, jobject obj,
+	jobject jni)
+{
+	NODEINST *ni;
+	XARRAY trans;
+	jobject object;
+	jintArray vArray;
+
+	/* convert Java parameters to C */
+	if (jni == 0) return(java_nullobject);
+	ni = (NODEINST *)java_environment->GetIntField(jni, java_addressID);
+
+	/* make the Electric call */
+	makerot(ni, trans);
+
+	/* convert C result to Java */
+	object = java_environment->AllocObject(java_classxarray);
+	vArray = java_environment->NewIntArray(9);
+	java_environment->SetIntArrayRegion(vArray, 0, 9, &trans[0][0]);
+	java_environment->SetObjectField(object, java_xarrayVID, (jobject)vArray);
+	return(object);
+}
+
+JNIEXPORT jobject JNICALL Java_Electric_makeTrans(JNIEnv *env, jobject obj,
+	jobject jni)
+{
+	NODEINST *ni;
+	XARRAY trans;
+	jobject object;
+	jintArray vArray;
+
+	/* convert Java parameters to C */
+	if (jni == 0) return(java_nullobject);
+	ni = (NODEINST *)java_environment->GetIntField(jni, java_addressID);
+
+	/* make the Electric call */
+	maketrans(ni, trans);
+
+	/* convert C result to Java */
+	object = java_environment->AllocObject(java_classxarray);
+	vArray = java_environment->NewIntArray(9);
+	java_environment->SetIntArrayRegion(vArray, 0, 9, &trans[0][0]);
+	java_environment->SetObjectField(object, java_xarrayVID, (jobject)vArray);
 	return(object);
 }
 
@@ -1772,7 +1929,7 @@ JNIEXPORT jint JNICALL Java_Electric_arcPolys(JNIEnv *env, jobject obj,
 	jobject jai)
 {
 	ARCINST *ai;
-	INTSML count;
+	INTBIG count;
 	jint jcount;
 
 	/* convert Java parameters to C */
@@ -1792,12 +1949,8 @@ JNIEXPORT jobject JNICALL Java_Electric_shapeArcPoly(JNIEnv *env, jobject obj,
 {
 	ARCINST *ai;
 	INTSML index;
-	jobject object;
-	jintArray xArray, yArray;
-	static POLYGON *poly = NOPOLYGON;
-
-	/* get polygon */
-	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, db_cluster);
+	jobject jpoly;
+	POLYGON *poly;
 
 	/* convert Java parameters to C */
 	if (jai == 0) return(java_nullobject);
@@ -1805,22 +1958,13 @@ JNIEXPORT jobject JNICALL Java_Electric_shapeArcPoly(JNIEnv *env, jobject obj,
 	index = (INTSML)jindex;
 
 	/* make the Electric call */
+	poly = allocpolygon(4, db_cluster);
 	shapearcpoly(ai, index, poly);
 
 	/* convert C result to Java */
-	object = java_environment->AllocObject(java_classpolygon);
-	xArray = java_environment->NewIntArray(poly->count);
-	yArray = java_environment->NewIntArray(poly->count);
-	java_environment->SetIntArrayRegion(xArray, 0, poly->count, poly->xv);
-	java_environment->SetIntArrayRegion(yArray, 0, poly->count, poly->yv);
-	java_environment->SetObjectField(object, java_polygonXVID, (jobject)xArray);
-	java_environment->SetObjectField(object, java_polygonYVID, (jobject)yArray);
-	java_environment->SetIntField(object, java_polygonCountID, poly->count);
-	java_environment->SetIntField(object, java_polygonStyleID, poly->style);
-	java_environment->SetObjectField(object, java_polygonTechID,
-		java_makeobject((INTBIG)poly->tech, VTECHNOLOGY));
-	java_environment->SetIntField(object, java_polygonLayerID, poly->layer);
-	return(object);
+	jpoly = java_makeobject((INTBIG)poly, VPOLYGON);
+	return(jpoly);
+
 }
 
 /****************************** ELECTRIC PORTPROTO ROUTINES ******************************/
@@ -2036,22 +2180,6 @@ JNIEXPORT jint JNICALL Java_Electric_killView(JNIEnv *env, jobject obj,
 
 /****************************** ELECTRIC MISCELLANEOUS ROUTINES ******************************/
 
-JNIEXPORT void JNICALL Java_Electric_changeLambda(JNIEnv *env, jobject obj,
-	jint joldlam, jint jlam, jobject jtech)
-{
-	TECHNOLOGY *tech;
-	INTBIG oldlam, lam;
-
-	/* convert Java parameters to C */
-	if (jtech == 0) return;
-	oldlam = joldlam;
-	lam = jlam;
-	tech = (TECHNOLOGY *)java_environment->GetIntField(jtech, java_addressID);
-
-	/* make the Electric call */
-	changelambda(oldlam, lam, tech);
-}
-
 JNIEXPORT jobject JNICALL Java_Electric_getArcProto(JNIEnv *env, jobject obj,
 	jstring jname)
 {
@@ -2196,6 +2324,128 @@ JNIEXPORT jint JNICALL Java_Electric_layerFunction(JNIEnv *env, jobject obj,
 	return(jfun);
 }
 
+JNIEXPORT jint JNICALL Java_Electric_maxDRCSurround(JNIEnv *env, jobject obj,
+	jobject jtech, jobject jlib, jint jlayer)
+{
+	TECHNOLOGY *tech;
+	LIBRARY *lib;
+	INTSML layer;
+	INTBIG dist;
+	jint jdist;
+
+	/* convert Java parameters to C */
+	if (jtech == 0 || jlib == 0) return(0);
+	tech = (TECHNOLOGY *)java_environment->GetIntField(jtech, java_addressID);
+	lib = (LIBRARY *)java_environment->GetIntField(jlib, java_addressID);
+	layer = (INTSML)jlayer;
+
+	/* make the Electric call */
+	dist = maxdrcsurround(tech, lib, layer);
+
+	/* convert C result to Java */
+	jdist = dist;
+	return(jdist);
+}
+
+JNIEXPORT jint JNICALL Java_Electric_DRCMinDistance(JNIEnv *env, jobject obj,
+	jobject jtech, jobject jlib, jint jlayer1, jint jlayer2, jint jconnected)
+{
+	TECHNOLOGY *tech;
+	LIBRARY *lib;
+	INTSML layer1, layer2, connected;
+	INTBIG dist;
+	jint jdist;
+
+	/* convert Java parameters to C */
+	if (jtech == 0 || jlib == 0) return(0);
+	tech = (TECHNOLOGY *)java_environment->GetIntField(jtech, java_addressID);
+	lib = (LIBRARY *)java_environment->GetIntField(jlib, java_addressID);
+	layer1 = (INTSML)jlayer1;
+	layer2 = (INTSML)jlayer2;
+	connected = (INTSML)jconnected;
+
+	/* make the Electric call */
+	dist = drcmindistance(tech, lib, layer1, layer2, connected);
+
+	/* convert C result to Java */
+	jdist = dist;
+	return(jdist);
+}
+
+JNIEXPORT jint JNICALL Java_Electric_DRCMinWidth(JNIEnv *env, jobject obj,
+	jobject jtech, jobject jlib, jint jlayer)
+{
+	TECHNOLOGY *tech;
+	LIBRARY *lib;
+	INTSML layer;
+	INTBIG dist;
+	jint jdist;
+
+	/* convert Java parameters to C */
+	if (jtech == 0 || jlib == 0) return(0);
+	tech = (TECHNOLOGY *)java_environment->GetIntField(jtech, java_addressID);
+	lib = (LIBRARY *)java_environment->GetIntField(jlib, java_addressID);
+	layer = (INTSML)jlayer;
+
+	/* make the Electric call */
+	dist = drcminwidth(tech, lib, layer);
+
+	/* convert C result to Java */
+	jdist = dist;
+	return(jdist);
+}
+
+JNIEXPORT void JNICALL Java_Electric_xformPoly(JNIEnv *env, jobject obj,
+	jobject jpoly, jobject jtrans)
+{
+	XARRAY trans;
+	POLYGON *poly;
+	INTBIG i;
+	jintArray vArray;
+
+	/* convert Java parameters to C */
+	if (jpoly == 0 || jtrans == 0) return;
+	poly = (POLYGON *)java_environment->GetIntField(jpoly, java_addressID);
+	vArray = (jintArray)java_environment->GetObjectField(jtrans, java_xarrayVID);
+	java_environment->GetIntArrayRegion(vArray, 0, 9, &trans[0][0]);
+
+	/* make the Electric call */
+	for(i=0; i<poly->count; i++)
+		xform(poly->xv[i], poly->yv[i], &poly->xv[i], &poly->yv[i], trans);
+}
+
+JNIEXPORT void JNICALL Java_Electric_freePolygon(JNIEnv *env, jobject obj,
+	jobject jpoly)
+{
+	POLYGON *poly;
+
+	/* convert Java parameters to C */
+	if (jpoly == 0) return;
+	poly = (POLYGON *)java_environment->GetIntField(jpoly, java_addressID);
+
+	/* make the Electric call */
+	freepolygon(poly);
+}
+
+JNIEXPORT jobject JNICALL Java_Electric_getTraversalPath(JNIEnv *env, jobject obj)
+{
+	NODEINST **nilist;
+	INTSML depth, i;
+	jobjectArray retarray;
+
+	/* make the Electric call */
+	gettraversalpath(&nilist, &depth);
+
+	/* convert C result to Java */
+	retarray = java_environment->NewObjectArray((depth+1), java_classnodeinst, NULL);
+	for(i=0; i<depth; i++)
+		java_environment->SetObjectArrayElement(retarray, i,
+			java_makeobject((INTBIG)nilist[i], VNODEINST));
+	java_environment->SetObjectArrayElement(retarray, depth,
+		java_makeobject((INTBIG)NONODEINST, VNODEINST));
+	return(retarray);
+}
+
 /****************************** SUPPORT ******************************/
 
 /*
@@ -2255,7 +2505,7 @@ jint JNICALL java_vfprintf(FILE *fp, const char *format, va_list args)
  */
 void JNICALL java_exit(jint code)
 {
-	ttyputmsg("Exiting JAVA with code %d", code);
+	ttyputmsg(_("Exiting JAVA with code %d"), code);
 }
 
 /*
@@ -2264,6 +2514,7 @@ void JNICALL java_exit(jint code)
 char *java_describeobject(jobject obj)
 {
 	static char descr[100];
+	REGISTER char *pt;
 	INTBIG addr, type;
 
 	if (obj == 0) return("NULL");
@@ -2279,7 +2530,10 @@ char *java_describeobject(jobject obj)
 			return(descr);
 
 		case VSTRING:
-			return((char *)addr);
+			pt = (char *)addr;
+			if (java_allocarraybuffer(strlen(pt) + 1) != 0) return("NULL");
+			strcpy(java_arraybuffer, pt);
+			return(java_arraybuffer);
 
 		case VNODEINST:
 			sprintf(descr, "Nodeinst(%ld)", addr);
@@ -2353,11 +2607,15 @@ char *java_describeobject(jobject obj)
 			sprintf(descr, "Graphics(%ld)", addr);
 			return(descr);
 
+		case VPOLYGON:
+			sprintf(descr, "Polygon(%ld)", addr);
+			return(descr);
+
 		case VCONSTRAINT:
 			sprintf(descr, "Constraint(%ld)", addr);
 			return(descr);
 	}
-	return("UNKNOWN");
+	return(_("UNKNOWN"));
 }
 
 /*
@@ -2535,6 +2793,12 @@ void java_getobjectaddrtype(jobject obj, INTBIG *addr, INTBIG *type)
 		*type = VCONSTRAINT;
 		return;
 	}
+	if (java_environment->IsInstanceOf(obj, java_classpolygon))
+	{
+		*addr = java_environment->GetIntField(obj, java_addressID);
+		*type = VPOLYGON;
+		return;
+	}
 
 	/* int arrays */
 	if (java_environment->IsInstanceOf(obj, java_classarrayint))
@@ -2565,12 +2829,10 @@ jobject java_makeobject(INTBIG addr, INTBIG type)
 	{
 		case VINTEGER:
 		case VSHORT:
-			object = java_environment->AllocObject(java_classint);
-			java_environment->CallVoidMethod(object, java_midIntInit, (jint)addr);
+			object = java_makejavaobject(addr, type, java_classint, VINTEGER);
 			break;
 		case VFLOAT:
-			object = java_environment->AllocObject(java_classfloat);
-			java_environment->CallVoidMethod(object, java_midFloatInit, (jfloat)castfloat(addr));
+			object = java_makejavaobject(addr, type, java_classfloat, VFLOAT);
 			break;
 		case VSTRING:
 			object = java_environment->NewStringUTF((char *)addr);
@@ -2632,6 +2894,9 @@ jobject java_makeobject(INTBIG addr, INTBIG type)
 		case VCONSTRAINT:
 			object = java_makejavaobject(addr, type, java_classconstraint, VCONSTRAINT);
 			break;
+		case VPOLYGON:
+			object = java_makejavaobject(addr, type, java_classpolygon, VPOLYGON);
+			break;
 		default:
 			object = java_nullobject;
 			break;
@@ -2660,7 +2925,16 @@ jobject java_makejavaobject(INTBIG addr, INTBIG type, jclass javaclass, INTBIG d
 	} else
 	{
 		object = java_environment->AllocObject(javaclass);
-		java_environment->SetIntField(object, java_addressID, addr);
+		if ((type&VTYPE) == VFLOAT)
+		{
+			java_environment->CallVoidMethod(object, java_midFloatInit, (jfloat)castfloat(addr));
+		} else if ((type&VTYPE) == VINTEGER || (type&VTYPE) == VSHORT)
+		{
+			java_environment->CallVoidMethod(object, java_midIntInit, (jint)addr);
+		} else
+		{
+			java_environment->SetIntField(object, java_addressID, addr);
+		}
 	}
 	return(object);
 }
