@@ -107,7 +107,6 @@ int tcl_noundoallowed(ClientData dummy, Tcl_Interp *interp, int argc, char **arg
 int tcl_getview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 int tcl_newview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
-int tcl_changelambda(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 int tcl_tellaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 int tcl_askaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
 int tcl_getarcproto(ClientData dummy, Tcl_Interp *interp, int argc, char **argv);
@@ -181,15 +180,15 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	/* set the system version */
 	if (Tcl_SetVar(tcl_interp, "el_version", el_version, TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set el_version variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set el_version variable"));
 	}
 
 	/* set the Electric library directory */
 	if (Tcl_SetVar(tcl_interp, "el_libdir", el_libdir, TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set el_libdir variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set el_libdir variable"));
 	}
 
 	/* set the Electric LISP directory */
@@ -199,8 +198,8 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	(void)addtoinfstr(DIRSEP);
 	if (Tcl_SetVar(tcl_interp, "el_lispdir", returninfstr(), TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set el_lispdir variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set el_lispdir variable"));
 	}
 
 	/* set the Electric Tcl directory */
@@ -211,15 +210,15 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	path = returninfstr();
 	if (Tcl_SetVar(tcl_interp, "el_tcldir", path, TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set el_tcldir variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set el_tcldir variable"));
 	}
 
 	/* set the Tcl library directory - for internal Tcl use */
 	if (Tcl_SetVar(tcl_interp, "tcl_library", path, TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set tcl_library variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set tcl_library variable"));
 	}
 
 #ifdef USETK
@@ -231,15 +230,15 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	path = returninfstr();
 	if (Tcl_SetVar(tcl_interp, "el_tkdir", path, TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set el_tkdir variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set el_tkdir variable"));
 	}
 
 	/* set the Tk library directory - for internal Tk use */
 	if (Tcl_SetVar(tcl_interp, "tk_library", path, TCL_GLOBAL_ONLY | TCL_LEAVE_ERR_MSG) == NULL)
 	{
-		ttyputerr("Tcl_SetVar failed: %s", tcl_interp->result);
-		ttyputmsg("couldn't set tk_library variable");
+		ttyputerr(_("Tcl_SetVar failed: %s"), tcl_interp->result);
+		ttyputmsg(_("couldn't set tk_library variable"));
 	}
 #endif
 
@@ -287,7 +286,6 @@ void el_tclinterpreter(Tcl_Interp *interp)
 	Tcl_CreateCommand(tcl_interp, "getview",         tcl_getview,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "newview",         tcl_newview,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "killview",        tcl_killview,        (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
-	Tcl_CreateCommand(tcl_interp, "changelambda",    tcl_changelambda,    (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "tellaid",         tcl_tellaid,         (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "askaid",          tcl_askaid,          (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
 	Tcl_CreateCommand(tcl_interp, "getarcproto",     tcl_getarcproto,     (ClientData)0, (Tcl_CmdDeleteProc *)NULL);
@@ -403,7 +401,7 @@ INTBIG tcl_converttowarnedelectric(char *name, INTBIG want, char *msg)
 	tcl_converttoanyelectric(name, &addr, &type);
 	if (type != want)
 	{
-		Tcl_AppendResult(tcl_interp, msg, " argument has the wrong type", (char *)NULL);
+		Tcl_AppendResult(tcl_interp, msg, _(" argument has the wrong type"), (char *)NULL);
 		return(-1);
 	}
 	return(addr);
@@ -1219,7 +1217,7 @@ int tcl_replacenodeinst(ClientData dummy, Tcl_Interp *interp, int argc, char **a
 	if (ni == NONODEINST || np == NONODEPROTO) return TCL_ERROR;
 
 	/* call Electric */
-	nni = replacenodeinst(ni, np);
+	nni = replacenodeinst(ni, np, 0);
 
 	/* convert result */
 	Tcl_AppendResult(interp, tcl_converttotcl((INTBIG)nni, VNODEINST), (char *) NULL);
@@ -1504,7 +1502,7 @@ int tcl_undoabatch(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	/* call Electric */
 	if (undoabatch(&aid) == 0)
 	{
-		Tcl_AppendResult(interp, "Error during undoabatch", (char *)NULL);
+		Tcl_AppendResult(interp, _("Error during undoabatch"), (char *)NULL);
 		return TCL_ERROR;
 	}
 
@@ -1590,30 +1588,6 @@ int tcl_killview(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 
 /*************************** MISCELLANEOUS ROUTINES ***************************/
 
-int tcl_changelambda(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
-{
-	REGISTER TECHNOLOGY *tech;
-	REGISTER INTBIG oldl, newl;
-
-	/* get input */
-	if (argc != 3 && argc != 4)
-	{
-		Tcl_AppendResult(interp, "Usage: changelambda OLDLAMBDA NEWLAMBDA [TECHNOLOGY]", (char *)NULL);
-		return TCL_ERROR;
-	}
-	oldl = myatoi(argv[1]);
-	newl = myatoi(argv[2]);
-	if (argc == 3) tech = NOTECHNOLOGY; else
-	{
-		tech = (TECHNOLOGY *)tcl_converttowarnedelectric(argv[3], VTECHNOLOGY, "third");
-		if (tech == NOTECHNOLOGY) return TCL_ERROR;
-	}
-
-	/* call Electric */
-	changelambda(oldl, newl, tech);
-	return TCL_OK;
-}
-
 int tcl_tellaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 {
 	REGISTER AIDENTRY *aid;
@@ -1644,7 +1618,7 @@ int tcl_askaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 	REGISTER AIDENTRY *aid;
 	INTBIG addr, addr0, addr1, addr2, addr3, type;
 	int aidArgc, ret, i, argcS, first;
-	char **aidArgv, **argvS, *command, line[256];
+	char **aidArgv, **argvS, *command;
 
 	/* get input */
 	if (argc != 3)
@@ -1677,15 +1651,11 @@ int tcl_askaid(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
 				first = 0;
 				for (i=0; i<argcS; i++)
 				{
-					if (first != 0) (void)addtoinfstr('/');
+					if (first != 0) (void)addtoinfstr('\n');
 					first++;
 					tcl_converttoanyelectric(argvS[i], &addr, &type);
-					(void)addstringtoinfstr("FACET=");
-					(void)addstringtoinfstr(describenodeproto(((GEOM *)addr)->entryaddr.ni->parent));
-					(void)addstringtoinfstr(" FROM=");
-					(void)sprintf(line, "0%lo", addr);
-					(void)addstringtoinfstr(line);
-					(void)addstringtoinfstr(";-1;0");
+					(void)formatinfstr("FACET=%s FROM=0%lo;-1;0",
+						describenodeproto(((GEOM *)addr)->entryaddr.ni->parent), addr);
 				}
 				ret = askaid(aid, command, (INTBIG)returninfstr());
 			}
@@ -2107,7 +2077,7 @@ INTSML tcl_loadtclmsg(char *s, ...)
 
 	if (Tcl_VarEval(tcl_interp, line, 0) == TCL_ERROR)
 	{
-		ttyputerr("'%s' gave error '%s'", line, tcl_interp->result);
+		ttyputerr(_("'%s' gave error '%s'"), line, tcl_interp->result);
 		return(1);
 	}
 	return(0);
