@@ -622,7 +622,7 @@ BOXPOLY *db_mrg_do_break(BOXPOLY *me, BOXPOLY *him, INTSML *rtc)
 	}
 
 	/* give the user a warning if this routine did not catch some case */
-	ttyputerr("WARNING: MERGING DONE INCORRECTLY");
+	ttyputerr(_("Warning: merging done incorrectly"));
 	ttyputerr("me: left = %ld, right = %ld, top = %ld, bot = %ld",
 		me->left, me->right, me->top, me->bot);
 	ttyputerr("him: left = %ld, right = %ld, top = %ld, bot = %ld",
@@ -1874,7 +1874,7 @@ INTSML db_mergepoly(MPOLY *mp, MPOLY *omp);
 void   db_mergesimplifyandbbox(MPOLY *mp);
 INTSML db_mergewalkedge(MPOLY *mp, INTBIG i, MPOLY *omp, MPOLY *newmp);
 
-/* #define DEBUGWALK 1 */			/* uncomment to debug polygon point traversal */
+/* #define DEBUGWALK    1 */		/* uncomment to debug polygon point traversal */
 /* #define SHOWRESULTS  1 */		/* uncomment to show results of each merge */
 /* #define SHOWTICKS    1 */		/* uncomment to show coordinate values with results */
 /* #define DESIREDLAYER 6 */		/* uncomment to select a specific layer */
@@ -1981,26 +1981,6 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 	mp->tech = tech;
 	db_mergesimplifyandbbox(mp);
 
-#if 0
-	{
-		char line[20];
-		(void)initinfstr();
-		addstringtoinfstr("Adding polygon on layer ");
-		sprintf(line, "%ld", layer);
-		addstringtoinfstr(line);
-		addstringtoinfstr(" is");
-		for(i=0; i<mp->count; i++)
-		{
-			addstringtoinfstr(" (");
-			addstringtoinfstr(latoa(mp->x[i]));
-			addstringtoinfstr(",");
-			addstringtoinfstr(latoa(mp->y[i]));
-			addstringtoinfstr(")");
-		}
-		ttyputmsg("%s", returninfstr());
-	}
-#endif
-
 	/* now look for merges */
 	for(omp = db_mpolylist; omp != NOMPOLY; omp = omp->nextmpoly)
 	{
@@ -2052,7 +2032,7 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 		static INTBIG xoff = 0, yoff = 0;
 		char line[20];
 
-		xoff += el_curtech->deflambda * 150;
+		xoff += el_curlib->lambda[el_curtech->techindex] * 150;
 		facet = getcurfacet();
 		if (facet == NONODEPROTO) return;
 		prim = getnodeproto("metal-1-node");
@@ -2116,9 +2096,10 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 		}
 		for(mp = db_mpolylist; mp != NOMPOLY; mp = mp->nextmpoly)
 		{
-			REGISTER INTBIG j;
+			REGISTER INTBIG j, lambda;
 			extern NODEPROTO *gen_invispinprim;
 
+			lambda = el_curlib->lambda[el_curtech->techindex];
 			for(i=0; i<mp->count; i++)
 			{
 				/* see if the X value has already been done */
@@ -2134,7 +2115,7 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 
 				/* show the X coordinate */
 				ni = newnodeinst(gen_invispinprim, mp->x[i]+xoff, mp->x[i]+xoff,
-					ly-el_curtech->deflambda*2+yoff, ly-el_curtech->deflambda*2+yoff,
+					ly-lambda*2+yoff, ly-lambda*2+yoff,
 						0, 0, facet);
 				if (ni != NONODEINST)
 				{
@@ -2162,8 +2143,8 @@ void mergestorepolygon(INTBIG layer, TECHNOLOGY *tech, POLYGON *poly)
 				if (omp != mp) continue;
 
 				/* show the Y coordinate */
-				ni = newnodeinst(gen_invispinprim, lx-el_curtech->deflambda*2+xoff,
-					lx-el_curtech->deflambda*2+xoff, mp->y[i]+yoff, mp->y[i]+yoff, 0, 0, facet);
+				ni = newnodeinst(gen_invispinprim, lx-lambda*2+xoff,
+					lx-lambda*2+xoff, mp->y[i]+yoff, mp->y[i]+yoff, 0, 0, facet);
 				if (ni != NONODEINST)
 				{
 					REGISTER VARIABLE *var;
@@ -2197,6 +2178,7 @@ void mergedone(void (*writepolygon)(INTSML, TECHNOLOGY*, INTBIG*, INTBIG*, INTSM
 
 	for(mp = db_mpolylist; mp != NOMPOLY; mp = mp->nextmpoly)
 	{
+		db_mergesimplifyandbbox(mp);
 		(*writepolygon)((INTSML)mp->layer, mp->tech, mp->x, mp->y, (INTSML)mp->count);
 	}
 }
@@ -2293,7 +2275,9 @@ INTSML db_mergepoly(MPOLY *mp, MPOLY *omp)
 	for(i=0; i<mp->count; i++)
 	{
 		if (mp->seen[i] != 0) continue;
+#if 0
 		if (mp->intersect[i] != 0) continue;
+#endif
 		if (db_mergeisinside(mp->x[i], mp->y[i], omp) != 0) continue;
 		db_mergeholemp->count = 0;
 		if (db_mergewalkedge(mp, i, omp, db_mergeholemp) != 0) return(0);
@@ -2302,7 +2286,9 @@ INTSML db_mergepoly(MPOLY *mp, MPOLY *omp)
 	for(oi=0; oi<omp->count; oi++)
 	{
 		if (omp->seen[oi] != 0) continue;
+#if 0
 		if (omp->intersect[oi] != 0) continue;
+#endif
 		if (db_mergeisinside(omp->x[oi], omp->y[oi], mp) != 0) continue;
 		db_mergeholemp->count = 0;
 		if (db_mergewalkedge(omp, oi, mp, db_mergeholemp) != 0) return(0);
@@ -2503,8 +2489,10 @@ INTSML db_mergewalkedge(MPOLY *mp, INTBIG i, MPOLY *omp, MPOLY *newmp)
 	static INTBIG seen = 0;
 
 #ifdef DEBUGWALK
-	ttyputmsg("Walking around edge (polygon 1 has %d points, polygon 2 has %d points):",
-		mp->count, omp->count);
+	ttyputmsg("Walking around edge, polygon 0 has %d points:", mp->count);
+	for(pt=0; pt<mp->count; pt++) ttyputmsg("  (%s,%s)", latoa(mp->x[pt]), latoa(mp->y[pt]));
+	ttyputmsg("Polygon 1 has %d points:", omp->count);
+	for(pt=0; pt<omp->count; pt++) ttyputmsg("  (%s,%s)", latoa(omp->x[pt]), latoa(omp->y[pt]));
 #endif
 	seen++;
 	if (seen == 0) seen++;
@@ -2525,7 +2513,7 @@ INTSML db_mergewalkedge(MPOLY *mp, INTBIG i, MPOLY *omp, MPOLY *newmp)
 			return(1);
 		if (newmp->count == 1000)
 		{
-			ttyputerr("WARNING: loop detected while merging polygons on layer %s",
+			ttyputerr(_("Warning: loop detected while merging polygons on layer %s"),
 				layername(mp->tech, (INTSML)mp->layer));
 			return(1);
 		}
