@@ -42,7 +42,7 @@ INTSML     db_hierlimit = 0;
 INTSML db_schematic_pages(NODEPROTO*);
 char *db_getframedesc(NODEPROTO*);
 INTSML db_copyxlibvars(INTBIG, INTBIG, INTBIG, INTBIG, NODEPROTO*, LIBRARY*);
-INTSML db_portassociate(NODEINST*, NODEINST*);
+INTSML db_portassociate(NODEINST*, NODEINST*, INTSML);
 INTSML db_doesntconnect(ARCPROTO*[], PORTPROTO*);
 
 /*
@@ -262,6 +262,7 @@ NODEPROTO *newnodeproto(char *fname, LIBRARY *lib)
 	np->adirty = 0;
 	np->cell = c;
 	np->cellview = view;
+	np->tech = whattech(np);
 	np->creationdate = getcurrenttime();
 	np->revisiondate = getcurrenttime();
 
@@ -314,30 +315,30 @@ NODEPROTO *db_newprimnodeproto(char *fname, INTBIG sx, INTBIG sy, INTSML pi,
 	{
 		if (np->primindex == pi)
 		{
-			ttyputmsg("Index %d of technology %s in use", pi, tech->techname);
+			ttyputmsg(_("Index %d of technology %s in use"), pi, tech->techname);
 			return(NONODEPROTO);
 		}
 		if (namesame(fname, np->primname) == 0)
 		{
-			ttyputmsg("Error: Two technologies with same name: %s and %s", fname, tech->techname);
+			ttyputmsg(_("Error: Two technologies with same name: %s and %s"), fname, tech->techname);
 			return(NONODEPROTO);
 		}
 	}
 	if (pi <= 0)
 	{
-		ttyputmsg("Error: Component index must be positive but %s:%s has %d",
+		ttyputmsg(_("Error: Component index must be positive but %s:%s has %d"),
 			tech->techname, fname, pi);
 		return(NONODEPROTO);
 	}
 	if (sx < 0 || sy < 0)
 	{
-		ttyputmsg("Error: Component size must be positive, but %s:%s is %ldx%ld",
+		ttyputmsg(_("Error: Component size must be positive, but %s:%s is %ldx%ld"),
 			tech->techname, fname, sx, sy);
 		return(NONODEPROTO);
 	}
 	for(pp = fname; *pp != 0; pp++) if (*pp <= ' ' || *pp == ':' || *pp >= 0177)
 	{
-		ttyputmsg("Error: Primitive name must not contain ':' and others but '%s:%s' does",
+		ttyputmsg(_("Error: Primitive name must not contain ':' and others but '%s:%s' does"),
 			tech->techname, fname);
 		return(NONODEPROTO);
 	}
@@ -346,7 +347,7 @@ NODEPROTO *db_newprimnodeproto(char *fname, INTBIG sx, INTBIG sy, INTSML pi,
 	np = allocnodeproto(tech->cluster);
 	if (np == NONODEPROTO)
 	{
-		ttyputmsg("Error: no memory for primitive %s in technology %s", fname, tech->techname);
+		ttyputnomemory();
 		return(NONODEPROTO);
 	}
 
@@ -366,7 +367,7 @@ NODEPROTO *db_newprimnodeproto(char *fname, INTBIG sx, INTBIG sy, INTSML pi,
 	/* initialize name and size */
 	if (allocstring(&np->primname, fname, tech->cluster) != 0)
 	{
-		ttyputmsg("Error: No memory for name in %s:%s", tech->techname, fname);
+		ttyputnomemory();
 		return(NONODEPROTO);
 	}
 	np->primindex = pi;
@@ -412,7 +413,7 @@ INTSML killnodeproto(NODEPROTO *np)
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = npt)
 	{
 		npt = pp->nextportproto;
-		if (killportproto(np, pp)) ttyputerr("killportproto oops");
+		if (killportproto(np, pp)) ttyputerr(_("killportproto error"));
 	}
 	while (np->firstarcinst != NOARCINST) db_killarcinst(np->firstarcinst);
 	while (np->firstnodeinst != NONODEINST) db_killnodeinst(np->firstnodeinst);
@@ -539,7 +540,7 @@ void db_retractnodeproto(NODEPROTO *np)
 			lastnp = onp;
 		}
 		if (lastnp != NONODEPROTO) lastnp->lastversion = np->lastversion;
-			else ttyputerr("Unusual version link in database!");
+			else ttyputerr(_("Unusual version link in database"));
 	} else
 	{
 		/* removing latest version of facet */
@@ -804,12 +805,12 @@ INTSML changefacetview(NODEPROTO *np, VIEW *view)
 
 	if ((np->cellview->viewstate&TEXTVIEW) != 0 && (view->viewstate&TEXTVIEW) == 0)
 	{
-		ttyputerr("Sorry, textual views cannot be made nontextual");
+		ttyputerr(_("Sorry, textual views cannot be made nontextual"));
 		return(1);
 	}
 	if ((np->cellview->viewstate&TEXTVIEW) == 0 && (view->viewstate&TEXTVIEW) != 0)
 	{
-		ttyputerr("Sorry, nontextual views cannot be made textual");
+		ttyputerr(_("Sorry, nontextual views cannot be made textual"));
 		return(1);
 	}
 
@@ -838,55 +839,30 @@ INTSML changefacetview(NODEPROTO *np, VIEW *view)
  */
 NODEPROTO *iconview(NODEPROTO *np)
 {
-	REGISTER NODEPROTO *rnp;
+	REGISTER NODEPROTO *rnp, *laynp, *schnp, *iconnp;
 
-	/* primitives have no icon view */
+	if (np == NONODEPROTO) return(NONODEPROTO);
+
+	/* must be complex */
 	if (np->primindex != 0) return(NONODEPROTO);
 
-	/* iconview of an icon is itself */
-	if (np->cellview == el_iconview) return(np);
-
+	/* Now look for views */
+	laynp = schnp = iconnp = NONODEPROTO;
 	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
-		if (rnp->cellview == el_iconview) return(rnp);
-	return(NONODEPROTO);
-}
+	{
+		if (rnp->cellview == el_layoutview) laynp = rnp;
+		if (rnp->cellview == el_schematicview ||
+			(rnp->cellview->viewstate&MULTIPAGEVIEW) != 0) schnp = rnp;
+		if (rnp->cellview == el_iconview) iconnp = rnp;
+	}
 
-/*
- * routine to see if facet "np" has a VHDL view, and if so, return that facet.
- * Returns NONODEPROTO if the facet does not have a VHDL view
- */
-NODEPROTO *vhdlview(NODEPROTO *np)
-{
-	REGISTER NODEPROTO *rnp;
-
-	/* primitives have no VHDL view */
-	if (np->primindex != 0) return(NONODEPROTO);
-
-	/* VHDL view of VHDL is itself */
-	if (np->cellview == el_vhdlview) return(np);
-
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
-		if (rnp->cellview == el_vhdlview) return(rnp);
-	return(NONODEPROTO);
-}
-
-/*
- * routine to see if facet "np" has a Verilog view, and if so, return that facet.
- * Returns NONODEPROTO if the facet does not have a Verilog view
- */
-NODEPROTO *verilogview(NODEPROTO *np)
-{
-	REGISTER NODEPROTO *rnp;
-
-	/* primitives have no Verilog view */
-	if (np->primindex != 0) return(NONODEPROTO);
-
-	/* Verilog view of Verilog is itself */
-	if (np->cellview == el_verilogview) return(np);
-
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
-		if (rnp->cellview == el_verilogview) return(rnp);
-	return(NONODEPROTO);
+	if (iconnp != NONODEPROTO)
+	{
+		/* if there is layout AND schematics and this is layout, then no icon */
+		if (laynp != NONODEPROTO && schnp != NONODEPROTO && np->cellview == el_layoutview)
+			return(NONODEPROTO);
+	}
+	return(iconnp);
 }
 
 /*
@@ -927,34 +903,58 @@ NODEPROTO *contentsview(NODEPROTO *np)
 /* function to return a layout view if there is one */
 NODEPROTO *layoutview(NODEPROTO *np)
 {
-	REGISTER NODEPROTO *rnp;
+	REGISTER NODEPROTO *rnp, *laynp, *schnp, *uknnp;
 
 	if (np == NONODEPROTO) return(NONODEPROTO);
 
 	/* must be complex */
-	if (np->primindex != 0) return (NONODEPROTO);
+	if (np->primindex != 0) return(NONODEPROTO);
 
 	/* Now look for views */
-
-	/* layout has first precedence */
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
-		if (rnp->cellview == el_layoutview) return(rnp);
-
-	/* schematics come next */
+	laynp = schnp = uknnp = NONODEPROTO;
 	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
 	{
-		if (rnp->cellview == el_schematicview) return(rnp);
-		if ((rnp->cellview->viewstate&MULTIPAGEVIEW) != 0) return(rnp);
+		if (rnp->cellview == el_layoutview) laynp = rnp;
+		if (rnp->cellview == el_schematicview ||
+			(rnp->cellview->viewstate&MULTIPAGEVIEW) != 0) schnp = rnp;
+		if (rnp->cellview == el_unknownview) uknnp = rnp;
 	}
 
+	/* if this is an icon, look for schematic first */
+	if (np->cellview == el_iconview && schnp != NONODEPROTO) return(schnp);
+
+	/* layout has first precedence */
+	if (laynp != NONODEPROTO) return(laynp);
+
+	/* schematics come next */
+	if (schnp != NONODEPROTO) return(schnp);
+
 	/* then look for unknown */
-	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
-		if (rnp->cellview == el_unknownview) return(rnp);
+	if (uknnp != NONODEPROTO) return(uknnp);
 
 	/* keep what we have */
 	return(NONODEPROTO);
 }
 
+/*
+ * routine to see if facet "np" has an equivalent of view "v", and if so, return that facet.
+ * Returns NONODEPROTO if the facet does not have an equivalent in that view.
+ */
+NODEPROTO *anyview(NODEPROTO *np, VIEW *v)
+{
+	REGISTER NODEPROTO *rnp;
+
+	/* primitives have no icon view */
+	if (np->primindex != 0) return(NONODEPROTO);
+
+	/* return self if already that type */
+	if (np->cellview == v) return(np);
+
+	for(rnp = np->cell->firstincell; rnp != NONODEPROTO; rnp = rnp->nextincell)
+		if (rnp->cellview == v) return(rnp);
+	return(NONODEPROTO);
+}
+
 /*
  * routine to obtain the equivalent port on a facet with an alternate view.
  * The original facet is "np" with port "pp".  The routine returns the port
@@ -972,7 +972,7 @@ PORTPROTO *equivalentport(NODEPROTO *np, PORTPROTO *pp, NODEPROTO *enp)
 
 	/* don't report errors for global ports not on icons */
 	if (enp->cellview != el_iconview || (pp->userbits&BODYONLY) == 0)
-		ttyputerr("Warning: no port in facet %s corresponding to port %s in facet %s",
+		ttyputerr(_("Warning: no port in facet %s corresponding to port %s in facet %s"),
 			describenodeproto(enp), pp->protoname, describenodeproto(np));
 	return(NOPORTPROTO);
 }
@@ -1200,8 +1200,8 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 			case 1:			/* facet name/version */
 				if (np == NONODEPROTO) break;
 				if ((np->cellview->viewstate&MULTIPAGEVIEW) == 0)
-					(void)sprintf(ndstring, "Name: %s - - Page 1 of 1", np->cell->cellname); else
-						(void)sprintf(ndstring, "Name: %s - - Page %s of %d", np->cell->cellname,
+					(void)sprintf(ndstring, _("Name: %s - - Page 1 of 1"), np->cell->cellname); else
+						(void)sprintf(ndstring, _("Name: %s - - Page %s of %d"), np->cell->cellname,
 							&np->cellview->viewname[15], db_schematic_pages(np));
 				poly->xv[0] = poly->xv[3] = schxsize/2 - framewid - xlogobox;
 				poly->xv[1] = poly->xv[2] = schxsize/2 - framewid;
@@ -1244,7 +1244,7 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				break;
 			case 5:			/* creation date */
 				if (np == NONODEPROTO) break;
-				(void)sprintf(ndstring, "Created: %s", timetostring(np->creationdate));
+				(void)sprintf(ndstring, _("Created: %s"), timetostring(np->creationdate));
 				poly->xv[0] = poly->xv[3] = schxsize/2 - framewid - xlogobox;
 				poly->xv[1] = poly->xv[2] = schxsize/2 - framewid;
 				poly->yv[0] = poly->yv[1] = -schysize/2 + framewid + ylogobox / 6;
@@ -1265,7 +1265,7 @@ void framepoly(INTSML boxnum, POLYGON *poly, NODEPROTO *np)
 				break;
 			case 7:			/* revision date */
 				if (np == NONODEPROTO) break;
-				(void)sprintf(ndstring, "Revised: %s", timetostring(np->revisiondate));
+				(void)sprintf(ndstring, _("Revised: %s"), timetostring(np->revisiondate));
 				poly->xv[0] = poly->xv[3] = schxsize/2 - framewid - xlogobox;
 				poly->xv[1] = poly->xv[2] = schxsize/2 - framewid;
 				poly->yv[0] = poly->yv[1] = -schysize/2 + framewid;
@@ -1319,10 +1319,10 @@ INTSML db_schematic_pages(NODEPROTO *np)
 		thispage = atoi(&onp->cellview->viewname[15]);
 		if (thispage > maxpage) maxpage = thispage;
 		if (thispage < 1)
-			ttyputerr("Schematic page %d found in %s - should be positive integer",
+			ttyputerr(_("Schematic page %d found in %s - should be positive integer"),
 				thispage, onp->cellview->viewname);
 	}
-	if (count < maxpage) ttyputerr("Missing schematic pages in %s", np->cell->cellname);
+	if (count < maxpage) ttyputerr(_("Missing schematic pages in %s"), np->cell->cellname);
 	return(maxpage);
 }
 
@@ -1396,7 +1396,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 				lnt->cellview == ni->proto->cellview) break;
 		if (lnt == NONODEPROTO)
 		{
-			ttyputerr("Can't find %s facet in destination library", describenodeproto(ni->proto));
+			ttyputerr(_("Can't find %s facet in destination library"), describenodeproto(ni->proto));
 			return(NONODEPROTO);
 		}
 
@@ -1409,7 +1409,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 					break;
 			if (ppt == NOPORTPROTO)
 			{
-				ttyputerr("Cannot find port %s in facet %s", pp->protoname, describenodeproto(lnt));
+				ttyputerr(_("Cannot find port %s in facet %s"), pp->protoname, describenodeproto(lnt));
 				return(NONODEPROTO);
 			}
 		}
@@ -1421,7 +1421,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 					break;
 			if (ppt == NOPORTPROTO)
 			{
-				ttyputerr("Cannot find port %s in facet %s", pp->protoname, describenodeproto(lnt));
+				ttyputerr(_("Cannot find port %s in facet %s"), pp->protoname, describenodeproto(lnt));
 				return(NONODEPROTO);
 			}
 		}
@@ -1466,7 +1466,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 				if (namesame(ni->proto->cell->cellname, c->cellname) == 0) break;
 			if (c == NOCELL)
 			{
-				ttyputerr("Error: no cell %s (used in facet %s)", ni->proto->cell->cellname,
+				ttyputerr(_("Error: no cell %s (used in facet %s)"), ni->proto->cell->cellname,
 					describenodeproto(fromnp));
 				return(NONODEPROTO);
 			}
@@ -1476,7 +1476,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 				if (lnt->cellview == ni->proto->cellview) break;
 			if (lnt == NONODEPROTO)
 			{
-				ttyputerr("Error: no %s view of cell %s (used in facet %s)",
+				ttyputerr(_("Error: no %s view of cell %s (used in facet %s)"),
 					ni->proto->cellview->viewname, ni->proto->cell->cellname,
 						describenodeproto(fromnp));
 				return(NONODEPROTO);
@@ -1542,7 +1542,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 				}
 			}
 			if (opt[i] == NOPORTPROTO)
-				ttyputerr("Error: no port for %s arc on %s node", describearcproto(ai->proto),
+				ttyputerr(_("Error: no port for %s arc on %s node"), describearcproto(ai->proto),
 					describenodeproto(ai->end[i].nodeinst->proto));
 		}
 
@@ -1584,7 +1584,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 				p1 = p1->nextportproto, p2 = p2->nextportproto)
 					if (pp->subportproto == p2) break;
 		if (pp->subportproto != p2)
-			ttyputerr("Error: no port on %s facet", describenodeproto(pp->subnodeinst->proto));
+			ttyputerr(_("Error: no port on %s facet"), describenodeproto(pp->subnodeinst->proto));
 
 		/* create the nodeinst portinst */
 		ppt = db_newportproto(np, ni, p1, pp->protoname);
@@ -1611,7 +1611,7 @@ NODEPROTO *copynodeproto(NODEPROTO *fromnp, LIBRARY *tolib, char *toname)
 
 	/* report failures to copy variables across libraries */
 	if (failures != 0)
-		ttyputmsg("WARNING: cross-library copy of facet %s deleted %d variables",
+		ttyputmsg(_("WARNING: cross-library copy of facet %s deleted %d variables"),
 			describenodeproto(fromnp), failures);
 
 	/* reset (copy) date information */
@@ -1745,12 +1745,12 @@ INTSML db_copyxlibvars(INTBIG fromaddr, INTBIG fromtype, INTBIG toaddr,
  * intact.  The routine returns the address of the new replacing nodeinst if
  * successful, NONODEINST if the replacement cannot be done.
  */
-NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
+NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np, INTSML ignoreportnames)
 {
 	REGISTER PORTPROTO *pp, *opt;
 	INTBIG endx[2], endy[2], bx, by, cx, cy, lxo, hxo, lyo, hyo, lx, hx, ly, hy, psx, psy,
 		arcdx, arcdy, arccount, thisend, xp, yp;
-	REGISTER INTSML i, zigzag, ang, fixedalignment;
+	REGISTER INTBIG i, zigzag, ang, fixedalignment;
 	XARRAY trans;
 	REGISTER VARIABLE *varold, *varnew;
 	NODEINST *endnodeinst[2];
@@ -1775,17 +1775,29 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 	if (np->primindex == 0)
 	{
 		/* facet replacement: determine location of replacement */
+#if 0
 		lx = ni->lowx;   hx = lx + np->highx - np->lowx;
 		ly = ni->lowy;   hy = ly + np->highy - np->lowy;
+#else
+		lx = ni->lowx - ni->proto->lowx + np->lowx;
+		hx = ni->highx - ni->proto->highx + np->highx;
+		ly = ni->lowy - ni->proto->lowy + np->lowy;
+		hy = ni->highy - ni->proto->highy + np->highy;
+#endif
 
 		/* adjust position for facet center alignment */
 		varold = getvalkey((INTBIG)ni->proto, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
 		varnew = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER|VISARRAY, el_prototype_center);
-		if (varold != NOVARIABLE && varnew != NOVARIABLE) fixedalignment = 1;
-		corneroffset(ni, ni->proto, ni->rotation, ni->transpose, &bx, &by, 0);
-		corneroffset(NONODEINST, np, ni->rotation, ni->transpose, &cx, &cy, 0);
-		lx += bx-cx;   hx += bx-cx;
-		ly += by-cy;   hy += by-cy;
+		if (varold != NOVARIABLE && varnew != NOVARIABLE)
+		{
+			fixedalignment = 1;
+			corneroffset(ni, ni->proto, ni->rotation, ni->transpose, &bx, &by, 0);
+			corneroffset(NONODEINST, np, ni->rotation, ni->transpose, &cx, &cy, 0);
+			lx = ni->lowx;   hx = lx + np->highx - np->lowx;
+			ly = ni->lowy;   hy = ly + np->highy - np->lowy;
+			lx += bx-cx;   hx += bx-cx;
+			ly += by-cy;   hy += by-cy;
+		}
 	} else
 	{
 		/* primitive replacement: compute proper size of new part */
@@ -1806,7 +1818,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 	newno->userbits |= ni->userbits&NEXPAND;
 
 	/* associate the ports between these nodes */
-	if (db_portassociate(ni, newno) != 0)
+	if (db_portassociate(ni, newno, ignoreportnames) != 0)
 	{
 		db_killnodeinst(newno);
 		return((NODEINST *)db_error(DBNOMEM|DBREPLACENODEINST));
@@ -1822,7 +1834,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 		if (opt == NOPORTPROTO)
 		{
 			if (db_printerrors != 0)
-				ttyputmsg("No port on new node corresponds to old port %s", pi->proto->protoname);
+				ttyputmsg(_("No port on new node corresponds to old port: %s"), pi->proto->protoname);
 			db_killnodeinst(newno);
 			return((NODEINST *)db_error(DBPORTMM|DBREPLACENODEINST));
 		}
@@ -1834,7 +1846,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 		if (opt->connects[i] == NOARCPROTO)
 		{
 			if (db_printerrors != 0)
-				ttyputmsg("%s arc on old port %s cannot connect to new port %s",
+				ttyputmsg(_("%s arc on old port %s cannot connect to new port %s"),
 					describearcinst(ai), pi->proto->protoname, opt->protoname);
 			db_killnodeinst(newno);
 			return((NODEINST *)db_error(DBPORTMM|DBREPLACENODEINST));
@@ -1866,7 +1878,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 		}
 	}
 
-	/* see if the old export ports are the same */
+	/* see if the old exports are the same */
 	for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 	{
 		/* make sure there is an association for this port */
@@ -1874,12 +1886,13 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 		if (opt == NOPORTPROTO)
 		{
 			if (db_printerrors != 0)
-				ttyputmsg("No port on new node corresponds to old port %s", pe->proto->protoname);
+				ttyputmsg(_("No port on new node corresponds to old port: %s"),
+					pe->proto->protoname);
 			db_killnodeinst(newno);
 			return((NODEINST *)db_error(DBPORTMM|DBREPLACENODEINST));
 		}
 
-		/* ensure that all arcs connected at exported sites still connect */
+		/* ensure that all arcs connected at exports still connect */
 		if (db_doesntconnect(opt->connects, pe->exportproto) != 0)
 		{
 			db_killnodeinst(newno);
@@ -1911,7 +1924,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 		}
 		if (endportproto[0] == NOPORTPROTO || endportproto[1] == NOPORTPROTO)
 		{
-			ttyputerr("Cannot re-connect %s arc", describearcinst(ai));
+			ttyputerr(_("Cannot re-connect %s arc"), describearcinst(ai));
 			continue;
 		}
 
@@ -1939,7 +1952,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 			newni = db_newnodeinst(pinnp, lx,hx, ly,hy, 0, 0, ni->parent);
 			newai = db_newarcinst(ai->proto, ai->width, ai->userbits, endnodeinst[0],
 				endportproto[0], endx[0],endy[0], newni, pinnp->firstportproto, cx, cy, ni->parent);
-			i = (INTSML)ai->userbits;
+			i = ai->userbits;
 			if ((i&ISNEGATED) != 0) i &= ~ISNEGATED;
 			newai2 = db_newarcinst(ai->proto, ai->width, i, newni, pinnp->firstportproto, cx, cy,
 				endnodeinst[1], endportproto[1], endx[1],endy[1], ni->parent);
@@ -1973,7 +1986,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
 		db_killarcinst(ai);
 	}
 
-	/* now replace the exported ports */
+	/* now replace the exports */
 	for(;;)
 	{
 		for(pp = ni->parent->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -2000,7 +2013,7 @@ NODEINST *replacenodeinst(NODEINST *ni, NODEPROTO *np)
  * port prototype on "ni2" in its "temp1" field (NOPORTPROTO if the match
  * cannot be found).  The routine returns nonzero if there is an error.
  */
-INTSML db_portassociate(NODEINST *ni1, NODEINST *ni2)
+INTSML db_portassociate(NODEINST *ni1, NODEINST *ni2, INTSML ignoreportnames)
 {
 	REGISTER INTSML i, j, total2;
 	REGISTER INTBIG *xpos2, *ypos2;
@@ -2033,17 +2046,20 @@ INTSML db_portassociate(NODEINST *ni1, NODEINST *ni2)
 	}
 
 	/* associate on port name matches */
-	for(pp1 = ni1->proto->firstportproto; pp1 != NOPORTPROTO; pp1 = pp1->nextportproto)
+	if (ignoreportnames == 0)
 	{
-		for(pp2 = ni2->proto->firstportproto; pp2 != NOPORTPROTO; pp2 = pp2->nextportproto)
-			if (pp2->temp1 == -1)
+		for(pp1 = ni1->proto->firstportproto; pp1 != NOPORTPROTO; pp1 = pp1->nextportproto)
 		{
-			/* stop if the ports have different name */
-			if (namesame(pp2->protoname, pp1->protoname) != 0) continue;
+			for(pp2 = ni2->proto->firstportproto; pp2 != NOPORTPROTO; pp2 = pp2->nextportproto)
+				if (pp2->temp1 == -1)
+			{
+				/* stop if the ports have different name */
+				if (namesame(pp2->protoname, pp1->protoname) != 0) continue;
 
-			/* store the correct association of ports */
-			pp1->temp1 = (INTBIG)pp2;
-			pp2->temp1 = (INTBIG)pp1;
+				/* store the correct association of ports */
+				pp1->temp1 = (INTBIG)pp2;
+				pp2->temp1 = (INTBIG)pp1;
+			}
 		}
 	}
 
@@ -2125,7 +2141,7 @@ INTSML db_portassociate(NODEINST *ni1, NODEINST *ni2)
 
 /*
  * helper routine to ensure that all arcs connected to port "pp" or any of
- * its exported sites can connect to the list in "conn".  Returns nonzero
+ * its export sites can connect to the list in "conn".  Returns nonzero
  * if the connection cannot be made
  */
 INTSML db_doesntconnect(ARCPROTO *conn[], PORTPROTO *pp)
@@ -2147,7 +2163,7 @@ INTSML db_doesntconnect(ARCPROTO *conn[], PORTPROTO *pp)
 			if (conn[i] == NOARCPROTO)
 			{
 				if (db_printerrors != 0)
-					ttyputmsg("%s arc in facet %s cannot connect to port %s",
+					ttyputmsg(_("%s arc in facet %s cannot connect to port %s"),
 						describearcinst(pi->conarcinst), describenodeproto(ni->parent), pp->protoname);
 				return(1);
 			}
@@ -2164,7 +2180,7 @@ INTSML db_doesntconnect(ARCPROTO *conn[], PORTPROTO *pp)
 }
 
 /*
- * routine to move an exported portproto to a different nodeinst in the facet.
+ * routine to move an export to a different nodeinst in the facet.
  * The routine expects both ports to be in the same place and simply shifts
  * the arcs without re-constraining them. The portproto is currently "oldpt"
  * in facet "facet".  It is to be moved to nodeinst "newno", subportproto
