@@ -46,11 +46,11 @@ static VARIABLE *tech_serpentvar;
 /* for multiple contact cut polygons */
 static INTBIG tech_moscutlx, tech_moscuthx, tech_moscutly, tech_moscuthy,
 	tech_moscutbasex, tech_moscutbasey, tech_moscutsizex, tech_moscutsizey,
-	tech_moscutsep;
-static INTSML tech_moscuttotal, tech_moscutsx, tech_moscutsy;
+	tech_moscutsep, tech_moscuttopedge, tech_moscutleftedge, tech_moscutrightedge,
+	tech_moscuttotal, tech_moscutsx, tech_moscutsy;
 
 /* for displayable variables */
-static INTSML tech_ndisplayindex, tech_ndisplaysubindex, tech_adisplayindex;
+static INTBIG tech_ndisplayindex, tech_ndisplaysubindex, tech_adisplayindex;
 
 /* for circular arcs */
 static INTSML tech_arcpieces, tech_anglebase, tech_anglerange;
@@ -66,9 +66,9 @@ static VARIABLE *tech_firstvar;
 
 /* prototypes for local routines */
 void db_adjusttree(NODEPROTO*);
-void tech_shortenmostrans(NODEINST*, POLYGON*, TECH_POLYGON*, INTBIG, INTSML, TECH_PORTS*);
+void tech_shortenmostrans(NODEINST*, POLYGON*, TECH_POLYGON*, INTBIG, INTBIG, TECH_PORTS*);
 INTSML db_stillinport(ARCINST*, INTSML, INTBIG, INTBIG);
-INTSML tech_displayableanyvars(void);
+INTBIG tech_displayableanyvars(void);
 VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 	INTBIG ly, INTBIG hy, INTBIG addr, INTBIG type, TECHNOLOGY *tech);
 
@@ -99,7 +99,7 @@ INTSML tech_doinitprocess(TECHNOLOGY *tech)
 			nty->ysize*lam/WHOLE, nty->nodeindex, tech);
 		if (nty->creation == NONODEPROTO)
 		{
-			ttyputerr("Cannot create nodeprotos");
+			ttyputerr(_("Cannot create nodeprotos"));
 			return(1);
 		}
 		nty->creation->userbits = nty->initialbits;
@@ -112,7 +112,8 @@ INTSML tech_doinitprocess(TECHNOLOGY *tech)
 		ap = db_newarcproto(tech, at->arcname, at->arcwidth*lam/WHOLE, at->arcindex);
 		if (ap == NOARCPROTO)
 		{
-			ttyputerr("Cannot create arcproto %s in technology %s", at->arcname, tech->techname);
+			ttyputerr(_("Cannot create arcproto %s in technology %s"),
+				at->arcname, tech->techname);
 			return(1);
 		}
 		ap->userbits = at->initialbits;
@@ -173,14 +174,14 @@ INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
 			/* create the portproto */
 			if (portinst[j].addr != NOPORTPROTO)
 			{
-				ttyputerr("Warning: node %s of technology %s shares port descriptions",
+				ttyputerr(_("Warning: node %s of technology %s shares port descriptions"),
 					nty->creation->primname, tech->techname);
 			}
 			portinst[j].addr = db_newprimportproto(nty->creation,
 				(ARCPROTO **)&portinst[j].portarcs[1], portinst[j].protoname);
 			if (portinst[j].addr == NOPORTPROTO)
 			{
-				ttyputerr("Error creating ports");
+				ttyputerr(_("Error creating ports"));
 				return(1);
 			}
 			portinst[j].addr->userbits = portinst[j].initialbits;
@@ -229,6 +230,7 @@ INTSML tech_doaddportsandvars(TECHNOLOGY *tech)
 void tech_convertmocmoslib(LIBRARY *lib)
 {
 	REGISTER INTSML prims;
+	REGISTER INTBIG lambda;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCINST *ai;
 	REGISTER NODEINST *ni;
@@ -238,10 +240,11 @@ void tech_convertmocmoslib(LIBRARY *lib)
 		if (namesame(mocmostech->techname, "mocmos") == 0) break;
 	if (mocmostech == NOTECHNOLOGY)
 	{
-		ttyputmsg("Cannot find 'mocmos' technology");
+		ttyputmsg(_("Cannot find 'mocmos' technology"));
 		return;
 	}
 
+	lambda = lib->lambda[mocmostech->techindex];
 	prims = 0;
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
@@ -250,7 +253,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 			if (ai->proto->tech != mocmostech) continue;
 			if (namesame(ai->proto->protoname, "S-Active") != 0) continue;
 			undogeom(ai->geom, np);
-			ai->width += 4 * mocmostech->deflambda;
+			ai->width += 4 * lambda;
 			linkgeom(ai->geom, np);
 			prims++;
 		}
@@ -263,10 +266,10 @@ void tech_convertmocmoslib(LIBRARY *lib)
 				namesame(ni->proto->primname, "Metal-1-S-Active-Con") == 0)
 			{
 				undogeom(ni->geom, np);
-				ni->lowx -= 2 * mocmostech->deflambda;
-				ni->highx += 2 * mocmostech->deflambda;
-				ni->lowy -= 2 * mocmostech->deflambda;
-				ni->highy += 2 * mocmostech->deflambda;
+				ni->lowx -= 2 * lambda;
+				ni->highx += 2 * lambda;
+				ni->lowy -= 2 * lambda;
+				ni->highy += 2 * lambda;
 				linkgeom(ni->geom, np);
 				prims++;
 				continue;
@@ -274,10 +277,10 @@ void tech_convertmocmoslib(LIBRARY *lib)
 			if (namesame(ni->proto->primname, "Metal-1-Substrate-Con") == 0)
 			{
 				undogeom(ni->geom, np);
-				ni->lowx -= 4 * mocmostech->deflambda;
-				ni->highx += 4 * mocmostech->deflambda;
-				ni->lowy -= 4 * mocmostech->deflambda;
-				ni->highy += 4 * mocmostech->deflambda;
+				ni->lowx -= 4 * lambda;
+				ni->highx += 4 * lambda;
+				ni->lowy -= 4 * lambda;
+				ni->highy += 4 * lambda;
 				linkgeom(ni->geom, np);
 				prims++;
 				continue;
@@ -288,7 +291,7 @@ void tech_convertmocmoslib(LIBRARY *lib)
 	/* if nothing was changed, quit now */
 	if (prims == 0)
 	{
-		ttyputmsg("No MOSIS CMOS objects found to alter");
+		ttyputmsg(_("No MOSIS CMOS objects found to alter"));
 		return;
 	}
 
@@ -298,11 +301,11 @@ void tech_convertmocmoslib(LIBRARY *lib)
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 		if (np->firstinst == NONODEINST) db_adjusttree(np);
 
-	ttyputmsg("%d S-active arcs, S-Active pins, Metal-1-S-Active", prims);
-	ttyputmsg("  contacts, S-Transistors, and Metal-1-Substrate");
-	ttyputmsg("  contacts from the MOSIS CMOS technology in this");
-	ttyputmsg("  library have been adjusted.");
-	ttyputmsg("NOW DO A -debug check-database TO ADJUST FACET SIZES");
+	ttyputmsg(_("%d S-active arcs, S-Active pins, Metal-1-S-Active"), prims);
+	ttyputmsg(_("  contacts, S-Transistors, and Metal-1-Substrate"));
+	ttyputmsg(_("  contacts from the MOSIS CMOS technology in this"));
+	ttyputmsg(_("  library have been adjusted."));
+	ttyputmsg(_("NOW DO A -debug check-database TO ADJUST FACET SIZES"));
 }
 
 void db_adjusttree(NODEPROTO *np)
@@ -356,7 +359,7 @@ void db_adjusttree(NODEPROTO *np)
  * diffusion and box 1 is the polysilicon.
  */
 void tech_shortenmostrans(NODEINST *ni, POLYGON *poly, TECH_POLYGON *lay, INTBIG lambda,
-	INTSML box, TECH_PORTS *portstruct)
+	INTBIG box, TECH_PORTS *portstruct)
 {
 	INTBIG lx, hx, ly, hy;
 	REGISTER INTBIG wid, swid, len, x1, y1, x2, y2, shrink1, shrink2, ang, end1, end2, dist,
@@ -529,7 +532,7 @@ INTBIG tech_getextendfactor(INTBIG wid, INTBIG extend)
 /*
  * routine to determine whether pin display should be supressed by counting
  * the number of arcs and seeing if there are one or two and also by seeing if
- * the node has exported ports (then draw it if there are three or more).
+ * the node has exports (then draw it if there are three or more).
  * Returns nonzero if the pin should be supressed.  If "ap" is NOARCPROTO, then
  * any arc can be connected.  Otherwise, only count the number of arcs with
  * that type.
@@ -552,15 +555,16 @@ INTSML tech_pinusecount(NODEINST *ni, ARCPROTO *ap)
  * setup the globals for the subsequent calls to "tech_moscutpoly".  The size
  * of a single cut is "cutsizex" by "cutsizey", the indentation from the edge
  * of the node is in "cutindent", and the separation between cuts is "cutsep",
- * all given in WHOLE fractions of lambda
+ * all given in WHOLE fractions of lambda.  "reasonable" is loaded with a
+ * smaller number of polygons to use when too many become prohibitive.
  */
-INTSML tech_moscutcount(NODEINST *ni, INTSML cutsizex, INTSML cutsizey, INTSML cutindent,
-	INTSML cutsep)
+INTBIG tech_moscutcount(NODEINST *ni, INTBIG cutsizex, INTBIG cutsizey, INTBIG cutindent,
+	INTBIG cutsep, INTBIG *reasonable)
 {
 	REGISTER INTBIG lambda, lx, hx, ly, hy;
 
 	/* get the lambda value */
-	lambda = ni->proto->tech->deflambda;
+	lambda = lambdaofnode(ni);
 	tech_moscutsizex = cutsizex;
 	tech_moscutsizey = cutsizey;
 	tech_moscutsep = cutsep;
@@ -580,6 +584,7 @@ INTSML tech_moscutcount(NODEINST *ni, INTSML cutsizex, INTSML cutsizey, INTSML c
 	if (tech_moscutsx <= 0) tech_moscutsx = 1;
 	if (tech_moscutsy <= 0) tech_moscutsy = 1;
 	tech_moscuttotal = tech_moscutsx * tech_moscutsy;
+	*reasonable = tech_moscuttotal;
 	if (tech_moscuttotal != 1)
 	{
 		/* prepare for the multiple contact cut locations */
@@ -589,6 +594,13 @@ INTSML tech_moscutcount(NODEINST *ni, INTSML cutsizex, INTSML cutsizey, INTSML c
 		tech_moscutbasey = (hy-ly-cutindent*2 - cutsizey*tech_moscutsy -
 			cutsep*(tech_moscutsy-1)) * WHOLE / lambda / 2 +
 				(tech_moscutly + cutindent) * WHOLE / lambda;
+		if (tech_moscutsx > 2 && tech_moscutsy > 2)
+		{
+			*reasonable = tech_moscutsx * 2 + (tech_moscutsy-2) * 2;
+			tech_moscuttopedge = tech_moscutsx*2;
+			tech_moscutleftedge = tech_moscutsx*2 + tech_moscutsy-2;
+			tech_moscutrightedge = tech_moscutsx*2 + (tech_moscutsy-2)*2;
+		}
 	}
 	return(tech_moscuttotal);
 }
@@ -601,13 +613,42 @@ INTSML tech_moscutcount(NODEINST *ni, INTSML cutsizex, INTSML cutsizey, INTSML c
  * This routine presumes that "tech_moscutcount" has already been called
  * so that the globals "tech_moscutlx", "tech_moscuthx", "tech_moscutly",
  * "tech_moscuthy", "tech_moscutbasex", "tech_moscutbasey", "tech_moscuttotal",
- * "tech_moscutsizex", and "tech_moscutsizey" are set.
+ * "tech_moscutsizex", "tech_moscutsizey", "tech_moscuttopedge",
+ * "tech_moscutleftedge", and "tech_moscutrightedge" are set.
  */
-void tech_moscutpoly(NODEINST *ni, INTSML cut, INTBIG descrip[])
+void tech_moscutpoly(NODEINST *ni, INTBIG cut, INTBIG descrip[])
 {
-	REGISTER INTBIG lambda;
+	REGISTER INTBIG lambda, cutx, cuty;
 
-	lambda = ni->proto->tech->deflambda;
+	lambda = lambdaofnode(ni);
+
+	if (tech_moscutsx > 2 && tech_moscutsy > 2)
+	{
+		/* rearrange cuts so that the initial ones go around the outside */
+		if (cut < tech_moscutsx)
+		{
+			/* bottom edge: it's ok as is */
+		} else if (cut < tech_moscuttopedge)
+		{
+			/* top edge: shift up */
+			cut += tech_moscutsx * (tech_moscutsy-2);
+		} else if (cut < tech_moscutleftedge)
+		{
+			/* left edge: rearrange */
+			cut = (cut - tech_moscuttopedge) * tech_moscutsx + tech_moscutsx;
+		} else if (cut < tech_moscutrightedge)
+		{
+			/* right edge: rearrange */
+			cut = (cut - tech_moscutleftedge) * tech_moscutsx + tech_moscutsx*2-1;
+		} else
+		{
+			/* center: rearrange and scale down */
+			cut = cut - tech_moscutrightedge;
+			cutx = cut % (tech_moscutsx-2);
+			cuty = cut / (tech_moscutsx-2);
+			cut = cuty * tech_moscutsx + cutx+tech_moscutsx+1;
+		}
+	}
 
 	if (tech_moscutsx == 1)
 	{
@@ -753,16 +794,16 @@ void tech_fillpoly(POLYGON *poly, TECH_POLYGON *lay, NODEINST *ni, INTBIG lambda
  * is returned.  Otherwise, one polygon will be drawn for every segment of
  * the serpent times every one of the "count" layers.
  */
-INTSML tech_inittrans(INTSML count, NODEINST *ni)
+INTBIG tech_inittrans(INTBIG count, NODEINST *ni)
 {
-	REGISTER INTSML total;
+	REGISTER INTBIG total;
 
 	/* see if the transistor has serpentine information */
 	tech_serpentvar = gettrace(ni);
 	if (tech_serpentvar == NOVARIABLE) return(count);
 
 	/* trace data is there: make sure there are enough points */
-	total = (INTSML)getlength(tech_serpentvar);
+	total = getlength(tech_serpentvar);
 	if (total < 4)
 	{
 		tech_serpentvar = NOVARIABLE;
@@ -800,9 +841,10 @@ INTSML tech_inittrans(INTSML count, NODEINST *ni)
  * segment that goes from bottom to top.
  */
 void tech_filltrans(POLYGON *poly, TECH_POLYGON **lay, TECH_SERPENT *laylist,
-	NODEINST *ni, INTBIG lambda, INTSML box, TECH_PORTS *portstruct)
+	NODEINST *ni, INTBIG lambda, INTBIG box, TECH_PORTS *portstruct)
 {
-	REGISTER INTSML thissg, next, angle, ang, total, segment, element, otherang;
+	REGISTER INTSML angle, ang;
+	REGISTER INTBIG thissg, next, total, segment, element, otherang;
 	REGISTER INTBIG sin, cos, xoff, yoff, thisxl, thisyl, thisxr, thisyr, lwid,
 		rwid, extend, scale, thisx, thisy, nextx, nexty, *list, nextxl, nextyl,
 		nextxr, nextyr, otherx, othery;
@@ -1039,7 +1081,7 @@ void tech_filltransport(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans
 	total /= 2;
 
 	/* see if nonstandard width is specified */
-	lambda = ni->proto->tech->deflambda;
+	lambda = lambdaofnode(ni);
 	defwid = lambda * defwid / WHOLE;
 	diffinset = lambda * diffinset / WHOLE;   diffextend = lambda * diffextend / WHOLE;
 	polyinset = lambda * polyinset / WHOLE;   polyextend = lambda * polyextend / WHOLE;
@@ -1152,7 +1194,7 @@ void tech_filltransport(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans
 /*
  * routine to compute the number of displayable polygons on nodeinst "ni"
  */
-INTSML tech_displayablenvars(NODEINST *ni)
+INTBIG tech_displayablenvars(NODEINST *ni)
 {
 	tech_numvar = ni->numvar;
 	tech_firstvar = ni->firstvar;
@@ -1168,13 +1210,13 @@ VARIABLE *tech_filldisplayablenvar(NODEINST *ni, POLYGON *poly)
 	tech_numvar = ni->numvar;
 	tech_firstvar = ni->firstvar;
 	return(tech_filldisplayableanyvar(poly, ni->lowx, ni->highx,
-		ni->lowy, ni->highy, (INTBIG)ni, VNODEINST, whattech(ni->proto)));
+		ni->lowy, ni->highy, (INTBIG)ni, VNODEINST, ni->proto->tech));
 }
 
 /*
  * routine to compute the number of displayable polygons on nodeproto "np"
  */
-INTSML tech_displayablefacetvars(NODEPROTO *np)
+INTBIG tech_displayablefacetvars(NODEPROTO *np)
 {
 	tech_numvar = np->numvar;
 	tech_firstvar = np->firstvar;
@@ -1190,7 +1232,7 @@ VARIABLE *tech_filldisplayablefacetvar(NODEPROTO *np, POLYGON *poly)
 	tech_numvar = np->numvar;
 	tech_firstvar = np->firstvar;
 	return(tech_filldisplayableanyvar(poly, np->lowx, np->highx,
-		np->lowy, np->highy, (INTBIG)np, VNODEPROTO, whattech(np)));
+		np->lowy, np->highy, (INTBIG)np, VNODEPROTO, np->tech));
 }
 
 /******************** PORTINST DESCRIPTION ********************/
@@ -1236,7 +1278,7 @@ void tech_fillportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	}
 
 	/* get the lambda value */
-	lambda = ni->proto->tech->deflambda;
+	lambda = lambdaofnode(ni);
 
 	/* get the high/low X/Y of the port area */
 	subrange(ni->lowx, ni->highx, portdata->lowxmul, portdata->lowxsum,
@@ -1279,7 +1321,7 @@ INTSML db_stillinport(ARCINST *ai, INTSML e, INTBIG x, INTBIG y)
 /*
  * routine to compute the number of displayable polygons on portproto "pp"
  */
-INTSML tech_displayableportvars(PORTPROTO *pp)
+INTBIG tech_displayableportvars(PORTPROTO *pp)
 {
 	tech_numvar = pp->numvar;
 	tech_firstvar = pp->firstvar;
@@ -1293,12 +1335,18 @@ INTSML tech_displayableportvars(PORTPROTO *pp)
 VARIABLE *tech_filldisplayableportvar(PORTPROTO *pp, POLYGON *poly)
 {
 	INTBIG x, y;
+	REGISTER INTSML saverot, savetrn;
+	REGISTER NODEINST *ni;
 
-	portposition(pp->subnodeinst, pp->subportproto, &x, &y);
+	ni = pp->subnodeinst;
+	saverot = ni->rotation;   savetrn = ni->transpose;
+	ni->rotation = ni->transpose = 0;
+	portposition(ni, pp->subportproto, &x, &y);
+	ni->rotation = saverot;   ni->transpose = savetrn;
 	tech_numvar = pp->numvar;
 	tech_firstvar = pp->firstvar;
 	return(tech_filldisplayableanyvar(poly, x, x,
-		y, y, (INTBIG)pp, VPORTPROTO, whattech(pp->parent)));
+		y, y, (INTBIG)pp, VPORTPROTO, pp->parent->tech));
 }
 
 /******************** ARCINST DESCRIPTION ********************/
@@ -1371,10 +1419,10 @@ INTSML tech_initcurvedarc(ARCINST *ai, INTSML total)
  * The arc prototype structure is in "arcprotos".  The routine returns zero
  * if successful, nonzero if the arc is not curved.
  */
-INTSML tech_curvedarcpiece(ARCINST *ai, INTSML box, POLYGON *poly, TECH_ARCS **arcprotos)
+INTSML tech_curvedarcpiece(ARCINST *ai, INTBIG box, POLYGON *poly, TECH_ARCS **arcprotos)
 {
-	REGISTER INTSML aindex, a;
-	REGISTER INTBIG sin, cos, innerradius, outerradius, wid;
+	REGISTER INTSML a;
+	REGISTER INTBIG aindex, sin, cos, innerradius, outerradius, wid;
 	REGISTER TECH_ARCLAY *thista;
 
 	if (tech_arcpieces == 0) return(1);
@@ -1419,7 +1467,7 @@ INTSML tech_curvedarcpiece(ARCINST *ai, INTSML box, POLYGON *poly, TECH_ARCS **a
 	poly->layer = thista->lay;
 
 	/* get the inner and outer radii of the arc */
-	wid = ai->width - thista->off * ai->proto->tech->deflambda / WHOLE;
+	wid = ai->width - thista->off * lambdaofarc(ai) / WHOLE;
 	outerradius = tech_radius + wid / 2;
 	innerradius = outerradius - wid;
 
@@ -1464,21 +1512,22 @@ void tech_makearrow(ARCINST *ai, POLYGON *poly)
 	poly->count = 2;
 	poly->xv[0] = x1;   poly->yv[0] = y1;
 	poly->xv[1] = x2;   poly->yv[1] = y2;
-	if ((ai->userbits&NOTEND1) == 0) tech_addheadarrow(poly, angle, x2, y2);
+	if ((ai->userbits&NOTEND1) == 0) tech_addheadarrow(poly, angle, x2, y2,
+		lambdaofarc(ai));
 }
 
 /*
  * helper routine to add an arrow head to the arc in "poly", given that
  * the arc runs from (x,y) and is at an angle of "angle" tenth-degrees
  */
-void tech_addheadarrow(POLYGON *poly, INTSML angle, INTBIG x, INTBIG y)
+void tech_addheadarrow(POLYGON *poly, INTSML angle, INTBIG x, INTBIG y, INTBIG lambda)
 {
 	REGISTER INTSML c;
 	REGISTER INTBIG dist;
 
 	c = poly->count;
 	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
-	dist = K1 * el_curtech->deflambda / WHOLE;
+	dist = K1 * lambda / WHOLE;
 	poly->xv[c] = x;    poly->yv[c] = y;   c++;
 	poly->xv[c] = x + mult(cosine((INTSML)((angle+1500) % 3600)), dist);
 	poly->yv[c] = y + mult(sine((INTSML)((angle+1500) % 3600)), dist);   c++;
@@ -1625,14 +1674,14 @@ void tech_makeendpointpoly(INTBIG len, INTBIG wid, INTBIG angle, INTBIG x1, INTB
  */
 void tech_resetnegated(ARCINST *ai)
 {
-	ttyputmsg("Warning: arc %s cannot be negated: state reset", describearcinst(ai));
+	ttyputmsg(_("Warning: arc %s cannot be negated: state reset"), describearcinst(ai));
 	ai->userbits &= ~ISNEGATED;
 }
 
 /*
  * routine to compute the number of displayable polygons on arcinst "ai"
  */
-INTSML tech_displayableavars(ARCINST *ai)
+INTBIG tech_displayableavars(ARCINST *ai)
 {
 	tech_numvar = ai->numvar;
 	tech_firstvar = ai->firstvar;
@@ -1657,9 +1706,9 @@ VARIABLE *tech_filldisplayableavar(ARCINST *ai, POLYGON *poly)
  * routine to compute the number of displayable polygons in the pair "tech_numvar/
  * tech_firstvar"
  */
-INTSML tech_displayableanyvars(void)
+INTBIG tech_displayableanyvars(void)
 {
-	REGISTER INTSML i, total;
+	REGISTER INTBIG i, total;
 	REGISTER VARIABLE *var;
 
 	tech_ndisplayindex = tech_ndisplaysubindex = total = 0;
@@ -1668,7 +1717,7 @@ INTSML tech_displayableanyvars(void)
 		var = &tech_firstvar[i];
 		if ((var->type&VDISPLAY) == 0) continue;
 		if ((var->type&VISARRAY) == 0) total++; else
-			total += (INTSML)getlength(var);
+			total += getlength(var);
 	}
 	return(total);
 }
@@ -1728,7 +1777,7 @@ VARIABLE *tech_filldisplayableanyvar(POLYGON *poly, INTBIG lx, INTBIG hx,
 			len = getlength(var);
 			if (tech_ndisplaysubindex < len)
 			{
-				whichindex = tech_ndisplaysubindex++;
+				whichindex = (INTSML)tech_ndisplaysubindex++;
 				poly->string = describevariable(var, whichindex, -1);
 				descript = var->textdescript;
 				if ((var->textdescript&VTPOSITION) == VTPOSBOXED)
