@@ -56,7 +56,7 @@ static char        dr_ymaxfile[132];
 INTSML dr_readshorterrors(INTBIG);
 void   dr_flatprint(NODEPROTO*, XARRAY);
 void   dr_transistor_hack(POLYGON*, NODEINST*);
-void   dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*);
+void   dr_flatdesc_poly(POLYGON*, INTBIG, XARRAY, TECHNOLOGY*, NODEPROTO*);
 void   dr_flatprop(ARCINST*, INTBIG);
 
 /*
@@ -70,23 +70,23 @@ INTSML dr_flatignore(char *facet)
 	np = getnodeproto(facet);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("No facet called %s", facet);
+		ttyputerr(_("No facet called %s"), facet);
 		return(1);
 	}
 	if (np->primindex != 0)
 	{
-		ttyputerr("Can only ignore facets, not primitives");
+		ttyputerr(_("Can only ignore facets, not primitives"));
 		return(1);
 	}
 	for(i=0; i<dr_nflat_ignored; i++) if (dr_flatignored[i] == np)
 		return(0);
 	if (dr_nflat_ignored == MAX_DRC_FLATIGNORE)
 	{
-		ttyputerr("Too many facets");
+		ttyputerr(_("Too many facets"));
 		return(1);
 	}
 	dr_flatignored[dr_nflat_ignored++] = np;
-	ttyputmsg("Facet %s will be ignored from flat DRC", describenodeproto(np));
+	ttyputmsg(_("Facet %s will be ignored from flat DRC"), describenodeproto(np));
 	return(0);
 }
 
@@ -101,24 +101,24 @@ INTSML dr_flatunignore(char *facet)
 	np = getnodeproto(facet);
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("No facet called %s", facet);
+		ttyputerr(_("No facet called %s"), facet);
 		return(1);
 	}
 	if (np->primindex != 0)
 	{
-		ttyputerr("Can only unignore facets, not primitives");
+		ttyputerr(_("Can only unignore facets, not primitives"));
 		return(1);
 	}
 	for(i=0; i<dr_nflat_ignored && dr_flatignored[i] != np; i++) ;
 	if (i == dr_nflat_ignored)
 	{
-		ttyputerr("Not being ignored");
+		ttyputerr(_("Not being ignored"));
 		return(1);
 	}
 	for(; i<dr_nflat_ignored; i++)
 		dr_flatignored[i-1] = dr_flatignored[i];
 	dr_nflat_ignored--;
-	ttyputmsg("Facet %s will be included in flat DRC", describenodeproto(np));
+	ttyputmsg(_("Facet %s will be included in flat DRC"), describenodeproto(np));
 	return(0);
 }
 
@@ -135,10 +135,10 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 
 	if (simnp == NONODEPROTO)
 	{
-		ttyputerr("No facet to flatten for DRC");
+		ttyputerr(_("No facet to flatten for DRC"));
 		return(1);
 	}
-	dr_maintech = whattech(simnp);
+	dr_maintech = simnp->tech;
 
 	/* create output file names */
 	(void)sprintf(dr_flatdrcfile, "%s", simnp->cell->cellname);
@@ -151,13 +151,13 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	(void)strcat(dr_ymaxfile, "_maxy.drc");
 
 	/* create the file */
-	dr_file = xcreate(dr_flatdrcfile, FILETYPETEXT, 0, 0);
+	dr_file = xcreate(dr_flatdrcfile, el_filetypetext, 0, 0);
 	if (dr_file == NULL)
 	{
-		ttyputerr("Cannot write %s", dr_flatdrcfile);
+		ttyputerr(_("Cannot write %s"), dr_flatdrcfile);
 		return(1);
 	}
-	ttyputmsg("Writing flattened %s circuit into '%s'...",
+	ttyputmsg(_("Writing flattened %s circuit into '%s'..."),
 		dr_maintech->techname, dr_flatdrcfile);
 
 	/* re-assign net-list values, starting at each port of the top facet */
@@ -192,30 +192,30 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	/* clean up the file */
 	xclose(dr_file);
 
-	if (stopping("DRC") != 0) return(0);
+	if (stopping(STOPREASONDRC)) return(0);
 
 	/* no point continuing if nothing to do */
 	if (dr_flat_boxcount == 0)
 	{
-		ttyputmsg("Zero boxes written");
-		ttyputmsg("DRC short detection complete");
+		ttyputmsg(_("Zero boxes written"));
+		ttyputmsg(_("DRC short detection complete"));
 		return(0);
 	}
 
 	/* setup communication with fast short finding program */
-	ttyputmsg("%ld boxes written, now attempting fast short detection...", dr_flat_boxcount);
+	ttyputmsg(_("%ld boxes written, now attempting fast short detection..."), dr_flat_boxcount);
 	(void)epipe(dr_fromshorts);
 	dr_process = efork();
 	if (dr_process == 1)
 	{
-		ttyputerr("Shortcheck cannot run on this machine");
+		ttyputerr(_("Shortcheck cannot run on this machine"));
 		return(0);
 	}
 	if (dr_process == 0)
 	{
 		save1 = channelreplacewithchannel(1, dr_fromshorts[1]);
 		save2 = channelreplacewithchannel(2, dr_fromshorts[1]);
-		(void)sprintf(p1, "%ld", el_curtech->deflambda);
+		(void)sprintf(p1, "%ld", el_curlib->lambda[el_curtech->techindex]);
 		(void)sprintf(p2, "%ld", dr_flat_boxcount);
 		if ((flatdrcloc = egetenv("FLATDRCLOC")) == NULL)
 			flatdrcloc = FLATDRCLOC;
@@ -227,7 +227,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 		eexec(flatdrcloc, execpars);
 		channelrestore(1, save1);
 		channelrestore(2, save2);
-		ttyputerr("Cannot run fast short detection");
+		ttyputerr(_("Cannot run fast short detection"));
 		exit(1);
 	}
 
@@ -243,13 +243,13 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	/* if this program ran correctly, stop now */
 	if (ret == 0)
 	{
-		ttyputmsg("DRC short detection complete");
+		ttyputmsg(_("DRC short detection complete"));
 		return(0);
 	}
 
 	/* setup for slow short detection */
-	ttyputmsg("Too many boxes: disk version must be run");
-	ttyputmsg("  Interim step: sorting by minimum Y into '%s'...", dr_yminfile);
+	ttyputmsg(_("Too many boxes: disk version must be run"));
+	ttyputmsg(_("  Interim step: sorting by minimum Y into '%s'..."), dr_yminfile);
 	if ((dr_process = efork()) == 0)
 	{
 		execpars[0] = SORTNAME;
@@ -260,11 +260,11 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 		execpars[5] = dr_flatdrcfile;
 		execpars[6] = 0;
 		eexec(SORTLOC, execpars);
-		ttyputerr("Cannot run sort");
+		ttyputerr(_("Cannot run sort"));
 		exit(1);
 	}
 	ewait(dr_process);
-	ttyputmsg("  Interim step: sorting by maximum Y into '%s'...", dr_ymaxfile);
+	ttyputmsg(_("  Interim step: sorting by maximum Y into '%s'..."), dr_ymaxfile);
 	if ((dr_process = efork()) == 0)
 	{
 		execpars[0] = SORTNAME;
@@ -275,18 +275,18 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 		execpars[5] = dr_flatdrcfile;
 		execpars[6] = 0;
 		eexec(SORTLOC, execpars);
-		ttyputerr("Cannot run sort");
+		ttyputerr(_("Cannot run sort"));
 		exit(1);
 	}
 	ewait(dr_process);
 
-	ttyputmsg("Now invoking slow short detection...");
+	ttyputmsg(_("Now invoking slow short detection..."));
 	(void)epipe(dr_fromshorts);
 	if ((dr_process = efork()) == 0)
 	{
 		save1 = channelreplacewithchannel(1, dr_fromshorts[1]);
 		save2 = channelreplacewithchannel(2, dr_fromshorts[1]);
-		(void)sprintf(p1, "%ld", el_curtech->deflambda);
+		(void)sprintf(p1, "%ld", el_curlib->lambda[el_curtech->techindex]);
 		if ((sflatdrcloc = egetenv("SFLATDRCLOC")) == NULL)
 			sflatdrcloc = SFLATDRCLOC;
 		execpars[0] = SFLATDRCNAME;
@@ -297,7 +297,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 		eexec(sflatdrcloc, execpars);
 		channelrestore(1, save1);
 		channelrestore(2, save2);
-		ttyputerr("Cannot run slow DRC");
+		ttyputerr(_("Cannot run slow DRC"));
 		exit(1);
 	}
 
@@ -310,7 +310,7 @@ INTSML dr_flatwrite(NODEPROTO *simnp)
 	eclose(dr_fromshorts[0]);
 	ekill(dr_process);
 	ewait(dr_process);
-	ttyputmsg("DRC short detection complete");
+	ttyputmsg(_("DRC short detection complete"));
 	return(0);
 }
 
@@ -319,7 +319,6 @@ INTSML dr_readshorterrors(INTBIG where)
 	REGISTER char *ptr, *layname;
 	REGISTER INTBIG i, errors, lx, hx, ly, hy;
 	char line[200], *err, layer[50];
-	extern AIDENTRY *us_aid;
 	INTBIG sx, sy, cx, cy;
 
 	/* read from the DRC and list on the status terminal */
@@ -327,7 +326,7 @@ INTSML dr_readshorterrors(INTBIG where)
 	ptr = line;
 	for(;;)
 	{
-		if (stopping("DRC") != 0) break;
+		if (stopping(STOPREASONDRC)) break;
 		i = eread(where, ptr, 1);
 		if (i != 1) break;
 		if (*ptr == '\n')
@@ -335,7 +334,7 @@ INTSML dr_readshorterrors(INTBIG where)
 			*ptr = 0;
 
 			/* special case to detect failure of fast short program */
-			if (strcmp(line, "Out of space") == 0) return(1);
+			if (strcmp(line, _("Out of space")) == 0) return(1);
 
 			if (line[0] == 'L')
 			{
@@ -351,7 +350,7 @@ INTSML dr_readshorterrors(INTBIG where)
 				lx = cx-sx/2;   hx = cx+sx/2;
 				ly = cy-sy/2;   hy = cy+sy/2;
 				layname = layername(dr_maintech, (INTSML)atoi(layer));
-				ttyputmsg("Error on %s layer from X(%s...%s) Y(%s...%s)",
+				ttyputmsg(_("Error on %s layer from X(%s...%s) Y(%s...%s)"),
 					layname, latoa(lx), latoa(hx), latoa(ly), latoa(hy));
 				(void)askaid(us_aid, "show-area", lx, hx, ly, hy, el_curwindowpart->curnodeproto);
 				flushscreen(); /* empty graphics buffer */
@@ -376,7 +375,7 @@ INTSML dr_readshorterrors(INTBIG where)
  */
 void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 {
-	REGISTER INTSML i;
+	REGISTER INTBIG i;
 	REGISTER ARCINST *ai;
 	REGISTER PORTPROTO *pp, *spp;
 	REGISTER PORTARCINST *pi;
@@ -384,9 +383,9 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 	REGISTER NODEINST *ni;
 	static POLYGON *poly = NOPOLYGON;
 	XARRAY subtrans, temptrans1, temptrans2;
-	INTSML n;
+	INTBIG n;
 
-	if (stopping("DRC") != 0) return;
+	if (stopping(STOPREASONDRC)) return;
 
 	/* see if this facet is to be ignored */
 	for(i = 0; i < dr_nflat_ignored; i++) if (facet == dr_flatignored[i]) return;
@@ -424,7 +423,7 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 		for(i = 0; i < n; i++)
 		{
 			shapearcpoly(ai, i, poly);
-			dr_flatdesc_poly(poly, ai->temp2, mytrans, ai->proto->tech);
+			dr_flatdesc_poly(poly, ai->temp2, mytrans, ai->proto->tech, facet);
 		}
 	}
 
@@ -435,7 +434,7 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 			pp->temp2 = 0;
 
-		/* set network numbers from arcs and exported ports */
+		/* set network numbers from arcs and exports */
 		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 		{
 			pp = pi->proto;
@@ -470,14 +469,14 @@ void dr_flatprint(NODEPROTO *facet, XARRAY mytrans)
 			if (ni->proto->tech == dr_maintech)
 			{
 				makerot(ni, subtrans);
-				n = nodeEpolys(ni);
+				n = nodeEpolys(ni, 0);
 				for(i = 0; i < n; i ++)
 				{
 					shapeEnodepoly(ni, i, poly);
 					if (poly->portproto == NOPORTPROTO) continue;
 					dr_transistor_hack(poly, ni);
 					xformpoly(poly, subtrans);
-					dr_flatdesc_poly(poly, poly->portproto->temp2, mytrans, ni->proto->tech);
+					dr_flatdesc_poly(poly, poly->portproto->temp2, mytrans, ni->proto->tech, facet);
 				}
 			}
 		} else
@@ -560,14 +559,14 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 		REGISTER TECH_SERPENT *st;
 		REGISTER TECH_POLYGON *lay;
 
-		lambda = ni->proto->tech->deflambda;
+		lambda = lambdaofnode(ni);
 		i = 0;
 		for (lay = &thistn->ele[i].basics; lay->portnum != portnum; lay = &thistn->ele[i].basics)
 			i++;
 		st = &thistn->ele[i];
 		active_overlap = st->lwidth + st->rwidth;
 		i=0; do lay = &thistn->ele[i++].basics; while (lay->portnum != 0);
-		gate_min_distance = (INTSML)drcmindistance(ni->proto->tech, lay->layernum, lay->layernum, 0);
+		gate_min_distance = (INTSML)drcmindistance(ni->proto->tech, ni->parent->cell->lib, lay->layernum, lay->layernum, 0);
 		if (active_overlap > gate_min_distance)
 		{
 			correction = ((active_overlap - gate_min_distance) / WHOLE) * lambda;
@@ -580,8 +579,7 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 					poly->yv[0] += correction;
 			} else
 			{
-				INTBIG lx, hx, ly, hy;
-				REGISTER INTSML centerx, centery, xwid, ywid;
+				INTBIG lx, hx, ly, hy, centerx, centery, xwid, ywid;
 				REGISTER INTBIG default_width = (active_overlap/WHOLE) * lambda;
 
 				/* I don't really know which polygons of the serpentine transistor
@@ -592,8 +590,8 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
 				centerx = (ni->lowx + ni->highx) / 2;
 				centery = (ni->lowy + ni->highy) / 2;
 				getbbox(poly, &lx, &hx, &ly, &hy);
-				xwid = (INTSML)(hx - lx);
-				ywid = (INTSML)(hy - ly);
+				xwid = hx - lx;
+				ywid = hy - ly;
 				for(i = 0; i < poly->count; i++)
 				{
 					if (xwid == default_width)
@@ -616,7 +614,7 @@ void dr_transistor_hack(POLYGON *poly, NODEINST *ni)
  * number is "net".  The polygon is transformed by "trans" and is from
  * technology "tech".
  */
-void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech)
+void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech, NODEPROTO *facet)
 {
 	INTBIG lx, hx, ly, hy, lxb, hxb, lyb, hyb;
 	REGISTER INTBIG xv, yv;
@@ -627,7 +625,7 @@ void dr_flatdesc_poly(POLYGON *poly, INTBIG net, XARRAY trans, TECHNOLOGY *tech)
 	if (*(((char **)tech->temp1)[poly->layer]) == 0) return;
 
 	/* ignore layers that have no design rules */
-	if (maxdrcsurround(tech, poly->layer) < 0) return;
+	if (maxdrcsurround(tech, facet->cell->lib, poly->layer) < 0) return;
 
 	xformpoly(poly, trans);
 	getbbox(poly, &lxb, &hxb, &lyb, &hyb);
