@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /*************************** FLAG BIT SETTINGS ****************************/
 
 #define	MARKN             040				/* NODEINST->userbits: nodeinst is marked */
@@ -222,6 +227,7 @@ extern POLYGON     *db_staticpolygons;
 #define	DBVARARRDIS    33					/* variable cannot be displayable array */
 #define	DBLASTECH      34					/* this is the last technology */
 #define	DBTECINUSE     35					/* technology is still in use */
+#define	DBNOSLIDING    36					/* sliding not allowed */
 
 #define	DBADDSTRINGTOINFSTR		(1<<16)
 #define	DBADDTECHNOLOGY			(2<<16)
@@ -277,10 +283,7 @@ extern POLYGON     *db_staticpolygons;
 extern INTBIG       db_lasterror;			/* last error message */
 extern INTSML       db_printerrors;			/* flag for printing internal errors */
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
+/*************************** PROTOTYPES ****************************/
 
 /* database prototypes */
 void         db_addportarcinst(NODEINST*, PORTARCINST*);
@@ -311,13 +314,14 @@ void         db_freevar(INTBIG, INTBIG);
 void         db_freevariablememory(void);
 void         db_freevars(VARIABLE**, INTSML*);
 CHANGEBATCH *db_getcurrentbatch(void);
-float        db_getcurrentscale(INTSML, INTSML);
-void         db_getinternalunitscale(INTBIG*, INTBIG*, INTSML, INTSML);
+float        db_getcurrentscale(INTBIG, INTBIG);
+void         db_getinternalunitscale(INTBIG*, INTBIG*, INTBIG, INTBIG);
 INTSML       db_getvarptr(INTBIG, INTBIG, VARIABLE***, INTSML**);
 void         db_initclusters(void);
 void         db_initdatabase(void);
 void         db_initializechanges(void);
 void         db_inittechcache(void);
+void         db_inittranslation(void);
 void         db_insertnodeproto(NODEPROTO*);
 void         db_killarcinst(ARCINST*);
 void         db_killnodeinst(NODEINST*);
@@ -339,8 +343,8 @@ void         db_retractnodeproto(NODEPROTO*);
 void         db_retractportproto(PORTPROTO*);
 void         db_retractwindowpart(WINDOWPART *w);
 void         db_rtnbbox(RTNODE*, INTSML, INTBIG*, INTBIG*, INTBIG*, INTBIG*);
-void         db_scaleonefacet(NODEPROTO*, INTBIG, INTBIG);
-void         db_scaletechnology(TECHNOLOGY*, INTBIG, INTBIG);
+void         db_scalearcinst(ARCINST *ai, INTBIG num, INTBIG denom);
+void         db_scalenodeinst(NODEINST *ni, INTBIG num, INTBIG denom);
 void         db_setchangefacet(NODEPROTO*);
 void         db_setcurrenttool(AIDENTRY*);
 INTSML       db_stillinport(ARCINST*, INTSML, INTBIG, INTBIG);
