@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 #include <setjmp.h>
 
 /* successive versions of the binary file have smaller numbers */
@@ -44,26 +49,30 @@
 
 /* I/O formats: */
 #define	FBINARY                  0		/* Binary */
-#define	FCIF                     1		/* CIF */
-#define	FDXF                     2		/* DXF format */
-#define	FEDIF                    3		/* Electronic Design Interchange Format */
-#define	FGDS                     4		/* Calma GDS-II format */
-#define	FHPGL                    5		/* HPGL format (plotting) */
-#define	FL                       6		/* L format (Silicon Compilers) */
-#define	FPOSTSCRIPT              7		/* PostScript (plotting) */
-#define	FPRINTEDPOSTSCRIPT       8		/* Printed PostScript (plotting) */
-#define	FQUICKDRAW               9		/* Quickdraw (plotting) */
-#define FSDF                    10		/* SDF */
-#define	FTEXT                   11		/* Text */
-#define	FVHDL                   12		/* VHDL */
-#define	FSUE                    13		/* SUE */
-#define	FLEF                    14		/* LEF (Library Exchange Format) */
-#define	FDEF                    15		/* DEF (Design Exchange Format) */
-#define	FSKILL                  16		/* SKILL (CADENCE command language) */
-#define	FEAGLE                  17		/* EAGLE (CadSoft) netlist */
-#define	FPADS                   18		/* PADS netlist */
+#define	FBINARYNOBACKUP          1		/* Binary without backup */
+#define	FCIF                     2		/* CIF */
+#define	FDXF                     3		/* DXF format */
+#define	FEDIF                    4		/* Electronic Design Interchange Format */
+#define	FGDS                     5		/* Calma GDS-II format */
+#define	FHPGL                    6		/* HPGL format (plotting) */
+#define	FL                       7		/* L format (Silicon Compilers) */
+#define	FPOSTSCRIPT              8		/* PostScript (plotting) */
+#define	FPRINTEDPOSTSCRIPT       9		/* Printed PostScript (plotting) */
+#define	FQUICKDRAW              10		/* Quickdraw (plotting) */
+#define FSDF                    11		/* SDF */
+#define	FTEXT                   12		/* Text */
+#define	FVHDL                   13		/* VHDL */
+#define	FSUE                    14		/* SUE */
+#define	FLEF                    15		/* LEF (Library Exchange Format) */
+#define	FDEF                    16		/* DEF (Design Exchange Format) */
+#define	FSKILL                  17		/* SKILL (CADENCE command language) */
+#define	FEAGLE                  18		/* EAGLE (CadSoft) netlist */
+#define	FPADS                   19		/* PADS netlist */
+#define	FECAD                   20		/* ECAD netlist */
 
 /* aid:inout.IO_state: */
+#define NUMIOSTATEBITWORDS       2		/* number of words for these bits */
+
 #define	CIFINSQUARE             01		/* bit set for CIF input to square wires */
 #define	CIFOUTEXACT             02		/* bit set for CIF output to mimic screen */
 #define	CIFOUTMERGE             04		/* bit set for CIF output to merge polygons */
@@ -89,16 +98,20 @@
 #define	CIFOUTNOTOPCALL  020000000		/* bit set for CIF output to not call top cell */
 #define	GDSINIGNOREUKN   040000000		/* bit set for GDS input to ignore unknown layers */
 #define DEFNOLOGICAL    0100000000		/* bit set to ignore DEF logical data */
+#define BINOUTBACKUP    0600000000		/* bits that determine binary output backups */
+#define BINOUTNOBACK    0000000000		/*   for no backup of binary output files */
+#define BINOUTONEBACK   0200000000		/*   for one backup of binary output files */
+#define BINOUTFULLBACK  0400000000		/*   for full backup of binary output files */
+#define CHECKATWRITE   01000000000		/* bit set for database check before write */
+#define PSCOLORSTIP    02000000000		/* bit set for stippled color PostScript */
+#define PSHIERARCHICAL 04000000000		/* bit set for hierarchical PostScript */
+#define	PLOTFOCUSDPY  010000000000		/* bit set to focus plot output on display */
+#define	SKILLNOHIER   020000000000		/* bit set to ignore subfacets in SKILL */
 
 #define	DEFAULTPSWIDTH         638		/* default PostScript page width (8.5" at 75dpi) */
 #define	DEFAULTPSHEIGHT        825		/* default PostScript page height (11.0" at 75dpi) */
 #define	DEFAULTPSMARGIN         56		/* default PostScript page height (0.75" at 75dpi) */
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* miscellaneous */
 extern FILE        *io_fileout;			/* channel for output */
 extern jmp_buf      io_filerror;		/* nonlocal jump when I/O fails */
@@ -108,7 +121,24 @@ extern INTBIG       io_postscriptfilename;/* key for "IO_postscript_filename" */
 extern INTBIG       io_postscriptfiledate;/* key for "IO_postscript_filedate" */
 extern INTBIG       io_postscriptepsscale;/* key for "IO_postscript_EPS_scale" */
 extern INTSML       io_verbose;			/* 0: silent  1:verbose  -1:display facets during input */
-extern AIDENTRY    *io_aid;				/* the I/O aid object */
+extern INTBIG       io_filetypeblib;	/* Binary library disk file descriptor */
+extern INTBIG       io_filetypecif;		/* CIF disk file descriptor */
+extern INTBIG       io_filetypedef;		/* DEF disk file descriptor */
+extern INTBIG       io_filetypedxf;		/* DXF disk file descriptor */
+extern INTBIG       io_filetypeeagle;	/* EAGLE netlist disk file descriptor */
+extern INTBIG       io_filetypeecad;	/* ECAD netlist disk file descriptor */
+extern INTBIG       io_filetypeedif;	/* EDIF disk file descriptor */
+extern INTBIG       io_filetypegds;		/* GDS disk file descriptor */
+extern INTBIG       io_filetypehpgl;	/* HPGL disk file descriptor */
+extern INTBIG       io_filetypel;		/* L disk file descriptor */
+extern INTBIG       io_filetypelef;		/* LEF disk file descriptor */
+extern INTBIG       io_filetypepads;	/* PADS netlist disk file descriptor */
+extern INTBIG       io_filetypeps;		/* PostScript disk file descriptor */
+extern INTBIG       io_filetypeskill;	/* SKILL commands disk file descriptor */
+extern INTBIG       io_filetypesdf;		/* SDF disk file descriptor */
+extern INTBIG       io_filetypesue;		/* SUE disk file descriptor */
+extern INTBIG       io_filetypetlib;	/* Text library disk file descriptor */
+extern INTBIG       io_filetypevhdl;	/* VHDL disk file descriptor */
 
 /* prototypes for tool interface */
 void io_init(INTBIG*, char*[], AIDENTRY*);
@@ -118,6 +148,8 @@ INTBIG io_request(char*, va_list);
 void io_slice(void);
 
 /* prototypes for intratool interface */
+INTBIG    *io_getstatebits(void);
+void       io_setstatebits(INTBIG *bits);
 PORTPROTO *io_convertoldportname(char *portname, NODEPROTO *np);
 void       io_fixnewlib(LIBRARY *lib, INTBIG statusitem);
 void       io_setoutputbloat(char *layer, INTBIG amount);
@@ -137,10 +169,11 @@ INTSML     io_readsdflibrary(LIBRARY *lib);
 INTSML     io_readsuelibrary(LIBRARY *lib);
 INTSML     io_readtextlibrary(LIBRARY *lib);
 INTSML     io_readvhdllibrary(LIBRARY *lib);
-INTSML     io_writebinlibrary(LIBRARY *lib);
+INTSML     io_writebinlibrary(LIBRARY *lib, INTSML nobackup);
 INTSML     io_writeciflibrary(LIBRARY *lib);
 INTSML     io_writedxflibrary(LIBRARY *lib);
 INTSML     io_writeeaglelibrary(LIBRARY *lib);
+INTSML     io_writeecadlibrary(LIBRARY *lib);
 INTSML     io_writeediflibrary(LIBRARY *lib);
 INTSML     io_writegdslibrary(LIBRARY *lib);
 INTSML     io_writehpgllibrary(LIBRARY *lib);
