@@ -28,11 +28,26 @@
  * info@staticfreesoft.com
  */
 
-extern INTBIG      net_use_port_nameskey;		/* key for "NET_use_port_names" */
-extern INTBIG      net_compare_hierarchykey;	/* key for "NET_compare_hierarchy" */
-extern INTBIG      net_unify_port_nameskey;		/* key for "NET_unify_port_names" */
-extern AIDENTRY   *net_aid;						/* the aid objects */
-extern INTSML      net_debug;					/* nonzero for debugging */
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
+extern INTBIG      net_ncc_optionskey;			/* key for "NET_ncc_options" */
+extern INTBIG      net_lastgoodncckey;			/* key for "NET_last_good_ncc" */
+
+/* the meaning of aid:network.NET_ncc_options */
+#define NCCHIERARCHICAL         01				/* set to expand hierarchy during NCC */
+#define NCCUSEPORTNAMES         02				/* set to use port names during NCC */
+#define NCCUNIFYPORTNAMES       04				/* set to unify port names during NCC */
+#define NCCVERBOSE             010				/* set to dump information during NCC */
+#define NCCIGNOREPWRGND        020				/* set to ignore power/ground during NCC */
+#define NCCRECURSE             040				/* set to do NCC recursively */
+#define NCCUSEPORTNAMESOVER   0100				/* set to override port names use for a facet */
+#define NCCUNIFYPORTNAMESOVER 0200				/* set to override port unification for a facet */
+#define NCCIGNOREPWRGNDOVER   0400				/* set to override P&G ignoring for a facet */
+#define NCCCHECKSIZE         01000				/* set to check component size during NCC */
+#define NCCCHECKSIZEOVER     02000				/* set to override check component size check for a facet */
 
 /*********************** EQUIVALENCE MODULES ***********************/
 
@@ -77,14 +92,16 @@ extern PCOMP *net_pcompfree;
 #define	NOPNET ((PNET *)-1)
 
 /* meaning of PNET->flags */
-#define	POWERNET    1				/* if net is power */
-#define	GROUNDNET   2				/* if net is ground */
-#define	EXPORTEDNET 4				/* if net is exported */
+#define	POWERNET      1				/* if net is power */
+#define	GROUNDNET     2				/* if net is ground */
+#define	EXPORTEDNET   4				/* if net is exported */
+#define	USEDNET     010				/* if net is used */
 
 typedef struct Ipnet
 {
 	INTSML         flags;			/* state bits */
 	PORTPROTO     *realport;		/* top-level port on this net (if any) */
+	NETWORK       *network;			/* real network that this references */
 	struct Ipnet  *nextpnet;		/* next in list */
 } PNET;
 extern PNET *net_pnetfree;
@@ -100,11 +117,6 @@ typedef struct Ipconn
 } PCONN;
 extern PCONN *net_pconnfree;
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for tool interface */
 void net_init(INTBIG*, char*[], AIDENTRY*);
 void net_done(void);
@@ -126,7 +138,7 @@ NETWORK *net_gethighlightednet(INTSML, INTSML);
 void     net_freeallpcomp(PCOMP*);
 void     net_freeallpnet(PNET*);
 PCOMP   *net_makepseudo(NODEPROTO*, INTSML*, INTSML*, INTSML*, INTSML*, PNET**,
-			INTSML, INTSML, INTSML);
+			INTSML, INTSML, INTSML, INTSML, INTSML);
 INTSML   net_equate(INTSML);
 INTSML   net_compare(void);
 INTSML   net_setfirst(void);
