@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /* the meaning of "ROUT_state" */
 #define STITCHMODE             07			/* type of stitching being done */
 #define NOSTITCH                0			/* no stitching */
@@ -82,11 +87,6 @@ extern INTBIG ro_mazeboundary;
 
 /****************************** ROUTINES ******************************/
 
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
-
 /* prototypes for tool interface */
 void ro_init(INTBIG*, char*[], AIDENTRY*);
 void ro_done(void);
@@ -113,6 +113,9 @@ void   ro_mazeroutecell(void);
 void   ro_mazerouteselected(void);
 void   ro_mimicstitch(INTSML forced);
 INTSML ro_river(NODEPROTO*);
+#if ROUTAIDSUN
+  void ro_par(void);
+#endif
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
