@@ -28,6 +28,11 @@
  * info@staticfreesoft.com
  */
 
+#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
+extern "C"
+{
+#endif
+
 /***********************************************************************
 	General Constants
 ------------------------------------------------------------------------
@@ -725,12 +730,9 @@ typedef struct tbuffer
 #define SC_ALS_FORMAT 1
 #define SC_SILOS_FORMAT 2
 
-extern AIDENTRY   *sc_aid;		/* the Silicon Compiler aid object */
-
-#if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
-extern "C"
-{
-#endif
+extern AIDENTRY   *sc_aid;				/* the Silicon Compiler aid object */
+extern INTBIG      sc_filetypescsim;	/* Silicon compiler simulation file descriptor */
+extern INTBIG      sc_filetypesctab;	/* Silicon compiler table file descriptor */
 
 /* prototypes for tool interface */
 void sc_init(INTBIG*, char*[], AIDENTRY*);
