@@ -35,8 +35,8 @@ extern "C"
 
 /* prototypes for technology routines */
 INTSML gem_initprocess(TECHNOLOGY *tech, INTSML pass);
-void gem_shapenodepoly(NODEINST*, INTSML, POLYGON*);
-void gem_shapearcpoly(ARCINST*, INTSML, POLYGON*);
+void gem_shapenodepoly(NODEINST*, INTBIG, POLYGON*);
+void gem_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
