@@ -35,8 +35,8 @@ extern "C"
 
 /* prototypes for technology routines */
 INTSML rcmos_initprocess(TECHNOLOGY*, INTSML);
-INTSML rcmos_arcpolys(ARCINST*);
-void rcmos_shapearcpoly(ARCINST*, INTSML, POLYGON*);
+INTBIG rcmos_arcpolys(ARCINST*);
+void rcmos_shapearcpoly(ARCINST*, INTBIG, POLYGON*);
 
 #if defined(__cplusplus) && !defined(ALLCPLUSPLUS)
 }
