@@ -72,9 +72,10 @@ void us_invertdragup(void);
 void us_createabegin(void);
 INTSML us_createadown(INTBIG, INTBIG);
 void us_createaup(void);
+void us_createajoinedobject(GEOM**, PORTPROTO**);
 void us_createinsinit(ARCINST*, NODEPROTO*);
 INTSML us_createinsdown(INTBIG, INTBIG);
-void us_multidraginit(INTBIG, INTBIG, GEOM**, NODEINST**, INTSML, INTSML, INTSML);
+void us_multidraginit(INTBIG, INTBIG, GEOM**, NODEINST**, INTBIG, INTSML);
 void us_multidragbegin(void);
 INTSML us_multidragdown(INTBIG, INTBIG);
 void us_multidragup(void);
