@@ -385,6 +385,7 @@ void   io_fixtechlayers(void);
 void   io_unifylambdavalues(LIBRARY *lib);
 void   io_libraryoptiondlog(void);
 void   io_getversion(LIBRARY *lib, INTBIG *major, INTBIG *minor, INTBIG *detail);
+void   parseelectricversion(char *version, INTBIG *major, INTBIG *minor, INTBIG *detail);
 
 INTBIG *io_getstatebits(void)
 {
@@ -1891,20 +1892,36 @@ void io_fixnewlib(LIBRARY *lib, INTBIG statusitem)
 /*
  * Routine to find the version of Electric that generated library "lib" and
  * parse it into three fields: the major version number, minor version, and
- * a detail version number.  The detail version number can be a letter.  So,
- * for example, version "6.02d" parses into major=6, minor=2, detail=4.
+ * a detail version number.
  */
 void io_getversion(LIBRARY *lib, INTBIG *major, INTBIG *minor, INTBIG *detail)
 {
 	REGISTER VARIABLE *var;
+
+	var = getval((INTBIG)lib, VLIBRARY, VSTRING, "LIB_former_version");
+	if (var == NOVARIABLE)
+	{
+		*major = *minor = *detail = 0;
+		return;
+	}
+	parseelectricversion((char *)var->addr, major, minor, detail);
+}
+
+/*
+ * Routine to parse the version of Electric in "version" into three fields:
+ * the major version number, minor version, and a detail version number.
+ * The detail version number can be a letter.  If it is omitted, it is
+ * assumed to be 999.  If it is a number, it is beyond 1000.  For example:
+ *    "6.02d"     major=6, minor=2, detail=4
+ *    "6.02"      major=6, minor=2, detail=999
+ *    "6.02.1"    major=6, minor=2, detail=1001
+ */
+void parseelectricversion(char *version, INTBIG *major, INTBIG *minor, INTBIG *detail)
+{
 	REGISTER char *pt;
 
-	*major = *minor = *detail = 0;
-	var = getval((INTBIG)lib, VLIBRARY, VSTRING, "LIB_former_version");
-	if (var == NOVARIABLE) return;
-	pt = (char *)var->addr;
-
 	/* parse the version fields */
+	pt = version;
 	*major = atoi(pt);
 	while (isdigit(*pt) != 0) pt++;
 	if (*pt++ != '.') return;
@@ -1913,12 +1930,15 @@ void io_getversion(LIBRARY *lib, INTBIG *major, INTBIG *minor, INTBIG *detail)
 	if (*pt == 0) { *detail = 999;   return; }
 	if (*pt == '.')
 	{
-		*detail = atoi(&pt[1]);
+		*detail = atoi(&pt[1]) + 1000;
 	} else
 	{
 		if (islower(*pt) != 0) *detail = *pt - 'a' + 1; else
 			if (isupper(*pt) != 0) *detail = *pt - 'A' + 1;
 	}
+#if 0
+	ttyputmsg("Version '%s' is numbered %ld.%ld.%ld", version, *major, *minor, *detail);
+#endif
 }
 
 /* Technology: Lambda Adjustment */
