@@ -48,12 +48,14 @@ void io_putout(void*, INTSML);
 void io_putoutbig(void*);
 void io_putstring(char*);
 
-INTSML io_writebinlibrary(LIBRARY *lib)
+INTSML io_writebinlibrary(LIBRARY *lib, INTSML nobackup)
 {
 	INTBIG i, a, n, p, magic, aacount, techcount, nodepprotoindex,
 		portpprotoindex, arcprotoindex, nodeprotoindex, nodeindex,
-		portprotoindex, arcindex, geomindex, curnodeproto, cellindex;
-	INTSML save;
+		portprotoindex, arcindex, geomindex, curnodeproto, cellindex,
+		*curstate;
+	UINTBIG olddate;
+	INTSML save, year, month, mday, hour, minute, second;
 	REGISTER NODEPROTO *np;
 	REGISTER ARCPROTO *ap;
 	REGISTER PORTPROTO *pp;
@@ -62,7 +64,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 	REGISTER LIBRARY *olib;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER char *rename, *name, *istrue, *dotaddr, *msg;
-	char *truename, *arg[3];
+	char *truename, *arg[3], datesuffix[30];
 	unsigned char wordsize;
 	REGISTER CELL *c;
 	REGISTER VIEW *v;
@@ -81,34 +83,75 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 	if (dotaddr != 0) *dotaddr = '.';
 	if (i != 0)
 	{
-		ttyputerr("No memory! saving to 'PANIC'");
-		name = "PANIC";
+		ttyputerr(_("No memory! saving to 'PANIC'"));
+		name = _("PANIC");
 	} else name = returninfstr();
 
+	curstate = io_getstatebits();
+	if ((curstate[0]&CHECKATWRITE) != 0)
+	{
+		ttyputmsg(_("Checking all libraries..."));
+		us_checkdatabase(0);
+	}
+	if (nobackup != 0) curstate[0] &= ~(BINOUTBACKUP|CHECKATWRITE);
+
 	rename = 0;
-	if ((lib->userbits&READFROMDISK) == 0) msg = "Library File"; else
+	if ((lib->userbits&READFROMDISK) == 0) msg = _("Library File"); else
 	{
 		msg = 0;
 
 		/* if the file already exists, rename it first */
 		if (fileexistence(name) == 1)
-			rename = (char *)emalloc((strlen(name)+8), el_tempcluster);
+			rename = (char *)emalloc((strlen(name)+15), el_tempcluster);
 		if (rename != 0)
 		{
-			(void)strcpy(rename, name);
-			(void)strcat(rename, ".XXXXXX");
-			emaketemp(rename);
-			if (erename(name, rename) != 0)
+			switch (curstate[0]&BINOUTBACKUP)
 			{
-				efree(rename);
-				rename = 0;
+				case BINOUTNOBACK:
+					(void)strcpy(rename, name);
+					(void)strcat(rename, ".XXXXXX");
+					emaketemp(rename);
+					if (erename(name, rename) != 0)
+					{
+						efree(rename);
+						rename = 0;
+					}
+					break;
+				case BINOUTONEBACK:
+					(void)strcpy(rename, name);
+					(void)strcat(rename, "~");
+					if (fileexistence(rename) == 1) (void)eunlink(rename);
+					(void)erename(name, rename);
+					efree(rename);
+					rename = 0;
+					break;
+				case BINOUTFULLBACK:
+					olddate = filedate(name);
+					parsetime(olddate, &year, &month, &mday, &hour, &minute, &second);
+					for(i=0; i<1000; i++)
+					{
+						if (i == 0) sprintf(datesuffix, "-%d-%d-%d", year, month+1, mday); else
+							sprintf(datesuffix, "-%d-%d-%d--%d", year, month+1, mday, i);
+						(void)strcpy(rename, name);
+						rename[strlen(rename)-5] = 0;
+						(void)strcat(rename, datesuffix);
+						(void)strcat(rename, ".elib");
+						if (fileexistence(rename) == 0) break;
+					}
+					erename(name, rename);
+					efree(rename);
+					rename = 0;
+					break;
 			}
 		}
 	}
-	io_fileout = xcreate(name, FILETYPEBLIB, msg, &truename);
+
+	/* create the new library file */
+	io_fileout = xcreate(name, io_filetypeblib, msg, &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
+		if (rename != 0) efree(rename);
 		return(1);
 	}
 
@@ -124,10 +167,14 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 
 	if (setjmp(io_filerror))
 	{
-		ttyputerr("Error writing %s", name);
+		ttyputerr(_("Error writing %s"), name);
 		xclose(io_fileout);
 		io_cleanup();
-		if (rename != 0) ttyputmsg("Old binary file saved in %s", rename);
+		if (rename != 0)
+		{
+			ttyputmsg(_("Old binary file saved in %s"), rename);
+			efree(rename);
+		}
 		return(1);
 	}
 
@@ -228,10 +275,10 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 
 	if (io_verbose > 0)
 	{
-		ttyputmsg("Writing %ld aids, %ld technologies", aacount, techcount);
-		ttyputmsg("        %ld prim nodes, %ld prim ports, %ld arc protos",
+		ttyputmsg(_("Writing %ld aids, %ld technologies"), aacount, techcount);
+		ttyputmsg(_("        %ld prim nodes, %ld prim ports, %ld arc protos"),
 			nodepprotoindex, portpprotoindex, arcprotoindex);
-		ttyputmsg("        %ld cells %ld facets, %ld ports, %ld nodes, %ld arcs",
+		ttyputmsg(_("        %ld cells %ld facets, %ld ports, %ld nodes, %ld arcs"),
 			cellindex, nodeprotoindex, portprotoindex, nodeindex, arcindex);
 	}
 
@@ -276,7 +323,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 		io_putoutbig(&n);
 		for(p = 0, pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto) p++;
 		io_putoutbig(&p);
-		if (io_verbose > 0) ttyputmsg("Facet %s has %ld arcs, %ld nodes, %ld ports",
+		if (io_verbose > 0) ttyputmsg(_("Facet %s has %ld arcs, %ld nodes, %ld ports"),
 			describenodeproto(np), a, n, p);
 	}
 
@@ -378,7 +425,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 	/* write all of the cell names in this library */
 	for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
 	{
-		if (stopping("Binary output") != 0) longjmp(io_filerror, 1);
+		if (stopping(STOPREASONBINARY)) longjmp(io_filerror, 1);
 
 		/* write the cell name */
 		io_putstring(c->cellname);
@@ -386,7 +433,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 		/* write variable information */
 		io_writevariables(c->firstvar, c->numvar);
 
-		if (io_verbose > 0) ttyputmsg("Wrote cell %s", c->cellname);
+		if (io_verbose > 0) ttyputmsg(_("Wrote cell %s"), c->cellname);
 	}
 
 	/* write all of the cell names in external libraries */
@@ -410,7 +457,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 	/* write all of the facets in this library */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		if (stopping("Binary output") != 0) longjmp(io_filerror, 1);
+		if (stopping(STOPREASONBINARY)) longjmp(io_filerror, 1);
 		io_writenodeproto(np, 1);
 	}
 
@@ -428,7 +475,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 	/* write all of the arcs and nodes in this library */
 	for(np = lib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
-		if (stopping("Binary output") != 0) longjmp(io_filerror, 1);
+		if (stopping(STOPREASONBINARY)) longjmp(io_filerror, 1);
 		a = n = 0;
 		for(ai = np->firstarcinst; ai != NOARCINST; ai = ai->nextarcinst)
 		{
@@ -440,7 +487,7 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 			io_writenodeinst(ni);
 			n++;
 		}
-		if (io_verbose > 0) ttyputmsg("Wrote %ld arcs and %ld nodes in facet %s",
+		if (io_verbose > 0) ttyputmsg(_("Wrote %ld arcs and %ld nodes in facet %s"),
 			a, n, describenodeproto(np));
 	}
 
@@ -453,12 +500,12 @@ INTSML io_writebinlibrary(LIBRARY *lib)
 	/* if the file was renamed, kill the backup copy */
 	if (rename != 0)
 	{
-		if (eunlink(rename) < 0) ttyputerr("Cannot delete backup file %s", rename);
+		if (eunlink(rename) < 0) ttyputerr(_("Cannot delete backup file %s"), rename);
 		efree(rename);
 	}
 
-	ttyputmsg("%s written (%ld %s)", name, nodeprotoindex,
-		makeplural("facet", nodeprotoindex));
+	ttyputmsg(_("%s written (%ld %s)"), name, nodeprotoindex,
+		makeplural(_("facet"), nodeprotoindex));
 	lib->userbits = (lib->userbits & ~(LIBCHANGEDMAJOR | LIBCHANGEDMINOR)) | READFROMDISK;
 	return(0);
 }
@@ -550,7 +597,7 @@ void io_writenodeproto(NODEPROTO *np, INTSML thislib)
 		io_writevariables(np->firstvar, np->numvar);
 	}
 
-	if (io_verbose > 0) ttyputmsg("Wrote facet %s", describenodeproto(np));
+	if (io_verbose > 0) ttyputmsg(_("Wrote facet %s"), describenodeproto(np));
 }
 
 void io_writenodeinst(NODEINST *ni)
@@ -593,12 +640,12 @@ void io_writenodeinst(NODEINST *ni)
 		io_writevariables(pi->firstvar, pi->numvar);
 	}
 
-	/* count the exported ports */
+	/* count the exports */
 	i = 0;
 	for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst) i++;
 	io_putoutbig(&i);
 
-	/* write the exported ports */
+	/* write the exports */
 	for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 	{
 		io_putoutbig(&pe->exportproto->temp1);
@@ -661,8 +708,8 @@ void io_writenamespace(void)
 	io_namesave = (char *)emalloc((el_numnames*2), el_tempcluster);
 	if (io_namesave == 0)
 	{
-		ttyputerr("No memory! destroying internal variables to save file");
-		ttyputerr("Saved file is good, memory NOT: quit when save finishes!");
+		ttyputerr(_("No memory! destroying internal variables to save file"));
+		ttyputerr(_("Saved file is good, memory NOT: quit when save finishes!"));
 		for(i=0; i<el_numnames; i++) *((INTSML *)el_namespace[i]) = i;
 	} else for(i=0; i<el_numnames; i++)
 	{
@@ -859,7 +906,7 @@ void io_putout(void *data, INTSML size)
 
 	if (size == 0)
 	{
-		ttyputmsg("Warning: null length data item; database may be bad");
+		ttyputmsg(_("Warning: null length data item; database may be bad"));
 		return;
 	}
 	ret = xfwrite((char *)data, size, 1, io_fileout);
