@@ -47,7 +47,7 @@ static UINTBIG    io_check_sum;					/* for CRC checksum */
 static UINTBIG    io_cifcrctab[256];			/* for CRC checksum */
 static INTSML     io_cif_resolution;			/* for resolution tests */
 static INTBIG     io_cif_polypoints;			/* for points on a polygon tests */
-static INTBIG     io_cifoutputstate;			/* current output state */
+static INTBIG    *io_cifoutputstate;			/* current output state */
 static INTBIG     io_cifoutoffx;				/* offset for current facet - for highlight */
 static INTBIG     io_cifoutoffy;				/* offset for current facet - for highlight */
 static NODEPROTO *io_cifoutcurnp;				/* node proto of facet being written */
@@ -124,7 +124,6 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	REGISTER TECHNOLOGY *tech;
 	REGISTER LIBRARY *olib;
 	REGISTER UINTBIG bytesread, i, j;
-	extern AIDENTRY *us_aid;
 	static UINTBIG crcrow[8] = {0x04C11DB7, 0x09823B6E, 0x130476DC, 0x2608EDB8,
 		0x4C11DB70, 0x9823B6E0, 0x34867077, 0x690CE0EE};
 	extern DIALOG us_progressdialog;
@@ -132,26 +131,24 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	/* create the proper disk file for the CIF */
 	if (lib->curnodeproto == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate CIF output");
+		ttyputerr(_("Must be editing a facet to generate CIF output"));
 		return(1);
 	}
 	(void)strcpy(file, lib->curnodeproto->cell->cellname);
 	if (strcmp(&file[strlen(file)-4],".cif") != 0) (void)strcat(file, ".cif");
 	name = truepath(file);
-	io_fileout = xcreate(name, FILETYPECIF, "CIF File", &truename);
+	io_fileout = xcreate(name, io_filetypecif, _("CIF File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
 	/* get current output state */
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) io_cifoutputstate = 0; else
-		io_cifoutputstate = var->addr;
+	io_cifoutputstate = io_getstatebits();
 
 	/* get form of output */
-	if ((io_cifoutputstate&CIFOUTNOTCEN) != 0) io_zero_offset = 1; else
+	if ((io_cifoutputstate[0]&CIFOUTNOTCEN) != 0) io_zero_offset = 1; else
 		io_zero_offset = 0;
 
 	/* get cif resolution */
@@ -169,7 +166,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 
 	/* initialize cif merging facility if needed */
 #ifndef FULLPOLYMERGE
-	if ((io_cifoutputstate&CIFOUTMERGE) != 0) mrginit();
+	if ((io_cifoutputstate[0]&CIFOUTMERGE) != 0) mrginit();
 #endif
 
 	/* initialize the CRC checksum accumulation */
@@ -194,7 +191,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 			tech->temp1 = var->addr;
 			if (getlength(var) != tech->layercount)
 			{
-				ttyputerr("Warning: CIF layer information is bad for technology %s.  Use 'CIF Options' to fix it",
+				ttyputerr(_("Warning: CIF layer information is bad for technology %s.  Use 'CIF Options' to fix it"),
 					tech->techname);
 				tech->temp1 = 0;
 			}
@@ -204,7 +201,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 		tech->temp2 = (var == NOVARIABLE ? 0 : var->addr);
 
 		/* if ignoring DRC mask layer, delete Generic technology layer names */
-		if (tech == gen_tech && (io_cifoutputstate&CIFOUTADDDRC) == 0) tech->temp1 = 0;
+		if (tech == gen_tech && (io_cifoutputstate[0]&CIFOUTADDDRC) == 0) tech->temp1 = 0;
 	}
 
 	/* figure out how many facets will be written */
@@ -216,7 +213,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	io_cifoutjobsize = io_cifoutfacetnumber;
 	if (DiaInitDialog(&us_progressdialog) != 0) return(1);
 	DiaPercent(1, 0);
-	DiaSetText(2, "Writing CIF...");
+	DiaSetText(2, _("Writing CIF..."));
 
 	/* write the CIF */
 	io_cifoutfacetnumber = 0;
@@ -228,7 +225,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 	io_cifwritefacet(lib->curnodeproto, 0);
 
 	/* clean up */
-	if ((io_cifoutputstate&CIFOUTNOTOPCALL) == 0)
+	if ((io_cifoutputstate[0]&CIFOUTNOTOPCALL) == 0)
 		io_cifprintf("C %d;\n", io_cifbase);
 	io_cifprintf("E\n");
 	xclose(io_fileout);
@@ -236,16 +233,16 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 
 #ifndef FULLPOLYMERGE
 	/* if doing polygon output */
-	if ((io_cifoutputstate&CIFOUTMERGE) != 0) mrgterm();
+	if ((io_cifoutputstate[0]&CIFOUTMERGE) != 0) mrgterm();
 #endif
 
 	/* tell the user that the file is written */
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 
 	if (io_cif_resolution != 0 && io_reserr_count != 0)
 	{
-		ttyputerr("WARNING: Highlighted %d resolution %s", io_reserr_count,
-			makeplural("error", io_reserr_count));
+		ttyputerr(_("WARNING: Highlighted %d resolution %s"), io_reserr_count,
+			makeplural(_("error"), io_reserr_count));
 	}
 
 	/* complete the checksum accumulation */
@@ -263,7 +260,7 @@ INTSML io_writeciflibrary(LIBRARY *lib)
 		bytesread >>= 8;
 	}
 	io_check_sum = ~io_check_sum & 0xFFFFFFFF;
-	ttyputmsg("(MOSIS CRC: %lu %ld)", io_check_sum, io_nchar);
+	ttyputmsg(_("(MOSIS CRC: %lu %ld)"), io_check_sum, io_nchar);
 
 	return(0);
 }
@@ -275,7 +272,7 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	REGISTER NODEPROTO *subnt, *bodysubnt, *onp;
 	REGISTER PORTPROTO *pp, *subpp;
 	REGISTER PORTARCINST *pi;
-	REGISTER INTSML i, j, sorted, total, validport;
+	REGISTER INTBIG i, j, sorted, total, validport;
 	REGISTER char *rname, *nname;
 	REGISTER INTBIG offx, offy, fun;
 	REGISTER LAYERREQ *req, *lastreq, *nextreq;
@@ -290,12 +287,11 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	if (fake == 0)
 	{
 		/* stop if requested */
-		if (stopping("CIF Output") != 0) return;
+		if (stopping(STOPREASONCIF)) return;
 
 		/* show progress */
 		(void)initinfstr();
-		(void)addstringtoinfstr("Writing ");
-		(void)addstringtoinfstr(describenodeproto(np));
+		(void)formatinfstr(_("Writing %s"), describenodeproto(np));
 		DiaSetText(2, returninfstr());
 		DiaPercent(1, io_cifoutfacetnumber * 100 / io_cifoutjobsize);
 	}
@@ -305,7 +301,7 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	{
 		subnt = subni->proto;
 		if (subnt->primindex != 0) continue;
-		if ((subni->userbits & NEXPAND) == 0 && (io_cifoutputstate&CIFOUTEXACT) != 0) continue;
+		if ((subni->userbits & NEXPAND) == 0 && (io_cifoutputstate[0]&CIFOUTEXACT) != 0) continue;
 
 		/* convert body facets to contents facets */
 		onp = contentsview(subnt);
@@ -337,7 +333,7 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 	io_cifprintf("9 %s;\n", np->cell->cellname);
 
 	io_cifoutcurlayer[0] = 0;
-	if ((io_cifoutputstate&CIFOUTMERGE) == 0)
+	if ((io_cifoutputstate[0]&CIFOUTMERGE) == 0)
 	{
 		/* no polygon merging: sort by layer */
 
@@ -353,7 +349,7 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 			if ((subni->userbits&WIPED) != 0) continue;
 			subnt = subni->proto;
 			if (subnt->primindex == 0) continue;
-			i = nodepolys(subni);
+			i = nodepolys(subni, 0);
 			for(j=0; j<i; j++)
 			{
 				shapenodepoly(subni, j, poly);
@@ -414,11 +410,12 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 				if (subnt->tech != req->tech) continue;
 				i = subni->rotation;
 				if (subni->transpose != 0) i = (i + 900) % 3600;
-				rx = ((cosine(i)>>14) * 100) >> 16;   ry = ((sine(i)>>14) * 100) >> 16;
+				rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
+				ry = ((sine((INTSML)i)>>14) * 100) >> 16;
 				makerot(subni, trans);
 
 				/* write a primitive nodeinst */
-				i = nodepolys(subni);
+				i = nodepolys(subni, 0);
 				for(j=0; j<i; j++)
 				{
 					shapenodepoly(subni, j, poly);
@@ -458,11 +455,12 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 			if (subnt->primindex == 0) continue;
 			i = subni->rotation;
 			if (subni->transpose != 0) i = (i + 900) % 3600;
-			rx = ((cosine(i)>>14) * 100) >> 16;   ry = ((sine(i)>>14) * 100) >> 16;
+			rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
+			ry = ((sine((INTSML)i)>>14) * 100) >> 16;
 			makerot(subni, trans);
 
 			/* write a primitive nodeinst */
-			i = nodepolys(subni);
+			i = nodepolys(subni, 0);
 			for(j=0; j<i; j++)
 			{
 				shapenodepoly(subni, j, poly);
@@ -497,9 +495,10 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 		if (subnt->primindex != 0) continue;
 		i = subni->rotation;
 		if (subni->transpose != 0) i = (i + 900) % 3600;
-		rx = ((cosine(i)>>14) * 100) >> 16;   ry = ((sine(i)>>14) * 100) >> 16;
+		rx = ((cosine((INTSML)i)>>14) * 100) >> 16;
+		ry = ((sine((INTSML)i)>>14) * 100) >> 16;
 		makerot(subni, trans);
-		if ((subni->userbits&NEXPAND) != 0 || (io_cifoutputstate&CIFOUTEXACT) == 0)
+		if ((subni->userbits&NEXPAND) != 0 || (io_cifoutputstate[0]&CIFOUTEXACT) == 0)
 		{
 			/* write a call to a facet */
 			if (io_zero_offset != 0)
@@ -551,11 +550,11 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 			/* resolution problem with call */
 			if (io_cif_resolution != 0)
 			{
-				if (io_zero_offset != 0) /* Why not use xpos and ypos here ?*/
+				if (io_zero_offset != 0) /* Why not use xpos and ypos here? */
 				{
 					if ((xpos%io_cif_resolution) != 0 || (ypos%io_cif_resolution) != 0)
 					{
-						io_cifprintf("(Call to symbol %ld does not resolve to grid);\n",
+						io_cifprintf(_("(Call to symbol %ld does not resolve to grid);\n"),
 							subnt->temp1);
 						io_reserr_count++;
 					}
@@ -564,7 +563,7 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 					if ((((subni->lowx+subni->highx)/2-offx)%io_cif_resolution) != 0 ||
 						(((subni->lowy+subni->highy)/2-offy)%io_cif_resolution) != 0)
 					{
-						io_cifprintf("(Call to symbol %ld does not resolve to grid);\n",
+						io_cifprintf(_("(Call to symbol %ld does not resolve to grid);\n"),
 							subnt->temp1);
 						io_reserr_count++;
 					}
@@ -613,7 +612,7 @@ void io_cifwritefacet(NODEPROTO *np, INTSML fake)
 
 		/* find valid layers on this node that surround the port */
 		validport = 0;
-		total = nodepolys(subni);
+		total = nodepolys(subni, 0);
 		for(i=0; i<total; i++)
 		{
 			shapenodepoly(subni, i, poly);
@@ -712,7 +711,7 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 
 		default:
 #ifdef FULLPOLYMERGE
-			if ((io_cifoutputstate&CIFOUTMERGE) != 0)
+			if ((io_cifoutputstate[0]&CIFOUTMERGE) != 0)
 			{
 				xformpoly(poly, trans);
 				for(k=0; k<poly->count; k++)
@@ -731,7 +730,7 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 				if (xh == xl || yh == yl) return;
 
 #ifndef FULLPOLYMERGE
-				if ((io_cifoutputstate&CIFOUTMERGE) != 0)
+				if ((io_cifoutputstate[0]&CIFOUTMERGE) != 0)
 				{
 					/* do polygon format output */
 					xform((xl+xh)/2, (yl+yh)/2, &xpos, &ypos, trans);
@@ -774,8 +773,8 @@ void io_outputcifpoly(TECHNOLOGY *tech, POLYGON *poly, INTBIG rx, INTBIG ry,
 				xformpoly(poly, trans);
 				if (bloat != 0)
 				{
-					ttyputmsg("Warning: complex CIF polygon cannot be bloated");
-					io_cifprintf("(NEXT POLYGON CANNOT BE BLOATED);\n");
+					ttyputmsg(_("Warning: complex CIF polygon cannot be bloated"));
+					io_cifprintf(_("(NEXT POLYGON CANNOT BE BLOATED);\n"));
 				}
 				if (poly->count == 1)
 					io_cifprintf(" 0V %ld %ld %ld %ld;\n", io_cif_outscale(poly->xv[0]-offx),
@@ -886,7 +885,6 @@ void io_cifprintf(char *msg, ...)
 void io_cifreserror(GEOM *pos, INTBIG length, INTBIG width, INTBIG xc, INTBIG yc)
 {
 	INTBIG left, right, top, bot;
-	extern AIDENTRY *us_aid;
 
 	left = xc - (length/2);
 	right = xc + (length/2);
@@ -926,7 +924,7 @@ void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 	/* check the number of points on the polygon */
 	if (count > io_cif_polypoints)
-		ttyputerr("WARNING: Polygon has too many points (%d)", count);
+		ttyputerr(_("WARNING: Polygon has too many points (%d)"), count);
 
 	/* search for any resolution errors on this polygon */
 	/* highlight any edges that don't resolve */
@@ -956,6 +954,21 @@ void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 	for(i=0; i<count; i++)
 	{
+#if 0
+		/* skip points that are colinear */
+		if (i > 0 && i < count-1)
+		{
+			float w, p;
+			w = (float)(xbuf[i+1] - xbuf[i-1]) / (float)(ybuf[i+1] - ybuf[i-1]);
+			p = (float)(xbuf[i] - xbuf[i-1]) / (float)(ybuf[i] - ybuf[i-1]);
+			if (w == p)
+			{
+				ttyputmsg("Collinear points that pass through (%ld,%ld)",
+					io_cif_outscale(xbuf[i]), io_cif_outscale(ybuf[i]));
+			}
+		}
+#endif
+
 		(void)sprintf(prbuf, " %ld %ld", io_cif_outscale(xbuf[i]),
 			io_cif_outscale(ybuf[i]));
 		prlen = strlen(prbuf); /* get length of coord. pair */
@@ -994,14 +1007,14 @@ void io_cif_write_polygon(INTSML layer, TECHNOLOGY *tech, INTBIG *xbuf, INTBIG *
 
 void io_cif_show_reserror(INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
 {
-	extern AIDENTRY *us_aid;
 	REGISTER NODEPROTO *np;
 
 	/* show resolution error if it is in the current window */
 	np = getcurfacet();
 	if (np == io_cifoutcurnp)
 		(void)askaid(us_aid, "show-line", x1, y1, x2, y2, np); else
-			ttyputmsg("Resolution error in subfacet %s", describenodeproto(io_cifoutcurnp));
+			ttyputmsg(_("Resolution error in subfacet %s"),
+				describenodeproto(io_cifoutcurnp));
 }
 
 INTBIG io_cif_outscale(INTBIG value)
@@ -1056,19 +1069,19 @@ void io_freelayerreq(LAYERREQ *req)
 /* CIF Options */
 DIALOGITEM io_cifoptionsdialogitems[] =
 {
- /*  1 */ {0, {168,380,192,452}, BUTTON, "OK"},
- /*  2 */ {0, {168,240,192,312}, BUTTON, "Cancel"},
+ /*  1 */ {0, {168,380,192,452}, BUTTON, N_("OK")},
+ /*  2 */ {0, {168,240,192,312}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {8,8,192,223}, SCROLL, ""},
- /*  4 */ {0, {8,232,24,312}, MESSAGE, "CIF Layer:"},
+ /*  4 */ {0, {8,232,24,312}, MESSAGE, N_("CIF Layer:")},
  /*  5 */ {0, {8,316,24,454}, EDITTEXT, ""},
- /*  6 */ {0, {32,232,48,454}, CHECK, "Output Mimics Display"},
- /*  7 */ {0, {56,232,72,454}, CHECK, "Output Merges Boxes"},
- /*  8 */ {0, {104,232,120,454}, CHECK, "Input Squares Wires"},
- /*  9 */ {0, {80,232,96,454}, CHECK, "Output Instantiates Top Level"},
- /* 10 */ {0, {128,232,144,376}, MESSAGE, "Output resolution:"},
+ /*  6 */ {0, {32,232,48,454}, CHECK, N_("Output Mimics Display")},
+ /*  7 */ {0, {56,232,72,454}, CHECK, N_("Output Merges Boxes")},
+ /*  8 */ {0, {104,232,120,454}, CHECK, N_("Input Squares Wires")},
+ /*  9 */ {0, {80,232,96,454}, CHECK, N_("Output Instantiates Top Level")},
+ /* 10 */ {0, {128,232,144,376}, MESSAGE, N_("Output resolution:")},
  /* 11 */ {0, {128,380,144,454}, EDITTEXT, ""}
 };
-DIALOG io_cifoptionsdialog = {{50,75,251,538}, "CIF Options", 11, io_cifoptionsdialogitems};
+DIALOG io_cifoptionsdialog = {{50,75,251,538}, N_("CIF Options"), 0, 11, io_cifoptionsdialogitems};
 
 /*
  * special case for the "CIF Options" dialog
@@ -1082,8 +1095,8 @@ DIALOG io_cifoptionsdialog = {{50,75,251,538}, "CIF Options", 11, io_cifoptionsd
  */
 void io_cifoptionsdlog(void)
 {
-	INTBIG i, itemHit;
-	REGISTER INTBIG curstate;
+	INTBIG newstate[NUMIOSTATEBITWORDS];
+	REGISTER INTBIG *curstate, oldresolution, i, itemHit, nameschanged;
 	REGISTER char **layernames, *pt;
 	REGISTER VARIABLE *var, *cifvar;
 
@@ -1107,17 +1120,18 @@ void io_cifoptionsdlog(void)
 	}
 	DiaSelectLine(3, 0);
 	DiaSetText(5, layernames[0]);
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) curstate = 0; else curstate = var->addr;
-	if ((curstate&CIFOUTEXACT) != 0) DiaSetControl(6, 1);
-	if ((curstate&CIFOUTMERGE) != 0) DiaSetControl(7, 1);
-	if ((curstate&CIFINSQUARE) != 0) DiaSetControl(8, 1);
-	if ((curstate&CIFOUTNOTOPCALL) == 0) DiaSetControl(9, 1);
+	curstate = io_getstatebits();
+	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
+	if ((curstate[0]&CIFOUTEXACT) != 0) DiaSetControl(6, 1);
+	if ((curstate[0]&CIFOUTMERGE) != 0) DiaSetControl(7, 1);
+	if ((curstate[0]&CIFINSQUARE) != 0) DiaSetControl(8, 1);
+	if ((curstate[0]&CIFOUTNOTOPCALL) == 0) DiaSetControl(9, 1);
 	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VINTEGER, "IO_cif_resolution");
-	if (var == NOVARIABLE) i = 0; else i = var->addr;
-	DiaSetText(11, latoa(i));
+	if (var == NOVARIABLE) oldresolution = 0; else oldresolution = var->addr;
+	DiaSetText(11, latoa(oldresolution));
 
 	/* loop until done */
+	nameschanged = 0;
 	for(;;)
 	{
 		itemHit = DiaNextHit();
@@ -1137,6 +1151,8 @@ void io_cifoptionsdlog(void)
 		{
 			i = DiaGetCurLine(3);
 			pt = DiaGetText(5);
+			if (strcmp(pt, layernames[i]) == 0) continue;
+			nameschanged++;
 			(void)reallocstring(&layernames[i], pt, el_tempcluster);
 			(void)initinfstr();
 			(void)addstringtoinfstr(layername(el_curtech, (INTSML)i));
@@ -1150,21 +1166,23 @@ void io_cifoptionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(6) != 0) curstate |= CIFOUTEXACT; else
-			curstate &= ~CIFOUTEXACT;
-		if (DiaGetControl(7) != 0) curstate |= CIFOUTMERGE; else
-			curstate &= ~CIFOUTMERGE;
-		if (DiaGetControl(8) != 0) curstate |= CIFINSQUARE; else
-			curstate &= ~CIFINSQUARE;
-		if (DiaGetControl(9) == 0) curstate |= CIFOUTNOTOPCALL; else
-			curstate &= ~CIFOUTNOTOPCALL;
-		(void)setvalkey((INTBIG)io_aid, VAID, io_state,
-			curstate, VINTEGER);
-		setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_cif_layer_names",
-			(INTBIG)layernames, VSTRING|VISARRAY|
-				(el_curtech->layercount<<VLENGTHSH));
+		if (DiaGetControl(6) != 0) newstate[0] |= CIFOUTEXACT; else
+			newstate[0] &= ~CIFOUTEXACT;
+		if (DiaGetControl(7) != 0) newstate[0] |= CIFOUTMERGE; else
+			newstate[0] &= ~CIFOUTMERGE;
+		if (DiaGetControl(8) != 0) newstate[0] |= CIFINSQUARE; else
+			newstate[0] &= ~CIFINSQUARE;
+		if (DiaGetControl(9) == 0) newstate[0] |= CIFOUTNOTOPCALL; else
+			newstate[0] &= ~CIFOUTNOTOPCALL;
+		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
+		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
+		if (nameschanged != 0)
+			setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_cif_layer_names",
+				(INTBIG)layernames, VSTRING|VISARRAY|
+					(el_curtech->layercount<<VLENGTHSH));
 		i = atola(DiaGetText(11));
-		setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_cif_resolution", i, VINTEGER);
+		if (i != oldresolution)
+			setval((INTBIG)el_curtech, VTECHNOLOGY, "IO_cif_resolution", i, VINTEGER);
 	}
 	for(i=0; i<el_curtech->layercount; i++) efree(layernames[i]);
 	efree((char *)layernames);
