@@ -52,7 +52,7 @@
 #define MAXLINE 2500
 
 static COMCOMP iodefop = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
-	INPUTOPT, " \t", "DEF options", 0};
+	INPUTOPT, " \t", M_("DEF options"), 0};
 
 INTBIG  io_deffilesize;
 INTBIG  io_deflineno;
@@ -110,10 +110,10 @@ INTSML io_readdeflibrary(LIBRARY *lib)
 	extern DIALOG us_progressdialog;
 
 	/* open the file */
-	fp = xopen(lib->libfile, FILETYPEDEF, "", &filename);
+	fp = xopen(lib->libfile, io_filetypedef, "", &filename);
 	if (fp == NULL)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 	strcpy(io_deffilename, filename);
@@ -126,7 +126,7 @@ INTSML io_readdeflibrary(LIBRARY *lib)
 		return(1);
 	}
 	DiaPercent(1, 0);
-	DiaSetText(2, "Reading DEF file...");
+	DiaSetText(2, _("Reading DEF file..."));
 	io_deflineno = 0;
 	io_deflinepos = 0;
 	io_defline[0] = 0;
@@ -139,8 +139,8 @@ INTSML io_readdeflibrary(LIBRARY *lib)
 	/* clean up */
 	DiaDoneDialog();
 	xclose(fp);
-	if (ret == 0) ttyputmsg("DEF file %s is read", lib->libfile); else
-		ttyputmsg("Error reading DEF file %s", lib->libfile);
+	if (ret == 0) ttyputmsg(_("DEF file %s is read"), lib->libfile); else
+		ttyputmsg(_("Error reading DEF file %s"), lib->libfile);
 	return(0);
 }
 
@@ -150,13 +150,11 @@ INTSML io_readdeflibrary(LIBRARY *lib)
 INTSML io_defreadfile(FILE *f, LIBRARY *lib)
 {
 	REGISTER char *key, *cellname;
-	REGISTER INTBIG options;
+	REGISTER INTBIG *options;
 	char curkey[200];
 	REGISTER NODEPROTO *facet;
-	REGISTER VARIABLE *var;
 
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) options = 0; else options = var->addr;
+	options = io_getstatebits();
 
 	for(;;)
 	{
@@ -175,15 +173,15 @@ INTSML io_defreadfile(FILE *f, LIBRARY *lib)
 		}
 		if (namesame(key, "DESIGN") == 0)
 		{
-			cellname = io_defmustgetkeyword(f, "DESIGN");
+			cellname = io_defmustgetkeyword(f, _("DESIGN"));
 			if (cellname == 0) return(1);
 			facet = newnodeproto(cellname, lib);
 			if (facet == NONODEPROTO)
 			{
-				io_definerror("Cannot create facet '%s'", cellname);
+				io_definerror(_("Cannot create facet '%s'"), cellname);
 				return(1);
 			}
-			if (io_defignoretosemicolon(f, "DESIGN") != 0) return(1);
+			if (io_defignoretosemicolon(f, _("DESIGN")) != 0) return(1);
 			continue;
 		}
 
@@ -219,13 +217,13 @@ INTSML io_defreadfile(FILE *f, LIBRARY *lib)
 
 		if (namesame(key, "SPECIALNETS") == 0)
 		{
-			if (io_defreadnets(f, facet, 1, options) != 0) return(1);
+			if (io_defreadnets(f, facet, 1, options[0]) != 0) return(1);
 			continue;
 		}
 
 		if (namesame(key, "NETS") == 0)
 		{
-			if (io_defreadnets(f, facet, 0, options) != 0) return(1);
+			if (io_defreadnets(f, facet, 0, options[0]) != 0) return(1);
 			continue;
 		}
 
@@ -245,11 +243,11 @@ INTSML io_defreadvias(FILE *f, NODEPROTO *facet)
 	REGISTER char *key;
 	char curkey[200];
 
-	if (io_defignoretosemicolon(f, "VIAS") != 0) return(1);
+	if (io_defignoretosemicolon(f, _("VIAS")) != 0) return(1);
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "VIAs");
+		key = io_defmustgetkeyword(f, _("VIAs"));
 		if (key == 0) return(1);
 		if (namesame(key, "-") == 0)
 		{
@@ -279,7 +277,7 @@ INTSML io_defreadvia(FILE *f)
 	REGISTER VIADEF *vd;
 
 	/* get the via name */
-	key = io_defmustgetkeyword(f, "VIA");
+	key = io_defmustgetkeyword(f, _("VIA"));
 	if (key == 0) return(1);
 
 	/* create a new via definition */
@@ -295,21 +293,21 @@ INTSML io_defreadvia(FILE *f)
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "VIA");
+		key = io_defmustgetkeyword(f, _("VIA"));
 		if (key == 0) return(1);
 		if (namesame(key, "+") == 0)
 		{
-			key = io_defmustgetkeyword(f, "VIA");
+			key = io_defmustgetkeyword(f, _("VIA"));
 			if (key == 0) return(1);
 			if (namesame(key, "RECT") == 0)
 			{
 				/* handle definition of a via rectangle */
-				key = io_defmustgetkeyword(f, "VIA");
+				key = io_defmustgetkeyword(f, _("VIA"));
 				if (key == 0) return(1);
 				io_defgetlayernodes(key, &pin, &pure, &ap);
 				if (pure == NONODEPROTO)
 				{
-					io_definerror("Layer %s not in current technology", key);
+					io_definerror(_("Layer %s not in current technology"), key);
 					pure = NONODEPROTO;
 				}
 				if (namesamen(key, "VIA", 3) == 0)
@@ -352,11 +350,11 @@ INTSML io_defreadcomponents(FILE *f, NODEPROTO *facet)
 	REGISTER char *key;
 	char curkey[200];
 
-	if (io_defignoretosemicolon(f, "COMPONENTS") != 0) return(1);
+	if (io_defignoretosemicolon(f, _("COMPONENTS")) != 0) return(1);
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "COMPONENTs");
+		key = io_defmustgetkeyword(f, _("COMPONENTs"));
 		if (key == 0) return(1);
 		if (namesame(key, "-") == 0)
 		{
@@ -389,10 +387,10 @@ INTSML io_defreadcomponent(FILE *f, NODEPROTO *facet)
 	char compname[200], modelname[200];
 
 	/* get the component name and model name */
-	key = io_defmustgetkeyword(f, "COMPONENT");
+	key = io_defmustgetkeyword(f, _("COMPONENT"));
 	if (key == 0) return(1);
 	strcpy(compname, key);
-	key = io_defmustgetkeyword(f, "COMPONENT");
+	key = io_defmustgetkeyword(f, _("COMPONENT"));
 	if (key == 0) return(1);
 	strcpy(modelname, key);
 
@@ -400,18 +398,18 @@ INTSML io_defreadcomponent(FILE *f, NODEPROTO *facet)
 	np = io_defgetnodeproto(modelname, facet->cell->lib);
 	if (np == NONODEPROTO)
 	{
-		io_definerror("Unknown cell (%s)", modelname);
+		io_definerror(_("Unknown cell (%s)"), modelname);
 		return(1);
 	}
 
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "COMPONENT");
+		key = io_defmustgetkeyword(f, _("COMPONENT"));
 		if (key == 0) return(1);
 		if (namesame(key, "+") == 0)
 		{
-			key = io_defmustgetkeyword(f, "COMPONENT");
+			key = io_defmustgetkeyword(f, _("COMPONENT"));
 			if (key == 0) return(1);
 			if (namesame(key, "PLACED") == 0)
 			{
@@ -427,7 +425,7 @@ INTSML io_defreadcomponent(FILE *f, NODEPROTO *facet)
 				ni = newnodeinst(np, lx, hx, ly, hy, trans, rot, facet);
 				if (ni == NONODEINST)
 				{
-					io_definerror("Unable to create node");
+					io_definerror(_("Unable to create node"));
 					return(1);
 				}
 				endobjectchange((INTBIG)ni, VNODEINST);
@@ -451,11 +449,11 @@ INTSML io_defreadpins(FILE *f, NODEPROTO *facet)
 	REGISTER char *key;
 	char curkey[200];
 
-	if (io_defignoretosemicolon(f, "PINS") != 0) return(1);
+	if (io_defignoretosemicolon(f, _("PINS")) != 0) return(1);
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "PINs");
+		key = io_defmustgetkeyword(f, _("PINs"));
 		if (key == 0) return(1);
 		if (namesame(key, "-") == 0)
 		{
@@ -490,7 +488,7 @@ INTSML io_defreadpin(FILE *f, NODEPROTO *facet)
 	XARRAY trans;
 
 	/* get the pin name */
-	key = io_defmustgetkeyword(f, "PIN");
+	key = io_defmustgetkeyword(f, _("PIN"));
 	if (key == 0) return(1);
 	strcpy(pinname, key);
 	portbits = havecoord = 0;
@@ -499,35 +497,35 @@ INTSML io_defreadpin(FILE *f, NODEPROTO *facet)
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "PIN");
+		key = io_defmustgetkeyword(f, _("PIN"));
 		if (key == 0) return(1);
 		if (namesame(key, "+") == 0)
 		{
-			key = io_defmustgetkeyword(f, "PIN");
+			key = io_defmustgetkeyword(f, _("PIN"));
 			if (key == 0) return(1);
 			if (namesame(key, "NET") == 0)
 			{
-				key = io_defmustgetkeyword(f, "net name");
+				key = io_defmustgetkeyword(f, _("net name"));
 				if (key == 0) return(1);
 				continue;
 			}
 			if (namesame(key, "DIRECTION") == 0)
 			{
-				key = io_defmustgetkeyword(f, "DIRECTION");
+				key = io_defmustgetkeyword(f, _("DIRECTION"));
 				if (key == 0) return(1);
 				if (namesame(key, "INPUT") == 0) portbits = INPORT; else
 				if (namesame(key, "OUTPUT") == 0) portbits = OUTPORT; else
 				if (namesame(key, "INOUT") == 0) portbits = BIDIRPORT; else
 				if (namesame(key, "FEEDTHRU") == 0) portbits = BIDIRPORT; else
 				{
-					io_definerror("Unknown direction (%s)", key);
+					io_definerror(_("Unknown direction (%s)"), key);
 					return(1);
 				}
 				continue;
 			}
 			if (namesame(key, "USE") == 0)
 			{
-				key = io_defmustgetkeyword(f, "USE");
+				key = io_defmustgetkeyword(f, _("USE"));
 				if (key == 0) return(1);
 				if (namesame(key, "SIGNAL") == 0) portbits = portbits; else
 				if (namesame(key, "POWER") == 0) portbits = PWRPORT; else
@@ -536,19 +534,19 @@ INTSML io_defreadpin(FILE *f, NODEPROTO *facet)
 				if (namesame(key, "TIEOFF") == 0) portbits = portbits; else
 				if (namesame(key, "ANALOG") == 0) portbits = portbits; else
 				{
-					io_definerror("Unknown usage (%s)", key);
+					io_definerror(_("Unknown usage (%s)"), key);
 					return(1);
 				}
 				continue;
 			}
 			if (namesame(key, "LAYER") == 0)
 			{
-				key = io_defmustgetkeyword(f, "LAYER");
+				key = io_defmustgetkeyword(f, _("LAYER"));
 				if (key == 0) return(1);
 				io_defgetlayernodes(key, &np, &pure, &ap);
 				if (np == NONODEPROTO)
 				{
-					io_definerror("Unknown layer (%s)", key);
+					io_definerror(_("Unknown layer (%s)"), key);
 					return(1);
 				}
 				if (io_defreadcoordinate(f, &lx, &ly) != 0) return(1);
@@ -587,14 +585,14 @@ INTSML io_defreadpin(FILE *f, NODEPROTO *facet)
 		ni = newnodeinst(np, lx, hx, ly, hy, trn, rot, facet);
 		if (ni == NONODEINST)
 		{
-			io_definerror("Unable to create pin");
+			io_definerror(_("Unable to create pin"));
 			return(1);
 		}
 		endobjectchange((INTBIG)ni, VNODEINST);
 		pp = newportproto(facet, ni, np->firstportproto, pinname);
 		if (pp == NOPORTPROTO)
 		{
-			io_definerror("Unable to create pin name");
+			io_definerror(_("Unable to create pin name"));
 			return(1);
 		}
 		pp->userbits = (pp->userbits & ~STATEBITS) | portbits;
@@ -612,7 +610,7 @@ INTSML io_defreadnets(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "NETs");
+		key = io_defmustgetkeyword(f, _("NETs"));
 		if (key == 0) return(1);
 		if (namesame(key, "-") == 0)
 		{
@@ -652,12 +650,12 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 	REGISTER VIADEF *vd;
 
 	/* get the net name */
-	key = io_defmustgetkeyword(f, "NET");
+	key = io_defmustgetkeyword(f, _("NET"));
 	if (key == 0) return(1);
 	strcpy(netname, key);
 
 	/* get the next keyword */
-	key = io_defmustgetkeyword(f, "NET");
+	key = io_defmustgetkeyword(f, _("NET"));
 	if (key == 0) return(1);
 
 	/* scan the "net" statement */
@@ -673,30 +671,30 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 		if (namesame(key, "+") == 0)
 		{
 			wantpinpairs = 0;
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 
 			if (namesame(key, "USE") == 0)
 			{
 				/* ignore "USE" keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 			} else if (namesame(key, "ROUTED") == 0)
 			{
 				/* handle "ROUTED" keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 				io_defgetlayernodes(key, &pin, &pure, &routap);
 				if (pin == NONODEPROTO)
 				{
-					io_definerror("Unknown layer (%s)", key);
+					io_definerror(_("Unknown layer (%s)"), key);
 					return(1);
 				}
 				pathstart = 1;
 				if (special != 0)
 				{
 					/* specialnets have width here */
-					key = io_defmustgetkeyword(f, "NET");
+					key = io_defmustgetkeyword(f, _("NET"));
 					if (key == 0) return(1);
 					v = (float)atof(key) / (float)io_defunits;
 					specialwidth = scalefromdispunit(v, DISPUNITMIC);
@@ -704,23 +702,23 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			} else if (namesame(key, "FIXED") == 0)
 			{
 				/* handle "FIXED" keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 				io_defgetlayernodes(key, &pin, &pure, &routap);
 				if (pin == NONODEPROTO)
 				{
-					io_definerror("Unknown layer (%s)", key);
+					io_definerror(_("Unknown layer (%s)"), key);
 					return(1);
 				}
 				pathstart = 1;
 			} else
 			{
-				io_definerror("Cannot handle '%s' nets", key);
+				io_definerror(_("Cannot handle '%s' nets"), key);
 				return(1);
 			}
 
 			/* get next keyword */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 			continue;
 		}
@@ -731,23 +729,23 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			/* it must be the "(" of a pin pair */
 			if (namesame(key, "(") != 0)
 			{
-				io_definerror("Expected '(' of pin pair");
+				io_definerror(_("Expected '(' of pin pair"));
 				return(1);
 			}
 
 			/* get the pin names */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 			if (namesame(key, "PIN") == 0)
 			{
-				/* find the exported port */
-				key = io_defmustgetkeyword(f, "NET");
+				/* find the export */
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 				for(pp = facet->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					if (namesame(key, pp->protoname) == 0) break;
 				if (pp == NOPORTPROTO)
 				{
-					io_definerror("Unknown pin '%s'", key);
+					io_definerror(_("Unknown pin '%s'"), key);
 					return(1);
 				}
 				ni = pp->subnodeinst;
@@ -762,28 +760,29 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 				}
 				if (ni == NONODEINST)
 				{
-					io_definerror("Unknown component '%s'", key);
+					io_definerror(_("Unknown component '%s'"), key);
 					return(1);
 				}
 
 				/* get the port name */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 				for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 					if (namesame(key, pp->protoname) == 0) break;
 				if (pp == NOPORTPROTO)
 				{
-					io_definerror("Unknown port '%s' on component '%s'", key, (char *)var->addr);
+					io_definerror(_("Unknown port '%s' on component '%s'"),
+						key, (char *)var->addr);
 					return(1);
 				}
 			}
 
 			/* get the close parentheses */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 			if (namesame(key, ")") != 0)
 			{
-				io_definerror("Expected ')' of pin pair");
+				io_definerror(_("Expected ')' of pin pair"));
 				return(1);
 			}
 
@@ -796,7 +795,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 					ni, pp, fx, fy, lastlogni, lastlogpp, tx, ty, facet);
 				if (ai == NOARCINST)
 				{
-					io_definerror("Could not create unrouted arc");
+					io_definerror(_("Could not create unrouted arc"));
 					return(1);
 				}
 				endobjectchange((INTBIG)ai, VARCINST);
@@ -805,7 +804,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			lastlogpp = pp;
 
 			/* get the next keyword and continue parsing */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 			continue;
 		}
@@ -813,16 +812,16 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 		/* handle "new" start of coordinate trace */
 		if (namesame(key, "NEW") == 0)
 		{
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 			io_defgetlayernodes(key, &pin, &pure, &routap);
 			if (pin == NONODEPROTO)
 			{
-				io_definerror("Unknown layer (%s)", key);
+				io_definerror(_("Unknown layer (%s)"), key);
 				return(1);
 			}
 			pathstart = 1;
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 			if (special != 0)
 			{
@@ -831,7 +830,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 				specialwidth = scalefromdispunit(v, DISPUNITMIC);
 
 				/* get the next keyword */
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 			}
 			continue;
@@ -839,12 +838,12 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 
 		if (namesame(key, "(") != 0)
 		{
-			io_definerror("Expected '(' of coordinate pair");
+			io_definerror(_("Expected '(' of coordinate pair"));
 			return(1);
 		}
 
 		/* get the X coordinate */
-		key = io_defmustgetkeyword(f, "NET");
+		key = io_defmustgetkeyword(f, _("NET"));
 		if (key == 0) return(1);
 		if (strcmp(key, "*") == 0) curx = lastx; else
 		{
@@ -853,7 +852,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 		}
 
 		/* get the Y coordinate */
-		key = io_defmustgetkeyword(f, "NET");
+		key = io_defmustgetkeyword(f, _("NET"));
 		if (key == 0) return(1);
 		if (strcmp(key, "*") == 0) cury = lasty; else
 		{
@@ -862,16 +861,16 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 		}
 
 		/* get the close parentheses */
-		key = io_defmustgetkeyword(f, "NET");
+		key = io_defmustgetkeyword(f, _("NET"));
 		if (key == 0) return(1);
 		if (namesame(key, ")") != 0)
 		{
-			io_definerror("Expected ')' of coordinate pair");
+			io_definerror(_("Expected ')' of coordinate pair"));
 			return(1);
 		}
 
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "NET");
+		key = io_defmustgetkeyword(f, _("NET"));
 		if (key == 0) return(1);
 
 		/* see if it is a via name */
@@ -890,7 +889,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			/* ignore the next keyword if a via name is coming */
 			if (vd != NOVIADEF)
 			{
-				key = io_defmustgetkeyword(f, "NET");
+				key = io_defmustgetkeyword(f, _("NET"));
 				if (key == 0) return(1);
 			}
 			continue;
@@ -906,7 +905,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			ly = cury - sy / 2;   hy = ly + sy;
 			if (vd->via == NONODEPROTO)
 			{
-				io_definerror("Cannot to create via");
+				io_definerror(_("Cannot to create via"));
 				return(1);
 			}
 
@@ -922,7 +921,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			ni = newnodeinst(vd->via, lx-plx, hx+phx, ly-ply, hy+phy, 0, 0, facet);
 			if (ni == NONODEINST)
 			{
-				io_definerror("Unable to create via layer");
+				io_definerror(_("Unable to create via layer"));
 				return(1);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
@@ -941,7 +940,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 					lastni, lastpp, curx, cury, ni, pp, curx, cury, facet);
 				if (ai == NOARCINST)
 				{
-					io_definerror("Unable to create net starting point");
+					io_definerror(_("Unable to create net starting point"));
 					return(1);
 				}
 				endobjectchange((INTBIG)ai, VARCINST);
@@ -951,7 +950,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 			placedvia = 1;
 
 			/* get the next keyword */
-			key = io_defmustgetkeyword(f, "NET");
+			key = io_defmustgetkeyword(f, _("NET"));
 			if (key == 0) return(1);
 		} else
 		{
@@ -975,7 +974,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 				ni = newnodeinst(np, lx, hx, ly, hy, 0, 0, facet);
 				if (ni == NONODEINST)
 				{
-					io_definerror("Unable to create net pin");
+					io_definerror(_("Unable to create net pin"));
 					return(1);
 				}
 				endobjectchange((INTBIG)ni, VNODEINST);
@@ -993,7 +992,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 				lastni, lastpp, lastx, lasty, ni, pp, curx, cury, facet);
 			if (ai == NOARCINST)
 			{
-				io_definerror("Unable to create net path");
+				io_definerror(_("Unable to create net path"));
 				return(1);
 			}
 			endobjectchange((INTBIG)ai, VARCINST);
@@ -1036,7 +1035,7 @@ INTSML io_defreadnet(FILE *f, NODEPROTO *facet, INTSML special, INTBIG options)
 					ni, pp, curx, cury, nextni, nextpp, curx, cury, facet);
 				if (ai == NOARCINST)
 				{
-					io_definerror("Unable to create net ending point");
+					io_definerror(_("Unable to create net ending point"));
 					return(1);
 				}
 				endobjectchange((INTBIG)ai, VARCINST);
@@ -1113,7 +1112,7 @@ INTSML io_defgetpin(INTBIG x, INTBIG y, ARCPROTO *ap, NODEPROTO *facet,
 	ni = newnodeinst(pin, lx, hx, ly, hy, 0, 0, facet);
 	if (ni == NONODEINST)
 	{
-		io_definerror("Unable to create net pin");
+		io_definerror(_("Unable to create net pin"));
 		return(1);
 	}
 	endobjectchange((INTBIG)ni, VNODEINST);
@@ -1129,30 +1128,30 @@ INTSML io_defreadunits(FILE *f)
 	REGISTER char *key;
 
 	/* get the "DISTANCE" keyword */
-	key = io_defmustgetkeyword(f, "UNITS");
+	key = io_defmustgetkeyword(f, _("UNITS"));
 	if (key == 0) return(1);
 	if (namesame(key, "DISTANCE") != 0)
 	{
-		io_definerror("Expected 'DISTANCE' after 'UNITS'");
+		io_definerror(_("Expected 'DISTANCE' after 'UNITS'"));
 		return(1);
 	}
 
 	/* get the "MICRONS" keyword */
-	key = io_defmustgetkeyword(f, "UNITS");
+	key = io_defmustgetkeyword(f, _("UNITS"));
 	if (key == 0) return(1);
 	if (namesame(key, "MICRONS") != 0)
 	{
-		io_definerror("Expected 'MICRONS' after 'UNITS'");
+		io_definerror(_("Expected 'MICRONS' after 'UNITS'"));
 		return(1);
 	}
 
 	/* get the amount */
-	key = io_defmustgetkeyword(f, "UNITS");
+	key = io_defmustgetkeyword(f, _("UNITS"));
 	if (key == 0) return(1);
 	io_defunits = atoi(key);
 
 	/* ignore the keyword */
-	if (io_defignoretosemicolon(f, "UNITS") != 0) return(1);
+	if (io_defignoretosemicolon(f, _("UNITS")) != 0) return(1);
 	return(0);
 }
 
@@ -1166,7 +1165,7 @@ INTSML io_defreadpropertydefinitions(FILE *f)
 	for(;;)
 	{
 		/* get the next keyword */
-		key = io_defmustgetkeyword(f, "PROPERTYDEFINITION");
+		key = io_defmustgetkeyword(f, _("PROPERTYDEFINITION"));
 		if (key == 0) return(1);
 		if (namesame(key, "END") == 0)
 		{
@@ -1201,7 +1200,7 @@ NODEPROTO *io_defgetnodeproto(char *name, LIBRARY *curlib)
 		if (np != NONODEPROTO)
 		{
 			/* must copy the facet */
-			newnp = us_copyrecursively(np, np->cell->cellname, curlib, np->cellview, 0, "");
+			newnp = us_copyrecursively(np, np->cell->cellname, curlib, np->cellview, 0, 0, "");
 			return(newnp);
 		}
 	}
@@ -1266,10 +1265,10 @@ void io_defgetlayernodes(char *name, NODEPROTO **pin, NODEPROTO **pure, ARCPROTO
 			node->proto = np;
 			node->lowx = 0;   node->highx = 1000;
 			node->lowy = 0;   node->highy = 1000;
-			j = nodepolys(node);
+			j = nodepolys(node, 0);
 			for(i=0; i<j; i++)
 			{
-				shapenodepoly(node, (INTSML)i, poly);
+				shapenodepoly(node, i, poly);
 				vialayer = poly->layer;
 				lfunc = layerfunction(el_curtech, vialayer) & LFTYPE;
 				if (layeriscontact(lfunc) != 0) break;
@@ -1326,32 +1325,32 @@ INTSML io_defreadcoordinate(FILE *f, INTBIG *x, INTBIG *y)
 	float v;
 
 	/* get "(" */
-	key = io_defmustgetkeyword(f, "coordinate");
+	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(1);
 	if (strcmp(key, "(") != 0)
 	{
-		io_definerror("Expected '(' in coordinate");
+		io_definerror(_("Expected '(' in coordinate"));
 		return(1);
 	}
 
 	/* get X */
-	key = io_defmustgetkeyword(f, "coordinate");
+	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(1);
 	v = (float)atof(key) / (float)io_defunits;
 	*x = scalefromdispunit(v, DISPUNITMIC);
 
 	/* get Y */
-	key = io_defmustgetkeyword(f, "coordinate");
+	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(1);
 	v = (float)atof(key) / (float)io_defunits;
 	*y = scalefromdispunit(v, DISPUNITMIC);
 
 	/* get ")" */
-	key = io_defmustgetkeyword(f, "coordinate");
+	key = io_defmustgetkeyword(f, _("coordinate"));
 	if (key == 0) return(1);
 	if (strcmp(key, ")") != 0)
 	{
-		io_definerror("Expected ')' in coordinate");
+		io_definerror(_("Expected ')' in coordinate"));
 		return(1);
 	}
 	return(0);
@@ -1361,7 +1360,7 @@ INTSML io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans)
 {
 	REGISTER char *key;
 
-	key = io_defmustgetkeyword(f, "orientation");
+	key = io_defmustgetkeyword(f, _("orientation"));
 	if (key == 0) return(1);
 	if (namesame(key, "N")  == 0) { *rot = 0;    *trans = 0; } else
 	if (namesame(key, "S")  == 0) { *rot = 1800; *trans = 0; } else
@@ -1372,7 +1371,7 @@ INTSML io_defreadorientation(FILE *f, INTSML *rot, INTSML *trans)
 	if (namesame(key, "FE") == 0) { *rot = 1800; *trans = 1; } else
 	if (namesame(key, "FW") == 0) { *rot = 0;    *trans = 1; } else
 	{
-		io_definerror("Unknown orientation (%s)", key);
+		io_definerror(_("Unknown orientation (%s)"), key);
 		return(1);
 	}
 	return(0);
@@ -1397,7 +1396,7 @@ char *io_defmustgetkeyword(FILE *f, char *where)
 	char *key;
 
 	key = io_defgetkeyword(f);
-	if (key == 0) io_definerror("EOF parsing %s", where);
+	if (key == 0) io_definerror(_("EOF parsing %s"), where);
 	return(key);
 }
 
@@ -1446,18 +1445,18 @@ void io_definerror(char *command, ...)
 	var_start(ap, command);
 	(void)vsprintf(line, command, ap);
 	va_end(ap);
-	ttyputerr("File %s, line %ld: %s", io_deffilename, io_deflineno, line);
+	ttyputerr(_("File %s, line %ld: %s"), io_deffilename, io_deflineno, line);
 }
 
 /* DEF Options */
 DIALOGITEM io_defoptionsdialogitems[] =
 {
- /*  1 */ {0, {64,156,88,228}, BUTTON, "OK"},
- /*  2 */ {0, {64,16,88,88}, BUTTON, "Cancel"},
- /*  3 */ {0, {32,8,48,230}, CHECK, "Place logical interconnect"},
- /*  4 */ {0, {8,8,24,230}, CHECK, "Place physical interconnect"}
+ /*  1 */ {0, {64,156,88,228}, BUTTON, N_("OK")},
+ /*  2 */ {0, {64,16,88,88}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {32,8,48,230}, CHECK, N_("Place logical interconnect")},
+ /*  4 */ {0, {8,8,24,230}, CHECK, N_("Place physical interconnect")}
 };
-DIALOG io_defoptionsdialog = {{50,75,147,314}, "DEF Options", 4, io_defoptionsdialogitems};
+DIALOG io_defoptionsdialog = {{50,75,147,314}, N_("DEF Options"), 0, 4, io_defoptionsdialogitems};
 
 /*
  * special case for the "DEF Options" dialog
@@ -1466,14 +1465,14 @@ DIALOG io_defoptionsdialog = {{50,75,147,314}, "DEF Options", 4, io_defoptionsdi
  */
 void io_defoptionsdlog(void)
 {
-	INTBIG itemHit, options;
-	REGISTER VARIABLE *var;
+	REGISTER INTBIG itemHit, *curstate, i;
+	INTBIG newstate[NUMIOSTATEBITWORDS];
 
 	if (DiaInitDialog(&io_defoptionsdialog) != 0) return;
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE) options = 0; else options = var->addr;
-	if ((options&DEFNOLOGICAL) == 0) DiaSetControl(3, 1);
-	if ((options&DEFNOPHYSICAL) == 0) DiaSetControl(4, 1);
+	curstate = io_getstatebits();
+	for(i=0; i<NUMIOSTATEBITWORDS; i++) newstate[i] = curstate[i];
+	if ((curstate[0]&DEFNOLOGICAL) == 0) DiaSetControl(3, 1);
+	if ((curstate[0]&DEFNOPHYSICAL) == 0) DiaSetControl(4, 1);
 
 	/* loop until done */
 	for(;;)
@@ -1489,11 +1488,12 @@ void io_defoptionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(3) == 0) options |= DEFNOLOGICAL; else
-			options &= ~DEFNOLOGICAL;
-		if (DiaGetControl(4) == 0) options |= DEFNOPHYSICAL; else
-			options &= ~DEFNOPHYSICAL;
-		(void)setvalkey((INTBIG)io_aid, VAID, io_state, options, VINTEGER);
+		if (DiaGetControl(3) == 0) newstate[0] |= DEFNOLOGICAL; else
+			newstate[0] &= ~DEFNOLOGICAL;
+		if (DiaGetControl(4) == 0) newstate[0] |= DEFNOPHYSICAL; else
+			newstate[0] &= ~DEFNOPHYSICAL;
+		for(i=0; i<NUMIOSTATEBITWORDS; i++) if (curstate[i] != newstate[i]) break;
+		if (i < NUMIOSTATEBITWORDS) io_setstatebits(newstate);
 	}
 	DiaDoneDialog();
 }
