@@ -92,7 +92,7 @@ static INTSML          io_gdslayerused;
 static INTSML          io_gdslayerwhich;
 static INTBIG          io_gdssrefcount;
 static INTBIG          io_gdsrecomputed;
-static INTBIG          io_gdscurstate;
+static INTBIG         *io_gdscurstate;
 
 /* globals */
 static STREAM          io_gdsstream;
@@ -119,37 +119,37 @@ static char            io_gdslibraryname[IDSTRING+1];
 
 static char *io_gdsIerror_string[] =
 {
-	"success",											/* 0 */
-	"Invalid GDS II datatype",							/* 1 */
-	"GDS II version number is not decipherable",		/* 2 */
-	"GDS II header statement is missing",				/* 3 */
-	"Library name is missing",							/* 4 */
-	"Begin library statement is missing",				/* 5 */
-	"Date value is not a valid number",					/* 6 */
-	"Libname statement is missing",						/* 7 */
-	"Generations value is invalid",						/* 8 */
-	"Units statement has invalid number format",		/* 9 */
-	"Units statement is missing",						/* 10 */
-	"Warning this structure is empty",					/* 11 */
-	"Structure name is missing",						/* 12 */
-	"Strname statement is missing",						/* 13 */
-	"Begin structure statement is missing",				/* 14 */
-	"Element end statement is missing",					/* 15 */
-	"Structure reference name is missing",				/* 16 */
-	"Structure reference has no translation value",		/* 17 */
-	"Boundary has no points",							/* 18 */
-	"Structure reference is missing its flags field",	/* 19 */
-	"Not enough points in the shape",					/* 20 */
-	"Too many points in the shape",						/* 21 */
-	"Invalid layer number",								/* 22 */
-	"Layer statement is missing",						/* 23 */
-	"No datatype field",								/* 24 */
-	"Path element has no points",						/* 25 */
-	"Text element has no reference point",				/* 26 */
-	"Array reference has no parameters",				/* 27 */
-	"Array reference name is missing",					/* 28 */
-	"Property has no value",							/* 29 */
-	"Array orientation oblique"							/* 30 */
+	N_("success"),											/* 0 */
+	N_("Invalid GDS II datatype"),							/* 1 */
+	N_("GDS II version number is not decipherable"),		/* 2 */
+	N_("GDS II header statement is missing"),				/* 3 */
+	N_("Library name is missing"),							/* 4 */
+	N_("Begin library statement is missing"),				/* 5 */
+	N_("Date value is not a valid number"),					/* 6 */
+	N_("Libname statement is missing"),						/* 7 */
+	N_("Generations value is invalid"),						/* 8 */
+	N_("Units statement has invalid number format"),		/* 9 */
+	N_("Units statement is missing"),						/* 10 */
+	N_("Warning this structure is empty"),					/* 11 */
+	N_("Structure name is missing"),						/* 12 */
+	N_("Strname statement is missing"),						/* 13 */
+	N_("Begin structure statement is missing"),				/* 14 */
+	N_("Element end statement is missing"),					/* 15 */
+	N_("Structure reference name is missing"),				/* 16 */
+	N_("Structure reference has no translation value"),		/* 17 */
+	N_("Boundary has no points"),							/* 18 */
+	N_("Structure reference is missing its flags field"),	/* 19 */
+	N_("Not enough points in the shape"),					/* 20 */
+	N_("Too many points in the shape"),						/* 21 */
+	N_("Invalid layer number"),								/* 22 */
+	N_("Layer statement is missing"),						/* 23 */
+	N_("No datatype field"),								/* 24 */
+	N_("Path element has no points"),						/* 25 */
+	N_("Text element has no reference point"),				/* 26 */
+	N_("Array reference has no parameters"),				/* 27 */
+	N_("Array reference name is missing"),					/* 28 */
+	N_("Property has no value"),							/* 29 */
+	N_("Array orientation oblique")							/* 30 */
 };
 
 gsymbol io_gdsIoption_set[] =
@@ -359,7 +359,7 @@ unsigned char io_gdsIgetrawbyte(void)
 		{
 			if (io_verbose < 0 && io_gdsfilesize > 0)
 			DiaPercent(1, io_gdsbytesread*100/io_gdsfilesize); else
-				ttyputmsg("%ld bytes read (%ld%% done)", io_gdsbytesread,
+				ttyputmsg(_("%ld bytes read (%ld%% done)"), io_gdsbytesread,
 					io_gdsbytesread*100/io_gdsfilesize);
 		}
 	}
@@ -605,9 +605,9 @@ gsymbol io_gdsIgetrecord(datatype_symbol *gds_type)
 
 void io_gdsIerror(INTBIG n)
 {
-	ttyputerr("Error #%ld: at block number %ld index = %ld\n", n,
+	ttyputerr(_("Error #%ld: at block number %ld index = %ld\n"), n,
 		io_gdsblockcount, io_gdsbufferindex);
-	longjmp(io_gdsenv, (INTBIG)io_gdsIerror_string[n]);
+	longjmp(io_gdsenv, (INTBIG)_(io_gdsIerror_string[n]));
 }
 
 void io_gdsIgettoken(void)
@@ -712,7 +712,7 @@ void io_gdsIstep(INTBIG nc, INTBIG nr, INTBIG angle, INTBIG trans)
 		for (ir = 0; ir < nr; ir++)
 		{
 			/* create the node */
-			if ((io_gdscurstate&GDSINARRAYS) != 0 ||
+			if ((io_gdscurstate[0]&GDSINARRAYS) != 0 ||
 				(ir == 0 && ic == 0) ||
 					(ir == (nr-1) && ic == (nc-1)))
 			{
@@ -720,8 +720,8 @@ void io_gdsIstep(INTBIG nc, INTBIG nr, INTBIG angle, INTBIG trans)
 					pt.px + io_gdssref->highx + ox, pt.py + io_gdssref->lowy + oy,
 						pt.py + io_gdssref->highy + oy, (INTSML)trans, (INTSML)angle,
 							io_gdsstructure)) == NONODEINST)
-								longjmp(io_gdsenv, (INTBIG)"failed to create AREF");
-				if ((io_gdscurstate & GDSINEXPAND) != 0)
+								longjmp(io_gdsenv, (INTBIG)_("failed to create AREF"));
+				if ((io_gdscurstate[0] & GDSINEXPAND) != 0)
 					io_gdsinstance->userbits |= NEXPAND;
 				/* annotate the array info to this element */
 			}
@@ -809,7 +809,7 @@ void io_gdsIshape(INTBIG npts, shape_type perimeter, shape_type oclass)
 				if (newnodeinst(io_gdslayernode, io_gdsvertex[0].px,
 					io_gdsvertex[1].px, io_gdsvertex[0].py, io_gdsvertex[1].py, 0, 0,
 						io_gdsstructure) == NONODEINST)
-							longjmp(io_gdsenv, (INTBIG)"failed to create RECTANGLE");
+							longjmp(io_gdsenv, (INTBIG)_("failed to create RECTANGLE"));
 			}
 			break;
 
@@ -833,11 +833,11 @@ void io_gdsIshape(INTBIG npts, shape_type perimeter, shape_type oclass)
 			/* now create the node */
 			if ((ni = newnodeinst(io_gdslayernode, lx, hx, ly, hy, 0, 0,
 				io_gdsstructure)) == NONODEINST)
-					longjmp(io_gdsenv, (INTBIG)"failed to create POLYGON");
+					longjmp(io_gdsenv, (INTBIG)_("failed to create POLYGON"));
 
 			/* now allocate the trace */
 			pt = trace = emalloc((npts*2*SIZEOFINTBIG), el_tempcluster);
-			if (trace == 0) longjmp(io_gdsenv, (INTBIG)"no memory");
+			if (trace == 0) longjmp(io_gdsenv, (INTBIG)_("no memory"));
 			cx = (hx + lx) / 2;   cy = (hy + ly) / 2;
 			for (i=0; i<npts; i++)
 			{
@@ -848,7 +848,7 @@ void io_gdsIshape(INTBIG npts, shape_type perimeter, shape_type oclass)
 			/* store the trace information */
 			if (setvalkey((INTBIG)ni, VNODEINST, el_trace, (INTBIG)trace,
 				VINTEGER|VISARRAY|((npts*2)<<VLENGTHSH)) == NOVARIABLE)
-					longjmp(io_gdsenv, (INTBIG)"failed to create POLYGON points");
+					longjmp(io_gdsenv, (INTBIG)_("failed to create POLYGON points"));
 
 			/* free the polygon memory */
 			efree((char *)trace);
@@ -865,7 +865,7 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
 	VARIABLE *var;
 
 	/* no text */
-	if (!io_gdslayerused || !(io_gdscurstate&GDSINTEXT)) return;
+	if (!io_gdslayerused || !(io_gdscurstate[0]&GDSINTEXT)) return;
 	io_gdslayertext[io_gdslayerwhich]++;
 
 	io_gdsvertex[1].px = io_gdsvertex[0].px + MINFONTWIDTH * strlen(charstring);
@@ -875,12 +875,12 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
 	if ((ni = newnodeinst(io_gdslayernode, io_gdsvertex[0].px, io_gdsvertex[0].px,
 		io_gdsvertex[0].py, io_gdsvertex[0].py, (INTSML)trans, (INTSML)angle,
 			io_gdsstructure)) == NONODEINST)
-				longjmp(io_gdsenv, (INTBIG)"Could not create text marker");
+				longjmp(io_gdsenv, (INTBIG)_("Could not create text marker"));
 
 	/* now add the text */
 	if ((var = setvalkey((INTBIG)ni, VNODEINST, el_node_name, (INTBIG)charstring,
 		VSTRING|VDISPLAY)) == NOVARIABLE)
-			longjmp(io_gdsenv, (INTBIG)"Could not create text string");
+			longjmp(io_gdsenv, (INTBIG)_("Could not create text string"));
 
 	/* set the text size and orientation */
 	switch (rounddouble (scale))
@@ -935,8 +935,7 @@ void io_gdsItext(char *charstring, INTBIG vjust, INTBIG hjust, INTBIG angle,
  */
 void io_gdsIOnceinit(void)
 {
-	INTSML i;
-	INTBIG *layer_numbers, j, count, which;
+	INTBIG i, *layer_numbers, j, count, which;
 	VARIABLE *var;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER NODEINST *ni;
@@ -977,7 +976,7 @@ void io_gdsIOnceinit(void)
 					ni->highx = np->highx;
 					ni->lowy  = np->lowy;
 					ni->highy = np->highy;
-					j = nodepolys(ni);
+					j = nodepolys(ni, 0);
 					if (j != 1) continue;
 					shapenodepoly(ni, 0, poly);
 					if (i == poly->layer)
@@ -996,10 +995,11 @@ void io_gdsIOnceinit(void)
 				if (io_gdslayernodes[which] != NONODEPROTO) continue;
 				for(j=i+1; j<count; j++) if (which == layer_numbers[j]) break;
 				if (j < count) continue;
-				ttyputmsg("Cannot read GDS layer %ld (%s)", which, layername(el_curtech, i));
+				ttyputmsg(_("Cannot read GDS layer %ld (%s)"), which,
+					layername(el_curtech, (INTSML)i));
 			}
 		}
-	} else ttyputmsg("Technology has no GDSII layer numbers");
+	} else ttyputmsg(_("Technology has no GDSII layer numbers"));
 }
 
 /*
@@ -1180,14 +1180,14 @@ void io_gdsIdetermine_points(INTBIG min_points, INTBIG max_points, INTBIG *point
 		(*point_counter)++;
 		if (*point_counter > max_points)
 		{
-			ttyputmsg("Found %ld points", *point_counter);
+			ttyputmsg(_("Found %ld points"), *point_counter);
 			io_gdsIerror(21);
 		}
 		io_gdsIgettoken();
 	}
 	if (*point_counter < min_points)
 	{
-		ttyputmsg("Found %ld points", *point_counter);
+		ttyputmsg(_("Found %ld points"), *point_counter);
 		io_gdsIerror(20);
 	}
 }
@@ -1238,26 +1238,26 @@ void io_gdsIdetermine_layer(INTBIG *layer, INTBIG *sublayer)
 			io_gdscurlayer = *layer = io_gdstokenvalue16;
 			if (io_gdscurlayer >= MAXLAYERS)
 			{
-				ttyputmsg("GDS layer %ld is too high (limit is %d)",
+				ttyputmsg(_("GDS layer %ld is too high (limit is %d)"),
 					io_gdscurlayer, MAXLAYERS-1);
 				io_gdscurlayer = MAXLAYERS-1;
 			}
 			if (io_gdslayernodes[io_gdscurlayer] == NONODEPROTO)
 			{
-				if ((io_gdscurstate&GDSINIGNOREUKN) == 0)
+				if ((io_gdscurstate[0]&GDSINIGNOREUKN) == 0)
 				{
-					ttyputmsg("GDS layer %ld unknown, using Generic:DRC",
+					ttyputmsg(_("GDS layer %ld unknown, using Generic:DRC"),
 						io_gdscurlayer);
 				} else
 				{
-					ttyputmsg("GDS layer %ld unknown, ignoring it",
+					ttyputmsg(_("GDS layer %ld unknown, ignoring it"),
 						io_gdscurlayer);
 				}
 				io_gdslayernodes[io_gdscurlayer] = gen_drcprim;
 			}
 			io_gdslayernode = io_gdslayernodes[io_gdscurlayer];
 			if (io_gdslayernode == gen_drcprim &&
-				(io_gdscurstate&GDSINIGNOREUKN) != 0)
+				(io_gdscurstate[0]&GDSINIGNOREUKN) != 0)
 			{
 				io_gdslayerused = 0;
 			} else
@@ -1316,21 +1316,20 @@ void io_gdsIbeginstructure(void)
 					/* create the proto */
 					io_gdsstructure = newnodeproto(io_gdstokenstring, io_gdslibrary);
 					if (io_gdsstructure == NONODEPROTO)
-						longjmp(io_gdsenv, (INTBIG)"failed to create structure");
+						longjmp(io_gdsenv, (INTBIG)_("failed to create structure"));
 					if (io_verbose < 0 && io_gdsfilesize > 0)
 					{
 						(void)initinfstr();
-						(void)addstringtoinfstr("Reading ");
-						(void)addstringtoinfstr(io_gdstokenstring);
+						(void)formatinfstr(_("Reading %s"), io_gdstokenstring);
 						DiaSetText(2, returninfstr());
-					} else if (io_verbose != 0) ttyputmsg("Reading %s", io_gdstokenstring);
+					} else if (io_verbose != 0) ttyputmsg(_("Reading %s"), io_gdstokenstring);
 
 #ifdef PLACEFACETCENTERS
 					/* add the facet center */
 					if (newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
 						gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
 						gen_facetcenterprim->highy, 0, 0, io_gdsstructure) == NONODEINST)
-							longjmp(io_gdsenv, (INTBIG)"failed to create facet center");
+							longjmp(io_gdsenv, (INTBIG)_("failed to create facet center"));
 #endif
 					if (io_gdslibrary->curnodeproto == NONODEPROTO)
 						io_gdslibrary->curnodeproto = io_gdsstructure;
@@ -1391,13 +1390,13 @@ void io_gdsIdetermine_node(void)
 			io_gdscurlayer = io_gdstokenvalue16;
 			if (io_gdscurlayer >= MAXLAYERS)
 			{
-				ttyputmsg("GDS layer %ld is too high (limit is %d)",
+				ttyputmsg(_("GDS layer %ld is too high (limit is %d)"),
 					io_gdscurlayer, MAXLAYERS-1);
 				io_gdscurlayer = MAXLAYERS-1;
 			}
 			if (io_gdslayernodes[io_gdscurlayer] == NONODEPROTO)
 			{
-				ttyputmsg("GDS layer %ld unknown, using Generic:DRC",
+				ttyputmsg(_("GDS layer %ld unknown, using Generic:DRC"),
 					io_gdscurlayer);
 				io_gdslayernodes[io_gdscurlayer] = gen_drcprim;
 			}
@@ -1428,7 +1427,7 @@ void io_gdsIdetermine_node(void)
 		if (newnodeinst(io_gdslayernode, io_gdsvertex[0].px,
 			io_gdsvertex[0].px, io_gdsvertex[0].py, io_gdsvertex[0].py, 0, 0,
 				io_gdsstructure) == NONODEINST)
-					longjmp(io_gdsenv, (INTBIG) "failed to create NODE");
+					longjmp(io_gdsenv, (INTBIG) _("failed to create NODE"));
 	} else
 	{
 		io_gdsIonlyone(io_gdsIrecovery_set, GDS_ENDEL);
@@ -1456,7 +1455,7 @@ void io_gdsIdetermine_box(void)
 			if (newnodeinst(io_gdslayernode, io_gdsvertex[0].px, io_gdsvertex[1].px,
 				io_gdsvertex[0].py, io_gdsvertex[1].py , 0, 0,
 					io_gdsstructure) == NONODEINST)
-						longjmp(io_gdsenv, (INTBIG) "failed to create box");
+						longjmp(io_gdsenv, (INTBIG) _("failed to create box"));
 		}
 	} else
 	{
@@ -1606,7 +1605,7 @@ void io_gdsIdetermine_path(void)
 				{
 					io_gdslayerpoly[io_gdslayerwhich]++;
 					if (newnodeinst(io_gdslayernode, lx, hx, ly, hy, 0, 0, io_gdsstructure) == NONODEINST)
-						longjmp(io_gdsenv, (INTBIG)"failed to create outline");
+						longjmp(io_gdsenv, (INTBIG)_("failed to create outline"));
 				}
 				continue;
 			}
@@ -1622,7 +1621,7 @@ void io_gdsIdetermine_path(void)
 
 				/* determine shape of segment */
 				length = computedistance(fx, fy, tx, ty);
-				if (endcode == 0) fextend = textend = width/2;
+				if (endcode == 0) fextend = textend = 0; /* the 0 was width/2 */
 				j = figureangle(fx, fy, tx, ty);
 				tech_makeendpointpoly(length, width, j, fx, fy, fextend,
 					tx, ty, textend, poly);
@@ -1632,13 +1631,13 @@ void io_gdsIdetermine_path(void)
 				{
 					if (newnodeinst(io_gdslayernode, lx, hx, ly, hy, 0, 0,
 						io_gdsstructure) == NONODEINST)
-							longjmp(io_gdsenv, (INTBIG)"failed to create outline");
+							longjmp(io_gdsenv, (INTBIG)_("failed to create outline"));
 				} else
 				{
 					getbbox(poly, &lx, &hx, &ly, &hy);
 					ni = newnodeinst(io_gdslayernode, lx, hx, ly, hy, 0, 0, io_gdsstructure);
 					if (ni == NONODEINST)
-						longjmp(io_gdsenv, (INTBIG)"failed to create outline");
+						longjmp(io_gdsenv, (INTBIG)_("failed to create outline"));
 
 					/* set the shape into the node */
 					cx = (lx + hx) / 2;
@@ -1671,21 +1670,20 @@ void io_gdsIgetproto(char *name)
 	{
 		/* FILO order, create this nodeproto */
 		if ((np = newnodeproto(io_gdstokenstring, io_gdslibrary)) == NONODEPROTO)
-			longjmp(io_gdsenv, (INTBIG)"failed to create SREF proto");
+			longjmp(io_gdsenv, (INTBIG)_("failed to create SREF proto"));
 		if (io_verbose < 0 && io_gdsfilesize > 0)
 		{
 			(void)initinfstr();
-			(void)addstringtoinfstr("Reading ");
-			(void)addstringtoinfstr(io_gdstokenstring);
+			(void)formatinfstr(_("Reading %s"), io_gdstokenstring);
 			DiaSetText(2, returninfstr());
-		} else if (io_verbose != 0) ttyputmsg("Reading %s", io_gdstokenstring);
+		} else if (io_verbose != 0) ttyputmsg(_("Reading %s"), io_gdstokenstring);
 
 #ifdef PLACEFACETCENTERS
 		/* add the facet center */
 		if (newnodeinst(gen_facetcenterprim, gen_facetcenterprim->lowx,
 			gen_facetcenterprim->highx, gen_facetcenterprim->lowy,
 				gen_facetcenterprim->highy, 0, 0, np) == NONODEINST)
-					longjmp(io_gdsenv, (INTBIG)"failed to create facet center");
+					longjmp(io_gdsenv, (INTBIG)_("failed to create facet center"));
 #endif
 	}
 
@@ -1741,8 +1739,8 @@ void io_gdsIdetermine_sref(void)
 			io_gdsvertex[0].py + io_gdssref->lowy + oy,
 			io_gdsvertex[0].py + io_gdssref->highy + oy,
 			(INTSML)trans, (INTSML)angle, io_gdsstructure)) == NONODEINST)
-				longjmp(io_gdsenv, (INTBIG)"failed to create SREF");
-		if (io_gdscurstate&GDSINEXPAND)
+				longjmp(io_gdsenv, (INTBIG)_("failed to create SREF"));
+		if (io_gdscurstate[0]&GDSINEXPAND)
 			io_gdsinstance->userbits |= NEXPAND;
 		io_gdssrefcount++;
 	} else
@@ -1911,8 +1909,8 @@ void io_gdsIstructure(void)
 	}
 	if (empty_structure != 0)
 	{
-		ttyputmsg("%s", io_gdsIerror_string[11]);
-		ttyputerr("Error at block number %5d and offset %4d\n",
+		ttyputmsg("%s", _(io_gdsIerror_string[11]));
+		ttyputerr(_("Error at block number %5d and offset %4d"),
 			io_gdsblockcount, io_gdsbufferindex);
 		return;
 	}
@@ -1972,21 +1970,16 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 	char *msg, *filename;
 	NODEPROTO *np;
 	extern DIALOG us_progressdialog;
-	VARIABLE *var;
 
 	io_gdslibrary = lib;
 
 	/* get current state of I/O aid */
-	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (var == NOVARIABLE)
-		io_gdscurstate = 0;
-	else
-		io_gdscurstate = var->addr;
+	io_gdscurstate = io_getstatebits();
 
 	/* get the gds file */
-	if ((input = xopen(io_gdslibrary->libfile, FILETYPEGDS, "", &filename)) == NULL)
+	if ((input = xopen(io_gdslibrary->libfile, io_filetypegds, "", &filename)) == NULL)
 	{
-		ttyputerr("File %s not found", io_gdslibrary->libfile);
+		ttyputerr(_("File %s not found"), io_gdslibrary->libfile);
 		return(1);
 	}
 
@@ -2006,7 +1999,7 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 	/* setup the error return location */
 	if ((msg = (char *)setjmp(io_gdsenv)) != NULL)
 	{
-		ttyputerr("Error: %s", msg);
+		ttyputerr(_("Error: %s"), msg);
 		xclose(input);
 		if (io_verbose < 0 && io_gdsfilesize > 0) DiaDoneDialog();
 		return(1);
@@ -2028,8 +2021,8 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 		if (position == 0 || position == 3)
 		{
 			if (position == 0)
-				ttyputmsg("%s information:", skippath(io_gdslibrary->libfile)); else
-					ttyputmsg("Summary information:");
+				ttyputmsg(_("%s information:"), skippath(io_gdslibrary->libfile)); else
+					ttyputmsg(_("Summary information:"));
 			ttyputmsg("  %d %s", io_gdssrefcount, makeplural("SREF", io_gdssrefcount));
 			for (i = 0; i < MAXLAYERS; i++)
 			{
@@ -2037,12 +2030,12 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 				{
 					if (i < el_curtech->layercount)
 					{
-						ttyputmsg("  %d objects on layer %d (%s)",
+						ttyputmsg(_("  %d objects on layer %d (%s)"),
 							io_gdslayerpoly[i]+io_gdslayertext[i], i,
 								describenodeproto(io_gdslayernodes[i]));
 					} else
 					{
-						ttyputmsg("  %d objects on layer %d",
+						ttyputmsg(_("  %d objects on layer %d"),
 							io_gdslayerpoly[i]+io_gdslayertext[i], i);
 					}
 				}
@@ -2057,7 +2050,7 @@ INTSML io_readgdslibrary(LIBRARY *lib, INTSML position)
 	{
 		if (io_verbose < 0 && io_gdsfilesize > 0)
 		{
-			DiaSetText(2, "Cleaning up...");
+			DiaSetText(2, _("Cleaning up..."));
 			DiaPercent(1, 0);
 		}
 
@@ -2123,7 +2116,7 @@ void io_gdsIrecompute(NODEPROTO *np, INTBIG count)
 		io_gdsrecomputed++;
 		if ((io_gdsrecomputed%1000) == 0 && io_verbose < 0 && io_gdsfilesize > 0)
 		{
-			(void)sprintf(numsofar, "Cleaned up %d instances...", io_gdsrecomputed);
+			(void)sprintf(numsofar, _("Cleaned up %d instances..."), io_gdsrecomputed);
 			DiaSetText(2, numsofar);
 			if (count > 0)
 				DiaPercent(1, (io_gdsrecomputed*100)/count);
