@@ -96,36 +96,36 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 {
 	char file[100], buff[MAXSTR], *truename;
 	REGISTER NODEPROTO *np, *onp;
-	INTBIG lx, hx, ly, hy, hlx, hhx, hly, hhy, i, sulx, suhx, suly, suhy, sslx, sshx, ssly, sshy;
-	REGISTER VARIABLE *varstate, *varred, *vargreen, *varblue, *varscale;
-	extern AIDENTRY *us_aid;
+	INTBIG lx, hx, ly, hy, hlx, hhx, hly, hhy, i, *curstate,
+		sulx, suhx, suly, suhy, sslx, sshx, ssly, sshy;
+	REGISTER VARIABLE *varred, *vargreen, *varblue, *varscale;
 	REGISTER float scale;
 
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("No current facet to plot");
+		ttyputerr(_("No current facet to plot"));
 		return(1);
 	}
 
 	/* determine whether this is HPGL or HPGL/2 */
-	varstate = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
-	if (varstate == NOVARIABLE || (varstate->addr&HPGL2) == 0) io_hpgl2 = 0; else
+	curstate = io_getstatebits();
+	if ((curstate[0]&HPGL2) == 0) io_hpgl2 = 0; else
 		io_hpgl2 = 1;
 
 	/* create the output file */
 	if (io_hpgl2 != 0)
 	{
 		(void)sprintf(file, "%s.hpgl2", np->cell->cellname);
-		io_hpout = xcreate(file, FILETYPEHPGL, "HPGL/2 File", &truename);
+		io_hpout = xcreate(file, io_filetypehpgl, _("HPGL/2 File"), &truename);
 	} else
 	{
 		(void)sprintf(file, "%s.hpgl", np->cell->cellname);
-		io_hpout = xcreate(file, FILETYPEHPGL, "HPGL File", &truename);
+		io_hpout = xcreate(file, io_filetypehpgl, _("HPGL File"), &truename);
 	}
 	if (io_hpout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot create %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot create %s"), truename);
 		return(1);
 	}
 
@@ -141,15 +141,24 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 	}
 
 	/* see if focusing on highlighted area */
-	if (varstate != NOVARIABLE && (varstate->addr&PLOTFOCUS) != 0)
+	if ((curstate[0]&PLOTFOCUS) != 0)
 	{
-		onp = (NODEPROTO *)askaid(us_aid, "get-highlighted-area", (INTBIG)&hlx,
-			(INTBIG)&hhx, (INTBIG)&hly, (INTBIG)&hhy);
-		if (onp == NONODEPROTO)
-			ttyputerr("Warning: no highlighted area; plotting entire facet"); else
+		if ((curstate[0]&PLOTFOCUSDPY) != 0)
 		{
-			lx = hlx;   hx = hhx;
-			ly = hly;   hy = hhy;
+			lx = el_curwindowpart->screenlx;
+			hx = el_curwindowpart->screenhx;
+			ly = el_curwindowpart->screenly;
+			hy = el_curwindowpart->screenhy;
+		} else
+		{
+			onp = (NODEPROTO *)askaid(us_aid, "get-highlighted-area", (INTBIG)&hlx,
+				(INTBIG)&hhx, (INTBIG)&hly, (INTBIG)&hhy);
+			if (onp == NONODEPROTO)
+				ttyputerr(_("Warning: no highlighted area; plotting entire facet")); else
+			{
+				lx = hlx;   hx = hhx;
+				ly = hly;   hy = hhy;
+			}
 		}
 	}
 
@@ -177,7 +186,7 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 		varblue = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, "USER_colormap_blue");
 		if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 		{
-			ttyputmsg("Cannot get colors!");
+			ttyputmsg(_("Cannot get colors!"));
 			return(1);
 		}
 		for(i=0; i<256; i++)
@@ -268,7 +277,7 @@ INTSML io_writehpgllibrary(LIBRARY *lib)
 		io_hpcmd(";SP0;PU;DF;NR;\033.)");
 	}
 	xclose(io_hpout);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 	return(0);
 }
 
@@ -280,9 +289,7 @@ INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 	REGISTER INTSML k, font;
 	INTBIG xl, xh, yl, yh, x, y;
 	INTSML color;
-	static WINDOWPART *cachedwindow = NOWINDOWPART;
-	static NODEPROTO *cachedfacet = NONODEPROTO;
-	static TECHNOLOGY *cachedtech = NOTECHNOLOGY;
+	REGISTER TECHNOLOGY *tech;
 
 	/* ignore null layers */
 	if (poly->desc->bits == LAYERN || poly->desc->col == ALLOFF) return(1);
@@ -390,16 +397,8 @@ INTSML io_hppoly(POLYGON *poly, WINDOWPART *win)
 		case TEXTTOPRIGHT:
 		case TEXTBOTRIGHT:
 		case TEXTBOX:
-			if (win != cachedwindow || win->curnodeproto != cachedfacet)
-			{
-				cachedwindow = win;
-				cachedfacet = win->curnodeproto;
-				cachedtech = NOTECHNOLOGY;
-				if (cachedfacet != NONODEPROTO)
-					cachedtech = whattech(cachedfacet);
-			}
-			if (cachedtech == NOTECHNOLOGY) cachedtech = el_curtech;
-			font = truefontsize(poly->font, win, cachedtech);
+			tech = win->curnodeproto->tech;
+			font = truefontsize(poly->font, win, tech);
 			getbbox(poly, &xl, &xh, &yl, &yh);
 			io_hptext(poly->style, xl, xh, yl, yh, font, poly->string, color);
 			break;
