@@ -52,7 +52,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 {
 	char file[100], *truename;
 	REGISTER char *name;
-	REGISTER INTSML i, tot;
+	REGISTER INTBIG i, tot;
 	REGISTER float xs, ys;
 	REGISTER NODEPROTO *np;
 	REGISTER NODEINST *rni, *ni;
@@ -68,16 +68,16 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 	np = lib->curnodeproto;
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a facet to generate LEF output");
+		ttyputerr(_("Must be editing a facet to generate LEF output"));
 		return(1);
 	}
 	(void)strcpy(file, np->cell->cellname);
 	(void)strcat(file, ".lef");
 	name = truepath(file);
-	io_fileout = xcreate(name, FILETYPELEF, "LEF File", &truename);
+	io_fileout = xcreate(name, io_filetypelef, _("LEF File"), &truename);
 	if (io_fileout == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return(1);
 	}
 
@@ -146,7 +146,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 		}
 		xprintf(io_fileout, "    PORT\n");
 		io_lefoutcurlayer[0] = 0;
-		tot = nodeEpolys(rni);
+		tot = nodeEpolys(rni, 0);
 		for(i=0; i<tot; i++)
 		{
 			shapeEnodepoly(rni, i, poly);
@@ -174,7 +174,7 @@ INTSML io_writeleflibrary(LIBRARY *lib)
 	xclose(io_fileout);
 
 	/* tell the user that the file is written */
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 	return(0);
 }
 
@@ -187,7 +187,7 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
-	REGISTER INTSML i, tot, fun;
+	REGISTER INTBIG i, tot, fun;
 	char *extra;
 	XARRAY trans;
 	static POLYGON *poly = NOPOLYGON;
@@ -208,7 +208,7 @@ void io_lefoutspread(FILE *out, NODEPROTO *facet, NETWORK *net, NODEINST *ignore
 		/* write all layers on this node */
 		ni->temp1 = 1;
 		makerot(ni, trans);
-		tot = nodepolys(ni);
+		tot = nodepolys(ni, 0);
 		for(i=0; i<tot; i++)
 		{
 			shapenodepoly(ni, i, poly);
@@ -238,7 +238,7 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans)
 {
 	REGISTER NODEINST *ni;
 	REGISTER ARCINST *ai;
-	REGISTER INTSML i, tot;
+	REGISTER INTBIG i, tot;
 	XARRAY localtran, subrot, localrot, thisrot;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -257,7 +257,7 @@ void io_lefoutfacet(FILE *out, NODEPROTO *facet, INTSML top, XARRAY trans)
 		} else
 		{
 			/* primitive: find the metal layers */
-			tot = nodepolys(ni);
+			tot = nodepolys(ni, 0);
 			for(i=0; i<tot; i++)
 			{
 				shapenodepoly(ni, i, poly);
