@@ -138,7 +138,7 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	sdfi_curfacet = getcurfacet();
 	if (sdfi_curfacet == NONODEPROTO)
 	{
-		ttyputerr("No current facet with which to merge data, aborting SDF input");
+		ttyputerr(_("No current facet with which to merge data, aborting SDF input"));
 		return(1);
 	}
 
@@ -151,10 +151,10 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	if (SDF_absolute_iopath_delay_key == 0) SDF_absolute_iopath_delay_key = makekey("SDF_absolute_iopath_delay");
 
 	/* open the file */
-	fp = xopen(lib->libfile, FILETYPESDF, "", &filename);
+	fp = xopen(lib->libfile, io_filetypesdf, "", &filename);
 	if (fp == NULL)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 
@@ -166,7 +166,7 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 		return(1);
 	}
 	DiaPercent(1, 0);
-	DiaSetText(2, "Reading SDF file...");
+	DiaSetText(2, _("Reading SDF file..."));
 
 	/* read the file */
 	lt = sdfi_readfile(fp);
@@ -174,19 +174,19 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	xclose(fp);
 	if (lt == 0)
 	{
-		ttyputerr("Error reading file");
+		ttyputerr(_("Error reading file"));
 		return(1);
 	}
-	ttyputmsg("SDF file %s is read", lib->libfile);
+	ttyputmsg(_("SDF file %s is read"), lib->libfile);
 
 	/* parse the tree */
 	if (sdfi_parsetree(lt) != 0)
 	{
 		sdfi_killptree(lt);
-		ttyputerr("Errors occured during SDF file parsing");
+		ttyputerr(_("Errors occured during SDF file parsing"));
 		return(1);
 	}
-	ttyputmsg("Successfully parsed SDF file");
+	ttyputmsg(_("Successfully parsed SDF file"));
 
 	/* release tree memory */
 	sdfi_killptree(lt);
@@ -225,7 +225,7 @@ INTSML io_readsdflibrary(LIBRARY *lib)
 	if (sdfi_timescale != NULL)
 		(void)setval((INTBIG)sdfi_curfacet, VNODEPROTO, "SDF_timescale", (INTBIG)sdfi_timescale, VSTRING);
 
-	ttyputmsg("Back-annotation information has been added (library must be saved)");
+	ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	return(0);
 }
@@ -315,7 +315,7 @@ LISPTREE *sdfi_readfile(FILE *f)
 
 	if (sdfi_treedepth != 0)
 	{
-		ttyputerr("Not enough close parenthesis in file");
+		ttyputerr(_("Not enough close parenthesis in file"));
 		return(0);
 	}
 	return(treetop);
@@ -335,7 +335,7 @@ INTSML sdfi_pushkeyword(char *keyword)
 	{
 		if (sdfi_treedepth >= MAXDEPTH)
 		{
-			ttyputerr("Nesting too deep (more than %d)", MAXDEPTH);
+			ttyputerr(_("Nesting too deep (more than %d)"), MAXDEPTH);
 			return(1);
 		}
 
@@ -365,7 +365,7 @@ INTSML sdfi_pushkeyword(char *keyword)
 		/* pop tree stack */
 		if (sdfi_treedepth <= 0)
 		{
-			ttyputerr("Too many close parenthesis");
+			ttyputerr(_("Too many close parenthesis"));
 			return(1);
 		}
 		sdfi_treedepth--;
@@ -491,10 +491,10 @@ INTSML sdfi_parsetree(LISPTREE *lt)
 	}
 	if (total == 0)
 	{
-		ttyputerr("No DELAYFILE definition found");
+		ttyputerr(_("No DELAYFILE definition found"));
 		return(1);
 	}
-	ttyputmsg("Found %d DELAYFILE %s", total, (total == 1) ? "definition" : "definitions");
+	ttyputmsg(_("Found %d DELAYFILE %s"), total, makeplural(_("definition"), total));
 	return(0);
 }
 
@@ -518,11 +518,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltsdfversion != 0)
 			{
-				ttyputerr("Multiple 'sdfversion' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'sdfversion' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_sdfversion, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found SDFVERSION: %s", sdfi_sdfversion);
+			if (io_verbose > 0) ttyputmsg(_("Found SDFVERSION: %s"), sdfi_sdfversion);
 			ltsdfversion = scanlt;
 			continue;
 		}
@@ -531,16 +531,16 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltdesign != 0)
 			{
-				ttyputerr("Multiple 'design' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'design' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_design, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found DESIGN: %s", sdfi_design);
+			if (io_verbose > 0) ttyputmsg(_("Found DESIGN: %s"), sdfi_design);
 
 			/* check to see if design matches current facet */
 			if (namesame(sdfi_curfacet->cell->cellname, sdfi_design) != 0)
 			{
-				ttyputerr("Current facet (%s) does not match DESIGN (%s).  Aborting SDF input",
+				ttyputerr(_("Current facet (%s) does not match DESIGN (%s).  Aborting SDF input"),
 					sdfi_curfacet->cell->cellname, sdfi_design);
 				return(1);
 			}
@@ -552,11 +552,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltdate != 0)
 			{
-				ttyputerr("Multiple 'date' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'date' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_date, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found DATE: %s", sdfi_date);
+			if (io_verbose > 0) ttyputmsg(_("Found DATE: %s"), sdfi_date);
 			ltdate = scanlt;
 			continue;
 		}
@@ -565,11 +565,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltvendor != 0)
 			{
-				ttyputerr("Multiple 'vendor' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'vendor' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_vendor, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found VENDOR: %s", sdfi_vendor);
+			if (io_verbose > 0) ttyputmsg(_("Found VENDOR: %s"), sdfi_vendor);
 			ltvendor = scanlt;
 			continue;
 		}
@@ -578,11 +578,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltprogram != 0)
 			{
-				ttyputerr("Multiple 'program' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'program' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_program, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found PROGRAM: %s", sdfi_program);
+			if (io_verbose > 0) ttyputmsg(_("Found PROGRAM: %s"), sdfi_program);
 			ltprogram = scanlt;
 			continue;
 		}
@@ -591,11 +591,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltversion != 0)
 			{
-				ttyputerr("Multiple 'version' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'version' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_version, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found VERSION: %s", sdfi_version);
+			if (io_verbose > 0) ttyputmsg(_("Found VERSION: %s"), sdfi_version);
 			ltversion = scanlt;
 			continue;
 		}
@@ -604,16 +604,16 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltdivider != 0)
 			{
-				ttyputerr("Multiple 'divider' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'divider' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 
-			if (io_verbose > 0) ttyputmsg("Found DIVIDER: %s", (char *)scanlt->paramvalue[0]);
+			if (io_verbose > 0) ttyputmsg(_("Found DIVIDER: %s"), (char *)scanlt->paramvalue[0]);
 			sdfi_setstring(&sdfi_divider, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found DIVIDER: %s", sdfi_divider);
+			if (io_verbose > 0) ttyputmsg(_("Found DIVIDER: %s"), sdfi_divider);
 			if (namesame(sdfi_divider, ".") != 0 && namesame(sdfi_divider, "/") != 0)
 			{
-				ttyputerr("illegal DIVIDER - %s (line %ld)", sdfi_divider, scanlt->lineno);
+				ttyputerr(_("illegal DIVIDER - %s (line %ld)"), sdfi_divider, scanlt->lineno);
 				return(1);
 			}
 			ltdivider = scanlt;
@@ -624,11 +624,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltvoltage != 0)
 			{
-				ttyputerr("Multiple 'voltage' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'voltage' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_voltage, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found VOLTAGE: %s", sdfi_voltage);
+			if (io_verbose > 0) ttyputmsg(_("Found VOLTAGE: %s"), sdfi_voltage);
 			ltvoltage = scanlt;
 			continue;
 		}
@@ -637,11 +637,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (ltprocess != 0)
 			{
-				ttyputerr("Multiple 'process' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'process' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_process, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found PROCESS: %s", sdfi_process);
+			if (io_verbose > 0) ttyputmsg(_("Found PROCESS: %s"), sdfi_process);
 			ltprocess = scanlt;
 			continue;
 		}
@@ -650,11 +650,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (lttemperature != 0)
 			{
-				ttyputerr("Multiple 'temperature' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'temperature' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_temperature, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found TEMPERATURE: %s", sdfi_temperature);
+			if (io_verbose > 0) ttyputmsg(_("Found TEMPERATURE: %s"), sdfi_temperature);
 			lttemperature = scanlt;
 			continue;
 		}
@@ -663,11 +663,11 @@ INTSML sdfi_parsedelayfile(LISPTREE *lt)
 		{
 			if (lttimescale != 0)
 			{
-				ttyputerr("Multiple 'timescale' sections for a delayfile (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'timescale' sections for a delayfile (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_timescale, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found TIMESCALE: %s", sdfi_timescale);
+			if (io_verbose > 0) ttyputmsg(_("Found TIMESCALE: %s"), sdfi_timescale);
 			lttimescale = scanlt;
 			if (sdfi_parsetimescale(scanlt) != 0) return(1);
 			continue;
@@ -698,7 +698,7 @@ INTSML sdfi_parsetimescale(LISPTREE *lt)
 		strcat(t1, (char *)lt->paramvalue[1]);
 	} else
 	{
-		ttyputerr("illegal TIMESCALE - too many parameters (line %ld)", lt->lineno);
+		ttyputerr(_("illegal TIMESCALE - too many parameters (line %ld)"), lt->lineno);
 		return(1);
 	}
 
@@ -713,11 +713,11 @@ INTSML sdfi_parsetimescale(LISPTREE *lt)
 	else if (namesame(t1, "100ps") == 0 || namesame(t1, "100.0ps") == 0) sdfi_timeconvert = 100;
 	else
 	{
-		ttyputerr("illegal TIMESCALE - unknown unit or value (line %ld)", lt->lineno);
+		ttyputerr(_("illegal TIMESCALE - unknown unit or value (line %ld)"), lt->lineno);
 		return(1);
 	}
 
-	if (io_verbose > 0) ttyputmsg("timescale conversion = %ld", sdfi_timeconvert);
+	if (io_verbose > 0) ttyputmsg(_("timescale conversion = %ld"), sdfi_timeconvert);
 
 	return(0);
 }
@@ -745,11 +745,11 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 		{
 			if (ltcelltype != 0)
 			{
-				ttyputerr("Multiple 'celltype' sections for a cell (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'celltype' sections for a cell (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_celltype, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found CELLTYPE: %s", sdfi_celltype);
+			if (io_verbose > 0) ttyputmsg(_("Found CELLTYPE: %s"), sdfi_celltype);
 			ltcelltype = scanlt;
 			continue;
 		}
@@ -757,11 +757,11 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 		{
 			if (ltinstance != 0)
 			{
-				ttyputerr("Multiple 'instance' sections for a cell (line %ld)", scanlt->lineno);
+				ttyputerr(_("Multiple 'instance' sections for a cell (line %ld)"), scanlt->lineno);
 				return(1);
 			}
 			sdfi_setstring(&sdfi_instance, (char *)scanlt->paramvalue[0]);
-			if (io_verbose > 0) ttyputmsg("Found INSTANCE: %s", sdfi_instance);
+			if (io_verbose > 0) ttyputmsg(_("Found INSTANCE: %s"), sdfi_instance);
 
 			ni = sdfi_getcellinstance(sdfi_celltype, sdfi_instance);
 
@@ -785,7 +785,7 @@ INTSML sdfi_parsecell(LISPTREE *lt)
 				killstringarray(sa);
 			} else
 			{
-				ttyputerr("No matching node for CELLTYPE: %s, INSTANCE: %s. Aborting SDF input",
+				ttyputerr(_("No matching node for CELLTYPE: %s, INSTANCE: %s. Aborting SDF input"),
 					sdfi_celltype, sdfi_instance);
 				return(1);
 			}
@@ -976,12 +976,12 @@ INTSML sdfi_parseport(LISPTREE *lt, NODEINST *ni)
 
 	if (io_verbose > 0)
 	{
-		ttyputmsg("PORT %s transition delay table", portname);
+		ttyputmsg(_("PORT %s transition delay table"), portname);
 		for (i=0; i<12; i++)
 		{
 			if (rvl[i].tvalue != NULL)
 			{
-				ttyputmsg("transition: %s, delay: %s", rvl[i].tname, rvl[i].tvalue);
+				ttyputmsg(_("transition: %s, delay: %s"), rvl[i].tname, rvl[i].tvalue);
 			}
 		}
 	}
@@ -1125,12 +1125,12 @@ INTSML sdfi_parseiopath(LISPTREE *lt, NODEINST *ni)
 
 	if (io_verbose > 0)
 	{
-		ttyputmsg("IOPATH %s -> %s transition delay table", iportname, oportname);
+		ttyputmsg(_("IOPATH %s -> %s transition delay table"), iportname, oportname);
 		for (i=0; i<12; i++)
 		{
 			if (rvl[i].tvalue != NULL)
 			{
-				ttyputmsg("transition: %s, delay: %s", rvl[i].tname, rvl[i].tvalue);
+				ttyputmsg(_("transition: %s, delay: %s"), rvl[i].tname, rvl[i].tvalue);
 			}
 		}
 	}
