@@ -109,13 +109,6 @@ SUEEXTRAWIRE io_suetwoportwires[] =
 SUEEQUIV io_sueequivs[] =
 {
 	/* name         primitive          NEG ANG    X   Y  VAR                      VALUE  WIR EXTRA-WIRES */
-#if 0
-	{"nand2_my",   &sch_andprim,        1,   0,   0,  0, 0,                       0,      0, 0},
-	{"nand3_my",   &sch_andprim,        1,   0,   0,  0, 0,                       0,      0, 0},
-	{"nor2_my",    &sch_orprim,         1,   0,   0,  0, 0,                       0,      0, 0},
-	{"nor3_my",    &sch_orprim,         1,   0,   0,  0, 0,                       0,      0, 0},
-	{"invert2",    &sch_bufprim,        1,   0,   0,  0, 0,                       0,      0, 0},
-#endif
 	{"pmos10",     &sch_transistorprim, 0, 900, -K2,  0, "SCHEM_transistor_type", "pmos", 3, io_suetransistorwires},
 	{"pmos4",      &sch_transistorprim, 0, 900, -K2,  0, "SCHEM_transistor_type", "pmos", 3, io_suetransistorwires},
 	{"pmos",       &sch_transistorprim, 0, 900, -K2,  0, "SCHEM_transistor_type", "pmos", 3, io_suetransistorwires},
@@ -182,8 +175,10 @@ INTSML     io_sueadddirectory(char *directory);
 INTBIG     io_suearraylength(char *name);
 void       io_suecleardirectories(void);
 NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count);
+char      *io_sueexpandname(char *portname, INTBIG count, INTBIG which);
+char      *io_suefindbusname(ARCINST *ai);
 INTSML     io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy, NODEPROTO *np,
-			NODEINST **ni, PORTPROTO **pp, NODEINST *notthisnode);
+			NODEINST **ni, PORTPROTO **pp, NODEINST *notthisnode, INTBIG lambda);
 NODEINST  *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp);
 void       io_suefreenets(SUENET *firstsn);
 void       io_suefreewires(SUEWIRE *firstsw);
@@ -191,17 +186,18 @@ INTSML     io_suegetnextline(char **keywords, INTSML curlydepth);
 NODEPROTO *io_suegetnodeproto(LIBRARY *lib, char *protoname);
 void       io_suekillnet(SUENET *sn);
 void       io_suekillwire(SUEWIRE *sw);
-INTBIG     io_suemakex(INTBIG x);
-INTBIG     io_suemakey(INTBIG y);
+INTBIG     io_suemakex(INTBIG x, INTBIG lambda);
+INTBIG     io_suemakey(INTBIG y, INTBIG lambda);
 PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *thename);
 SUENET    *io_suenewnet(void);
 SUEWIRE   *io_suenewwire(void);
 void       io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet);
-void       io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y,
-			INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel);
-void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet);
+void       io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
+			INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel, char **thetext);
+void       io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda);
 NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname);
 NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name);
+char      *io_suesearchbusname(ARCINST *ai);
 PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy);
 
 /*
@@ -236,10 +232,10 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 		*filename, **filelist;
 
 	/* open the file */
-	io_suefilein = xopen(lib->libfile, FILETYPESUE, "", &filename);
+	io_suefilein = xopen(lib->libfile, io_filetypesue, "", &filename);
 	if (io_suefilein == 0)
 	{
-		ttyputerr("File %s not found", lib->libfile);
+		ttyputerr(_("File %s not found"), lib->libfile);
 		return(1);
 	}
 
@@ -312,7 +308,7 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 
 	/* read the file */
 	DiaPercent(1, 0);
-	DiaSetText(2, "Reading SUE file...");
+	DiaSetText(2, _("Reading SUE file..."));
 	topfacet = io_suereadfile(lib, facetname);
 	if (topfacet != NONODEPROTO)
 		lib->curnodeproto = topfacet;
@@ -320,7 +316,7 @@ INTSML io_readsuelibrary(LIBRARY *lib)
 	/* clean up */
 	DiaDoneDialog();
 	xclose(io_suefilein);
-	ttyputmsg("%s read", truesuefile);
+	ttyputmsg(_("%s read"), truesuefile);
 
 	return(0);
 }
@@ -330,14 +326,14 @@ INTSML io_readsuelibrary(LIBRARY *lib)
  */
 NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 {
-	char *keywords[MAXKEYWORDS], *thename, *thelabel, *namestring;
+	char *keywords[MAXKEYWORDS], *thename, *thelabel, *thetext, *namestring;
 	char suevarname[200], *detailvar, *detailvalue,
 		*pt, *cpt, *startkey, save;
 	char **argnames, **argvalues, **newargnames, **newargvalues;
 	INTBIG outline[MAXICONPOINTS*2], x, y, type, dx, dy, px, py, pinx, piny, xoff, yoff,
 		numargs, namestrlen;
 	REGISTER INTBIG count, i, lx, hx, ly, hy, curly, xshrink, yshrink,
-		varcount, varindex, varoffset, pos, invertoutput,
+		varcount, varindex, varoffset, pos, invertoutput, lambda,
 		keycount, cx, cy, p1x, p1y, p2x, p2y, start, extent, numextrawires, len;
 	INTSML rot, trn, rotation;
 	XARRAY trans;
@@ -359,6 +355,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 	io_suelastline[0] = 0;
 	numargs = 0;
 	namestrlen = 0;
+	lambda = lib->lambda[sch_tech->techindex];
 	for(;;)
 	{
 	   /* get the next line of text */
@@ -372,7 +369,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			/* write any wires from the last proc */
 			if (facet != NONODEPROTO)
 			{
-				io_sueplacewires(firstsuewire, firstsuenet, facet);
+				io_sueplacewires(firstsuewire, firstsuenet, facet, lambda);
 				io_suefreewires(firstsuewire);
 				io_sueplacenets(firstsuenet, facet);
 				io_suefreenets(firstsuenet);
@@ -382,7 +379,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 
 			if (count < 2)
 			{
-				ttyputerr("Facet %s, line %d: 'proc' is missing arguments: %s",
+				ttyputerr(_("Facet %s, line %d: 'proc' is missing arguments: %s"),
 					facetname, io_suelineno, io_sueorigline);
 				continue;
 			}
@@ -407,7 +404,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				iconfacet = facet = newnodeproto(returninfstr(), lib);
 			} else
 			{
-				ttyputerr("Facet %s, line %d: unknown 'proc' statement: %s",
+				ttyputerr(_("Facet %s, line %d: unknown 'proc' statement: %s"),
 					facetname, io_suelineno, io_sueorigline);
 			}
 			continue;
@@ -418,14 +415,14 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		{
 			if (count < 2)
 			{
-				ttyputerr("Facet %s, line %d: 'make' is missing arguments: %s",
+				ttyputerr(_("Facet %s, line %d: 'make' is missing arguments: %s"),
 					facetname, io_suelineno, io_sueorigline);
 				continue;
 			}
 
 			/* extract parameters */
-			io_sueparseparameters(&keywords[2], count-2, &x, &y, &rot, &trn,
-				&type, &thename, &thelabel);
+			io_sueparseparameters(&keywords[2], count-2, &x, &y, lambda, &rot, &trn,
+				&type, &thename, &thelabel, &thetext);
 
 			/* save the name string */
 			if (thename != 0)
@@ -441,13 +438,12 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				thename = namestring;
 			}
 
-
 			/* ignore self-references */
 			if (namesame(keywords[1], facetname) == 0)
 			{
 				if (x != 0 || y != 0)
 				{
-					/* place facet-center */
+					/* place facet-center? */
 				}
 				continue;
 			}
@@ -481,22 +477,22 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				proto = sch_offpageprim;
 				makeangle(rot, trn, trans);
 				xform(K2, 0, &xoff, &yoff, trans);
-				xoff = muldiv(xoff, sch_tech->deflambda, WHOLE);
-				yoff = muldiv(yoff, sch_tech->deflambda, WHOLE);
+				xoff = muldiv(xoff, lambda, WHOLE);
+				yoff = muldiv(yoff, lambda, WHOLE);
 			} else if (namesame(keywords[1], "input") == 0)
 			{
 				proto = sch_offpageprim;
 				makeangle(rot, trn, trans);
 				xform(-K2, 0, &xoff, &yoff, trans);
-				xoff = muldiv(xoff, sch_tech->deflambda, WHOLE);
-				yoff = muldiv(yoff, sch_tech->deflambda, WHOLE);
+				xoff = muldiv(xoff, lambda, WHOLE);
+				yoff = muldiv(yoff, lambda, WHOLE);
 			} else if (namesame(keywords[1], "output") == 0)
 			{
 				proto = sch_offpageprim;
 				makeangle(rot, trn, trans);
 				xform(K2, 0, &xoff, &yoff, trans);
-				xoff = muldiv(xoff, sch_tech->deflambda, WHOLE);
-				yoff = muldiv(yoff, sch_tech->deflambda, WHOLE);
+				xoff = muldiv(xoff, lambda, WHOLE);
+				yoff = muldiv(yoff, lambda, WHOLE);
 			} else if (namesame(keywords[1], "rename_net") == 0)
 			{
 				proto = sch_wirepinprim;
@@ -509,8 +505,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					{
 						makeangle(rot, trn, trans);
 						xform(0, -K2, &xoff, &yoff, trans);
-						xoff = muldiv(xoff, sch_tech->deflambda, WHOLE);
-						yoff = muldiv(yoff, sch_tech->deflambda, WHOLE);
+						xoff = muldiv(xoff, lambda, WHOLE);
+						yoff = muldiv(yoff, lambda, WHOLE);
 						proto = sch_gndprim;
 					}
 					if (namesame(thename, "vdd") == 0)
@@ -522,8 +518,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				xshrink = -K2;
 				makeangle(rot, trn, trans);
 				xform(Q1, 0, &xoff, &yoff, trans);
-				xoff = muldiv(xoff, sch_tech->deflambda, WHOLE);
-				yoff = muldiv(yoff, sch_tech->deflambda, WHOLE);
+				xoff = muldiv(xoff, lambda, WHOLE);
+				yoff = muldiv(yoff, lambda, WHOLE);
 			}
 
 			/* now check for internal associations to known primitives */
@@ -538,8 +534,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					rotation = io_sueequivs[i].rotation;
 					makeangle(rot, trn, trans);
 					xform(io_sueequivs[i].xoffset, io_sueequivs[i].yoffset, &xoff, &yoff, trans);
-					xoff = muldiv(xoff, sch_tech->deflambda, WHOLE);
-					yoff = muldiv(yoff, sch_tech->deflambda, WHOLE);
+					xoff = muldiv(xoff, lambda, WHOLE);
+					yoff = muldiv(yoff, lambda, WHOLE);
 					rot += rotation;
 					if (rot >= 3600) rot -= 3600;
 					detailvar = io_sueequivs[i].detailvar;
@@ -573,7 +569,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			{
 				/* see if the reference is arrayed */
 				len = io_suearraylength(thename);
-				if (len > 0)
+				if (len > 1)
 				{
 					/* arrayed node: search for the pseudo version */
 					strcpy(suevarname, keywords[1]);
@@ -615,14 +611,14 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			/* stop now if SUE node is unknown */
 			if (proto == NONODEPROTO)
 			{
-				ttyputmsg("Cannot make '%s' in facet %s", keywords[1], describenodeproto(facet));
+				ttyputmsg(_("Cannot make '%s' in facet %s"), keywords[1], describenodeproto(facet));
 				continue;
 			}
 
 			/* create the instance */
 			defaultnodesize(proto, &px, &py);
-			px -= muldiv(xshrink, sch_tech->deflambda, WHOLE);
-			py -= muldiv(yshrink, sch_tech->deflambda, WHOLE);
+			px -= muldiv(xshrink, lambda, WHOLE);
+			py -= muldiv(yshrink, lambda, WHOLE);
 			lx = x - px/2 + xoff;   hx = lx + px;
 			ly = y - py/2 + yoff;   hy = ly + py;
 			ni = newnodeinst(proto, lx, hx, ly, hy, trn, rot, facet);
@@ -643,8 +639,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				if (pp == NOPORTPROTO) continue;
 				portposition(ni, pp, &x, &y);
 				makeangle(ni->rotation, ni->transpose, trans);
-				px = muldiv(extrawires[i].xoffset, sch_tech->deflambda, WHOLE);
-				py = muldiv(extrawires[i].yoffset, sch_tech->deflambda, WHOLE);
+				px = muldiv(extrawires[i].xoffset, lambda, WHOLE);
+				py = muldiv(extrawires[i].yoffset, lambda, WHOLE);
 				xform(px, py, &dx, &dy, trans);
 				defaultnodesize(sch_wirepinprim, &px, &py);
 				pinx = x + dx;   piny = y + dy;
@@ -661,7 +657,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					ni, pp, x, y, nni, npp, pinx, piny, facet);
 				if (ai == NOARCINST)
 				{
-					ttyputerr("Error adding extra wires to node %s", keywords[1]);
+					ttyputerr(_("Error adding extra wires to node %s"), keywords[1]);
 					break;
 				}
 			}
@@ -677,7 +673,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 					ppt = io_suenewexport(facet, ni, pp, thename);
 					if (ppt == NOPORTPROTO)
 					{
-						ttyputmsg("Facet %s, line %d, could not create port %s", 
+						ttyputmsg(_("Facet %s, line %d, could not create port %s"), 
 							facetname, io_suelineno, thename);
 					} else
 					{
@@ -716,7 +712,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 				sprintf(suevarname, "SUE_%s", &keywords[i][1]);
 				for(pt = suevarname; *pt != 0; pt++) if (*pt == ' ')
 				{
-					ttyputmsg("Facet %s, line %d, bad variable name (%s)", 
+					ttyputmsg(_("Facet %s, line %d, bad variable name (%s)"), 
 						facetname, io_suelineno, suevarname);
 					break;
 				}
@@ -740,7 +736,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 						pos = -pos;
 						var->textdescript |= VTYOFFNEG;
 					}
-					var->textdescript |= (pos * 4 / sch_tech->deflambda) << VTYOFFSH;
+					var->textdescript |= (pos * 4 / lambda) << VTYOFFSH;
 				}
 			}
 			continue;
@@ -750,10 +746,10 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		if (namesame(keywords[0], "make_wire") == 0)
 		{
 			sw = io_suenewwire();
-			sw->x[0] = io_suemakex(atoi(keywords[1]));
-			sw->y[0] = io_suemakey(atoi(keywords[2]));
-			sw->x[1] = io_suemakex(atoi(keywords[3]));
-			sw->y[1] = io_suemakey(atoi(keywords[4]));
+			sw->x[0] = io_suemakex(atoi(keywords[1]), lambda);
+			sw->y[0] = io_suemakey(atoi(keywords[2]), lambda);
+			sw->x[1] = io_suemakex(atoi(keywords[3]), lambda);
+			sw->y[1] = io_suemakey(atoi(keywords[4]), lambda);
 			sw->nextsuewire = firstsuewire;
 			firstsuewire = sw;
 			continue;
@@ -762,8 +758,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		/* handle "icon_term" for defining ports in icons */
 		if (namesame(keywords[0], "icon_term") == 0)
 		{
-			io_sueparseparameters(&keywords[1], count-1, &x, &y, &rot, &trn,
-				&type, &thename, &thelabel);
+			io_sueparseparameters(&keywords[1], count-1, &x, &y, lambda, &rot, &trn,
+				&type, &thename, &thelabel, &thetext);
 			strcpy(suevarname, thename);
 
 			if (net_buswidth(suevarname) > 1) proto = sch_buspinprim; else
@@ -778,7 +774,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			ppt = io_suenewexport(facet, ni, proto->firstportproto, suevarname);
 			if (ppt == NOPORTPROTO)
 			{
-				ttyputmsg("Facet %s, line %d, could not create port %s", 
+				ttyputmsg(_("Facet %s, line %d, could not create port %s"), 
 					facetname, io_suelineno, suevarname);
 			} else
 			{
@@ -794,15 +790,15 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		{
 			if (count != 9)
 			{
-				ttyputerr("Facet %s, line %d: needs 9 arguments, has %d: %s",
+				ttyputerr(_("Facet %s, line %d: needs 9 arguments, has %d: %s"),
 					facetname, io_suelineno, count, io_sueorigline);
 				continue;
 			}
 			start = 0;   extent = 359;
-			p1x = io_suemakex(atoi(keywords[1]));
-			p1y = io_suemakey(atoi(keywords[2]));
-			p2x = io_suemakex(atoi(keywords[3]));
-			p2y = io_suemakey(atoi(keywords[4]));
+			p1x = io_suemakex(atoi(keywords[1]), lambda);
+			p1y = io_suemakey(atoi(keywords[2]), lambda);
+			p2x = io_suemakex(atoi(keywords[3]), lambda);
+			p2y = io_suemakey(atoi(keywords[4]), lambda);
 			if (namesame(keywords[5], "-start") == 0) start = atoi(keywords[6]);
 			if (namesame(keywords[7], "-extent") == 0) extent = atoi(keywords[8]);
 			lx = mini(p1x, p2x);   hx = maxi(p1x, p2x);
@@ -830,8 +826,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		{
 			for(i=1; i<count; i++)
 			{
-				if ((i%2) != 0) outline[i-1] = io_suemakex(atoi(keywords[i])); else
-					outline[i-1] = io_suemakey(atoi(keywords[i]));
+				if ((i%2) != 0) outline[i-1] = io_suemakex(atoi(keywords[i]), lambda); else
+					outline[i-1] = io_suemakey(atoi(keywords[i]), lambda);
 			}
 			keycount = count / 2;
 
@@ -864,7 +860,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			/* extract parameters */
 			if (namesame(keywords[1], "$args") != 0)
 			{
-				ttyputerr("Facet %s, line %d: has unrecognized 'icon_setup'",
+				ttyputerr(_("Facet %s, line %d: has unrecognized 'icon_setup'"),
 					facetname, io_suelineno);
 				continue;
 			}
@@ -929,8 +925,8 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 		if (namesame(keywords[0], "icon_property") == 0)
 		{
 			/* extract parameters */
-			io_sueparseparameters(&keywords[1], count-1, &x, &y, &rot, &trn,
-				&type, &thename, &thelabel);
+			io_sueparseparameters(&keywords[1], count-1, &x, &y, lambda, &rot, &trn,
+				&type, &thename, &thelabel, &thetext);
 			if (thelabel == 0) continue;
 
 			/* substitute parameters */
@@ -960,16 +956,31 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 			continue;
 		}
 
+		/* handle "make_text" for placing strings */
+		if (namesame(keywords[0], "make_text") == 0)
+		{
+			/* extract parameters */
+			io_sueparseparameters(&keywords[1], count-1, &x, &y, lambda, &rot, &trn,
+				&type, &thename, &thelabel, &thetext);
+			if (thetext == 0) continue;
+
+			ni = newnodeinst(gen_invispinprim, x, x, y, y, 0, 0, facet);
+			if (ni == NONODEINST) continue;
+			var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)thetext, VSTRING|VDISPLAY);
+			if (var != NOVARIABLE) var->textdescript = (TXTSMALL << VTSIZESH) | VTPOSCENT;
+			endobjectchange((INTBIG)ni, VNODEINST);
+			continue;
+		}
+
 		/* ignore known keywords */
 		if (namesame(keywords[0], "icon_title") == 0 ||
-			namesame(keywords[0], "make_text") == 0 ||
 			namesame(keywords[0], "make_line") == 0 ||
 			namesame(keywords[0], "}") == 0)
 		{
 			continue;
 		}
 
-		ttyputerr("Facet %s, line %d: unknown keyword (%s): %s", facetname,
+		ttyputerr(_("Facet %s, line %d: unknown keyword (%s): %s"), facetname,
 			io_suelineno, keywords[0], io_sueorigline);
 	}
 
@@ -988,7 +999,7 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
 	/* cleanup the current facet */
 	if (facet != NONODEPROTO)
 	{
-		io_sueplacewires(firstsuewire, firstsuenet, facet);
+		io_sueplacewires(firstsuewire, firstsuenet, facet, lambda);
 		io_suefreewires(firstsuewire);
 		io_sueplacenets(firstsuenet, facet);
 		io_suefreenets(firstsuenet);
@@ -1012,12 +1023,13 @@ NODEPROTO *io_suereadfile(LIBRARY *lib, char *facetname)
  * "-type"    placed into "type"
  * "-name"    placed into "thename".
  * "-label"   placed into "thelabel".
+ * "-text"    placed into "thetext".
  */
-void io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y,
-	INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel)
+void io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y, INTBIG lambda,
+	INTSML *rot, INTSML *trn, INTBIG *type, char **thename, char **thelabel, char **thetext)
 {
 	char *pt;
-	REGISTER INTSML doingname;
+	REGISTER INTSML textloc;
 	REGISTER INTBIG i;
 
 	*x = *y = 0;
@@ -1026,6 +1038,7 @@ void io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y,
 	*type = 0;
 	*thename = 0;
 	*thelabel = 0;
+	*thetext = 0;
 	for(i=0; i<count; i += 2)
 	{
 		if (namesame(keywords[i], "-origin") == 0)
@@ -1054,10 +1067,12 @@ void io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y,
 			if (namesame(keywords[i+1], "inout") == 0) *type = BIDIRPORT;
 		}
 		if (namesame(keywords[i], "-name") == 0 ||
-			namesame(keywords[i], "-label") == 0)
+			namesame(keywords[i], "-label") == 0 ||
+			namesame(keywords[i], "-text") == 0)
 		{
-			if (namesame(keywords[i], "-name") == 0) doingname = 1; else
-				doingname = 0;
+			if (namesame(keywords[i], "-name") == 0) textloc = 0; else
+				if (namesame(keywords[i], "-label") == 0) textloc = 1; else
+					textloc = 2;
 			(void)initinfstr();
 			pt = keywords[i+1];
 			if (pt[0] != '{') (void)addstringtoinfstr(pt); else
@@ -1081,12 +1096,16 @@ void io_sueparseparameters(char **keywords, INTBIG count, INTBIG *x, INTBIG *y,
 					i = -1;
 				}
 			}
-			if (doingname != 0) *thename = returninfstr(); else
-				*thelabel = returninfstr();
+			switch (textloc)
+			{
+				case 0: *thename = returninfstr();    break;
+				case 1: *thelabel = returninfstr();   break;
+				case 2: *thetext = returninfstr();    break;
+			}
 		}
 	}
-	*x = io_suemakex(*x);
-	*y = io_suemakey(*y);
+	*x = io_suemakex(*x, lambda);
+	*y = io_suemakey(*y, lambda);
 	*rot = (3600 - *rot) % 3600;
 }
 
@@ -1139,15 +1158,15 @@ PORTPROTO *io_suenewexport(NODEPROTO *facet, NODEINST *ni, PORTPROTO *pp, char *
 }
 
 /* Routine to convert SUE X coordinate "x" to Electric coordinates */
-INTBIG io_suemakex(INTBIG x)
+INTBIG io_suemakex(INTBIG x, INTBIG lambda)
 {
-	return(x * sch_tech->deflambda / 8);
+	return(x * lambda / 8);
 }
 
 /* Routine to convert SUE Y coordinate "y" to Electric coordinates */
-INTBIG io_suemakey(INTBIG y)
+INTBIG io_suemakey(INTBIG y, INTBIG lambda)
 {
-	return(-y * sch_tech->deflambda / 8);
+	return(-y * lambda / 8);
 }
 
 /*
@@ -1157,24 +1176,31 @@ INTBIG io_suemakey(INTBIG y)
 void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 {
 	SUENET *sn;
-	REGISTER INTBIG pass;
+	REGISTER INTBIG pass, isbus;
 	REGISTER ARCINST *ai, *bestai;
 	REGISTER INTBIG cx, cy, dist, bestdist, sea;
 	REGISTER GEOM *geom;
+	REGISTER char *netname, *busname;
 
-	for(pass=0; pass<2; pass++)
+	/* 3 passes: qualified labels, unqualified busses, unqualified wires */
+	for(pass=0; pass<3; pass++)
 	{
 		for(sn = firstsuenet; sn != NOSUENET; sn = sn->nextsuenet)
 		{
 			/* unqualified labels (starting with "[") happen second */
 			if (*sn->label == '[')
 			{
+				/* unqualified label: pass 2 or 3 only */
 				if (pass == 0) continue;
 			} else
 			{
-				if (pass == 1) continue;
+				/* qualified label: pass 1 only */
+				if (pass != 0) continue;
 			}
 
+			/* see if this is a bus */
+			if (net_buswidth(sn->label) > 1) isbus = 1; else isbus = 0;
+
 			sea = initsearch(sn->x, sn->x, sn->y, sn->y, facet);
 			bestai = NOARCINST;
 			for(;;)
@@ -1183,6 +1209,13 @@ void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 				if (geom == NOGEOM) break;
 				if (geom->entrytype != OBJARCINST) continue;
 				ai = geom->entryaddr.ai;
+				if (isbus != 0)
+				{
+					if (ai->proto != sch_busarc) continue;
+				} else
+				{
+					if (ai->proto == sch_busarc) continue;
+				}
 				cx = (ai->end[0].xpos + ai->end[1].xpos) / 2;
 				cy = (ai->end[0].ypos + ai->end[1].ypos) / 2;
 				dist = computedistance(cx, cy, sn->x, sn->y);
@@ -1193,16 +1226,139 @@ void io_sueplacenets(SUENET *firstsuenet, NODEPROTO *facet)
 				}
 			}
 			if (bestai != NOARCINST)
-				us_setarcname(bestai, sn->label);
+			{
+				if (pass == 1)
+				{
+					/* only allow busses */
+					if (bestai->proto != sch_busarc) continue;
+				} else if (pass == 2)
+				{
+					/* disallow busses */
+					if (bestai->proto == sch_busarc) continue;
+				}
+				netname = sn->label;
+				if (*netname == '[')
+				{
+					/* find the proper name of the network */
+					busname = io_suefindbusname(bestai);
+					if (busname != 0)
+					{
+						(void)initinfstr();
+						(void)addstringtoinfstr(busname);
+						(void)addstringtoinfstr(netname);
+						netname = returninfstr();
+					}
+				}
+				us_setarcname(bestai, netname);
+			}
 		}
 	}
 }
 
+/*
+ * Routine to start at "ai" and search all wires until it finds a named bus.
+ * Returns zero if no bus name is found.
+ */
+char *io_suefindbusname(ARCINST *ai)
+{
+	REGISTER ARCINST *oai;
+	REGISTER char *busname, *pt;
+	REGISTER VARIABLE *var;
+	static char pseudobusname[50];
+	REGISTER INTBIG index, len;
+
+	for(oai = ai->parent->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
+		oai->temp1 = 0;
+	busname = io_suesearchbusname(ai);
+	if (busname == 0)
+	{
+		for(index=1; ; index++)
+		{
+			sprintf(pseudobusname, "NET%ld", index);
+			len = strlen(pseudobusname);
+			for(oai = ai->parent->firstarcinst; oai != NOARCINST; oai = oai->nextarcinst)
+			{
+				var = getvalkey((INTBIG)oai, VARCINST, VSTRING, el_arc_name);
+				if (var == NOVARIABLE) continue;
+				pt = (char *)var->addr;
+				if (namesame(pseudobusname, pt) == 0) break;
+				if (namesamen(pseudobusname, pt, len) == 0 &&
+					pt[len] == '[') break;
+			}
+			if (oai == NOARCINST) break;
+		}
+		busname = pseudobusname;
+	}
+	return(busname);
+}
+
+char *io_suesearchbusname(ARCINST *ai)
+{
+	REGISTER ARCINST *oai;
+	REGISTER char *busname;
+	REGISTER INTBIG i;
+	REGISTER NODEINST *ni;
+	REGISTER PORTARCINST *pi;
+	REGISTER PORTEXPINST *pe;
+	REGISTER PORTPROTO *pp;
+	REGISTER VARIABLE *var;
+
+	ai->temp1 = 1;
+	if (ai->proto == sch_busarc)
+	{
+		var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
+		if (var != NOVARIABLE)
+		{
+			(void)initinfstr();
+			for(busname = (char *)var->addr; *busname != 0; busname++)
+			{
+				if (*busname == '[') break;
+				(void)addtoinfstr(*busname);
+			}
+			return(returninfstr());
+		}
+	}
+	for(i=0; i<2; i++)
+	{
+		ni = ai->end[i].nodeinst;
+		if (ni->proto != sch_wirepinprim && ni->proto != sch_buspinprim &&
+			ni->proto != sch_offpageprim) continue;
+		if (ni->proto == sch_buspinprim || ni->proto == sch_offpageprim)
+		{
+			/* see if there is an arrayed port here */
+			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
+			{
+				pp = pe->exportproto;
+				for(busname = pp->protoname; *busname != 0; busname++)
+					if (*busname == '[') break;
+				if (*busname != 0)
+				{
+					(void)initinfstr();
+					for(busname = pp->protoname; *busname != 0; busname++)
+					{
+						if (*busname == '[') break;
+						(void)addtoinfstr(*busname);
+					}
+					return(returninfstr());
+				}
+			}
+		}
+		for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
+		{
+			oai = pi->conarcinst;
+			if (oai->temp1 != 0) continue;
+			busname = io_suesearchbusname(oai);
+			if (busname != 0) return(busname);
+		}
+	}
+	return(0);
+}
+
 /*
  * Routine to place all SUE wires into the facet (they are in a linked
  * list headed by "firstsuewire").
  */
-void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet)
+void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *facet, INTBIG lambda)
 {
 	SUEWIRE *sw, *osw;
 	SUENET *sn;
@@ -1371,7 +1527,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 		{
 			if (sw->ni[i] != NONODEINST) continue;
 			if (io_suefindnode(&sw->x[i], &sw->y[i], sw->x[1-i], sw->y[1-i], facet,
-				&sw->ni[i], &sw->pp[i], sw->ni[1-i]) == 0)
+				&sw->ni[i], &sw->pp[i], sw->ni[1-i], lambda) == 0)
 			{
 				if (sw->proto == sch_busarc) proto = sch_buspinprim; else
 					proto = sch_wirepinprim;
@@ -1415,7 +1571,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 							sw->ni[i], sw->pp[i], sw->x[i], sw->y[i], facet);
 					if (ai == NOARCINST)
 					{
-						ttyputerr("Error making fake connection");
+						ttyputerr(_("Error making fake connection"));
 						break;
 					}
 					endobjectchange((INTBIG)ai, VARCINST);
@@ -1432,7 +1588,7 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
 			sw->ni[1], sw->pp[1], sw->x[1], sw->y[1], facet);
 		if (ai == NOARCINST)
 		{
-			ttyputerr("Error placing wire");
+			ttyputerr(_("Error placing wire"));
 			continue;
 		}
 
@@ -1454,14 +1610,151 @@ void io_sueplacewires(SUEWIRE *firstsuewire, SUENET *firstsuenet, NODEPROTO *fac
  */
 NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 {
-	REGISTER NODEPROTO *iconnp, *newnp, *type;
-	REGISTER NODEINST *ni, *newni, *end0, *end1;
+	REGISTER NODEPROTO *iconnp, *contentsnp, *newnp, *type, *pinproto;
+	REGISTER NODEINST *ni, *newni, *end0, *end1, *pinni;
 	REGISTER PORTPROTO *port0, *port1, *pp, *newpp;
+	REGISTER ARCPROTO *conproto;
 	REGISTER ARCINST *ai, *newai;
-	char size[20];
+	REGISTER VARIABLE *var;
+	REGISTER INTBIG i, sizex, sizey, slop, lxdiff, hxdiff, lydiff, hydiff,
+		diff, side, pinsizex, pinsizey, lx, hx, ly, hy, ox, oy, width;
+	INTBIG x, y;
+	char size[20], *expandedname;
 
+	/* get the original icon and contents */
+	contentsnp = iconview(proto);
+	if (contentsnp == NONODEPROTO) contentsnp = proto;
 	iconnp = iconview(proto);
 	if (iconnp == NONODEPROTO) iconnp = proto;
+
+	/* create the arrayed contents facet */
+	(void)initinfstr();
+	(void)addstringtoinfstr(proto->cell->cellname);
+	sprintf(size, "-Size-%ld{sch}", count);
+	(void)addstringtoinfstr(size);
+	newnp = newnodeproto(returninfstr(), proto->cell->lib);
+	if (newnp == NONODEPROTO) return(NONODEPROTO);
+
+	/* build the arrayed contents facet */
+	sizex = iconnp->highx - iconnp->lowx;
+	sizey = iconnp->highy - iconnp->lowy;
+	slop = maxi(sizex, sizey) / 5;
+	for(i=0; i<count; i++)
+	{
+		lx = (sizex+slop*2) * i + slop;   hx = lx + sizex;
+		ly = (sizey+slop*2) * i + slop;   hy = ly + sizey;
+		newni = newnodeinst(iconnp, lx, hx, ly, hy, 0, 0, newnp);
+		if (newni == NONODEINST) return(NONODEPROTO);
+		endobjectchange((INTBIG)newni, VNODEINST);
+		for(pp = iconnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		{
+			portposition(pp->subnodeinst, pp->subportproto, &x, &y);
+			lxdiff = abs(x-iconnp->lowx);   hxdiff = abs(x-iconnp->highx);
+			lydiff = abs(y-iconnp->lowy);   hydiff = abs(y-iconnp->highy);
+			diff = lxdiff;   side = 0;
+			if (hxdiff < diff) { diff = hxdiff;   side = 1; }
+			if (lydiff < diff) { diff = lydiff;   side = 2; }
+			if (hydiff < diff) { diff = hydiff;   side = 3; }
+			portposition(newni, pp, &x, &y);
+			switch (side)
+			{
+				case 0:		/* left side */
+					ox = x - slop;   oy = y;   break;
+				case 1:		/* right side */
+					ox = x + slop;   oy = y;   break;
+				case 2:		/* bottom side */
+					ox = x;   oy = y - slop;   break;
+				case 3:		/* top side */
+					ox = x;   oy = y + slop;   break;
+			}
+			width = net_buswidth(pp->protoname);
+			if (width > 1)
+			{
+				pinproto = sch_buspinprim;
+				conproto = sch_busarc;
+			} else
+			{
+				pinproto = sch_wirepinprim;
+				conproto = sch_wirearc;
+			}
+			pinsizex = pinproto->highx - pinproto->lowx;
+			pinsizey = pinproto->highy - pinproto->lowy;
+			lx = ox - pinsizex/2;   hx = lx + pinsizex;
+			ly = oy - pinsizey/2;   hy = ly + pinsizey;
+			pinni = newnodeinst(pinproto, lx, hx, ly, hy, 0, 0, newnp);
+			if (pinni == NONODEINST) return(NONODEPROTO);
+			endobjectchange((INTBIG)pinni, VNODEINST);
+			newai = newarcinst(conproto, conproto->nominalwidth, us_makearcuserbits(conproto),
+				newni, pp, x, y, pinni, pinproto->firstportproto, ox, oy, newnp);
+			if (newai == NOARCINST) continue;
+			expandedname = io_sueexpandname(pp->protoname, count, i);
+			var = setvalkey((INTBIG)newai, VARCINST, el_arc_name,
+				(INTBIG)expandedname, VSTRING|VDISPLAY);
+			switch (side)
+			{
+				case 0:		/* left side */
+					var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSUPLEFT;   break;
+				case 1:		/* right side */
+					var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSUPRIGHT;  break;
+				case 2:		/* bottom side */
+					var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSRIGHT;    break;
+				case 3:		/* top side */
+					var->textdescript = (var->textdescript & ~VTPOSITION) | VTPOSRIGHT;    break;
+			}
+			endobjectchange((INTBIG)newai, VARCINST);
+		}
+	}
+	pinsizex = sch_buspinprim->highx - sch_buspinprim->lowx;
+	pinsizey = sch_buspinprim->highy - sch_buspinprim->lowy;
+	for(pp = iconnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+	{
+		expandedname = io_sueexpandname(pp->protoname, count, -1);
+		portposition(pp->subnodeinst, pp->subportproto, &x, &y);
+		lxdiff = abs(x-iconnp->lowx);   hxdiff = abs(x-iconnp->highx);
+		lydiff = abs(y-iconnp->lowy);   hydiff = abs(y-iconnp->highy);
+		diff = lxdiff;   side = 0;
+		if (hxdiff < diff) { diff = hxdiff;   side = 1; }
+		if (lydiff < diff) { diff = lydiff;   side = 2; }
+		if (hydiff < diff) { diff = hydiff;   side = 3; }
+		switch (side)
+		{
+			case 0:		/* left side */
+				x = 0;
+				y = muldiv(y - iconnp->lowy, count*(sizey+slop*2), iconnp->highy - iconnp->lowy);
+				ox = x-slop*2;   oy = y;
+				break;
+			case 1:		/* right side */
+				x = count*(sizex+slop*2);
+				y = muldiv(y - iconnp->lowy, count*(sizey+slop*2), iconnp->highy - iconnp->lowy);
+				ox = x+slop*2;   oy = y;
+				break;
+			case 2:		/* bottom side */
+				x = muldiv(x - iconnp->lowx, count*(sizex+slop*2), iconnp->highx - iconnp->lowx);
+				y = 0;
+				ox = x;   oy = y-slop*2;
+				break;
+			case 3:		/* top side */
+				x = muldiv(x - iconnp->lowx, count*(sizex+slop*2), iconnp->highx - iconnp->lowx);
+				y = count*(sizey+slop*2);
+				ox = x;   oy = y+slop*2;
+				break;
+		}
+		lx = x - pinsizex/2;   hx = lx + pinsizex;
+		ly = y - pinsizey/2;   hy = ly + pinsizey;
+		pinni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, newnp);
+		if (pinni == NONODEINST) continue;
+		endobjectchange((INTBIG)pinni, VNODEINST);
+		lx = ox - pinsizex/2;   hx = lx + pinsizex;
+		ly = oy - pinsizey/2;   hy = ly + pinsizey;
+		newni = newnodeinst(sch_buspinprim, lx, hx, ly, hy, 0, 0, newnp);
+		if (newni == NONODEINST) continue;
+		newpp = newportproto(newnp, newni, sch_buspinprim->firstportproto, expandedname);
+		endobjectchange((INTBIG)newni, VNODEINST);
+		newai = newarcinst(sch_busarc, sch_busarc->nominalwidth, us_makearcuserbits(sch_busarc),
+			pinni, sch_buspinprim->firstportproto, x, y, newni, sch_buspinprim->firstportproto, ox, oy, newnp);
+	}
+
+	/* create the arrayed icon facet */
 	(void)initinfstr();
 	(void)addstringtoinfstr(proto->cell->cellname);
 	sprintf(size, "-Size-%ld{ic}", count);
@@ -1470,7 +1763,7 @@ NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 	if (newnp == NONODEPROTO) return(NONODEPROTO);
 	newnp->userbits |= WANTNEXPAND;
 
-	/* copy the contents */
+	/* copy the icon to the arrayed icon */
 	for(ni = iconnp->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
 	{
 		type = ni->proto;
@@ -1504,11 +1797,99 @@ NODEPROTO *io_suecreatepseudo(NODEPROTO *proto, INTBIG count)
 		end0 = (NODEINST *)pp->subnodeinst->temp1;
 		if (end0->proto == pp->subnodeinst->proto) port0 = pp->subportproto; else
 			port0 = sch_buspinprim->firstportproto;
-		newpp = newportproto(newnp, end0, port0, pp->protoname);
+		expandedname = io_sueexpandname(pp->protoname, count, -1);
+		newpp = newportproto(newnp, end0, port0, expandedname);
 	}
 	return(newnp);
 }
 
+/*
+ * Routine to convert port name "portname" to an expanded version that handles
+ * "count" times as many signals.  If "which" is negative, expand to the full
+ * size.  Otherwise expand only entry "which".
+ */
+char *io_sueexpandname(char *portname, INTBIG count, INTBIG which)
+{
+	REGISTER char *pt, *pt2, *endpart, save;
+	REGISTER INTBIG i, index, startindex;
+	char arrbounds[30];
+
+	/* copy the name part */
+	(void)initinfstr();
+	for(pt = portname; *pt != 0; pt++)
+	{
+		if (*pt == '[') break;
+		(void)addtoinfstr(*pt);
+	}
+
+	/* if there is just a name, array it and stop */
+	if (*pt == 0)
+	{
+		if (which < 0)
+			sprintf(arrbounds, "[1:%ld]", count); else
+				sprintf(arrbounds, "[%ld]", which+1);
+		(void)addstringtoinfstr(arrbounds);
+		return(returninfstr());
+	}
+
+	/* arraying an array: magnify each element */
+	(void)addtoinfstr(*pt++);
+	for(;;)
+	{
+		for(endpart = pt; *endpart != 0; endpart++)
+			if (*endpart == ':' || *endpart == ']' || *endpart == ',') break;
+		if (*endpart == ':')
+		{
+			*endpart = 0;
+			startindex = myatoi(pt);
+			*endpart++ = ':';
+			pt2 = endpart;
+			for(endpart = pt2; *endpart != 0; endpart++)
+				if (*endpart == ']' || *endpart == ',') break;
+			save = *endpart;   *endpart = 0;
+			index = myatoi(pt2);
+			if (which < 0)
+				sprintf(arrbounds, "%ld:%ld", startindex*count-count+1, index*count); else
+					sprintf(arrbounds, "%ld:%ld", which*(index-startindex+1)+1, (which+1)*(index-startindex+1));
+			(void)addstringtoinfstr(arrbounds);
+		} else
+		{
+			save = *endpart;   *endpart = 0;
+			if (isanumber(pt) != 0)
+			{
+				index = myatoi(pt);
+				if (which < 0)
+					sprintf(arrbounds, "%ld:%ld", index*count-count+1, index*count); else
+						sprintf(arrbounds, "%ld", index*count-count+which+1);
+				(void)addstringtoinfstr(arrbounds);
+			} else
+			{
+				if (which < 0)
+				{
+					for(i=0; i<count; i++)
+					{
+						if (i != 0) (void)addtoinfstr(',');
+						(void)addstringtoinfstr(pt);
+						sprintf(arrbounds, "_%ld", i+1);
+						(void)addstringtoinfstr(arrbounds);
+					}
+				} else
+				{
+					(void)addstringtoinfstr(pt);
+					sprintf(arrbounds, "_%ld", which+1);
+					(void)addstringtoinfstr(arrbounds);
+				}
+			}
+		}
+		*endpart = save;
+		if (*endpart == 0) { addtoinfstr(']');   break; }
+		(void)addtoinfstr(*endpart);
+		if (*endpart == ']') break;
+		pt = endpart + 1;
+	}
+	return(returninfstr());
+}
+
 /*
  * Routine to find the port on node "ni" that attaches to the wire from (x,y) to (ox,oy).
  * Returns NOPORTPROTO if not found.
@@ -1552,10 +1933,23 @@ PORTPROTO *io_suewiredport(NODEINST *ni, INTBIG *x, INTBIG *y, INTBIG ox, INTBIG
 INTBIG io_suearraylength(char *name)
 {
 	REGISTER char *pt;
+	REGISTER INTBIG numopen, numclose;
 
-	if (name == 0) return(0);
-	for(pt = name; *pt != 0; pt++) if (*pt == '[') break;
-	if (*pt == 0) return(0);
+	if (name == 0) return(1);
+	numopen = numclose = 0;
+	for(pt = name; *pt != 0; pt++)
+	{
+		if (*pt == '[') numopen++;
+		if (*pt == ']') numclose++;
+	}
+	if (numopen == 0 && numclose == 0)
+	{
+		(void)initinfstr();
+		(void)addtoinfstr('[');
+		(void)addstringtoinfstr(name);
+		(void)addtoinfstr(']');
+		return(net_buswidth(returninfstr()));
+	}
 	return(net_buswidth(name));
 }
 
@@ -1599,7 +1993,7 @@ NODEINST *io_suefindpinnode(INTBIG x, INTBIG y, NODEPROTO *np, PORTPROTO **thepp
  * Routine to find the node at (x, y) and return it.
  */
 INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
-	NODEPROTO *np, NODEINST **rni, PORTPROTO **rpp, NODEINST *notthisnode)
+	NODEPROTO *np, NODEINST **rni, PORTPROTO **rpp, NODEINST *notthisnode, INTBIG lambda)
 {
 	REGISTER GEOM *geom;
 	REGISTER INTBIG sea;
@@ -1609,7 +2003,7 @@ INTSML io_suefindnode(INTBIG *x, INTBIG *y, INTBIG ox, INTBIG oy,
 	REGISTER PORTPROTO *pp, *bestpp;
 	static POLYGON *poly = NOPOLYGON;
 
-	slop = sch_tech->deflambda * 10;
+	slop = lambda * 10;
 	sea = initsearch(*x-slop, *x+slop, *y-slop, *y+slop, np);
 	bestpp = NOPORTPROTO;
 	for(;;)
@@ -1690,7 +2084,7 @@ NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name)
 		strcpy(subfilename, io_suedirectories[i]);
 		strcat(subfilename, name);
 		strcat(subfilename, ".sue");
-		f = xopen(subfilename, FILETYPESUE, "", &truename);
+		f = xopen(subfilename, io_filetypesue, "", &truename);
 		if (f != 0)
 		{
 			savefp = io_suefilein;
@@ -1699,7 +2093,7 @@ NODEPROTO *io_suereadfromdisk(LIBRARY *lib, char *name)
 			strcpy(saveorigline, io_sueorigline);
 			strcpy(savesuelastline, io_suelastline);
 			strcpy(lastprogressmsg, DiaGetText(2));
-			strcpy(suevarname, "Reading ");
+			strcpy(suevarname, _("Reading "));
 			strcat(suevarname, name);
 			strcat(suevarname, "...");
 			DiaSetText(2, suevarname);
