@@ -41,29 +41,26 @@
 static KEYWORD ercopt[] =
 {
 	{"analyze",        0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"current-error",  0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"next-error",     0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
-	{"previous-error", 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 COMCOMP erc_tablep = {ercopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "Electrical Rules action", "show defaults"};
+	0, " \t", M_("Electrical Rules action"), M_("show defaults")};
 
 /* ERC: Options Dialog */
 DIALOGITEM erc_optionsdialogitems[] =
 {
- /*  1 */ {0, {108,396,132,460}, BUTTON, "OK"},
- /*  2 */ {0, {108,296,132,360}, BUTTON, "Cancel"},
- /*  3 */ {0, {32,8,48,228}, RADIO, "Must have contact in every area"},
- /*  4 */ {0, {56,8,72,228}, RADIO, "Must have at least 1 contact"},
- /*  5 */ {0, {80,8,96,228}, RADIO, "Do not check for contacts"},
- /*  6 */ {0, {8,44,24,144}, MESSAGE, "For well:"},
- /*  7 */ {0, {32,248,48,480}, RADIO, "Must have contact in every area"},
- /*  8 */ {0, {56,248,72,480}, RADIO, "Must have at least 1 contact"},
- /*  9 */ {0, {80,248,96,480}, RADIO, "Do not check for contacts"},
- /* 10 */ {0, {8,284,24,384}, MESSAGE, "For substrate:"}
+ /*  1 */ {0, {108,396,132,460}, BUTTON, N_("OK")},
+ /*  2 */ {0, {108,296,132,360}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {32,8,48,228}, RADIO, N_("Must have contact in every area")},
+ /*  4 */ {0, {56,8,72,228}, RADIO, N_("Must have at least 1 contact")},
+ /*  5 */ {0, {80,8,96,228}, RADIO, N_("Do not check for contacts")},
+ /*  6 */ {0, {8,44,24,144}, MESSAGE, N_("For well:")},
+ /*  7 */ {0, {32,248,48,480}, RADIO, N_("Must have contact in every area")},
+ /*  8 */ {0, {56,248,72,480}, RADIO, N_("Must have at least 1 contact")},
+ /*  9 */ {0, {80,248,96,480}, RADIO, N_("Do not check for contacts")},
+ /* 10 */ {0, {8,284,24,384}, MESSAGE, N_("For substrate:")}
 };
-DIALOG erc_optionsdialog = {{50,75,191,564}, "ERC Options", 10, erc_optionsdialogitems};
+DIALOG erc_optionsdialog = {{50,75,191,564}, N_("ERC Options"), 0, 10, erc_optionsdialogitems};
 
 /* substrate/well contacts */
 #define NOSUBWELLCON ((SUBWELLCON *)-1)
@@ -72,7 +69,7 @@ typedef struct Isubwellcon
 {
 	INTBIG              x, y;
 	INTBIG              netnum;
-	INTSML              fun;
+	INTBIG              fun;
 	NODEPROTO          *np;
 	struct Isubwellcon *nextsubwellcon;
 } SUBWELLCON;
@@ -96,44 +93,13 @@ typedef struct Isubwellarea
 	POLYGON           *poly;
 	INTSML            layer;
 	TECHNOLOGY        *tech;
+	NODEPROTO         *facet;
 	struct Isubwellarea *nextsubwellarea;
 } SUBWELLAREA;
 
 SUBWELLAREA *erc_subwellareafree = NOSUBWELLAREA;
 SUBWELLAREA *erc_firstsubwellarea = NOSUBWELLAREA;
 
-/* ERC errors */
-#define NOERCERROR ((ERCERROR *)-1)
-
-#define NOSUB         1			/* no substrate contact found in facet */
-#define NOSUBINAREA   2			/* no well contact found in this area */
-#define SUBPROX       3			/* substrate areas too close to each other */
-#define SUBFLOATS     4			/* substrate contact is floating */
-#define SUBDISCON     5			/* substrate contacts disconnected from each other */
-#define NOWELL        6			/* no well contact found in facet */
-#define NOWELLINAREA  7			/* no substrate contact found in this area */
-#define WELLPROX      8			/* well areas too close to each other */
-#define WELLFLOATS    9			/* well contact is floating */
-#define WELLDISCON   10			/* well contacts disconnected from each other */
-#define FLOATINGARC  11			/* arc not globally connected */
-
-typedef struct Iercerror
-{
-	INTBIG            error;
-	INTBIG            x1, y1;
-	INTBIG            x2, y2;
-	POLYGON          *poly1;
-	POLYGON          *poly2;
-	struct Iercerror *prevercerror;
-	struct Iercerror *nextercerror;
-} ERCERROR;
-
-ERCERROR   *erc_ercerrorfree = NOERCERROR;
-ERCERROR   *erc_firstercerror = NOERCERROR;
-ERCERROR   *erc_curercerror = NOERCERROR;
-ERCERROR   *erc_nextercerror = NOERCERROR;
-ERCERROR   *erc_prevercerror = NOERCERROR;
-
 /* miscellaneous */
 
 /* the meaning of "ERC_options" */
@@ -156,25 +122,17 @@ INTBIG      erc_jobsize;					/* number of polygons to analyze */
 INTBIG      erc_polyscrunched;				/* number of polygons analyzed */
 INTBIG      erc_realrun;					/* nonzero if this is the real analysis */
 
-extern AIDENTRY *us_aid;
-
 /* prototypes for local routines */
-ERCERROR    *erc_allocercerror(INTBIG errtype);
 SUBWELLAREA *erc_allocsubwellarea(void);
 SUBWELLCON  *erc_allocsubwellcon(void);
 void         erc_analyzefacet(NODEPROTO *facet);
-void         erc_freeallerrors(void);
 void         erc_freeallsubwellareas(void);
 void         erc_freeallsubwellcons(void);
-void         erc_freeercerror(ERCERROR *ee);
 void         erc_freesubwellarea(SUBWELLAREA *swa);
 void         erc_freesubwellcon(SUBWELLCON *swc);
 void         erc_gathersubandwell(NODEPROTO *np, XARRAY trans);
 void         erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count);
-void         erc_identifypoint(INTBIG x, INTBIG y, NODEPROTO *facet);
 void         erc_optionsdlog(void);
-void         erc_reporterror(void);
-void         erc_showpoly(POLYGON *poly);
 INTSML       erc_substratelayer(TECHNOLOGY *tech, INTSML layer);
 INTSML       erc_truesubstratelayer(TECHNOLOGY *tech, INTSML layer);
 INTSML       erc_truewelllayer(TECHNOLOGY *tech, INTSML layer);
@@ -198,7 +156,6 @@ void erc_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 
 void erc_done(void)
 {
-	erc_freeallerrors();
 	erc_freeallsubwellcons();
 	erc_freeallsubwellareas();
 }
@@ -214,7 +171,7 @@ INTSML erc_set(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		ttyputerr("Usage: tellaid erc analyze");
+		ttyputusage("tellaid erc analyze");
 		return(0);
 	}
 
@@ -228,39 +185,8 @@ INTSML erc_set(INTSML count, char *par[])
 		erc_analyzefacet(np);
 		return(0);
 	}
-	if (namesamen(pp, "current-error", l) == 0)
-	{
-		erc_reporterror();
-		return(0);
-	}
-	if (namesamen(pp, "next-error", l) == 0)
-	{
-		if (erc_nextercerror == NOERCERROR)
-		{
-			ttyputmsg("No more ERC errors");
-			return(0);
-		}
-		erc_curercerror = erc_nextercerror;
-		erc_nextercerror = erc_curercerror->nextercerror;
-		erc_prevercerror = erc_curercerror->prevercerror;
-		erc_reporterror();
-		return(0);
-	}
-	if (namesamen(pp, "previous-error", l) == 0)
-	{
-		if (erc_prevercerror == NOERCERROR)
-		{
-			ttyputmsg("No more ERC errors");
-			return(0);
-		}
-		erc_curercerror = erc_prevercerror;
-		erc_nextercerror = erc_curercerror->nextercerror;
-		erc_prevercerror = erc_curercerror->prevercerror;
-		erc_reporterror();
-		return(0);
-	}
 
-	ttyputerr("Bad TELLAID ERC option: %s", pp);
+	ttyputbadusage("tellaid erc");
 	return(1);
 }
 
@@ -271,43 +197,38 @@ INTSML erc_set(INTSML count, char *par[])
  */
 void erc_analyzefacet(NODEPROTO *facet)
 {
-	REGISTER INTBIG errors, minsep, dist, errtype;
-	extern AIDENTRY *net_aid;
+	REGISTER INTBIG errors, minsep, dist;
 	REGISTER NODEPROTO *np;
 	REGISTER TECHNOLOGY *tech;
-	REGISTER char *abortseq;
+	REGISTER char *abortseq, *errormsg;
 	REGISTER SUBWELLCON *swc, *oswc;
-	REGISTER ERCERROR *ee;
 	REGISTER VARIABLE *var;
 	REGISTER PORTPROTO *pp, *opp;
 	REGISTER SUBWELLAREA *swa, *oswa;
+	REGISTER void *err;
 	extern DIALOG us_progressdialog;
 
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
 		return;
 	}
 
 	/* announce start of analysis */
 	(void)initinfstr();
-	(void)addstringtoinfstr("Checking electrical rules...");
+	(void)addstringtoinfstr(_("Checking electrical rules..."));
 	abortseq = getinterruptkey();
 	if (abortseq != 0)
-	{
-		(void)addstringtoinfstr(" (type ");
-		(void)addstringtoinfstr(abortseq);
-		(void)addstringtoinfstr(" to abort)");
-	}
+		(void)formatinfstr(_(" (type %s to abort)"), abortseq);
 	ttyputmsg(returninfstr());
 	if (DiaInitDialog(&us_progressdialog) != 0) return;
 	DiaPercent(1, 0);
-	DiaSetText(2, "Preparing to analyze...");
+	DiaSetText(2, _("Preparing to analyze..."));
 
 	/* initialize to analyze facet */
-	erc_freeallerrors();
+	initerrorlogging(_("ERC"));
 	erc_freeallsubwellcons();
 	erc_freeallsubwellareas();
 	erc_worstwelldist = erc_worstsubdist = 0;
@@ -344,14 +265,14 @@ void erc_analyzefacet(NODEPROTO *facet)
 	erc_jobsize = erc_polyscrunched;
 
 	/* now gather all of the geometry into the polygon merging system */
-	DiaSetText(2, "Gathering geometry...");
+	DiaSetText(2, _("Gathering geometry..."));
 	mergeinit();
 	erc_realrun = 1;
 	erc_polyscrunched = 0;
 	erc_gathersubandwell(facet, el_matid);
 
 	/* determine the number of polygon points in the analysis */
-	DiaSetText(2, "Analyzing...");
+	DiaSetText(2, _("Analyzing..."));
 	erc_polyscrunched = 0;
 	erc_realrun = 0;
 	mergedone(erc_getpolygon);
@@ -368,11 +289,10 @@ void erc_analyzefacet(NODEPROTO *facet)
 	{
 		if (swc->netnum == 0)
 		{
-			if (swc->fun == NPWELL) errtype = WELLFLOATS; else
-				errtype = SUBFLOATS;
-			ee = erc_allocercerror(errtype);
-			ee->x1 = swc->x;
-			ee->y1 = swc->y;
+			if (swc->fun == NPWELL) errormsg = _("Well contact is floating"); else
+				errormsg = _("Substrate contact is floating");
+			err = logerror(errormsg, erc_facet, 0);
+			(void)addpointtoerror(err, swc->x, swc->y);
 			continue;
 		}
 		for(oswc = swc->nextsubwellcon; oswc != NOSUBWELLCON; oswc = oswc->nextsubwellcon)
@@ -380,13 +300,11 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (oswc->netnum == 0) continue;
 			if (oswc->fun != swc->fun) continue;
 			if (oswc->netnum == swc->netnum) continue;
-			if (swc->fun == NPWELL) errtype = WELLDISCON; else
-				errtype = SUBDISCON;
-			ee = erc_allocercerror(errtype);
-			ee->x1 = swc->x;
-			ee->y1 = swc->y;
-			ee->x2 = oswc->x;
-			ee->y2 = oswc->y;
+			if (swc->fun == NPWELL) errormsg = _("Well contacts are not connected"); else
+				errormsg = _("Substrate contacts are not connected");
+			err = logerror(errormsg, erc_facet, 0);
+			(void)addpointtoerror(err, swc->x, swc->y);
+			(void)addpointtoerror(err, oswc->x, oswc->y);
 			break;
 		}
 	}
@@ -398,7 +316,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (swc->fun == NPSUBSTRATE) break;
 		if (swc == NOSUBWELLCON)
 		{
-			(void)erc_allocercerror(NOSUB);
+			(void)logerror(_("No substrate contact found in this facet"), erc_facet, 0);
 		}
 	}
 
@@ -409,7 +327,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 			if (swc->fun == NPWELL) break;
 		if (swc == NOSUBWELLCON)
 		{
-			(void)erc_allocercerror(NOWELL);
+			(void)logerror(_("No well contact found in this facet"), erc_facet, 0);
 		}
 	}
 
@@ -420,17 +338,17 @@ void erc_analyzefacet(NODEPROTO *facet)
 		{
 			if (swa->tech != oswa->tech || swa->layer != oswa->layer) continue;
 			if (swa->netnum == oswa->netnum && swa->netnum >= 0)
-				minsep = drcmindistance(swa->tech, swa->layer, swa->layer, 1); else
-					minsep = drcmindistance(swa->tech, swa->layer, swa->layer, 0);
+				minsep = drcmindistance(swa->tech, facet->cell->lib, swa->layer, swa->layer, 1); else
+					minsep = drcmindistance(swa->tech, facet->cell->lib, swa->layer, swa->layer, 0);
 			if (minsep < 0) continue;
 			dist = polyseparation(swa->poly, oswa->poly);
 			if (dist < minsep)
 			{
-				if (erc_welllayer(swa->tech, swa->layer) != 0) errtype = WELLPROX; else
-					errtype = SUBPROX;
-				ee = erc_allocercerror(errtype);
-				ee->poly1 = swa->poly;
-				ee->poly2 = oswa->poly;
+				if (erc_welllayer(swa->tech, swa->layer) != 0) errormsg = _("Well areas too close"); else
+					errormsg = _("Substrate areas too close");
+				err = logerror(errormsg, erc_facet, 0);
+				(void)addpolytoerror(err, swa->poly);
+				(void)addpolytoerror(err, oswa->poly);
 			}
 		}
 	}
@@ -443,14 +361,14 @@ void erc_analyzefacet(NODEPROTO *facet)
 		{
 			(void)askaid(us_aid, "show-line", erc_worstwellconx, erc_worstwellcony,
 				erc_worstwelledgex, erc_worstwelledgey, erc_facet);
-			ttyputmsg("Farthest distance from a well contact is %s",
+			ttyputmsg(_("Farthest distance from a well contact is %s"),
 				latoa(erc_worstwelldist));
 		}
 		if (erc_worstsubdist > 0)
 		{
 			(void)askaid(us_aid, "show-line", erc_worstsubconx, erc_worstsubcony,
 				erc_worstsubedgex, erc_worstsubedgey, erc_facet);
-			ttyputmsg("Farthest distance from a substrate contact is %s",
+			ttyputmsg(_("Farthest distance from a substrate contact is %s"),
 				latoa(erc_worstsubdist));
 		}
 	}
@@ -475,7 +393,7 @@ void erc_analyzefacet(NODEPROTO *facet)
 				case NPTRANE2L:
 				case NPTRANSREF:
 				case NPTRANS:
-					ttyputmsg("%ld nodes of type %s", np->temp1, describenodeproto(np));
+					ttyputmsg(_("%ld nodes of type %s"), np->temp1, describenodeproto(np));
 					break;
 			}
 		}
@@ -483,19 +401,14 @@ void erc_analyzefacet(NODEPROTO *facet)
 
 	/* report the number of networks */
 	DiaDoneDialog();
-	ttyputmsg("%ld networks found", erc_globalnetnumber);
+	ttyputmsg(_("%ld networks found"), erc_globalnetnumber);
 	
 	/* report the number of errors found */
-	errors = 0;
-	for(ee = erc_firstercerror; ee != NOERCERROR; ee = ee->nextercerror)
-		errors++;
+	errors = numerrors();
 	if (errors == 0)
-		ttyputmsg("No ERC errors found"); else
-			ttyputmsg("FOUND %ld ERC %s", errors, makeplural("ERROR", errors));
-	setval((INTBIG)us_aid, VAID, "USER_local_capv", errors, VINTEGER|VDONTSAVE);
-	erc_curercerror = NOERCERROR;
-	erc_nextercerror = erc_firstercerror;
-	erc_prevercerror = NOERCERROR;
+		ttyputmsg(_("No ERC errors found")); else
+			ttyputmsg(_("FOUND %ld ERC %s"), errors, makeplural(_("ERROR"), errors));
+	termerrorlogging();
 }
 
 /*
@@ -511,7 +424,8 @@ void erc_gathersubandwell(NODEPROTO *np, XARRAY trans)
 	REGISTER PORTEXPINST *pe;
 	REGISTER PORTPROTO *pp, *opp;
 	REGISTER NETWORK *net;
-	REGISTER INTSML i, tot, nfun, layer;
+	REGISTER INTBIG i, tot, nfun;
+	REGISTER INTSML layer;
 	char *extra;
 	static INTBIG checkstop = 0;
 	XARRAY localrot, localtran, final, subrot;
@@ -547,7 +461,7 @@ void erc_gathersubandwell(NODEPROTO *np, XARRAY trans)
 		{
 			if (erc_realrun != 0)
 			{
-				if (stopping("ERC") != 0) return;
+				if (stopping(STOPREASONERC)) return;
 
 				/* propagate global network numbers into this instance */
 				for(pp = subnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -576,7 +490,7 @@ void erc_gathersubandwell(NODEPROTO *np, XARRAY trans)
 				checkstop++;
 				if ((checkstop%10) == 0)
 				{
-					if (stopping("ERC") != 0) return;
+					if (stopping(STOPREASONERC)) return;
 				}
 				nfun = nodefunction(ni, &extra);
 				ni->proto->temp1++;
@@ -601,7 +515,7 @@ void erc_gathersubandwell(NODEPROTO *np, XARRAY trans)
 				}
 			}
 
-			tot = nodepolys(ni);
+			tot = nodepolys(ni, 0);
 			erc_polyscrunched += tot;
 			if (erc_realrun != 0)
 			{
@@ -629,7 +543,7 @@ void erc_gathersubandwell(NODEPROTO *np, XARRAY trans)
 		checkstop++;
 		if ((checkstop%10) == 0)
 		{
-			if (stopping("ERC") != 0) return;
+			if (stopping(STOPREASONERC)) return;
 		}
 		tot = arcpolys(ai);
 		erc_polyscrunched += tot;
@@ -654,10 +568,11 @@ void erc_gathersubandwell(NODEPROTO *np, XARRAY trans)
 void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML count)
 {
 	REGISTER INTSML i, first, welltype;
-	REGISTER INTBIG dist, bestdist, desiredcontact, perareabit, nocontacterror, prev, xp, yp;
+	REGISTER INTBIG dist, bestdist, desiredcontact, perareabit, prev, xp, yp;
 	REGISTER SUBWELLCON *swc, *bestswc;
-	REGISTER ERCERROR *ee;
 	REGISTER SUBWELLAREA *swa;
+	REGISTER void *err;
+	REGISTER char *nocontacterror;
 	static INTBIG checkstop = 0;
 
 	erc_polyscrunched += count;
@@ -666,7 +581,7 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 	checkstop++;
 	if ((checkstop%10) == 0)
 	{
-		if (stopping("ERC") != 0) return;
+		if (stopping(STOPREASONERC)) return;
 	} else
 	{
 		if (el_pleasestop != 0) return;
@@ -698,13 +613,13 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 		/* P-well */
 		desiredcontact = NPWELL;
 		perareabit = WELLCONPERAREA;
-		nocontacterror = NOWELLINAREA;
+		nocontacterror = _("No well contact found in this area");
 	} else
 	{
 		/* Select */
 		desiredcontact = NPSUBSTRATE;
 		perareabit = SUBCONPERAREA;
-		nocontacterror = NOSUBINAREA;
+		nocontacterror = _("No substrate contact found in this area");
 	}
 
 	/* find a contact in the area */
@@ -721,8 +636,8 @@ void erc_getpolygon(INTSML layer, TECHNOLOGY *tech, INTBIG *x, INTBIG *y, INTSML
 	{
 		if ((erc_options&WELLCONOPTIONS) == perareabit)
 		{
-			ee = erc_allocercerror(nocontacterror);
-			ee->poly1 = swa->poly;
+			err = logerror(nocontacterror, erc_facet, 0);
+			(void)addpolytoerror(err, swa->poly);
 		}
 		return;
 	}
@@ -930,150 +845,6 @@ void erc_freesubwellarea(SUBWELLAREA *swa)
 	erc_subwellareafree = swa;
 }
 
-/******************** ERROR REPORTING ********************/
-
-void erc_reporterror(void)
-{
-	REGISTER ERCERROR *ee;
-
-	ee = erc_curercerror;
-	if (ee == NOERCERROR)
-	{
-		ttyputmsg("No ERC errors");
-		return;
-	}
-	(void)askaid(us_aid, "clear");
-	switch (ee->error)
-	{
-		case NOWELL:
-			ttyputerr("No well contact found in this facet");
-		case NOWELLINAREA:
-			erc_showpoly(ee->poly1);
-			ttyputerr("No well contact found in this area");
-			break;
-		case WELLPROX:
-			erc_showpoly(ee->poly1);
-			erc_showpoly(ee->poly2);
-			ttyputerr("Well areas too close");
-			break;
-		case WELLFLOATS:
-			erc_identifypoint(ee->x1, ee->y1, erc_facet);
-			ttyputerr("Well contact is floating");
-			break;
-		case WELLDISCON:
-			erc_identifypoint(ee->x1, ee->y1, erc_facet);
-			erc_identifypoint(ee->x2, ee->y2, erc_facet);
-			ttyputerr("Well contacts are not connected");
-			break;
-		case NOSUB:
-			ttyputerr("No substrate contact found in this facet");
-			break;
-			break;
-		case NOSUBINAREA:
-			erc_showpoly(ee->poly1);
-			ttyputerr("No substrate contact found in this area");
-			break;
-		case SUBPROX:
-			erc_showpoly(ee->poly1);
-			erc_showpoly(ee->poly2);
-			ttyputerr("Substrate areas too close");
-			break;
-		case SUBFLOATS:
-			erc_identifypoint(ee->x1, ee->y1, erc_facet);
-			ttyputerr("Substrate contact is floating");
-			break;
-		case SUBDISCON:
-			erc_identifypoint(ee->x1, ee->y1, erc_facet);
-			erc_identifypoint(ee->x2, ee->y2, erc_facet);
-			ttyputerr("Substrate contacts are not connected");
-			break;
-		case FLOATINGARC:
-			erc_showpoly(ee->poly1);
-			ttyputerr("Arc not globally connected");
-			break;
-	}
-}
-
-void erc_showpoly(POLYGON *poly)
-{
-	REGISTER INTSML i;
-	REGISTER INTBIG fx, fy, tx, ty;
-
-	for(i=0; i<poly->count; i++)
-	{
-		if (i == 0)
-		{
-			fx = poly->xv[poly->count-1];
-			fy = poly->yv[poly->count-1];
-		} else
-		{
-			fx = poly->xv[i-1];
-			fy = poly->yv[i-1];
-		}
-		tx = poly->xv[i];
-		ty = poly->yv[i];
-		(void)askaid(us_aid, "show-line", fx, fy, tx, ty, erc_facet);
-	}
-}
-
-void erc_identifypoint(INTBIG x, INTBIG y, NODEPROTO *facet)
-{
-	REGISTER INTBIG consize;
-
-	consize = el_curtech->deflambda * 5;
-	(void)askaid(us_aid, "show-line", x-consize, y-consize,
-		x+consize, y+consize, facet);
-	(void)askaid(us_aid, "show-line", x-consize, y+consize,
-		x+consize, y-consize, facet);
-}
-
-ERCERROR *erc_allocercerror(INTBIG errtype)
-{
-	REGISTER ERCERROR *ee;
-
-	if (erc_ercerrorfree != NOERCERROR)
-	{
-		ee = erc_ercerrorfree;
-		erc_ercerrorfree = ee->nextercerror;
-	} else
-	{
-		ee = (ERCERROR *)emalloc(sizeof (ERCERROR), erc_aid->cluster);
-		if (ee == 0) return(NOERCERROR);
-	}
-	ee->error = errtype;
-	ee->poly1 = NOPOLYGON;
-	ee->poly2 = NOPOLYGON;
-	ee->prevercerror = NOERCERROR;
-	ee->nextercerror = erc_firstercerror;
-	if (erc_firstercerror != NOERCERROR) erc_firstercerror->prevercerror = ee;
-	erc_firstercerror = ee;
-	return(ee);
-}
-
-void erc_freeercerror(ERCERROR *ee)
-{
-	ee->nextercerror = erc_ercerrorfree;
-	erc_ercerrorfree = ee;
-}
-
-/*
- * Routine to free all previously stored ERC errors.
- */
-void erc_freeallerrors(void)
-{
-	REGISTER ERCERROR *ee;
-
-	while (erc_firstercerror != NOERCERROR)
-	{
-		ee = erc_firstercerror;
-		erc_firstercerror = ee->nextercerror;
-		efree((char *)ee);
-	}
-	erc_curercerror = NOERCERROR;
-	erc_nextercerror = NOERCERROR;
-	erc_prevercerror = NOERCERROR;
-}
-
 /******************** OPTIONS DIALOG ********************/
 
 /*
@@ -1087,13 +858,14 @@ void erc_freeallerrors(void)
  */
 void erc_optionsdlog(void)
 {
-	REGISTER INTBIG itemHit, ercoptions;
+	REGISTER INTBIG itemHit, ercoptions, oldoptions;
 	REGISTER VARIABLE *var;
 
 	if (DiaInitDialog(&erc_optionsdialog) != 0) return;
 	var = getvalkey((INTBIG)erc_aid, VAID, VINTEGER, erc_optionskey);
 	if (var == NOVARIABLE) ercoptions = 0; else
 		ercoptions = var->addr;
+	oldoptions = ercoptions;
 	switch (ercoptions & WELLCONOPTIONS)
 	{
 		case WELLCONPERAREA: DiaSetControl(3, 1);   break;
@@ -1140,7 +912,8 @@ void erc_optionsdlog(void)
 		if (DiaGetControl(7) != 0) ercoptions |= SUBCONPERAREA; else
 			if (DiaGetControl(8) != 0) ercoptions |= SUBCONONCE; else
 				ercoptions |= SUBCONIGNORE;
-		(void)setvalkey((INTBIG)erc_aid, VAID, erc_optionskey, ercoptions, VINTEGER);
+		if (ercoptions != oldoptions)
+			(void)setvalkey((INTBIG)erc_aid, VAID, erc_optionskey, ercoptions, VINTEGER);
 	}
 	DiaDoneDialog();
 }
