@@ -38,6 +38,7 @@
 #if PLAAID
 
 #include "global.h"
+#include "pla.h"
 #include "planmos.h"
 
 /* prototypes for local routines */
@@ -67,26 +68,26 @@ INTSML pla_Make(void)
 	TECHNOLOGY *tech;
 
 	if (pla_fin != NULL) xclose(pla_fin);
-	pla_fin = xopen(pla_infile, FILETYPEPLATAB, "", &filename);
+	pla_fin = xopen(pla_infile, pla_filetypeplatab, "", &filename);
 	if (pla_fin == NULL)
 	{
-		ttyputerr("File '%s' not found, use 'tellaid pla nmos file FILE'", pla_infile);
+		ttyputerr(_("File '%s' not found, use 'tellaid pla nmos file FILE'"), pla_infile);
 		return(ERRORRET);
 	}
 	if (pla_verbose == ON)
-		ttyputmsg("File '%s' has been opened for reading", pla_infile);
+		ttyputmsg(_("File '%s' has been opened for reading"), pla_infile);
 
 	/* Set the Technology to the Default Technology (nmos) */
 	tech = gettechnology(PLADEFTECH);
 	if (tech == NOTECHNOLOGY)
 	{
-		ttyputerr("'%s' is an undefined technology", PLADEFTECH);
+		ttyputerr(_("'%s' is an undefined technology"), PLADEFTECH);
 		return(ERRORRET);
 	}
 	if (el_curtech != tech)
-		ttyputmsg("Warning: current technology should be %s", tech->techname);
+		ttyputmsg(_("Warning: current technology should be %s"), tech->techname);
 
-	pla_lam = tech->deflambda;
+	pla_lam = el_curlib->lambda[tech->techindex];
 
 	/* Compute the widths of Vdd and Gnd lines */
 	if (pla_VddWidth < 4*pla_lam) pla_VddWidth = 4 * pla_lam;
@@ -114,7 +115,7 @@ INTSML pla_Make(void)
 		pla_etran_proto == NONODEPROTO || pla_bc_proto  == NONODEPROTO ||
 		pla_bp_proto    == NONODEPROTO)
 	{
-		ttyputerr("Cannot find primitive prototypes of nmos technology");
+		ttyputerr(_("Cannot find primitive prototypes of nmos technology"));
 		return(ERRORRET);
 	}
 
@@ -122,7 +123,7 @@ INTSML pla_Make(void)
 	pla_pu_proto = pla_nmos_Pullup();
 	if (pla_pu_proto  == NONODEPROTO)
 	{
-		ttyputerr("Cannot create pullup facet");
+		ttyputerr(_("Cannot create pullup facet"));
 		return(ERRORRET);
 	}
 	puX = pla_pu_proto->highx - pla_pu_proto->lowx;
@@ -131,7 +132,7 @@ INTSML pla_Make(void)
 	pla_in_proto = pla_nmos_Input();
 	if (pla_in_proto == NONODEPROTO)
 	{
-		ttyputerr("Cannot create input facet");
+		ttyputerr(_("Cannot create input facet"));
 		return(ERRORRET);
 	}
 	inX = pla_in_proto->highx - pla_in_proto->lowx;
@@ -140,7 +141,7 @@ INTSML pla_Make(void)
 	pla_connect_proto = pla_nmos_Connect();
 	if (pla_connect_proto == NONODEPROTO)
 	{
-		ttyputerr("Cannot create connect facet");
+		ttyputerr(_("Cannot create connect facet"));
 		return(ERRORRET);
 	}
 	connectX = pla_connect_proto->highx - pla_connect_proto->lowx;
@@ -149,7 +150,7 @@ INTSML pla_Make(void)
 	pla_prog_proto = pla_nmos_Program();
 	if (pla_prog_proto== NONODEPROTO)
 	{
-		ttyputerr("Cannot create program facet");
+		ttyputerr(_("Cannot create program facet"));
 		return(ERRORRET);
 	}
 	progX = pla_prog_proto->highx - pla_prog_proto->lowx;
@@ -158,7 +159,7 @@ INTSML pla_Make(void)
 	pla_out_proto = pla_nmos_Output();
 	if (pla_out_proto == NONODEPROTO)
 	{
-		ttyputerr("Cannot create output facet");
+		ttyputerr(_("Cannot create output facet"));
 		return(ERRORRET);
 	}
 	outX = pla_out_proto->highx - pla_out_proto->lowx;
@@ -166,13 +167,13 @@ INTSML pla_Make(void)
 
 	if (pla_verbose == ON)
 	{
-		ttyputmsg("Facets have been defined with sizes given below:");
-		ttyputmsg("Pullup  = %sx%s", latoa(puX), latoa(puY));
-		ttyputmsg("Input   = %sx%s", latoa(inX), latoa(inY));
-		ttyputmsg("Output  = %sx%s", latoa(outX), latoa(outY));
-		ttyputmsg("Program = %sx%s", latoa(progX), latoa(progY));
-		ttyputmsg("Connect = %sx%s", latoa(connectX), latoa(connectY));
-		ttyputmsg("VDD Width = %s, Gnd Width = %s", latoa(pla_VddWidth), latoa(pla_GndWidth));
+		ttyputmsg(_("Facets have been defined with sizes given below:"));
+		ttyputmsg(_("Pullup  = %sx%s"), latoa(puX), latoa(puY));
+		ttyputmsg(_("Input   = %sx%s"), latoa(inX), latoa(inY));
+		ttyputmsg(_("Output  = %sx%s"), latoa(outX), latoa(outY));
+		ttyputmsg(_("Program = %sx%s"), latoa(progX), latoa(progY));
+		ttyputmsg(_("Connect = %sx%s"), latoa(connectX), latoa(connectY));
+		ttyputmsg(_("VDD Width = %s, Gnd Width = %s"), latoa(pla_VddWidth), latoa(pla_GndWidth));
 	}
 
 	/* Create the pla prototype with these dimensions.
@@ -188,17 +189,17 @@ INTSML pla_Make(void)
 
 		if (pla_inputs == 0)
 		{
-			ttyputerr("Use 'tellaid pla nmos inputs VALUE' to set inputs");
+			ttyputerr(_("Use 'tellaid pla nmos inputs VALUE' to set inputs"));
 			return(ERRORRET);
 		}
 		if (pla_outputs == 0)
 		{
-			ttyputerr("Use 'tellaid pla nmos outputs VALUE' to set outputs");
+			ttyputerr(_("Use 'tellaid pla nmos outputs VALUE' to set outputs"));
 			return(ERRORRET);
 		}
 		if (pla_pterms == 0)
 		{
-			ttyputerr("Use 'tellaid pla nmos pterms VALUE' to set prod. terms");
+			ttyputerr(_("Use 'tellaid pla nmos pterms VALUE' to set prod. terms"));
 			return(ERRORRET);
 		}
 		if (namesame(pla_name, DEFNAME) == 0)
@@ -207,16 +208,16 @@ INTSML pla_Make(void)
 		pla_facet = newnodeproto(pla_name, el_curlib);
 		if (pla_facet == NONODEPROTO)
 		{
-			ttyputerr("Cannot create '%s' prototype", pla_name);
+			ttyputerr(_("Cannot create '%s' prototype"), pla_name);
 			return(ERRORRET);
 		}
 
-		ttyputmsg("Defining '%s'", pla_name);
+		ttyputmsg(_("Defining '%s'"), pla_name);
 		if (pla_verbose == ON)
-			ttyputmsg("Beginning to program the AND and OR planes.");
+			ttyputmsg(_("Beginning to program the AND and OR planes."));
 		if (pla_ProgramPLA(inX, inY, puX, puY, outX, outY, connectX,
 			connectY, pla_facet) == ERRORRET)
-				ttyputerr("PLA '%s' is incompletely defined", pla_name);
+				ttyputerr(_("PLA '%s' is incompletely defined"), pla_name);
 
 		while((pos = pla_GetKeyWord(keyword)) != ERRORRET)
 			if (pos == END) break;
@@ -238,15 +239,15 @@ PROGTRANS *pla_FindPColTrans(INTSML pterm, PROGTRANS *trans)
 	while (trans->uprogtrans != NOPROGTRANS)
 	{
 		if (trans->column != column)
-			ttyputerr("FindPColTrans: Column mismatch: wanted %d, got %d/%d",
+			ttyputerr(_("FindPColTrans: Column mismatch: wanted %d, got %d/%d"),
 				column, trans->column, trans->row);
 		trans = trans->uprogtrans;
 	}
 
 	if (trans->row >= pterm)
 	{
-		ttyputerr("FindPColTrans: Error.  Gone past row %d in column %d", pterm, trans->column);
-		ttyputerr("   Last progtrans in this column is at row=%d", trans->row);
+		ttyputerr(_("FindPColTrans: Error.  Gone past row %d in column %d"), pterm, trans->column);
+		ttyputerr(_("   Last progtrans in this column is at row=%d"), trans->row);
 		return(NOPROGTRANS);
 	}
 	return(trans);
@@ -275,35 +276,35 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 	firstptr= NOFACETIST;
 	cicv = picv = cicg = picg = NOVDDGND;
 
-	if (pla_verbose == ON) ttyputmsg("Placing the input facets");
+	if (pla_verbose == ON) ttyputmsg(_("Placing the input facets"));
 
 	for(i = 1; i <= pla_inputs; i++)
 	{
-		if (pla_verbose == ON) ttyputmsg("Placing input facet %d", i);
+		if (pla_verbose == ON) ttyputmsg(_("Placing input facet %d"), i);
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
 		if (ptr == NOFACETIST)
 		{
-			ttyputerr("PlaceInputs: ran out of storage space. i=%d", i);
+			ttyputerr(_("PlaceInputs: ran out of storage space. i=%d"), i);
 			break;
 		} else if (ptr == NOFACETIST) break;
 		ptr->findex = i;    /* remember which input this facet corresponds to */
 		ptr->facetinst = newnodeinst(pla_in_proto, llXpos, llXpos+inX,
 			llYpos, llYpos+inY, NOTRANS, NOROT, pla);
 		if (ptr->facetinst == NONODEINST)
-			ttyputerr("PlaceInputs: cannot instance input# %d", i);
+			ttyputerr(_("PlaceInputs: cannot instance input# %d"), i);
 
 		/* Record the Gnd and Vdd points for later connection */
 		cicg = pla_MkVddGnd(INFACETGND, &picg);
 		cicg->inst = ptr->facetinst;
 		cicg->port = pla_AssignPort(ptr->facetinst, llXpos+6*pla_lam, GndYpos);
 		if (cicg->port->port == NOPORTPROTO)
-			ttyputerr("PlaceInputs: can't access Gnd contact");
+			ttyputerr(_("PlaceInputs: can't access Gnd contact"));
 
 		cicv = pla_MkVddGnd(INFACETVDD, &picv);
 		cicv->inst = ptr->facetinst;
 		cicv->port = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, VddYpos);
 		if (cicv->port->port == NOPORTPROTO)
-			ttyputerr("PlaceInputs: can't access Vdd contact");
+			ttyputerr(_("PlaceInputs: can't access Vdd contact"));
 
 		/* Find the ports that connect into the PLA */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+2*pla_lam, llYpos+inY-pla_lam);
@@ -312,7 +313,7 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 
 		if (ptr->lport->port == NOPORTPROTO ||
 			ptr->rport->port == NOPORTPROTO || ptr->gport->port == NOPORTPROTO)
-				ttyputerr("PlaceInputs: cannot access ports into PLA");
+				ttyputerr(_("PlaceInputs: cannot access ports into PLA"));
 
 		/* Initialize the progtrans ends */
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
@@ -321,7 +322,7 @@ FACETIST *pla_PlaceInputs(INTBIG puX, INTBIG inX, INTBIG inY, NODEPROTO *pla)
 		(void)sprintf(portname, "Input%d", i);
 		if (newportproto(pla, ptr->facetinst, pla_FindPort(ptr->facetinst,llXpos+10*pla_lam,
 			llYpos+pla_lam), portname) == NOPORTPROTO)
-				ttyputerr("PlaceInputs: cannot export port Input%d", i);
+				ttyputerr(_("PlaceInputs: cannot export port Input%d"), i);
 
 		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
 		prevptr = ptr;
@@ -351,23 +352,23 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 	prevptr = firstptr = NOFACETIST;
 	cocv = pocv = cocg = pocg = NOVDDGND;
 
-	if (pla_verbose == ON) ttyputmsg("Placing the output facets");
+	if (pla_verbose == ON) ttyputmsg(_("Placing the output facets"));
 
 	for(o = 1; o <= (pla_outputs+pla_outputs%2)/2; o++)
 	{
-		if (pla_verbose == ON) ttyputmsg("Placing output facet %d", o);
+		if (pla_verbose == ON) ttyputmsg(_("Placing output facet %d"), o);
 
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
 		if (ptr == NOFACETIST)
 		{
-			ttyputerr("PlaceOutputs: ran out of storage space. o=%d", o);
+			ttyputerr(_("PlaceOutputs: ran out of storage space. o=%d"), o);
 			break;
 		} else if (ptr == NOFACETIST) break;
 		ptr->findex = o;
 		ptr->facetinst = newnodeinst(pla_out_proto, llXpos, llXpos+outX,
 			llYpos, llYpos+outY, NOTRANS, NOROT, pla);
 		if (ptr->facetinst == NONODEINST)
-			ttyputerr("PlaceOutputs: cannot instance output# %d", o);
+			ttyputerr(_("PlaceOutputs: cannot instance output# %d"), o);
 
 		/*
 		 * Connect the facets together in metal on the Gnd line if more than
@@ -378,13 +379,13 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 		cocg->inst = ptr->facetinst;
 		cocg->port = pla_AssignPort(ptr->facetinst, llXpos+outX-5*pla_lam, GndYpos);
 		if (cocg->port->port == NOPORTPROTO)
-			ttyputerr("PlaceOutputs: can't access Gnd contact");
+			ttyputerr(_("PlaceOutputs: can't access Gnd contact"));
 
 		cocv = pla_MkVddGnd(OUTFACETVDD, &pocv);
 		cocv->inst = ptr->facetinst;
 		cocv->port = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, VddYpos);
 		if (cocv->port->port == NOPORTPROTO)
-			ttyputerr("PlaceOutputs: can't access Vdd contact");
+			ttyputerr(_("PlaceOutputs: can't access Vdd contact"));
 
 		/* Find the ports that connect into the PLA */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+5*pla_lam, llYpos+outY-2*pla_lam);
@@ -392,7 +393,7 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 		ptr->gport = NOPORT;
 
 		if (ptr->lport->port == NOPORTPROTO || ptr->rport->port == NOPORTPROTO)
-			ttyputerr("PlaceOutputs: cant access ports to connect into PLA");
+			ttyputerr(_("PlaceOutputs: cant access ports to connect into PLA"));
 
 		/* Initialize the progtrans ends */
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
@@ -401,11 +402,11 @@ FACETIST *pla_PlaceOutputs(INTBIG orLeft, INTBIG outX, INTBIG outY, NODEPROTO *p
 		(void)sprintf(portname, "Output%d", 2*o-1);
 		if (newportproto(pla, ptr->facetinst,
 			pla_FindPort(ptr->facetinst,llXpos+pla_lam,llYpos+pla_lam), portname) == NOPORTPROTO)
-				ttyputerr("PlaceOutputs: cant export port Output%d", 2*o-1);
+				ttyputerr(_("PlaceOutputs: cant export port Output%d"), 2*o-1);
 		(void)sprintf(portname, "Output%d", 2*o);
 		if (newportproto(pla, ptr->facetinst,
 			pla_FindPort(ptr->facetinst,llXpos+11*pla_lam, llYpos+pla_lam), portname) == NOPORTPROTO)
-				ttyputerr("PlaceOutputs: cannot export port Output%d", 2*o);
+				ttyputerr(_("PlaceOutputs: cannot export port Output%d"), 2*o);
 
 		if (prevptr != NOFACETIST) prevptr->nextfacet = ptr;
 		prevptr = ptr;
@@ -434,36 +435,36 @@ FACETIST *pla_PlacePullupsonAND(INTBIG puX, INTBIG puY, INTBIG inY, NODEPROTO *p
 	calv = palv = NOVDDGND;
 
 	if (pla_verbose == ON)
-		ttyputmsg("Placing the pullup facets on the left edge of the AND-plane");
+		ttyputmsg(_("Placing the pullup facets on the left edge of the AND-plane"));
 
 	for(p = 1; p <= pla_pterms; p++)
 	{
 		if (pla_verbose == ON)
-			ttyputmsg("Placing pullup facet %d in AND-plane", p);
+			ttyputmsg(_("Placing pullup facet %d in AND-plane"), p);
 
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
 		if (ptr == NOFACETIST)
 		{
-			ttyputerr("PlacePullupsonAND: ran out of storage space, p=%d", p);
+			ttyputerr(_("PlacePullupsonAND: ran out of storage space, p=%d"), p);
 			break;
 		} else if (ptr == NOFACETIST) break;
 		ptr->findex = p;
 		ptr->facetinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
 			llYpos, llYpos+puY, NOTRANS, NOROT, pla);
 		if (ptr->facetinst == NONODEINST)
-			ttyputerr("PlacePullupsonAND: cannot instance pu# %d", p);
+			ttyputerr(_("PlacePullupsonAND: cannot instance pu# %d"), p);
 
 		/* Remember the Vdd points for later connection */
 		calv = pla_MkVddGnd(ANDLEFTVDD, &palv);
 		calv->inst = ptr->facetinst;
 		calv->port = pla_AssignPort(ptr->facetinst, pla_halfVdd, llYpos+4*pla_lam);
 		if (calv->port->port == NOPORTPROTO)
-			ttyputerr("PlacePullupsonAND: can't access Vdd contact");
+			ttyputerr(_("PlacePullupsonAND: can't access Vdd contact"));
 
 		/* Mark the diffusion end of the pu for connections across the plane */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+puX-2*pla_lam,llYpos+3*pla_lam);
 		if (ptr->lport->port == NOPORTPROTO)
-			ttyputerr("PlacePullupsonAND: cannot access bc port of pullup");
+			ttyputerr(_("PlacePullupsonAND: cannot access bc port of pullup"));
 
 		ptr->rport = NOPORT;
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
@@ -501,37 +502,37 @@ FACETIST *pla_PlacePullupsonOR(INTBIG andY, INTBIG orLeft, INTBIG inY, INTBIG pu
 	cotv = potv = NOVDDGND;
 
 	if (pla_verbose == ON)
-		ttyputmsg("Placing the pullups on the %s edge of the OR-plane",
-			(pla_samesideoutput == ON) ? "top" : "bottom");
+		ttyputmsg(_("Placing the pullups on the %s edge of the OR-plane"),
+			(pla_samesideoutput == ON) ? _("top") : _("bottom"));
 
 	for(i = 1; i <= pla_outputs; i++)
 	{
 		if (pla_verbose == ON)
-			ttyputmsg("Placing pullup facet %d in OR-plane", i);
+			ttyputmsg(_("Placing pullup facet %d in OR-plane"), i);
 
 		ptr = (FACETIST *)emalloc(sizeof(FACETIST), pla_aid->cluster);
 		if (ptr == NOFACETIST)
 		{
-			ttyputerr("PlacePullupsonOR: ran out of storage space, i=%d", i);
+			ttyputerr(_("PlacePullupsonOR: ran out of storage space, i=%d"), i);
 			break;
 		} else if (ptr == NOFACETIST) break;
 		ptr->findex = i;
 		ptr->facetinst = newnodeinst(pla_pu_proto, llXpos, llXpos+puX,
 			llYpos, llYpos+puY, NOTRANS, 2700, pla);
 		if (ptr->facetinst == NONODEINST)
-			ttyputerr("PlacePullupsonOR: cannot instance pu# %d", i);
+			ttyputerr(_("PlacePullupsonOR: cannot instance pu# %d"), i);
 
 		/* Remember the Vdd points for later connection */
 		cotv = pla_MkVddGnd(ORTOPVDD, &potv);
 		cotv->inst = ptr->facetinst;
 		cotv->port = pla_AssignPort(ptr->facetinst, llXpos+puX/2, VddYpos);
 		if (cotv->port->port == NOPORTPROTO)
-			ttyputerr("PlacePullupsonOR: can't access Vdd contact");
+			ttyputerr(_("PlacePullupsonOR: can't access Vdd contact"));
 
 		/* Mark the diffusion end of the pu for connections across the plane */
 		ptr->lport = pla_AssignPort(ptr->facetinst, llXpos+puX/2-pla_lam, bc_portY);
 		if (ptr->lport->port == NOPORTPROTO)
-			ttyputerr("PlacePullupsonOR: cannot access bc port of pullup");
+			ttyputerr(_("PlacePullupsonOR: cannot access bc port of pullup"));
 
 		ptr->rport = NOPORT;
 		ptr->rcoltrans = ptr->lcoltrans = NOPROGTRANS;
@@ -584,13 +585,13 @@ PROGTRANS *pla_Program(INTBIG lowx, INTBIG lowy, INTBIG orientation, NODEPROTO *
 	trans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_aid->cluster);
 	if (trans == NOPROGTRANS)
 	{
-		ttyputerr("Program: ran out of storage for PROGTRANS");
+		ttyputerr(_("Program: ran out of storage for PROGTRANS"));
 		return(NOPROGTRANS);
 	} else if (trans == NOPROGTRANS) return(NOPROGTRANS);
 
 	inst = newnodeinst(pla_prog_proto, lowx, highx, lowy, highy, NOTRANS, rot, pla);
 	if (inst == NONODEINST)
-		ttyputerr("Program: cannot instance programming trans");
+		ttyputerr(_("Program: cannot instance programming trans"));
 
 	trans->trans = inst;
 
@@ -630,7 +631,7 @@ PROGTRANS *pla_Program(INTBIG lowx, INTBIG lowy, INTBIG orientation, NODEPROTO *
 		trans->metalport->port  == NOPORTPROTO ||
 		trans->polyblport->port == NOPORTPROTO ||
 		trans->polytrport->port == NOPORTPROTO))
-			ttyputerr("Program: cannot find transistor ports");
+			ttyputerr(_("Program: cannot find transistor ports"));
 
 	trans->uprogtrans = trans->rprogtrans = NOPROGTRANS;
 
@@ -736,10 +737,10 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 
 	if (pla_verbose == ON)
 	{
-		ttyputmsg("Dimensions of the planes:");
-		ttyputmsg("  andX = %s,    andY = %s", latoa(andX), latoa(andY));
-		ttyputmsg("   orX = %s,     orY = %s", latoa(orX), latoa(andY));
-		ttyputmsg("orLeft = %s, orRight = %s", latoa(orLeft), latoa(orRight));
+		ttyputmsg(_("Dimensions of the planes:"));
+		ttyputmsg(_("  andX = %s,    andY = %s"), latoa(andX), latoa(andY));
+		ttyputmsg(_("   orX = %s,     orY = %s"), latoa(orX), latoa(andY));
+		ttyputmsg(_("orLeft = %s, orRight = %s"), latoa(orLeft), latoa(orRight));
 	}
 
 	/* Place all the input, output and pullup facets */
@@ -759,28 +760,28 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 	{
 		if (ptermptr == NOFACETIST)
 		{
-			ttyputerr("ProgramPLA: insufficient number of pullups on AND plane");
+			ttyputerr(_("ProgramPLA: insufficient number of pullups on AND plane"));
 			return(ERRORRET);
 		}
 
-		if (pla_verbose == ON) ttyputmsg("Programming row %ld.", p);
+		if (pla_verbose == ON) ttyputmsg(_("Programming row %ld."), p);
 
 		CurRow   = ptermptr->findex;
 		if (CurRow != p)
-			ttyputerr("ProgramPLA: Row Mismatch. CurRow=%ld, p=%ld", CurRow, p);
+			ttyputerr(_("ProgramPLA: Row Mismatch. CurRow=%ld, p=%ld"), CurRow, p);
 
 		/* Program the AND plane */
 		for(i = 1; i <= pla_inputs; i++)
 		{
 			if (inptr == NOFACETIST)
 			{
-				ttyputerr(" ProgramPLA: insufficient number of input facets");
+				ttyputerr(_(" ProgramPLA: insufficient number of input facets"));
 				return(ERRORRET);
 			}
 
 			CurCol = inptr->findex;
 			if (CurCol != i)
-				ttyputerr("ProgramPLA: Column Mismatch. CurCol=%ld, input=%ld", CurCol,i);
+				ttyputerr(_("ProgramPLA: Column Mismatch. CurCol=%ld, input=%ld"), CurCol,i);
 
 			PColTrans = NOPROGTRANS;
 
@@ -791,7 +792,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			 */
 			if ((val = pla_GetKeyWord(keyword)) == ERRORRET)
 			{
-				ttyputerr("End-of-File while programming AND plane");
+				ttyputerr(_("End-of-File while programming AND plane"));
 				return(ERRORRET);
 			}
 			switch(val)
@@ -806,7 +807,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 				case DONTCAREM: CurTrans = NOPROGTRANS;
 					break;
 				default:
-					ttyputerr("Undefined characters '%s' in programming section", keyword);
+					ttyputerr(_("Undefined characters '%s' in programming section"), keyword);
 					break;
 			}
 
@@ -818,12 +819,12 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			if (CurTrans == NOPROGTRANS)
 			{
 				if (pla_verbose == ON)
-					ttyputmsg("row=%ld, ANDcolumn=%ld not programmed.", CurRow, CurCol);
+					ttyputmsg(_("row=%ld, ANDcolumn=%ld not programmed."), CurRow, CurCol);
 				inptr = inptr->nextfacet;
 				continue;
 			}
 
-			if (pla_verbose == ON) ttyputmsg("row=%ld, ANDcolumn=%ld programmed.", CurRow, CurCol);
+			if (pla_verbose == ON) ttyputmsg(_("row=%ld, ANDcolumn=%ld programmed."), CurRow, CurCol);
 
 			CurTrans->row = (INTSML)CurRow;
 			CurTrans->column = (INTSML)CurCol;
@@ -866,7 +867,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			inY+(p-1)*puY, inY+(p-1)*puY+connectY, NOTRANS, NOROT, pla);
 
 		if (connect == NONODEINST)
-			ttyputerr("ProgramPLA: cannot instance connect facet. p=%ld", p);
+			ttyputerr(_("ProgramPLA: cannot instance connect facet. p=%ld"), p);
 
 		/*
 		 * Instance a progtrans structure and place the connect facet in it
@@ -875,7 +876,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 		CurTrans = (PROGTRANS *)emalloc(sizeof(PROGTRANS), pla_aid->cluster);
 		if (CurTrans == NOPROGTRANS)
 		{
-			ttyputerr("ProgramPLA: out of space while instancing connect. p=%ld", p);
+			ttyputnomemory();
 			return(ERRORRET);
 		} else if (CurTrans == NOPROGTRANS) return(ERRORRET);
 
@@ -895,7 +896,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 
 		if ((CurTrans->metalport->port == NOPORTPROTO ||
 			CurTrans->diffport->port == NOPORTPROTO || CurTrans->polytrport->port == NOPORTPROTO))
-				ttyputerr("ProgramPLA: cannot find connect facet ports. p=%ld",p);
+				ttyputerr(_("ProgramPLA: cannot find connect facet ports. p=%ld"), p);
 
 		CurTrans->uprogtrans = CurTrans->rprogtrans = NOPROGTRANS;
 
@@ -905,7 +906,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			 * Error.  This means that no programming transistors were
 			 * placed on this row in the AND plane.
 			 */
-			ttyputerr(" *** Warning: Nothing on AND plane on row %ld", p);
+			ttyputerr(_(" *** Warning: Nothing on AND plane on row %ld"), p);
 			ptermptr->lcoltrans = CurTrans;
 		} else PRowTrans->rprogtrans = CurTrans;
 
@@ -914,7 +915,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			PRowTrans->metalport->port, PRowTrans->metalport->x, PRowTrans->metalport->y,
 				CurTrans->trans, CurTrans->metalport->port, CurTrans->metalport->x,
 					CurTrans->metalport->y, pla) == NOARCINST)
-						ttyputerr("Cannot connect to connect facet. row=%ld", CurRow);
+						ttyputerr(_("Cannot connect to connect facet. row=%ld"), CurRow);
 
 		PRowTrans = CurTrans;
 
@@ -922,7 +923,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 		{
 			if (outptr == NOFACETIST)
 			{
-				ttyputerr(" ProgramPLA: insufficient number of output facets");
+				ttyputerr(_(" ProgramPLA: insufficient number of output facets"));
 				return(ERRORRET);
 			}
 
@@ -931,7 +932,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 			 *  So run in a loop twice.
 			 */
 			if (o != outptr->findex)
-				ttyputerr("ProgramPLA: Column Mismatch. outfacet#=%d, o=%d", outptr->findex, o);
+				ttyputerr(_("ProgramPLA: Column Mismatch. outfacet#=%d, o=%d"), outptr->findex, o);
 
 			for(out = 1; out >= 0; out--)
 			{
@@ -942,7 +943,7 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 
 					if ((val = pla_GetKeyWord(keyword)) == ERRORRET)
 					{
-						ttyputerr("End-of-File while programming OR plane");
+						ttyputerr(_("End-of-File while programming OR plane"));
 						return(ERRORRET);
 					}
 					switch(val)
@@ -956,19 +957,19 @@ INTSML pla_ProgramPLA(INTBIG inX, INTBIG inY, INTBIG puX, INTBIG puY, INTBIG out
 							CurTrans = NOPROGTRANS;
 							break;
 						default:
-							ttyputerr("Bad characters in programming section");
+							ttyputerr(_("Bad characters in programming section"));
 							break;
 					}
 					if (CurTrans == NOPROGTRANS)
 					{
 						/* This point is not being programmed */
 						if (pla_verbose == ON)
-							ttyputmsg("row=%ld, ORcolumn=%ld not programmed.", CurRow, CurCol);
+							ttyputmsg(_("row=%ld, ORcolumn=%ld not programmed."), CurRow, CurCol);
 						continue;
 					}
 
 					if (pla_verbose == ON)
-						ttyputmsg("row=%ld, ORcolumn=%ld programmed.", CurRow, CurCol);
+						ttyputmsg(_("row=%ld, ORcolumn=%ld programmed."), CurRow, CurCol);
 
 					CurTrans->row = (INTSML)CurRow;
 					CurTrans->column = (INTSML)CurCol;
