@@ -38,6 +38,7 @@
 #if PLAAID
 
 #include "global.h"
+#include "pla.h"
 #include "planmos.h"
 
 /* prototypes for local routines */
@@ -58,7 +59,7 @@ PORT *pla_AssignPort(NODEINST *inst, INTBIG x, INTBIG y)
 	prt = (PORT *)emalloc(sizeof(PORT), pla_aid->cluster);
 	if (prt == NOPORT)
 	{
-		ttyputerr("AssignPort: ran out of memory");
+		ttyputnomemory();
 		return(NOPORT);
 	}
 	if (prt == NOPORT) return(NOPORT);
@@ -87,10 +88,10 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 	for(currow = PullupAND; currow != NOFACETIST; currow = currow->nextfacet)
 	{
 		if (pla_verbose == ON)
-			ttyputmsg("connecting right from pullup# %d", currow->findex);
+			ttyputmsg(_("connecting right from pullup# %d"), currow->findex);
 
 		if (pla_ConnectFirstFacet(PULLUPSIDE, currow, pla) == ERRORRET)
-			ttyputerr("CHfromPuAND: cannot connect to first trans");
+			ttyputerr(_("CHfromPuAND: cannot connect to first trans"));
 
 		/* Find the end instance on the AND plane */
 		connect = currow->lcoltrans;
@@ -98,7 +99,7 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 			namesame(connect->trans->proto->cell->cellname, nmosConnect) != 0)
 				connect = connect->rprogtrans;
 		if (connect == NOPROGTRANS)
-			ttyputerr("CHfromPuAND: cannot find connect facet");
+			ttyputerr(_("CHfromPuAND: cannot find connect facet"));
 				else pla_DrawArcs(PULLUPSIDE, connect, currow, METAL, pla);
 
 		carg = pla_MkVddGnd(ANDRIGHTGND, &parg);
@@ -123,7 +124,7 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 			cgnd.trans = newnodeinst(pla_md_proto, orRight, orRight+pla_GndWidth,
 				gndY, gndY+4*pla_lam, NOTRANS, NOROT, pla);
 			if (cgnd.trans == NONODEINST)
-				ttyputerr("CHfromPuAND: cannot instance ground pin");
+				ttyputerr(_("CHfromPuAND: cannot instance ground pin"));
 
 			cgnd.diffport = pla_AssignPort(cgnd.trans, orRight+pla_halfGnd, gndY+2*pla_lam);
 			cgnd.diffport->port = pla_md_proto->firstportproto;
@@ -144,7 +145,7 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 					namesame(connect->trans->proto->cell->cellname, nmosConnect) != 0)
 						connect = connect->rprogtrans;
 				if (connect == NOPROGTRANS)
-					ttyputerr("Cannot find connect facet on prev row");
+					ttyputerr(_("Cannot find connect facet on prev row"));
 				if (connect != NOPROGTRANS)
 					for(ttrans = connect->rprogtrans; ttrans != NOPROGTRANS; ttrans = ttrans->rprogtrans)
 				{
@@ -152,7 +153,7 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 					if (newarcinst(pla_da_proto, 4*pla_lam, pla_userbits, ftrans->trans,
 						fport->port, fport->x, fport->y, ttrans->trans, tport->port, tport->x,
 							tport->y, pla) == NOARCINST)
-								ttyputerr("Cannot connect diff for prev row transistors");
+								ttyputerr(_("Cannot connect diff for prev row transistors"));
 					ftrans = ttrans;
 					fport  = tport;
 				}
@@ -160,7 +161,7 @@ void pla_CHfromPuAND(INTBIG orRight, FACETIST *PullupAND, NODEPROTO *pla)
 				if (newarcinst(pla_da_proto, 4*pla_lam, pla_userbits,
 					ftrans->trans, fport->port, fport->x, fport->y,
 						cgnd.trans, tport->port, tport->x, tport->y, pla) == NOARCINST)
-							ttyputerr("cannot connect to gnd for prev row transistors");
+							ttyputerr(_("cannot connect to gnd for prev row transistors"));
 			}
 		} else pla_DrawArcs(PULLUPSIDE, &cgnd, &connectfacet, POLY, pla);
 		prevrow = currow;
@@ -191,17 +192,17 @@ void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
 	{
 		if (inptr->lcoltrans == NOPROGTRANS && inptr->rcoltrans == NOPROGTRANS)
 		{
-			ttyputmsg("*** Warning. Input %d is never used at all.", inptr->findex);
+			ttyputmsg(_("*** Warning. Input %d is never used at all."), inptr->findex);
 			inptr = inptr->nextfacet;
 			continue;
 		}
 		if (inptr->lcoltrans == NOPROGTRANS)
-			ttyputmsg("*** Warning. Input %d is never used in negated form.", inptr->findex);
+			ttyputmsg(_("*** Warning. Input %d is never used in negated form."), inptr->findex);
 		if (inptr->rcoltrans == NOPROGTRANS)
-			ttyputmsg("*** Warning. Input %d is never used in unnegated form.", inptr->findex);
+			ttyputmsg(_("*** Warning. Input %d is never used in unnegated form."), inptr->findex);
 
 		if (pla_verbose == ON)
-			ttyputmsg("connecting up from input# %d", inptr->findex);
+			ttyputmsg(_("connecting up from input# %d"), inptr->findex);
 
 		/* Place a contact to ground at the top of the PLA right above the
 		 * current input facet.
@@ -210,7 +211,7 @@ void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
 			(inptr->gport->x)+2*pla_lam, inY+andY+3*pla_lam, inY+andY+3*pla_lam+pla_GndWidth,
 				NOTRANS, NOROT, pla);
 		if (trans.trans == NONODEINST)
-			ttyputerr("CVfromInput: cannot instance ground pin");
+			ttyputerr(_("CVfromInput: cannot instance ground pin"));
 
 		trans.diffport = pla_AssignPort(trans.trans, inptr->gport->x,
 			inY+andY+3*pla_lam+pla_halfGnd);
@@ -226,7 +227,7 @@ void pla_CVfromInput(INTBIG inY, INTBIG andY, FACETIST *inptr, NODEPROTO *pla)
 
 		/* We also need to connect the input facet to the first transistor */
 		if (pla_ConnectFirstFacet(INPUTSIDE, inptr, pla) == ERRORRET)
-			ttyputerr("CVfromInput: cannot connect to fist transistors");
+			ttyputerr(_("CVfromInput: cannot connect to first transistors"));
 
 		pla_DrawArcs(INPUTSIDE, &trans, inptr, POLY, pla);
 
@@ -249,7 +250,7 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 	while(outptr != NOFACETIST)
 	{
 		if (pla_ConnectFirstFacet(OUTPUTSIDE, outptr, pla) == ERRORRET)
-			ttyputerr("CVfromOutput: cannot connect to first transistors");
+			ttyputerr(_("CVfromOutput: cannot connect to first transistors"));
 
 		for(i = 1; i >= 0; i--)
 		{
@@ -258,16 +259,16 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 			{
 				case 1:
 					if (outptr->lcoltrans == NOPROGTRANS)
-					ttyputerr("*** Warning: Output %ld is never set", out);
+					ttyputerr(_("*** Warning: Output %ld is never set"), out);
 					break;
 				case 0:
 					if (outptr->rcoltrans == NOPROGTRANS && out <= pla_outputs)
-					ttyputerr("*** Warning: Output %ld is never set", out+i);
+					ttyputerr(_("*** Warning: Output %ld is never set"), out+i);
 					break;
 			}
 		}
 		if (pla_verbose == ON)
-			ttyputmsg("connecting up from output facet# %d", outptr->findex);
+			ttyputmsg(_("connecting up from output facet# %d"), outptr->findex);
 
 		pla_DrawArcs(OUTPUTSIDE, endtrans, outptr, METAL, pla);
 
@@ -282,7 +283,7 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 			if (newarcinst(pla_ma_proto, 3*pla_lam, pla_userbits,
 				endtrans->trans, fport->port, fport->x, fport->y,
 					puptr->facetinst, tport->port, tport->x, tport->y, pla) == NOARCINST)
-						ttyputerr("Cannot connect to pullup from L column");
+						ttyputerr(_("Cannot connect to pullup from L column"));
 			puptr = puptr->nextfacet;
 		}
 
@@ -296,7 +297,7 @@ void pla_CVfromOutput(FACETIST *outptr, FACETIST *puptr, NODEPROTO *pla)
 			if (newarcinst(pla_ma_proto, 3*pla_lam, pla_userbits,
 				endtrans->trans, fport->port, fport->x, fport->y,
 					puptr->facetinst, tport->port, tport->x, tport->y, pla) == NOARCINST)
-						ttyputerr("Cannot connect to pullup from R column");
+						ttyputerr(_("Cannot connect to pullup from R column"));
 			puptr = puptr->nextfacet;
 		}
 
@@ -460,8 +461,8 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 						ftrans->trans, fport->port, fport->x, fport->y,
 						ttrans->trans, tport->port, tport->x, tport->y, pla) == NOARCINST)
 					{
-						ttyputerr("DrawArcs: no diff ground arc on input side.");
-						ttyputerr("  frow=%d, fcol=%d, trow=%d, tcol=%d",
+						ttyputerr(_("DrawArcs: no diff ground arc on input side."));
+						ttyputerr(_("  frow=%d, fcol=%d, trow=%d, tcol=%d"),
 							ftrans->row, ftrans->column, ttrans->row, ttrans->column);
 					}
 					fport  = ftrans->polytrport;
@@ -502,8 +503,8 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 									fport->port, fport->x, fport->y, ttrans->trans,
 										tport->port, tport->x, tport->y, pla) == NOARCINST)
 								{
-									ttyputerr("no diff ground arc on pullup");
-									ttyputerr(" frow=%d, fcol=%d, trow=%d, tcol=%d",
+									ttyputerr(_("no diff ground arc on pullup"));
+									ttyputerr(_(" frow=%d, fcol=%d, trow=%d, tcol=%d"),
 										ftrans->row, ftrans->column, ttrans->row, ttrans->column);
 								}
 							}
@@ -518,10 +519,10 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 				ttrans->trans, tport->port, tport->x, tport->y, pla)
 					== NOARCINST)
 			{
-				ttyputerr("DrawArcs: no connecting arc.");
-				ttyputerr("frow=%d, fcol=%d, trow=%d, tcol=%d, layer=%s",
+				ttyputerr(_("DrawArcs: no connecting arc."));
+				ttyputerr(_("frow=%d, fcol=%d, trow=%d, tcol=%d, layer=%s"),
 					ftrans->row, ftrans->column, ttrans->row, ttrans->column,
-						(layer == METAL) ? "Metal" : ((layer == POLY) ? "Poly" : "Diff"));
+						(layer == METAL) ? _("Metal") : ((layer == POLY) ? _("Poly") : _("Diff")));
 			}
 
 			/* Break out of the loop if we are connecting from the Pullup side
@@ -554,7 +555,7 @@ void pla_DrawArcs(INTBIG from, PROGTRANS *endtrans, FACETIST *startfacet,
 				ftrans->trans, fport->port, fport->x, fport->y, endtrans->trans,
 					endtrans->diffport->port, endtrans->diffport->x, endtrans->diffport->y, pla)
 						== NOARCINST)
-							ttyputerr("DrawArcs: cannot connect to ground pin");
+							ttyputerr(_("DrawArcs: cannot connect to ground pin"));
 		}
 	}
 }
@@ -577,9 +578,8 @@ VDDGND *pla_MkVddGnd(INTBIG which, VDDGND **prevptr)
 	VDDGND *ptr;
 
 	ptr = (VDDGND *)emalloc(sizeof(VDDGND), pla_aid->cluster);
-	if (ptr == NOVDDGND)
-		ttyputerr("MkVddGnd: ran out of memory"); else
-			if (ptr == NOVDDGND) return(ptr);
+	if (ptr == NOVDDGND) ttyputnomemory(); else
+		if (ptr == NOVDDGND) return(ptr);
 
 	ptr->nextinst = NOVDDGND;
 	switch (which)
@@ -649,13 +649,13 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	VDDGND turnpin, turnpin1, forkpin;
 	INTBIG lowx, highx, lowy, highy, portx, porty;
 
-	if (pla_verbose == ON) ttyputmsg("Running the Vdd and Gnd lines");
+	if (pla_verbose == ON) ttyputmsg(_("Running the Vdd and Gnd lines"));
 
-	pla_ConnectThruFacets(VDD, pla_otv, "RunVddGnd: cannot connect on Vdd at Or Top", pla);
+	pla_ConnectThruFacets(VDD, pla_otv, _("RunVddGnd: cannot connect on Vdd at Or Top"), pla);
 
 	/* Export this as the external VDD connection point */
 	if (newportproto(pla, pla_otv->inst, pla_otv->port->port, "VDD") == NOPORTPROTO)
-		ttyputerr("RunVddGnd: cannot export VDD point");
+		ttyputerr(_("RunVddGnd: cannot export VDD point"));
 
 	/* Now instance a ground pin above the Pullups on the AND plane
 	 * and connect it to both the pu on OR and AND
@@ -668,15 +668,15 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_otv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_otv,
-		"RunVddGnd: cannot instance Vdd turnpin over pu AND", pla);
+		_("RunVddGnd: cannot instance Vdd turnpin over pu AND"), pla);
 
-	pla_ConnectOnMetal(VDD, &turnpin, "RunVddGnd: cannot connect turnpin to pu on top of OR", pla);
+	pla_ConnectOnMetal(VDD, &turnpin, _("RunVddGnd: cannot connect turnpin to pu on top of OR"), pla);
 
 	turnpin.nextinst = pla_alv;
-	pla_ConnectOnMetal(VDD, &turnpin, "RunVddGnd: cannot connect turnpin to pu on Left AND/Top", pla);
+	pla_ConnectOnMetal(VDD, &turnpin, _("RunVddGnd: cannot connect turnpin to pu on Left AND/Top"), pla);
 
 	/* Now connect through the pu on AND */
-	pla_ConnectThruFacets(VDD, pla_alv, "RunVddGnd: cannot connect on Vdd at And Left", pla);
+	pla_ConnectThruFacets(VDD, pla_alv, _("RunVddGnd: cannot connect on Vdd at And Left"), pla);
 
 	/* Instance a turnpin near the first input facet and connect it to
 	 * both the pullups and the input facets
@@ -686,15 +686,15 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_icv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_alv,
-		"RunVddGnd: cannot instance Vdd turnpin near Input facet", pla);
+		_("RunVddGnd: cannot instance Vdd turnpin near Input facet"), pla);
 
-	pla_ConnectOnMetal(VDD, &turnpin, "RunVddGnd: cannot connect turnpin to pu on Left AND/Bot",pla);
+	pla_ConnectOnMetal(VDD, &turnpin, _("RunVddGnd: cannot connect turnpin to pu on Left AND/Bot"),pla);
 
 	turnpin.nextinst = pla_icv;
-	pla_ConnectOnMetal(VDD, &turnpin, "RunVddGnd: cannot connect turnpin to infacet on left", pla);
+	pla_ConnectOnMetal(VDD, &turnpin, _("RunVddGnd: cannot connect turnpin to infacet on left"), pla);
 
 	/* Connect through the input facets */
-	pla_ConnectThruFacets(VDD, pla_icv, "RunVddGnd: cannot connect on Vdd at Input facets", pla);
+	pla_ConnectThruFacets(VDD, pla_icv, _("RunVddGnd: cannot connect on Vdd at Input facets"), pla);
 
 	/* Instance yet two more turnpins on the right of the input facets */
 	lowx  = puX + andX;
@@ -705,26 +705,26 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_icv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_icv,
-		"RunVddGnd: cannot instance top Vdd turnpin after Input Facet", pla);
+		_("RunVddGnd: cannot instance top Vdd turnpin after Input Facet"), pla);
 
-	pla_ConnectOnMetal(VDD, &turnpin, "RunVddGnd: cannot connect turnpin to last input facet", pla);
+	pla_ConnectOnMetal(VDD, &turnpin, _("RunVddGnd: cannot connect turnpin to last input facet"), pla);
 
 	lowy = (pla_ocv->port->y) - pla_halfVdd;
 	highy = lowy + pla_VddWidth;
 	porty = pla_ocv->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin1, &turnpin,
-		"RunVddGnd: cannot instance bot Vdd turnpin after Input Facet", pla);
+		_("RunVddGnd: cannot instance bot Vdd turnpin after Input Facet"), pla);
 
 	pla_ConnectOnMetal(VDD, &turnpin1,
-		"RunVddGnd: cannot connect the two turnpins on left of input", pla);
+		_("RunVddGnd: cannot connect the two turnpins on left of input"), pla);
 
 	turnpin1.nextinst = pla_ocv;
-	pla_ConnectOnMetal(VDD, &turnpin1, "RunVddGnd: cannot connect through output facets", pla);
+	pla_ConnectOnMetal(VDD, &turnpin1, _("RunVddGnd: cannot connect through output facets"), pla);
 
 	/*  Let us lay out the Ground line now.  Begin with the input facets. */
 	pla_ConnectThruFacets(GND, pla_icg,
-		"RunVddGnd: cannot connect on Gnd at Input", pla);
+		_("RunVddGnd: cannot connect on Gnd at Input"), pla);
 
 	/* Instance a fork pin at the end of the input facets.  One arm from
 	 * this fork goes up between the planes and the other through the
@@ -738,11 +738,11 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_icg->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &forkpin, pla_arg,
-		"RunVddGnd: cannot instance Gnd fork pin", pla);
-	pla_ConnectThruFacets(GND, &forkpin, "RunVddGnd: cannot connect through And Right Gnds", pla);
+		_("RunVddGnd: cannot instance Gnd fork pin"), pla);
+	pla_ConnectThruFacets(GND, &forkpin, _("RunVddGnd: cannot connect through And Right Gnds"), pla);
 
 	forkpin.nextinst = pla_icg;
-	pla_ConnectOnMetal(GND, &forkpin, "RunVddGnd: cannot connect input facets to fork pin", pla);
+	pla_ConnectOnMetal(GND, &forkpin, _("RunVddGnd: cannot connect input facets to fork pin"), pla);
 
 	/* Instance a turn pin at the top of the planes */
 	lowy  = (pla_atg->port->y) - pla_halfGnd;
@@ -750,15 +750,15 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_atg->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_arg,
-		"RunVddGnd: cannot instance Gnd on AND top", pla);
+		_("RunVddGnd: cannot instance Gnd on AND top"), pla);
 
 	pla_ConnectOnMetal(GND, &turnpin,
-		"RunVddGnd: cannot connect turnpin to Gnd on Right AND/Top", pla);
+		_("RunVddGnd: cannot connect turnpin to Gnd on Right AND/Top"), pla);
 
 	turnpin.nextinst = pla_atg;
-	pla_ConnectOnMetal(GND, &turnpin, "RunVddGnd: cannot connect turnpin to And Top Gnds", pla);
+	pla_ConnectOnMetal(GND, &turnpin, _("RunVddGnd: cannot connect turnpin to And Top Gnds"), pla);
 
-	pla_ConnectThruFacets(GND, pla_atg, "RunVddGnd: cannot connect through And Top Gnds", pla);
+	pla_ConnectThruFacets(GND, pla_atg, _("RunVddGnd: cannot connect through And Top Gnds"), pla);
 
 	/* Connect through the other arm of the Gnd fork.
 	 * Begin by instancing a turnpin below the fork pin
@@ -771,12 +771,12 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_ocg->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, &forkpin,
-		"RunVddGnd: cannot instance Gnd turnpin before Output Facet", pla);
+		_("RunVddGnd: cannot instance Gnd turnpin before Output Facet"), pla);
 
-	pla_ConnectOnMetal(GND, &turnpin, "RunVddGnd: cannot connect forkpin to turnpin", pla);
+	pla_ConnectOnMetal(GND, &turnpin, _("RunVddGnd: cannot connect forkpin to turnpin"), pla);
 
 	turnpin.nextinst = pla_ocg;
-	pla_ConnectThruFacets(GND, &turnpin, "RunVddGnd: cannot connect through output facets", pla);
+	pla_ConnectThruFacets(GND, &turnpin, _("RunVddGnd: cannot connect through output facets"), pla);
 
 	/* Instance a turn pin after the output facets */
 	lowx  = (pla_org->port->x) - pla_halfGnd;
@@ -787,17 +787,17 @@ void pla_RunVddGnd(INTBIG puX, INTBIG andX, NODEPROTO *pla)
 	porty = pla_ocg->port->y;
 
 	pla_InstTurnPin(lowx, highx, lowy, highy, portx, porty, &turnpin, pla_ocg,
-		"RunVddGnd: cannot instance Gnd turnpin after Output Facet", pla);
+		_("RunVddGnd: cannot instance Gnd turnpin after Output Facet"), pla);
 
 	pla_ConnectOnMetal(GND, &turnpin,
-		"RunVddGnd: cannot connect Output facets to turnpin on right", pla);
+		_("RunVddGnd: cannot connect Output facets to turnpin on right"), pla);
 
 	turnpin.nextinst = pla_org;
-	pla_ConnectThruFacets(GND, &turnpin, "RunVddGnd: cannot connect through Or Right Gnds", pla);
+	pla_ConnectThruFacets(GND, &turnpin, _("RunVddGnd: cannot connect through Or Right Gnds"), pla);
 
 	/* Export this as the external GND connection point */
 	if (newportproto(pla, pla_org->inst, pla_org->port->port, "GND") == NOPORTPROTO)
-		ttyputerr("RunVddGnd: cannot export GND point");
+		ttyputerr(_("RunVddGnd: cannot export GND point"));
 }
 
 #endif  /* PLAAID - at top */
