@@ -40,9 +40,9 @@
 
 /* the ROUTER aid table */
 static COMCOMP routerfacetp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Facet to stitch", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Facet to stitch"), 0};
 COMCOMP routerarcp = {NOKEYWORD, topofarcs, nextarcs, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Arc prototype to use in stitching (* to reset)", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Arc prototype to use in stitching (* to reset)"), 0};
 static KEYWORD routerautoopt[] =
 {
 	{"stitch-now",             1,{&routerfacetp,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -50,7 +50,7 @@ static KEYWORD routerautoopt[] =
 	TERMKEY
 };
 static COMCOMP routerautop = {routerautoopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Auto-stitching action", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Auto-stitching action"), 0};
 static KEYWORD routermimicopt[] =
 {
 	{"do-now",                 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -62,19 +62,19 @@ static KEYWORD routermimicopt[] =
 	TERMKEY
 };
 static COMCOMP routermimicp = {routermimicopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Mimic-stitching action", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Mimic-stitching action"), 0};
 static COMCOMP routerriverp = {NOKEYWORD, topoffacets, nextfacets, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Facet to river-route", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Facet to river-route"), 0};
 static COMCOMP routermazesetboundaryp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
-	0, " \t", "routing boundary", 0};
+	0, " \t", M_("routing boundary"), 0};
 static COMCOMP routermazesetgridxp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
-	0, " \t", "routing grid x", 0};
+	0, " \t", M_("routing grid x"), 0};
 static COMCOMP routermazesetgridyp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
-	0, " \t", "routing grid y", 0};
+	0, " \t", M_("routing grid y"), 0};
 static COMCOMP routermazesetoffsetxp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
-	0, " \t", "routing offset x", 0};
+	0, " \t", M_("routing offset x"), 0};
 static COMCOMP routermazesetoffsetyp = {NOKEYWORD,NOTOPLIST,NONEXTLIST,NOPARAMS,NOBACKUP,
-	0, " \t", "routing offset y", 0};
+	0, " \t", M_("routing offset y"), 0};
 static KEYWORD routermazesetopt[] =
 {
 	{"boundary",			 1,{&routermazesetboundaryp,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -83,7 +83,7 @@ static KEYWORD routermazesetopt[] =
 	TERMKEY
 };
 static COMCOMP routermazesetp = {routermazesetopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "set operation", 0 };
+	0, " \t", M_("set operation"), 0 };
 static KEYWORD routermazerouteopt[] =
 {
 	{"cell",	 0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -91,7 +91,7 @@ static KEYWORD routermazerouteopt[] =
 	TERMKEY
 };
 static COMCOMP routermazeroutep = {routermazerouteopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "routing operation", 0 };
+	0, " \t", M_("routing operation"), 0 };
 static KEYWORD routermazeopt[] =
 {
 	{"set",	    1, {&routermazesetp,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -99,20 +99,32 @@ static KEYWORD routermazeopt[] =
 	TERMKEY
 };
 COMCOMP routermazep = {routermazeopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "Maze routing operation", 0 };
+	0, " \t", M_("Maze routing operation"), 0 };
 static KEYWORD routernopt[] =
 {
 	{"select",             0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	TERMKEY
 };
 static COMCOMP routernp = {routernopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Negating action", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Negating action"), 0};
+#if ROUTAIDSUN
+static KEYWORD routerparopt[] =
+{
+	{"go",               0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
+	TERMKEY
+};
+static COMCOMP routerparp = {routerparopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
+	NOBACKUP, INPUTOPT, " \t", M_("General auto routing action"), 0};
+#endif
 static KEYWORD routeropt[] =
 {
 	{"auto-stitch",    1,{&routerautop,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"mimic-stitch",   1,{&routermimicp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"river-route",    1,{&routerriverp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"maze-route",     1,{&routermazep,NOKEY,NOKEY,NOKEY,NOKEY}},
+#if ROUTAIDSUN
+	{"par-route",      1,{&routerparp,NOKEY,NOKEY,NOKEY,NOKEY}},
+#endif
 	{"use-arc",        1,{&routerarcp,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"select",         0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
 	{"no-stitch",      0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -121,7 +133,7 @@ static KEYWORD routeropt[] =
 	TERMKEY
 };
 COMCOMP ro_routerp = {routeropt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "Routing action", 0};
+	0, " \t", M_("Routing action"), 0};
 
 RCHECK *ro_firstrcheck;
 RCHECK *ro_rcheckfree;
@@ -147,19 +159,19 @@ static INTBIG     *ro_findnetlisty;
 /* Routing Options */
 DIALOGITEM ro_optionsdialogitems[] =
 {
- /*  1 */ {0, {216,208,240,272}, BUTTON, "OK"},
- /*  2 */ {0, {216,12,240,76}, BUTTON, "Cancel"},
+ /*  1 */ {0, {216,208,240,272}, BUTTON, N_("OK")},
+ /*  2 */ {0, {216,12,240,76}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {32,88,48,272}, POPUP, ""},
- /*  4 */ {0, {32,8,48,88}, MESSAGE, "Currently:"},
- /*  5 */ {0, {8,8,24,220}, MESSAGE, "Arc to use in stitching routers:"},
- /*  6 */ {0, {68,8,84,268}, CHECK, "Mimic stitching can unstitch"},
- /*  7 */ {0, {116,24,132,268}, CHECK, "Ports must match"},
- /*  8 */ {0, {188,8,204,268}, CHECK, "Mimic stitching runs interactively"},
- /*  9 */ {0, {92,8,108,268}, MESSAGE, "Mimic stitching restrictions:"},
- /* 10 */ {0, {164,24,180,268}, CHECK, "Node types must match"},
- /* 11 */ {0, {140,24,156,268}, CHECK, "Nodes sizes must match"}
+ /*  4 */ {0, {32,8,48,88}, MESSAGE, N_("Currently:")},
+ /*  5 */ {0, {8,8,24,220}, MESSAGE, N_("Arc to use in stitching routers:")},
+ /*  6 */ {0, {68,8,84,268}, CHECK, N_("Mimic stitching can unstitch")},
+ /*  7 */ {0, {116,24,132,268}, CHECK, N_("Ports must match")},
+ /*  8 */ {0, {188,8,204,268}, CHECK, N_("Mimic stitching runs interactively")},
+ /*  9 */ {0, {92,8,108,268}, MESSAGE, N_("Mimic stitching restrictions:")},
+ /* 10 */ {0, {164,24,180,268}, CHECK, N_("Node types must match")},
+ /* 11 */ {0, {140,24,156,268}, CHECK, N_("Nodes sizes must match")}
 };
-DIALOG ro_optionsdialog = {{50,75,299,356}, "Routing Options", 11, ro_optionsdialogitems};
+DIALOG ro_optionsdialog = {{50,75,299,356}, N_("Routing Options"), 0, 11, ro_optionsdialogitems};
 
 /* prototypes for local routines */
 RCHECK *ro_allocrcheck(void);
@@ -208,7 +220,7 @@ void ro_queuercheck(NODEINST *ni)
 	r = ro_allocrcheck();
 	if (r == NORCHECK)
 	{
-		ttyputerr("ROUTING: out of space");
+		ttyputnomemory();
 		return;
 	}
 	r->entity = ni;
@@ -296,15 +308,15 @@ INTSML ro_set(INTSML count, char *par[])
 		switch (ro_state&STITCHMODE)
 		{
 			case NOSTITCH:
-				ttyputmsg("No stitching being done");          break;
+				ttyputmsg(_("No stitching being done"));          break;
 			case AUTOSTITCH:
-				ttyputmsg("Default is auto-stitch routing");   break;
+				ttyputmsg(_("Default is auto-stitch routing"));   break;
 			case MIMICSTITCH:
-				ttyputmsg("Default is mimic-stitch routing");  break;
+				ttyputmsg(_("Default is mimic-stitch routing"));  break;
 		}
 		var = getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey);
 		if (var != NOVARIABLE)
-			ttyputmsg("Default arc for river routing is %s",
+			ttyputmsg(_("Default arc for river routing is %s"),
 				describearcproto(((ARCPROTO *)var->addr)));
 		return(0);
 	}
@@ -335,17 +347,17 @@ INTSML ro_set(INTSML count, char *par[])
 				np = getnodeproto(par[2]);
 				if (np == NONODEPROTO)
 				{
-					ttyputerr("No facet named %s", par[2]);
+					ttyputerr(_("No facet named %s"), par[2]);
 					return(1);
 				}
 				if (np->primindex != 0)
 				{
-					ttyputerr("Can only stitch facets, not primitives");
+					ttyputerr(_("Can only stitch facets, not primitives"));
 					return(1);
 				}
 				if (np->cell->lib != el_curlib)
 				{
-					ttyputerr("Can only stitch facets in the current library");
+					ttyputerr(_("Can only stitch facets in the current library"));
 					return(1);
 				}
 			} else
@@ -353,7 +365,7 @@ INTSML ro_set(INTSML count, char *par[])
 				np = getcurfacet();
 				if (np == NONODEPROTO)
 				{
-					ttyputerr("No current facet");
+					ttyputerr(_("No current facet"));
 					return(1);
 				}
 			}
@@ -370,7 +382,7 @@ INTSML ro_set(INTSML count, char *par[])
 
 			/* restore routing state */
 			ro_state = savestate;
-			ttyputverbose("Facet %s stitched", describenodeproto(np));
+			ttyputverbose(_("Facet %s stitched"), describenodeproto(np));
 			return(0);
 		}
 		if (namesamen(pp, "highlighted-stitch-now", l) == 0)
@@ -378,7 +390,7 @@ INTSML ro_set(INTSML count, char *par[])
 			list = (GEOM **)askaid(us_aid, "get-all-nodes");
 			if (list[0] == NOGEOM)
 			{
-				ttyputerr("Select an area to be stitched");
+				ttyputerr(_("Select an area to be stitched"));
 				return(1);
 			}
 			for(l=0; list[l] != NOGEOM; l++)
@@ -393,10 +405,10 @@ INTSML ro_set(INTSML count, char *par[])
 
 			/* restore routing state */
 			ro_state = savestate;
-			ttyputverbose("Stitching complete");
+			ttyputverbose(_("Stitching complete"));
 			return(0);
 		}
-		ttyputerr("Bad AUTO-STITCH option: %s", pp);
+		ttyputbadusage("tellaid routing auto-stitch");
 		return(1);
 	}
 
@@ -404,7 +416,7 @@ INTSML ro_set(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			ttyputerr("Usage: tellaid routing mimic-stitch OPTION");
+			ttyputusage("tellaid routing mimic-stitch OPTION");
 			return(1);
 		}
 		l = strlen(pp = par[1]);
@@ -423,31 +435,31 @@ INTSML ro_set(INTSML count, char *par[])
 		{
 			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
 				ro_getoptions() | MIMICUNROUTES, VINTEGER);
-			ttyputverbose("Mimic stitcher will route and unroute");
+			ttyputverbose(_("Mimic stitcher will route and unroute"));
 			return(0);
 		}
 		if (namesamen(pp, "stitch-only", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
 				ro_getoptions() & ~MIMICUNROUTES, VINTEGER);
-			ttyputverbose("Mimic stitcher will only route, not unroute");
+			ttyputverbose(_("Mimic stitcher will only route, not unroute"));
 			return(0);
 		}
 		if (namesamen(pp, "port-general", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
 				ro_getoptions() | MIMICIGNOREPORTS, VINTEGER);
-			ttyputverbose("Mimic stitcher will route to any port");
+			ttyputverbose(_("Mimic stitcher will route to any port"));
 			return(0);
 		}
 		if (namesamen(pp, "port-specific", l) == 0 && l >= 8)
 		{
 			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey,
 				ro_getoptions() & ~MIMICIGNOREPORTS, VINTEGER);
-			ttyputverbose("Mimic stitcher will rout only to similar ports");
+			ttyputverbose(_("Mimic stitcher will rout only to similar ports"));
 			return(0);
 		}
-		ttyputerr("Bad mimic-stitching option: %s", pp);
+		ttyputbadusage("tellaid routing mimic-stitching");
 		return(1);
 	}
 
@@ -458,12 +470,12 @@ INTSML ro_set(INTSML count, char *par[])
 			np = getnodeproto(par[1]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No facet named %s", par[1]);
+				ttyputerr(_("No facet named %s"), par[1]);
 				return(1);
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr("Can only river-route facets, not primitives");
+				ttyputerr(_("Can only route facets, not primitives"));
 				return(1);
 			}
 		} else
@@ -471,13 +483,13 @@ INTSML ro_set(INTSML count, char *par[])
 			np = getcurfacet();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No current facet");
+				ttyputerr(_("No current facet"));
 				return(1);
 			}
 		}
 
-		if (ro_river(np) == 0) ttyputmsg("Routing not successful"); else
-			ttyputverbose("Facet %s river-routed", describenodeproto(np));
+		if (ro_river(np) == 0) ttyputmsg(_("Routing not successful")); else
+			ttyputverbose(_("Facet %s river-routed"), describenodeproto(np));
 		return(0);
 	}
 
@@ -498,71 +510,75 @@ INTSML ro_set(INTSML count, char *par[])
 				ro_mazerouteselected();
 				return(0);
 			}
-			ttyputerr("Bad maze-route option: %s", pp);
+			ttyputbadusage("tellaid routing maze-route");
 			return(1);
 		}
 		if (namesamen(pp, "set", l) == 0)
 		{
 			if (count <= 2)
 			{
-				ttyputmsg("Routing grid (%3.1f,%3.1f)", (double)ro_mazegridx/(double)sch_tech->deflambda,
-					(double)ro_mazegridy/(double)sch_tech->deflambda);
-				ttyputmsg("Routing offset (%3.1f,%3.1f)", (double)ro_mazeoffsetx/(double)sch_tech->deflambda,
-					(double)ro_mazeoffsety/(double)sch_tech->deflambda);
-				ttyputmsg("Routing boundary (%3.1f)", (double)ro_mazeboundary/(double)sch_tech->deflambda);
+				ttyputmsg(_("Routing grid: %sx%s"), latoa(ro_mazegridx), latoa(ro_mazegridy));
+				ttyputmsg(_("Routing offset: (%s,%s)"), latoa(ro_mazeoffsetx), latoa(ro_mazeoffsety));
+				ttyputmsg(_("Routing boundary: %s"), latoa(ro_mazeboundary));
 				return(0);
 			}
 
 			l = strlen(pp = par[2]);
 			if (namesamen(pp, "grid", l) == 0)
 			{
-				ro_mazegridx = (INTBIG)(atof(par[3]) * sch_tech->deflambda);
-				ro_mazegridy = (INTBIG)(atof(par[4]) * sch_tech->deflambda);
-				ttyputmsg("Routing grid (%3.1f,%3.1f)", (double)ro_mazegridx/(double)sch_tech->deflambda,
-					(double)ro_mazegridy/(double)sch_tech->deflambda);
+				ro_mazegridx = atola(par[3]);
+				ro_mazegridy = atola(par[4]);
+				ttyputmsg(_("Routing grid: %sx%s"), latoa(ro_mazegridx), latoa(ro_mazegridy));
 				return 0;
 			}
 			if (namesamen(pp, "offset", l) == 0)
 			{
-				ro_mazeoffsetx = (INTBIG)(atof(par[3]) * sch_tech->deflambda);
-				ro_mazeoffsety = (INTBIG)(atof(par[4]) * sch_tech->deflambda);
-				ttyputmsg("Routing offset (%3.1f,%3.1f)", (double)ro_mazeoffsetx/(double)sch_tech->deflambda,
-					(double)ro_mazeoffsety/(double)sch_tech->deflambda);
+				ro_mazeoffsetx = atola(par[3]);
+				ro_mazeoffsety = atola(par[4]);
+				ttyputmsg(_("Routing offset: (%s,%s)"), latoa(ro_mazeoffsetx), latoa(ro_mazeoffsety));
 				return 0;
 			}
 			if (namesamen(pp, "boundary", l) == 0)
 			{
-				ro_mazeboundary = (INTBIG)(atof(par[3]) * sch_tech->deflambda);
-				ttyputmsg("Routing boundary (%3.1f)", (double)ro_mazeboundary/(double)sch_tech->deflambda);
+				ro_mazeboundary = atola(par[3]);
+				ttyputmsg(_("Routing boundary: %s"), latoa(ro_mazeboundary));
 				return 0;
 			}
 
-			ttyputerr("Bad maze-route set option: %s", pp);
+			ttyputbadusage("tellaid routing maze-route set");
 			return(1);
 		}
 	}
 
+#if ROUTAIDSUN
+	if (namesamen(pp, "par-route", l) == 0)
+	{
+		ro_par();
+		return(0);
+	}
+#endif
+
 	if (namesamen(pp, "use-arc", l) == 0)
 	{
 		if (count < 2)
 		{
-			ttyputerr("Usage: tellaid routing use-arc ARCPROTO");
+			ttyputusage("tellaid routing use-arc ARCPROTO");
 			return(1);
 		}
 		if (strcmp(par[1], "*") == 0)
 		{
 			if (getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey) != NOVARIABLE)
 				(void)delvalkey((INTBIG)ro_aid, VAID, ro_preferedkey);
-			ttyputverbose("No arc will be presumed for stitching");
+			ttyputverbose(_("No arc will be presumed for stitching"));
 			return(0);
 		}
 		ap = getarcproto(par[1]);
 		if (ap == NOARCPROTO)
 		{
-			ttyputerr("No arc prototype called %s", par[1]);
+			ttyputerr(_("No arc prototype called %s"), par[1]);
 			return(1);
 		}
-		ttyputverbose("Default stitching arc will be %s", describearcproto(ap));
+		ttyputverbose(_("Default stitching arc will be %s"), describearcproto(ap));
 		(void)setvalkey((INTBIG)ro_aid, VAID, ro_preferedkey, (INTBIG)ap, VARCPROTO);
 		return(0);
 	}
@@ -577,7 +593,7 @@ INTSML ro_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputerr("Usage: tellaid routing not OPTION");
+			ttyputusage("tellaid routing not OPTION");
 			return(1);
 		}
 		l = strlen(pp = par[1]);
@@ -585,10 +601,10 @@ INTSML ro_set(INTSML count, char *par[])
 		{
 			(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
 				ro_state & ~SELECT, VINTEGER|VDONTSAVE);
-			ttyputverbose("Wire placement not subject to approval");
+			ttyputverbose(_("Wire placement not subject to approval"));
 			return(0);
 		}
-		ttyputerr("Bad ROUTING NOT option: %s", pp);
+		ttyputbadusage("tellaid routing not");
 		return(1);
 	}
 
@@ -596,11 +612,11 @@ INTSML ro_set(INTSML count, char *par[])
 	{
 		(void)setvalkey((INTBIG)ro_aid, VAID, ro_statekey,
 			ro_state | SELECT, VINTEGER|VDONTSAVE);
-		ttyputverbose("Wire placement subject to approval");
+		ttyputverbose(_("Wire placement subject to approval"));
 		return(0);
 	}
 
-	ttyputerr("Bad ROUTING option: %s", pp);
+	ttyputbadusage("tellaid routing");
 	return(1);
 }
 
@@ -616,11 +632,11 @@ void ro_slice(void)
 	{
 		case AUTOSTITCH:
 			ro_autostitch();
-			setactivity("Facets stitched");
+			setactivity(_("Facets stitched"));
 			break;
 		case MIMICSTITCH:
 			ro_mimicstitch(0);
-			setactivity("Facets stitched");
+			setactivity(_("Facets stitched"));
 			break;
 	}
 }
@@ -733,7 +749,7 @@ void ro_unroutecurrent(void)
 	for(selectcount=0; list[selectcount] != NOGEOM; selectcount++) ;
 	if (selectcount == 0)
 	{
-		ttyputerr("Must select arcs to unroute");
+		ttyputerr(_("Must select arcs to unroute"));
 		return;
 	}
 	np = geomparent(list[0]);
@@ -785,15 +801,11 @@ INTSML ro_unroutenet(NETWORK *net)
 	REGISTER ARCINST *ai, *nextai;
 	REGISTER NODEINST *ni, *nextni;
 	REGISTER NODEPROTO *np;
-	REGISTER INTBIG bits;
+	REGISTER INTBIG bits, wid, i, j, dist, bestdist, first, found, besti, bestj;
+	REGISTER INTSML *covered;
 
 	/* convert this net and mark arcs and nodes on it */
 	count = ro_findnetends(net, &nilist, &pplist, &xlist, &ylist);
-	if (count != 2)
-	{
-		ttyputerr("Network must have 2 ends: this has %ld", count);
-		return(0);
-	}
 
 	/* remove marked nodes and arcs */
 	np = net->parent;
@@ -804,7 +816,7 @@ INTSML ro_unroutenet(NETWORK *net)
 		startobjectchange((INTBIG)ai, VARCINST);
 		if (killarcinst(ai))
 		{
-			ttyputerr("Error deleting arc");
+			ttyputerr(_("Error deleting arc"));
 			return(1);
 		}
 	}
@@ -815,22 +827,50 @@ INTSML ro_unroutenet(NETWORK *net)
 		startobjectchange((INTBIG)ni, VNODEINST);
 		if (killnodeinst(ni))
 		{
-			ttyputerr("Error deleting intermediate node");
+			ttyputerr(_("Error deleting intermediate node"));
 			return(1);
 		}
 	}
 
-	/* now create the new unrouted wire */
+	/* now create the new unrouted wires */
 	bits = us_makearcuserbits(gen_unroutedarc);
-	ai = newarcinst(gen_unroutedarc, defaultarcwidth(gen_unroutedarc), bits,
-		nilist[0], pplist[0], xlist[0], ylist[0], nilist[1], pplist[1], xlist[1], ylist[1], np);
-	if (ai == NOARCINST)
+	wid = defaultarcwidth(gen_unroutedarc);
+	covered = (INTSML *)emalloc(count * SIZEOFINTSML, el_tempcluster);
+	if (covered == 0) return(0);
+	for(i=0; i<count; i++) covered[i] = 0;
+	for(first=0; ; first++)
 	{
-		ttyputerr("Could not create unrouted arc");
-		return(1);
+		found = 1;
+		for(i=0; i<count; i++)
+		{
+			for(j=i+1; j<count; j++)
+			{
+				if (first != 0)
+				{
+					if (covered[i] + covered[j] != 1) continue;
+				}
+				dist = computedistance(xlist[i], ylist[i], xlist[j], ylist[j]);
+				if (found == 0 && dist >= bestdist) continue;
+				found = 0;
+				bestdist = dist;
+				besti = i;
+				bestj = j;
+			}
+		}
+		if (found != 0) break;
+
+		covered[besti] = covered[bestj] = 1;
+		ai = newarcinst(gen_unroutedarc, wid, bits,
+			nilist[besti], pplist[besti], xlist[besti], ylist[besti],
+			nilist[bestj], pplist[bestj], xlist[bestj], ylist[bestj], np);
+		if (ai == NOARCINST)
+		{
+			ttyputerr(_("Could not create unrouted arc"));
+			return(1);
+		}
+		endobjectchange((INTBIG)ai, VARCINST);
+		(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
 	}
-	endobjectchange((INTBIG)ai, VARCINST);
-	(void)askaid(us_aid, "show-object", (INTBIG)ai->geom);
 	return(0);
 }
 
@@ -875,9 +915,17 @@ INTBIG ro_findnetends(NETWORK *net, NODEINST ***nilist, PORTPROTO ***pplist,
 			for(pi = ni->firstportarcinst; pi != NOPORTARCINST; pi = pi->nextportarcinst)
 				if (pi != thispi && pi->conarcinst->network == net) break;
 			if (pi == NOPORTARCINST) term = 1;
+			if (ni->firstportexpinst != NOPORTEXPINST) term = 1;
+			if (ni->proto->primindex == 0) term = 1;
 			if (term != 0)
 			{
-				/* valid network end: add it to the list */
+				/* valid network end: see if it is in the list */
+				for(j=0; j<listcount; j++)
+					if (ni == ro_findnetlistni[j] && thispi->proto == ro_findnetlistpp[j])
+						break;
+				if (j < listcount) continue;
+
+				/* add it to the list */
 				if (listcount >= ro_findnetlisttotal)
 				{
 					newtotal = listcount * 2;
@@ -951,14 +999,15 @@ INTBIG ro_getoptions(void)
  */
 void ro_optionsdlog(void)
 {
-	INTBIG itemHit, numarcnames, initialindex, i, options;
+	INTBIG itemHit, numarcnames, initialindex, i, options, oldoptions;
 	REGISTER VARIABLE *var;
-	extern AIDENTRY *ro_aid;
-	REGISTER ARCPROTO *ap, **arcs;
+	REGISTER ARCPROTO *ap, **arcs, *oldap;
 	char **arcnames, *paramstart[3];
 
 	/* gather list of arcs */
-	var = getval((INTBIG)ro_aid, VAID, VARCPROTO, "ROUT_prefered_arc");
+	var = getvalkey((INTBIG)ro_aid, VAID, VARCPROTO, ro_preferedkey);
+	if (var == NOVARIABLE) oldap = NOARCPROTO; else
+		oldap = (ARCPROTO *)var->addr;
 	numarcnames = 0;
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 		numarcnames++;
@@ -973,10 +1022,7 @@ void ro_optionsdlog(void)
 	{
 		arcs[numarcnames] = ap;
 		arcnames[numarcnames] = ap->protoname;
-		if (var != NOVARIABLE)
-		{
-			if (ap == (ARCPROTO *)var->addr) initialindex = numarcnames;
-		}
+		if (ap == oldap) initialindex = numarcnames;
 		numarcnames++;
 	}
 
@@ -986,7 +1032,7 @@ void ro_optionsdlog(void)
 	DiaSetPopupEntry(3, initialindex);
 	efree((char *)arcnames);
 	ap = arcs[initialindex];
-	options = ro_getoptions();
+	oldoptions = options = ro_getoptions();
 	if ((options&MIMICUNROUTES) != 0) DiaSetControl(6, 1);
 	if ((options&MIMICIGNOREPORTS) == 0) DiaSetControl(7, 1);
 	if ((options&MIMICIGNORENODETYPE) == 0) DiaSetControl(10, 1);
@@ -1024,11 +1070,15 @@ void ro_optionsdlog(void)
 			options &= ~MIMICIGNORENODESIZE;
 		if (DiaGetControl(8) != 0) options |= MIMICINTERACTIVE; else
 			options &= ~MIMICINTERACTIVE;
-		(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey, options, VINTEGER);
+		if (options != oldoptions)
+			(void)setvalkey((INTBIG)ro_aid, VAID, ro_optionskey, options, VINTEGER);
 		paramstart[0] = "use-arc";
-		if (ap == NOARCPROTO) paramstart[1] = "*"; else
-			paramstart[1] = ap->protoname;		
-		(void)tellaid(ro_aid, 2, paramstart);
+		if (ap != oldap)
+		{
+			if (ap == NOARCPROTO) paramstart[1] = "*"; else
+				paramstart[1] = ap->protoname;
+			(void)tellaid(ro_aid, 2, paramstart);
+		}
 	}
 	DiaDoneDialog();
 	efree((char *)arcs);
