@@ -61,13 +61,12 @@ void ro_autostitch(void)
 	REGISTER ARCPROTO *ap;
 	REGISTER LIBRARY *lib;
 	REGISTER TECHNOLOGY *tech;
-	extern AIDENTRY *net_aid;
 	REGISTER VARIABLE *var;
 
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
 		return;
 	}
@@ -98,7 +97,7 @@ void ro_autostitch(void)
 			bbarray = emalloc((total * 4 * SIZEOFINTBIG), el_tempcluster);
 			if (bbarray == 0)
 			{
-				ttyputerr("No memory for stitching");
+				ttyputnomemory();
 				ni->temp2 = -1;
 			} else
 			{
@@ -149,7 +148,7 @@ void ro_autostitch(void)
 	for(r = ro_firstrcheck; r != NORCHECK; r = nextr)
 	{
 		nextr = r->nextcheck;
-		if (stopping("Routing") == 0)
+		if (stopping(STOPREASONROUTING) == 0)
 		{
 			ni = r->entity;
 			if ((ni->parent->userbits&NLOCKED) != 0) continue;
@@ -175,7 +174,7 @@ void ro_autostitch(void)
 
 	/* report results */
 	if (count != 0)
-		ttyputmsg("AUTO ROUTING: added %ld %s", count, makeplural("wire", count));
+		ttyputmsg(_("AUTO ROUTING: added %ld %s"), count, makeplural(_("wire"), count));
 }
 
 /*
@@ -185,7 +184,7 @@ void ro_autostitch(void)
 INTBIG ro_checkstitching(NODEINST *ni)
 {
 	REGISTER INTBIG search, lx, hx, ly, hy, bestdist, dist, ox, oy, stitched, count;
-	REGISTER INTSML tot, i, j, bbp;
+	REGISTER INTBIG tot, i, j, bbp;
 	INTBIG x, y;
 	XARRAY trans, localtran, temp;
 	REGISTER GEOM *geom;
@@ -205,7 +204,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 	count = 0;
 	for(;;)
 	{
-		if (stopping("Routing") != 0) { termsearch(search);   return(count); }
+		if (stopping(STOPREASONROUTING)) { termsearch(search);   return(count); }
 
 		/* find another node in this area */
 		if ((geom = nextobject(search)) == NOGEOM) break;
@@ -264,7 +263,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 				}
 
 				/* look at all polygons on this nodeinst */
-				tot = nodeEpolys(rni);
+				tot = nodeEpolys(rni, 0);
 				for(j=0; j<tot; j++)
 				{
 					shapeEnodepoly(rni, j, poly);
@@ -314,7 +313,7 @@ INTBIG ro_checkstitching(NODEINST *ni)
 			oy = (oni->lowy + oni->highy) / 2;
 
 			/* look at all polygons on this nodeinst */
-			tot = nodeEpolys(ni);
+			tot = nodeEpolys(ni, 0);
 			for(j=0; j<tot; j++)
 			{
 				shapeEnodepoly(ni, j, poly);
@@ -394,7 +393,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 	XARRAY localtran, temp, trans;
 	INTBIG x, y, plx, phx, ply, phy;
 	static POLYGON *opoly = NOPOLYGON;
-	REGISTER INTSML tot, j, stitched, bbp;
+	REGISTER INTBIG tot, j, stitched, bbp;
 	REGISTER NETWORK *net, *onet;
 	REGISTER INTBIG dist, ox, oy, bestdist, lx, hx, ly, hy;
 
@@ -408,7 +407,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 	stitched = 0;
 	if (oni->proto->primindex == 0)
 	{
-		/* complex facet: look at all exported ports */
+		/* complex facet: look at all exportes */
 		if (oni->temp2 == 0 || oni->temp2 == -1) bbp = -1; else
 		{
 			getbbox(poly, &plx, &phx, &ply, &phy);
@@ -447,7 +446,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 			}
 
 			/* look at all polygons on this nodeinst */
-			tot = nodeEpolys(rni);
+			tot = nodeEpolys(rni, 0);
 			for(j=0; j<tot; j++)
 			{
 				shapeEnodepoly(rni, j, opoly);
@@ -482,7 +481,7 @@ INTBIG ro_testpoly(NODEINST *ni, PORTPROTO *pp, ARCPROTO *ap, POLYGON *poly, NOD
 		oy = (ni->lowy + ni->highy) / 2;
 
 		/* look at all polygons on this nodeinst */
-		tot = nodeEpolys(oni);
+		tot = nodeEpolys(oni, 0);
 		for(j=0; j<tot; j++)
 		{
 			shapeEnodepoly(oni, j, opoly);
@@ -604,7 +603,7 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2)
 		/* loop on user response */
 		for(;;)
 		{
-			ttyputmsg("Ok? ");
+			ttyputmsg(_("Ok? "));
 			ch = (char)ttygetchar();
 			(void)askaid(us_aid, "clear");
 			if (ch == 's')
@@ -619,25 +618,25 @@ INTBIG ro_didaccept(ARCINST *ai, ARCINST *alt1, ARCINST *alt2)
 			if (ch == 'n')
 			{
 				startobjectchange((INTBIG)ai, VARCINST);
-				if (killarcinst(ai) != 0) ttyputerr("Problem retracting arc");
+				if (killarcinst(ai) != 0) ttyputerr(_("Problem retracting arc"));
 				if (alt1 != NOARCINST)
 				{
 					startobjectchange((INTBIG)alt1, VARCINST);
 					if (killarcinst(alt1) != 0)
-						ttyputerr("Problem retracting arc");
+						ttyputerr(_("Problem retracting arc"));
 				}
 				if (alt2 != NOARCINST)
 				{
 					startobjectchange((INTBIG)alt2, VARCINST);
 					if (killarcinst(alt2) != 0)
-						ttyputerr("Problem retracting arc");
+						ttyputerr(_("Problem retracting arc"));
 				}
-				ttyputmsg("Stitch not made");
+				ttyputmsg(_("Stitch not made"));
 				return(0);
 			}
-			ttyputmsg("Type: y, SPACE, or CARRIAGE-RETURN to accept");
-			ttyputmsg("      n to reject");
-			ttyputmsg("      s to continue silently");
+			ttyputmsg(_("Type: y, SPACE, or CARRIAGE-RETURN to accept"));
+			ttyputmsg(_("      n to reject"));
+			ttyputmsg(_("      s to continue silently"));
 		}
 	}
 	return(1);
@@ -664,7 +663,7 @@ void ro_findsmallestlayer(ARCPROTO *ap)
 {
 	REGISTER ARCINST *ai;
 	REGISTER float area, bestarea;
-	REGISTER INTSML i, j, bestfound;
+	REGISTER INTBIG i, j, bestfound;
 	static POLYGON *poly = NOPOLYGON;
 
 	/* quit if the value has already been computed */
