@@ -345,7 +345,7 @@ void ro_mazerouteselected(void)
 	for(selectcount=0; list[selectcount] != NOGEOM; selectcount++) ;
 	if (selectcount == 0)
 	{
-		ttyputerr("Select arcs to route");
+		ttyputerr(_("Select arcs to route"));
 		return;
 	}
 	np = geomparent(list[0]);
@@ -411,7 +411,7 @@ void ro_mazeroutecell(void)
  */
 INTSML ro_mazeroutenet(NETWORK *net)
 {
-	INTBIG lx, ly, hx, hy;
+	INTBIG lx, ly, hx, hy, lambda;
 	INTSML i, ret, first;
 	NODEPROTO *np;
 	NODEINST **nilist;
@@ -434,7 +434,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	count = ro_findnetends(net, &nilist, &pplist, &xplist, &yplist);
 	if (count != 2)
 	{
-		ttyputerr("Can only route nets with 2 ends, this has %ld", count);
+		ttyputerr(_("Can only route nets with 2 ends, this has %ld"), count);
 		return(1);
 	}
 
@@ -442,10 +442,10 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	for(i=0; i<count; i++)
 	{
 		tech = ro_findtech(nilist[i], pplist[i]);
-		if (i == 0) ro_mazegridx = tech->deflambda; else
+		lambda = nilist[i]->parent->cell->lib->lambda[tech->techindex];
+		if (i == 0) ro_mazegridx = lambda; else
 		{
-			if (tech->deflambda < ro_mazegridx)
-				ro_mazegridx = tech->deflambda;
+			if (lambda < ro_mazegridx) ro_mazegridx = lambda;
 		}
 	}
 	ro_mazegridy = ro_mazegridx;
@@ -472,7 +472,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	}
 	if (first != 0)
 	{
-		ttyputerr("Internal error: no bounding area for routing");
+		ttyputerr(_("Internal error: no bounding area for routing"));
 		return(1);
 	}
 
@@ -487,7 +487,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 		startobjectchange((INTBIG)ai, VARCINST);
 		if (killarcinst(ai))
 		{
-			ttyputerr("Error deleting original arc");
+			ttyputerr(_("Error deleting original arc"));
 			return(1);
 		}
 	}
@@ -498,7 +498,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 		startobjectchange((INTBIG)ni, VNODEINST);
 		if (killnodeinst(ni))
 		{
-			ttyputerr("Error deleting intermediate pin");
+			ttyputerr(_("Error deleting intermediate pin"));
 			return(1);
 		}
 	}
@@ -511,7 +511,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	srnet = ro_mazeadd_net(region);
 	if (srnet == NOSRNET)
 	{
-		ttyputerr("Could not allocate internal net");
+		ttyputerr(_("Could not allocate internal net"));
 		return(1);
 	}
 
@@ -526,7 +526,7 @@ INTSML ro_mazeroutenet(NETWORK *net)
 			lx, ly, hx, hy, ni, pp);
 		if (fsp == NOSRPORT)
 		{
-			ttyputerr("Port could not be defined");
+			ttyputerr(_("Port could not be defined"));
 			return(1);
 		}
 	}
@@ -534,19 +534,19 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	/* do maze routing */
 	if (ro_mazedebug)
 	{
-		ro_mazedebuggingout = xcreate("routing", FILETYPETEXT, 0, &dummy);
+		ro_mazedebuggingout = xcreate("routing", el_filetypetext, 0, &dummy);
 		if (ro_mazedebuggingout == NULL) return(1);
-		ro_mazedump_layer("before", region, (UINTBIG)3);
+		ro_mazedump_layer(_("before"), region, (UINTBIG)3);
 	}
 	ret = ro_mazeroute_net(srnet);
 	if (ret != 0)
 	{
-		ttyputerr("Could not route net");
+		ttyputerr(_("Could not route net"));
 		return(1);
 	}
 	if (ro_mazedebug)
 	{
-		ro_mazedump_layer("after", region, (UINTBIG)3);
+		ro_mazedump_layer(_("after"), region, (UINTBIG)3);
 		xclose(ro_mazedebuggingout);
 	}
 
@@ -554,13 +554,13 @@ INTSML ro_mazeroutenet(NETWORK *net)
 	ret = ro_mazeextract_paths(np, srnet);
 	if (ret != 0)
 	{
-		ttyputerr("Could not create paths");
+		ttyputerr(_("Could not create paths"));
 		return(1);
 	}
 
 	/* ensure that the facet is the proper size */
 	(*el_curconstraint->solve)(np);
-	setactivity("Maze routing");
+	setactivity(_("Maze routing"));
 	return(0);
 }
 
@@ -583,17 +583,17 @@ SRREGION *ro_mazedefine_region(NODEPROTO *np, INTBIG lx, INTBIG ly, INTBIG hx, I
 	region = ro_mazeget_region(lx, ly, hx, hy, ro_mazegridx, ro_mazegridy, ro_mazeoffsetx, ro_mazeoffsety);
 	if (region == NOSRREGION)
 	{
-		ttyputerr("Could not allocate routing region (%ld<=X<=%ld %ld<=Y<=%ld)", lx, hx, ly, hy);
+		ttyputerr(_("Could not allocate routing region (%ld<=X<=%ld %ld<=Y<=%ld)"), lx, hx, ly, hy);
 		return NOSRREGION;
 	}
-	if (stopping("routing") != 0) return(NOSRREGION);
+	if (stopping(STOPREASONROUTING)) return(NOSRREGION);
 
 	/* search region for nodes/arcs to add to database */
 	search = initsearch(lx, hx, ly, hy, np);
 	transid(trans);
 	while ((look = nextobject(search)) != NOGEOM)
 	{
-		if (stopping("routing") != 0) return(NOSRREGION);
+		if (stopping(STOPREASONROUTING)) return(NOSRREGION);
 		if (look->entrytype == OBJNODEINST)
 		{
 			/* draw this facet */
@@ -751,7 +751,7 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 				yc-ys/2, yc+ys/2, 0, 0, parent);
 			if (fni[0] == NONODEINST)
 			{
-				ttyputerr("Could not create pin");
+				ttyputerr(_("Could not create pin"));
 				return(1);
 			}
 			endobjectchange((INTBIG)fni[0], VNODEINST);
@@ -770,7 +770,7 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 				yc-ys/2, yc+ys/2, 0, 0, parent);
 			if (tni[0] == NONODEINST)
 			{
-				ttyputerr("Could not create pin");
+				ttyputerr(_("Could not create pin"));
 				return(1);
 			}
 			endobjectchange((INTBIG)tni[0], VNODEINST);
@@ -786,7 +786,7 @@ INTSML ro_mazeextract_paths(NODEPROTO *parent, SRNET *net)
 				fx, fy, tni[0], tpp[0], tx, ty, parent);
 			if (ai == NOARCINST)
 			{
-				ttyputerr("Could not create path (arc)");
+				ttyputerr(_("Could not create path (arc)"));
 				return(1);
 			}
 			endobjectchange((INTBIG)ai, VARCINST);
@@ -914,7 +914,7 @@ void ro_mazedraw_showpoly(POLYGON *obj, SRREGION *region, INTSML layer)
  */
 void ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *region)
 {
-	INTSML i, j;
+	INTBIG i, j;
 	INTBIG width;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -955,7 +955,7 @@ void ro_mazedraw_arcinst(ARCINST *ai, XARRAY trans, NETWORK *net, SRREGION *regi
  */
 void ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION *region)
 {
-	INTSML j, high;
+	INTBIG j, high;
 	XARRAY localtran, subrot;
 	INTBIG bx, by, ux, uy, swap;
 	static POLYGON *poly = NOPOLYGON;
@@ -980,7 +980,7 @@ void ro_mazedraw_nodeinst(NODEINST *ni, XARRAY prevtrans, NETWORK *net, SRREGION
 	if (np->primindex != 0)
 	{
 		/* primitive nodeinst: ask the technology how to draw it */
-		high = nodepolys(ni);
+		high = nodepolys(ni, 0);
 		for (j = 0; j < high; j++)
 		{
 			/* get description of this layer */
@@ -1177,7 +1177,7 @@ INTBIG ro_mazefindport(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEI
 		ni = newnodeinst(np, lx,hx, ly,hy, 0, 0, pnt);
 		if (ni == NONODEINST)
 		{
-			ttyputerr("Cannot create splitting pin");
+			ttyputerr(_("Cannot create splitting pin"));
 			return 0;
 		}
 		endobjectchange((INTBIG)ni, VNODEINST);
@@ -1191,7 +1191,7 @@ INTBIG ro_mazefindport(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEI
 		ar2 = newarcinst(nap, wid, bits2, ni, pp, x, y, tno, tpt, tendx, tendy, pnt);
 		if (ar1 == NOARCINST || ar2 == NOARCINST)
 		{
-			ttyputerr("Error creating the split arc parts");
+			ttyputerr(_("Error creating the split arc parts"));
 			return cnt;
 		}
 		(void)copyvars((INTBIG)ai, VARCINST, (INTBIG)ar1, VARCINST);
@@ -1201,7 +1201,7 @@ INTBIG ro_mazefindport(NODEPROTO *facet, INTBIG x, INTBIG y, ARCPROTO *ap, NODEI
 		/* delete the old arcinst */
 		startobjectchange((INTBIG)ai, VARCINST);
 		if (killarcinst(ai))
-			ttyputerr("Error deleting original arc");
+			ttyputerr(_("Error deleting original arc"));
 	}
 
 	return cnt;
@@ -1369,17 +1369,17 @@ SRREGION *ro_mazeget_region(INTBIG wlx, INTBIG wly, INTBIG whx, INTBIG why,
 		ro_mazegridx, ro_mazegridy, ro_mazeoffsetx, ro_mazeoffsety);
 	if (hlayer == NOSRLAYER)
 	{
-		ttyputerr("Could not allocate horizontal layer");
+		ttyputerr(_("Could not allocate horizontal layer"));
 		return NOSRREGION;
 	}
 	vlayer = ro_mazeadd_layer(ro_theregion, SCH_VERTLAYER, SRVERTPREF,
 		ro_mazegridx, ro_mazegridy, ro_mazeoffsetx, ro_mazeoffsety);
 	if (vlayer == NOSRLAYER)
 	{
-		ttyputerr("Could not allocate vertical layer");
+		ttyputerr(_("Could not allocate vertical layer"));
 		return NOSRREGION;
 	}
-	if (stopping("routing") != 0) return(NOSRREGION);
+	if (stopping(STOPREASONROUTING)) return(NOSRREGION);
 
 	return ro_theregion;
 }
@@ -1445,7 +1445,7 @@ SRLAYER *ro_mazeadd_layer(SRREGION *region, INTSML index, SRDIRECTION direction,
 	/* sensibility check */
 	if (layer->wid > MAXGRIDSIZE || layer->hei > MAXGRIDSIZE)
 	{
-		ttyputerr("This route is too large to solve (limit is %dx%d grid, this is %ldx%ld)",
+		ttyputerr(_("This route is too large to solve (limit is %dx%d grid, this is %ldx%ld)"),
 			MAXGRIDSIZE, MAXGRIDSIZE, layer->wid, layer->hei);
 		return NOSRLAYER;
 	}
@@ -1913,7 +1913,7 @@ INTSML ro_mazecreate_wavefront(SRPORT *port)
 				}
 				if (onedge == 0)
 				{
-					ttyputerr("Node %s is blocked", describenodeinst(port->ni));
+					ttyputerr(_("Node %s is blocked"), describenodeinst(port->ni));
 					return 1;
 				}
 			}
@@ -2718,7 +2718,7 @@ INTSML ro_mazeroute_net(SRNET *net)
 	}
 	if (routingarc == NOARCPROTO)
 	{
-		ttyputerr("Cannot find wire to route");
+		ttyputerr(_("Cannot find wire to route"));
 		return(1);
 	}
 	ro_mazevertwire = routingarc;
@@ -2794,7 +2794,7 @@ INTSML ro_mazeroute_net(SRNET *net)
 	do
 	{
 		if (++code > SR_GMAX) code = SR_GSTART;
-		if (stopping("routing") != 0) return SRERROR;
+		if (stopping(STOPREASONROUTING)) return SRERROR;
 		for (blocked = 0, port = net->ports; port != NOSRPORT; port = port->next)
 		{
 			/* if part of other wavefront, get the next one */
