@@ -34,6 +34,7 @@
 #include "global.h"
 #include "usrdiacom.h"
 #include "sc1.h"
+#include "sim.h"
 #include <setjmp.h>
 #include <math.h>
 
@@ -43,7 +44,6 @@ extern COMCOMP    sc_silcomp;
 
 /*********** Global Variables ******************************************/
 
-char			**sc_errmsgtbl;
 SCCELL			*sc_cells, *sc_curcell;
 jmp_buf			sc_please_stop;
 
@@ -75,7 +75,6 @@ void Sc_initialize(void)
 {
 	sc_cells = NULL;
 	sc_curcell = NULL;
-	sc_errmsgtbl = sc_standard_errmsg;
 }
 
 /***********************************************************************
@@ -93,18 +92,19 @@ void Sc_main(void)
 	int	   count, l, err;
 	char   *pars[PARS];
 
-	ttyputmsg("QUISC - Queen's University Interactive Silicon Compiler");
-	ttyputmsg("Version %s, %s", VERSION, DATE);
+	ttyputmsg(_("QUISC - Queen's University Interactive Silicon Compiler"));
+	ttyputmsg(_("Version %s, %s"), VERSION, DATE);
 
 	if (setjmp(sc_please_stop))
 	{
 		Sc_clear_stop();
-		ttyputmsg("Command Aborted...");
+		ttyputmsg(_("Command Aborted..."));
 	}
 
 	for (;;)
 	{
-		count = ttygetfullparam("Enter command> ", &sc_silcomp, PARS, pars);
+		count = ttygetfullparam(_("Enter command> "), &sc_silcomp, PARS, pars);
+		if (count < 0) break;
 		if (count == 0) continue;
 		l = strlen(pars[0]);
 		l = maxi(l, 3);
@@ -136,7 +136,7 @@ void Sc_one_command(int count, char *pars[])
 	if (setjmp(sc_please_stop))
 	{
 		Sc_clear_stop();
-		ttyputmsg("Command Aborted...");
+		ttyputmsg(_("Command Aborted..."));
 		return;
 	}
 
@@ -178,7 +178,7 @@ int Sc_seterrmsg(int errnum, ...)
 	va_list ap;
 
 	var_start(ap, errnum);
-	(void)vsprintf(sc_swork, sc_errmsgtbl[errnum], ap);
+	(void)vsprintf(sc_swork, _(sc_standard_errmsg[errnum]), ap);
 	va_end(ap);
 	sc_errmsg = sc_swork;
 	return(errnum);
@@ -213,7 +213,7 @@ int Sc_parse(int count, char *pars[])
 		return(Sc_create(count-1, &pars[1]));
 
 	if (namesamen(sptr, "delete", l) == 0)
-		return( Sc_delete() );
+		return(Sc_delete());
 
 	if (namesamen(sptr, "export", l) == 0)
 		return(Sc_export(count-1, &pars[1]));
@@ -228,19 +228,19 @@ int Sc_parse(int count, char *pars[])
 		return(Sc_library(count-1, &pars[1]));
 
 	if (namesamen(sptr, "make", l) == 0)
-		return( Sc_maker(count - 1, &pars[1]) );
+		return(Sc_maker(count - 1, &pars[1]));
 
 	if (namesamen(sptr, "order", l) == 0)
-		return( Sc_order(count-1, &pars[1]) );
+		return(Sc_order(count-1, &pars[1]));
 
 	if (namesamen(sptr, "place", l) == 0)
 		return(Sc_place(count-1, &pars[1]));
 
 	if (namesamen(sptr, "pull", l) == 0)
-		return( Sc_pull(count - 1, &pars[1]) );
+		return(Sc_pull(count - 1, &pars[1]));
 
 	if (namesamen(sptr, "route", l) == 0)
-		return( Sc_route(count - 1, &pars[1]) );
+		return(Sc_route(count - 1, &pars[1]));
 
 	if (namesamen(sptr, "schematic", l) == 0)
 	{
@@ -249,7 +249,7 @@ int Sc_parse(int count, char *pars[])
 	}
 
 	if (namesamen(sptr, "select", l) == 0)
-		return( Sc_select(count-1, &pars[1]) );
+		return(Sc_select(count-1, &pars[1]));
 
 	if (namesamen(sptr, "set", l) == 0)
 		return(Sc_xset(count-1, &pars[1]));
@@ -258,12 +258,12 @@ int Sc_parse(int count, char *pars[])
 		return(Sc_show(count-1, &pars[1]));
 
 	if (namesamen(sptr, "simulation", l) == 0)
-		return( Sc_simulation(count-1, &pars[1]) );
+		return(Sc_simulation(count-1, &pars[1]));
 
 	if (namesamen(sptr, "verify", l) == 0)
-		return( Sc_verify() );
+		return(Sc_verify());
 
-	return( Sc_seterrmsg(SC_UNKNOWN, sptr) );
+	return(Sc_seterrmsg(SC_UNKNOWN, sptr));
 }
 
 /***********************************************************************
@@ -286,20 +286,20 @@ int Sc_compile(int count, char *pars[])
 	np = getcurfacet();
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("No current facet");
+		ttyputerr(_("No current facet"));
 		return(SC_NOERROR);
 	}
 
-	(void)askaid(vhdl_aid, "want-netlist-input", (INTBIG)np, FILETYPEQUISC);
+	(void)askaid(vhdl_aid, "want-netlist-input", (INTBIG)np, sim_filetypequisc);
 
 	/* begin input of the netlist */
-	i = askaid(vhdl_aid, "begin-netlist-input", (INTBIG)np, FILETYPEQUISC, (INTBIG)&intended);
+	i = askaid(vhdl_aid, "begin-netlist-input", (INTBIG)np, sim_filetypequisc, (INTBIG)&intended);
 	if (i != 0)
 	{
-		ttyputerr("Cannot find netlist in %s", intended);
+		ttyputerr(_("Cannot find netlist in %s"), intended);
 		return(SC_NOERROR);
 	}
-	ttyputmsg("Compiling netlist in %s...", intended);
+	ttyputmsg(_("Compiling netlist in %s..."), intended);
 
 	/* read file until end is found */
 	(void)Sc_cpu_time(TIME_RESET);
@@ -350,14 +350,14 @@ int Sc_compile(int count, char *pars[])
 		}
 		if ((err = Sc_parse(icount, par)))
 		{
-			ttyputmsg("ERROR line %d : SCERR %d - %s", lnum, err, sc_errmsg);
+			ttyputmsg(_("ERROR line %d : SCERR %d - %s"), lnum, err, sc_errmsg);
 			ttyputmsg(inbuf);
-			ttyputmsg("Aborting compile...");
+			ttyputmsg(_("Aborting compile..."));
 			break;
 		}
 	}
 	(void)askaid(vhdl_aid, "end-input");
-	ttyputmsg("Done (time = %s seconds)", Sc_cpu_time(TIME_ABS));
+	ttyputmsg(_("Done (time = %s seconds)"), Sc_cpu_time(TIME_ABS));
 	return(SC_NOERROR);
 }
 
@@ -392,14 +392,14 @@ int Sc_show(int count, char *pars[])
 	l = maxi(l, 2);
 	if (namesamen(sptr, "cells", l) == 0)
 	{
-		ttyputmsg("***** List of cells *****");
+		ttyputmsg(_("***** List of cells *****"));
 		for (cells = sc_cells; cells; cells = cells->next)
 		{
 			if (cells == sc_curcell)
 				ttyputmsg(" -->%s", cells->name); else
 					ttyputmsg("    %s", cells->name);
 		}
-		ttyputmsg("***** End of cell list *****");
+		ttyputmsg(_("***** End of cell list *****"));
 		return(0);
 	}
 
@@ -427,8 +427,8 @@ int Sc_show(int count, char *pars[])
 			}
 		}
 
-		/* list all exported ports on the cell */
-		ttyputmsg("Ports for cell %s:", sptr);
+		/* list all exports on the cell */
+		ttyputmsg(_("Ports for cell %s:"), sptr);
 		if (cells != NULL)
 		{
 			for (port = cells->ports; port; port = port->next)
@@ -436,82 +436,82 @@ int Sc_show(int count, char *pars[])
 				switch (port->bits & SCPORTTYPE)
 				{
 					case SCGNDPORT:
-						ptype = "Ground port";
+						ptype = _("Ground port");
 						break;
 					case SCPWRPORT:
-						ptype = "Power port";
+						ptype = _("Power port");
 						break;
 					case SCBIDIRPORT:
-						ptype = "Bidirectional port";
+						ptype = _("Bidirectional port");
 						break;
 					case SCOUTPORT:
-						ptype = "Output port";
+						ptype = _("Output port");
 						break;
 					case SCINPORT:
-						ptype = "Input port";
+						ptype = _("Input port");
 						break;
 					default:
-						ptype = "Unknown type";
+						ptype = _("Unknown type");
 						break;
 				}
 				*pdir = 0;
 				bits = port->bits;
 				if (bits & SCPORTDIRUP)
-					(void)strcat(pdir, " up");
+					(void)strcat(pdir, _(" up"));
 				if (bits & SCPORTDIRDOWN)
-					(void)strcat(pdir, " down");
+					(void)strcat(pdir, _(" down"));
 				if (bits & SCPORTDIRRIGHT)
-					(void)strcat(pdir, " right");
+					(void)strcat(pdir, _(" right"));
 				if (bits & SCPORTDIRLEFT)
-					(void)strcat(pdir, " left");
+					(void)strcat(pdir, _(" left"));
 				if (!(bits & SCPORTDIRMASK))
-					(void)strcat(pdir, " none");
+					(void)strcat(pdir, _(" none"));
 				ttyputmsg("  %-20s    %-20s    %-20s", port->name,
 					ptype, pdir);
 			}
 		} else
 		{
 			for (leafport = Sc_first_leaf_port(leafcell); leafport != NULL;
-				leafport = Sc_next_leaf_port(leafport) )
+				leafport = Sc_next_leaf_port(leafport))
 			{
 				switch (Sc_leaf_port_type(leafport))
 				{
 					case SCGNDPORT:
-						ptype = "Ground port";
+						ptype = _("Ground port");
 						break;
 					case SCPWRPORT:
-						ptype = "Power port";
+						ptype = _("Power port");
 						break;
 					case SCBIDIRPORT:
-						ptype = "Bidirectional port";
+						ptype = _("Bidirectional port");
 						break;
 					case SCOUTPORT:
-						ptype = "Output port";
+						ptype = _("Output port");
 						break;
 					case SCINPORT:
-						ptype = "Input port";
+						ptype = _("Input port");
 						break;
 					default:
-						ptype = "Unknown type";
+						ptype = _("Unknown type");
 						break;
 				}
 				*pdir = 0;
 				bits = Sc_leaf_port_bits(leafport);
 				if (bits & SCPORTDIRUP)
-					(void)strcat(pdir, " up");
+					(void)strcat(pdir, _(" up"));
 				if (bits & SCPORTDIRDOWN)
-					(void)strcat(pdir, " down");
+					(void)strcat(pdir, _(" down"));
 				if (bits & SCPORTDIRRIGHT)
-					(void)strcat(pdir, " right");
+					(void)strcat(pdir, _(" right"));
 				if (bits & SCPORTDIRLEFT)
-					(void)strcat(pdir, " left");
+					(void)strcat(pdir, _(" left"));
 				if (!(bits & SCPORTDIRMASK))
-					(void)strcat(pdir, " none");
+					(void)strcat(pdir, _(" none"));
 				ttyputmsg("  %-20s    %-20s    %-20s",
 					Sc_leaf_port_name(leafport), ptype, pdir);
 			}
 		}
-		ttyputmsg("End of port list.");
+		ttyputmsg(_("End of port list."));
 		return(0);
 	}
 
@@ -523,13 +523,13 @@ int Sc_show(int count, char *pars[])
 		}
 		Sc_leaf_facet_get_nums(leafcell, &cnums);
 		ttyputmsg("****************************************");
-		ttyputmsg("**      LEAF CELL MAGIC NUMBERS       **");
+		ttyputmsg(_("**      LEAF CELL MAGIC NUMBERS       **"));
 		ttyputmsg("****************************************");
 		ttyputmsg(" ");
-		ttyputmsg("Top active distance      =  %d", cnums.top_active);
-		ttyputmsg("Bottom active distance   =  %d", cnums.bottom_active);
-		ttyputmsg("Left active distance     =  %d", cnums.left_active);
-		ttyputmsg("Right active distance    =  %d", cnums.right_active);
+		ttyputmsg(_("Top active distance      =  %d"), cnums.top_active);
+		ttyputmsg(_("Bottom active distance   =  %d"), cnums.bottom_active);
+		ttyputmsg(_("Left active distance     =  %d"), cnums.left_active);
+		ttyputmsg(_("Right active distance    =  %d"), cnums.right_active);
 		ttyputmsg("----------------------------------------");
 		return(SC_NOERROR);
 	}
@@ -562,7 +562,7 @@ int Sc_show(int count, char *pars[])
 		{
 			all_flag = FALSE;
 		}
-		ttyputmsg("Instances for cell %s:", cells->name);
+		ttyputmsg(_("Instances for cell %s:"), cells->name);
 		Sc_nitreelist(cells->niroot, all_flag);
 		return(0);
 	}
@@ -571,7 +571,7 @@ int Sc_show(int count, char *pars[])
 	{
 		if (sc_curcell == NULL)
 			return(Sc_seterrmsg(SC_NOCELL));
-		ttyputmsg("List of extracted nodes for cell %s:", sc_curcell->name);
+		ttyputmsg(_("List of extracted nodes for cell %s:"), sc_curcell->name);
 		Sc_extract_print_nodes(sc_curcell);
 		return(SC_NOERROR);
 	}
@@ -596,11 +596,11 @@ int Sc_show(int count, char *pars[])
 				return(Sc_seterrmsg(SC_CELLNOFIND, sptr));
 		}
 		if (cells->placement == NULL)
-			return( Sc_seterrmsg(SC_CELL_NO_PLACE, cells->name) );
-		ttyputmsg("*****  PLACEMENT for cell %s *****", sptr);
+			return(Sc_seterrmsg(SC_CELL_NO_PLACE, cells->name));
+		ttyputmsg(_("*****  PLACEMENT for cell %s *****"), sptr);
 		for (row = cells->placement->rows; row; row = row->next)
 		{
-			ttyputmsg("For Row #%d, size %d:", row->row_num, row->row_size);
+			ttyputmsg(_("For Row #%d, size %d:"), row->row_num, row->row_size);
 			for (place = row->start; place; place = place->next)
 				ttyputmsg("    %8d    %-s", place->xpos, place->cell->name);
 		}
@@ -612,7 +612,7 @@ int Sc_show(int count, char *pars[])
 		if (--count == 0)
 		{
 			if (sc_curcell == NULL)
-				return( Sc_seterrmsg(SC_NOCELL) );
+				return(Sc_seterrmsg(SC_NOCELL));
 			cells = sc_curcell;
 		} else
 		{
@@ -624,12 +624,12 @@ int Sc_show(int count, char *pars[])
 					break;
 			}
 			if (cells == NULL)
-				return( Sc_seterrmsg(SC_CELLNOFIND, sptr) );
+				return(Sc_seterrmsg(SC_CELLNOFIND, sptr));
 		}
 		if (cells->route == NULL)
-			return( Sc_seterrmsg(SC_CELL_NO_ROUTE, cells->name) );
+			return(Sc_seterrmsg(SC_CELL_NO_ROUTE, cells->name));
 		ttyputmsg("****************************************");
-		ttyputmsg("**     CHANNEL ROUTING INFORMATION    **");
+		ttyputmsg(_("**     CHANNEL ROUTING INFORMATION    **"));
 		ttyputmsg("****************************************");
 		ttyputmsg(" ");
 		Sc_route_print_channel(cells->route->channels);
@@ -659,7 +659,7 @@ void Sc_nitreelist(SCNITREE *ntp, int all_flag)
 	switch (ntp->type)
 	{
 		case SCSPECIALCELL:
-			type = "Special";
+			type = _("Special");
 			break;
 		case SCCOMPLEXCELL:
 			type = ((SCCELL *)(ntp->np))->name;
@@ -698,7 +698,7 @@ int Sc_select(int count, char *pars[])
 			break;
 	}
 	if (cell == NULL)
-		return( Sc_seterrmsg(SC_CELLNOFIND, pars[0]) );
+		return(Sc_seterrmsg(SC_CELLNOFIND, pars[0]));
 	sc_curcell = cell;
 
 	return(SC_NOERROR);
@@ -766,50 +766,50 @@ int Sc_xset(int count, char *pars[])
 					cnums.right_active = atoi(pars[numpar++]);
 				continue;
 			}
-			return( Sc_seterrmsg(SC_SET_CNUMS_XOPT, pars[numpar]) );
+			return(Sc_seterrmsg(SC_SET_CNUMS_XOPT, pars[numpar]));
 		}
 		if ((err = Sc_leaf_facet_set_nums(leafcell, &cnums)))
 			return(err);
 		return(SC_NOERROR);
 	}
 
-	if ( namesamen("node-name", pars[0], l) == 0 )
+	if (namesamen("node-name", pars[0], l) == 0)
 	{
 		/* check for sufficient parameters */
 		if (count < 4)
-			return( Sc_seterrmsg(SC_SET_NAME_NO_PARS) );
+			return(Sc_seterrmsg(SC_SET_NAME_NO_PARS));
 
 		/* search for instance */
-		if ( *(instptr = Sc_findni(&sc_curcell->niroot, pars[1])) == NULL)
-			return( Sc_seterrmsg(SC_SET_NAME_INST_NO_FIND, pars[1]) );
+		if (*(instptr = Sc_findni(&sc_curcell->niroot, pars[1])) == NULL)
+			return(Sc_seterrmsg(SC_SET_NAME_INST_NO_FIND, pars[1]));
 
 		/* search for port on instance */
 		for (iport = (*instptr)->ports; iport; iport = iport->next)
 		{
-			if ( (*instptr)->type == SCLEAFCELL )
+			if ((*instptr)->type == SCLEAFCELL)
 			{
-				if ( namesame(Sc_leaf_port_name(iport->port), pars[2]) == 0 )
+				if (namesame(Sc_leaf_port_name(iport->port), pars[2]) == 0)
 					break;
-			} else if ( (*instptr)->type == SCCOMPLEXCELL )
+			} else if ((*instptr)->type == SCCOMPLEXCELL)
 			{
-				if ( namesame(((SCPORT *)(iport->port))->name, pars[2]) == 0)
+				if (namesame(((SCPORT *)(iport->port))->name, pars[2]) == 0)
 					break;
 			}
 		}
 		if (!iport)
-			return( Sc_seterrmsg(SC_SET_NAME_PORT_NO_FIND, pars[2], pars[1]) );
+			return(Sc_seterrmsg(SC_SET_NAME_PORT_NO_FIND, pars[2], pars[1]));
 
 		/* set extracted node name if possible */
 		if (iport->ext_node)
 		{
 			if (iport->ext_node->name)
 				efree(iport->ext_node->name);
-			if ( allocstring(&iport->ext_node->name, pars[3], sc_aid->cluster) )
-				return( Sc_seterrmsg(SC_NOMEMORY) );
+			if (allocstring(&iport->ext_node->name, pars[3], sc_aid->cluster))
+				return(Sc_seterrmsg(SC_NOMEMORY));
 			return(SC_NOERROR);
 		} else
 		{
-			return( Sc_seterrmsg(SC_SET_NAME_NO_NODE) );
+			return(Sc_seterrmsg(SC_SET_NAME_NO_NODE));
 		}
 	}
 
@@ -909,6 +909,7 @@ int Sc_order(int count, char *pars[])
 	int		i, j, k, err_flag;
 	char	*leafcell, *port, *whichpp[100];
 	FILE	*fp;
+	static INTBIG filetypesctab = -1;
 
 	if (!count)
 		return(Sc_seterrmsg(SC_ORDERNPARS));
@@ -921,8 +922,8 @@ int Sc_order(int count, char *pars[])
 	fp = (FILE *)NULL;
 	if (count > 1)
 	{
-		if ((fp = xopen(pars[1], FILETYPESCTAB, "", &filename)) == NULL)
-			return( Sc_seterrmsg(SC_ORDER_XOPEN_FILE, pars[1]) );
+		if ((fp = xopen(pars[1], sc_filetypesctab, "", &filename)) == NULL)
+			return(Sc_seterrmsg(SC_ORDER_XOPEN_FILE, pars[1]));
 	}
 
 	/* get ordering, terminated by a <CR> for manual input */
@@ -930,7 +931,7 @@ int Sc_order(int count, char *pars[])
 	{
 		if (fp == NULL)
 		{
-			sptr = ttygetline("Port>  ");
+			sptr = ttygetline(_("Port>  "));
 			if (sptr == 0 || strlen(sptr) == 0) break;
 			(void)strcpy(order, sptr);
 		} else
@@ -957,7 +958,7 @@ int Sc_order(int count, char *pars[])
 		/* and that no port appears more than once */
 		err_flag = FALSE;
 		for (port = Sc_first_leaf_port(leafcell); port;
-			port = Sc_next_leaf_port(port) )
+			port = Sc_next_leaf_port(port))
 		{
 			if (namesame(order, Sc_leaf_port_name(port)) == 0)
 			{
@@ -967,7 +968,7 @@ int Sc_order(int count, char *pars[])
 		}
 		if (port == NULL)
 		{
-			ttyputmsg("Error - port %s not found", order);
+			ttyputmsg(_("Error - port %s not found"), order);
 			err_flag = TRUE;
 		} else
 		{
@@ -975,7 +976,7 @@ int Sc_order(int count, char *pars[])
 			{
 				if (port == whichpp[k])
 				{
-					ttyputmsg("Error - port %s appears more than once",
+					ttyputmsg(_("Error - port %s appears more than once"),
 						order);
 					err_flag = TRUE;
 				}
@@ -990,14 +991,14 @@ int Sc_order(int count, char *pars[])
 
 	if (i == 0)
 	{
-		ttyputmsg("Warning - no ports specified");
+		ttyputmsg(_("Warning - no ports specified"));
 		if (fp) xclose(fp);
 		return(0);
 	}
 
 	/* add any ports which were not specified */
 	for (port = Sc_first_leaf_port(leafcell); port;
-		port = Sc_next_leaf_port(port) )
+		port = Sc_next_leaf_port(port))
 	{
 		for (j = 0; j < i; j++)
 		{
@@ -1055,7 +1056,7 @@ int Sc_pull(int count, char *pars[])
 
 	/* check if a cell is currently selected */
 	if (sc_curcell == NULL)
-		return( Sc_seterrmsg(SC_NOCELL) );
+		return(Sc_seterrmsg(SC_NOCELL));
 
 	/* expand all instances of complex cell type */
 	for (inst = sc_curcell->nilist; inst; inst = inst->next)
@@ -1103,7 +1104,7 @@ int Sc_pull_inst(SCNITREE *inst, SCCELL *cell, int info_flag)
 
 	subcell = (SCCELL *)inst->np;
 	if (info_flag)
-		ttyputmsg("Pulling instance %s of type %s into cell %s.",
+		ttyputmsg(_("Pulling instance %s of type %s into cell %s."),
 		   inst->name, subcell->name, cell->name);
 
 	/* first create components */
@@ -1423,7 +1424,7 @@ char  *Sc_cpu_time(int action)
 			sofar = 0.0;
 			return("0.00");
 	}
-	return("NO_TIME");
+	return(_("NO_TIME"));
 }
 
 /***********************************************************************
@@ -1444,7 +1445,7 @@ err			int			Returned error count, 0 = no error.
 
 int Sc_help(int count, char *pars[])
 {
-	(void)us_helpdlog("QUISC", pars);
+	(void)us_helpdlog("QUISC");
 	return(SC_NOERROR);
 }
 
