@@ -41,9 +41,11 @@
 ------------------------------------------------------------------------
 */
 
-AIDENTRY         *sc_aid;		/* the Silicon Compiler aid object */
-static INTBIG     sc_simkey;	/* key for the ALS info */
-static INTBIG     sc_silkey;	/* key for the silos information */
+AIDENTRY         *sc_aid;			/* the Silicon Compiler aid object */
+INTBIG            sc_filetypescsim;	/* Silicon compiler simulation file descriptor */
+INTBIG            sc_filetypesctab;	/* Silicon compiler table file descriptor */
+static INTBIG     sc_simkey;		/* key for the ALS info */
+static INTBIG     sc_silkey;		/* key for the silos information */
 static INTBIG     sc_bitskey;
 static INTBIG     sc_numskey;
 static NODEPROTO *sc_layer1proto = NONODEPROTO;
@@ -60,38 +62,38 @@ extern COMCOMP    sc_makep;
 /* Silicon Compiler Options */
 DIALOGITEM sc_optionsdialogitems[] =
 {
- /*  1 */ {0, {428,272,452,330}, BUTTON, "OK"},
- /*  2 */ {0, {428,40,452,98}, BUTTON, "Cancel"},
- /*  3 */ {0, {60,208,76,388}, POPUP, "Vertical arc"},
- /*  4 */ {0, {8,208,24,388}, POPUP, "Horizontal arc"},
- /*  5 */ {0, {8,8,24,180}, MESSAGE, "Horizontal routing arc:"},
- /*  6 */ {0, {60,8,76,180}, MESSAGE, "Vertical routing arc:"},
- /*  7 */ {0, {32,8,48,174}, MESSAGE, "Horizontal wire width:"},
+ /*  1 */ {0, {428,272,452,330}, BUTTON, N_("OK")},
+ /*  2 */ {0, {428,40,452,98}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {60,208,76,388}, POPUP, ""},
+ /*  4 */ {0, {8,208,24,388}, POPUP, ""},
+ /*  5 */ {0, {8,8,24,180}, MESSAGE, N_("Horizontal routing arc:")},
+ /*  6 */ {0, {60,8,76,180}, MESSAGE, N_("Vertical routing arc:")},
+ /*  7 */ {0, {32,8,48,174}, MESSAGE, N_("Horizontal wire width:")},
  /*  8 */ {0, {32,208,48,282}, EDITTEXT, "2.5"},
- /*  9 */ {0, {84,8,100,174}, MESSAGE, "Vertical wire width:"},
+ /*  9 */ {0, {84,8,100,174}, MESSAGE, N_("Vertical wire width:")},
  /* 10 */ {0, {84,208,100,282}, EDITTEXT, "2.5"},
- /* 11 */ {0, {120,8,136,174}, MESSAGE, "Power wire width:"},
+ /* 11 */ {0, {120,8,136,174}, MESSAGE, N_("Power wire width:")},
  /* 12 */ {0, {120,208,136,282}, EDITTEXT, "2.5"},
- /* 13 */ {0, {144,8,160,174}, MESSAGE, "Main power wire width:"},
+ /* 13 */ {0, {144,8,160,174}, MESSAGE, N_("Main power wire width:")},
  /* 14 */ {0, {144,208,160,282}, EDITTEXT, "2.5"},
- /* 15 */ {0, {184,12,200,203}, MESSAGE, "P-Well height (0 for none):"},
+ /* 15 */ {0, {184,12,200,203}, MESSAGE, N_("P-Well height (0 for none):")},
  /* 16 */ {0, {184,208,200,282}, EDITTEXT, "2.5"},
- /* 17 */ {0, {208,12,224,203}, MESSAGE, "P-Well offset from bottom:"},
+ /* 17 */ {0, {208,12,224,203}, MESSAGE, N_("P-Well offset from bottom:")},
  /* 18 */ {0, {208,208,224,282}, EDITTEXT, "2.5"},
- /* 19 */ {0, {248,12,264,203}, MESSAGE, "Via size:"},
+ /* 19 */ {0, {248,12,264,203}, MESSAGE, N_("Via size:")},
  /* 20 */ {0, {248,208,264,282}, EDITTEXT, "2.5"},
- /* 21 */ {0, {272,12,288,203}, MESSAGE, "Minimum metal spacing:"},
+ /* 21 */ {0, {272,12,288,203}, MESSAGE, N_("Minimum metal spacing:")},
  /* 22 */ {0, {272,208,288,282}, EDITTEXT, "2.5"},
- /* 23 */ {0, {312,12,328,203}, MESSAGE, "Routing: feed-through size:"},
+ /* 23 */ {0, {312,12,328,203}, MESSAGE, N_("Routing: feed-through size:")},
  /* 24 */ {0, {312,208,328,282}, EDITTEXT, "2.5"},
- /* 25 */ {0, {336,12,352,203}, MESSAGE, "Routing: min. port distance:"},
+ /* 25 */ {0, {336,12,352,203}, MESSAGE, N_("Routing: min. port distance:")},
  /* 26 */ {0, {336,208,352,282}, EDITTEXT, "2.5"},
- /* 27 */ {0, {360,12,376,203}, MESSAGE, "Routing: min. active dist.:"},
+ /* 27 */ {0, {360,12,376,203}, MESSAGE, N_("Routing: min. active dist.:")},
  /* 28 */ {0, {360,208,376,282}, EDITTEXT, "2.5"},
- /* 29 */ {0, {400,12,416,203}, MESSAGE, "Number of rows of cells:"},
+ /* 29 */ {0, {400,12,416,203}, MESSAGE, N_("Number of rows of cells:")},
  /* 30 */ {0, {400,208,416,282}, EDITTEXT, "5"}
 };
-DIALOG sc_optionsdialog = {{50,75,512,472}, "Silicon Compiler Options", 30, sc_optionsdialogitems};
+DIALOG sc_optionsdialog = {{50,75,512,472}, N_("Silicon Compiler Options"), 0, 30, sc_optionsdialogitems};
 
 /* prototypes for local routines */
 void Sc_set_leaf_port_type(PORTPROTO*, int);
@@ -119,9 +121,11 @@ void sc_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
 		ttyputmsg("ERROR making BITS key in SC Aid");
 	if ((sc_numskey = makekey("SC_nums")) == -1)
 		ttyputmsg("ERROR making NUMS key in SC Aid");
-	if ((sc_silkey = makekey("SC_silos")) == -1 )
+	if ((sc_silkey = makekey("SC_silos")) == -1)
 		ttyputmsg("ERROR making SILOS key in SC Aid.");
 	DiaDeclareHook("silcomp", &sc_makep, sc_optionsdlog);
+	sc_filetypescsim = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "scsim", _("QUISC simulation"));
+	sc_filetypesctab = setupfiletype("", "*.*", MACFSTAG('TEXT'), 0, "sctab", _("QUISC table"));
 }
 
 /***********************************************************************
@@ -172,7 +176,7 @@ Description:
 
 int Sc_stop(void)
 {
-	if (stopping("Silicon compiler")) return(TRUE);
+	if (stopping(STOPREASONSILCOMP)) return(TRUE);
 	return(FALSE);
 }
 
@@ -429,7 +433,7 @@ int Sc_leaf_facet_bits(char *leaffacet)
 		== NOVARIABLE)
 	{
 		if (setvalkey((INTBIG)leaffacet, VNODEPROTO, sc_bitskey, 0, VINTEGER) ==
-			NOVARIABLE) ttyputmsg("ERROR creating SCBITS variable.");
+			NOVARIABLE) ttyputmsg(_("ERROR creating SCBITS variable."));
 		return(0);
 	}
 	return(var->addr);
@@ -461,11 +465,11 @@ int  *Sc_leaf_facet_bits_address(char *leaffacet)
 		== NOVARIABLE)
 	{
 		if (setvalkey((INTBIG)leaffacet, VNODEPROTO, sc_bitskey, 0, VINTEGER) ==
-			NOVARIABLE) ttyputmsg("ERROR creating SCBITS variable.");
+			NOVARIABLE) ttyputmsg(_("ERROR creating SCBITS variable."));
 		if ((var = getvalkey((INTBIG)leaffacet, VNODEPROTO, VINTEGER,
 			sc_bitskey)) == NOVARIABLE)
 		{
-			ttyputmsg("ERROR creating SCBITS variable.");
+			ttyputmsg(_("ERROR creating SCBITS variable."));
 			return((int *)NULL);
 		}
 	}
@@ -810,7 +814,7 @@ int Sc_leaf_port_bits(char *leafport)
 	if (var == NOVARIABLE)
 	{
 		if (setvalkey((INTBIG)leafport, VPORTPROTO, sc_bitskey, 0, VINTEGER) ==
-			NOVARIABLE) ttyputmsg("ERROR creating SCBITS variable.");
+			NOVARIABLE) ttyputmsg(_("ERROR creating SCBITS variable."));
 		return(0);
 	}
 	return(var->addr);
@@ -841,11 +845,11 @@ int  *Sc_leaf_port_bits_address(char *leafport)
 	if (var == NOVARIABLE)
 	{
 		if (setvalkey((INTBIG)leafport, VPORTPROTO, sc_bitskey, 0, VINTEGER) ==
-			NOVARIABLE) ttyputmsg("ERROR creating SCBITS variable.");
+			NOVARIABLE) ttyputmsg(_("ERROR creating SCBITS variable."));
 		if ((var = getvalkey((INTBIG)leafport, VPORTPROTO, VINTEGER, sc_bitskey))
 			== NOVARIABLE)
 		{
-			ttyputmsg("ERROR creating SCBITS variable.");
+			ttyputmsg(_("ERROR creating SCBITS variable."));
 			return((int *)NULL);
 		}
 	}
@@ -1081,7 +1085,6 @@ err			int			Returned error code, 0 = no error.
 int Sc_library_read(char *libname)
 {
 	LIBRARY    *lib;
-	extern AIDENTRY   *io_aid;
 
 	/* check to see if library already exists */
 	for (lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -1268,7 +1271,7 @@ char  *Sc_create_leaf_instance(char *name, char *type, int minx, int maxx, int m
 
 	if (setvalkey((INTBIG)binst, VNODEINST, el_node_name, (INTBIG)name,
 		VSTRING|VDISPLAY) == NOVARIABLE)
-			ttyputmsg("ERROR creating name of instance '%s'.", name);
+			ttyputmsg(_("ERROR creating name of instance '%s'."), name);
 	return((char *)binst);
 }
 
@@ -1596,7 +1599,7 @@ void Sc_create_connection(NODEINST **ni, PORTPROTO **pp, INTBIG x, INTBIG y,
 Module:  Sc_create_export_port
 ------------------------------------------------------------------------
 Description:
-	Create an export port at the given instance at the given port.
+	Create an export at the given instance at the given port.
 	Note that ports of primitive instances are passed as NULL and must
 	be determined.
 ------------------------------------------------------------------------
@@ -1634,7 +1637,7 @@ char  *Sc_create_export_port(char *inst, char *port, char *name, int type, char
  */
 void Sc_schematic(void)
 {
-	ttyputmsg("Sorry, cannot handle schematics yet");
+	ttyputmsg(_("Sorry, cannot handle schematics yet"));
 }
 
 /****************************** DIALOG ******************************/
@@ -1658,21 +1661,39 @@ void Sc_schematic(void)
  */
 void sc_optionsdlog(void)
 {
-	INTBIG itemHit, numarcnames, horizindex, vertindex, i;
+	INTBIG itemHit, numarcnames, horizindex, vertindex, i, l1width, l2width,
+		pwrwidth, mainpwrwidth, pwellsize, pwelloffset, viasize, minspacing,
+		feedthrusize, portxmindist, activedist, numrows;
 	extern AIDENTRY *ro_aid;
 	REGISTER ARCPROTO *ap, *aphoriz, *apvert;
 	char **arcnames, numstring[20];
 
+	/* get parameters */
+	aphoriz      = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC);
+	apvert       = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_VERT_ARC);
+	l1width      = ScGetParameter(SC_PARAM_MAKE_L1_WIDTH);
+	l2width      = ScGetParameter(SC_PARAM_MAKE_L2_WIDTH);
+	pwrwidth     = ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH);
+	mainpwrwidth = ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH);
+	pwellsize    = ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE);
+	pwelloffset  = ScGetParameter(SC_PARAM_MAKE_PWELL_OFFSET);
+	viasize      = ScGetParameter(SC_PARAM_MAKE_VIA_SIZE);
+	minspacing   = ScGetParameter(SC_PARAM_MAKE_MIN_SPACING);
+	feedthrusize = ScGetParameter(SC_PARAM_ROUTE_FEEDTHRU_SIZE);
+	portxmindist = ScGetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST);
+	activedist   = ScGetParameter(SC_PARAM_ROUTE_ACTIVE_DIST);
+	numrows      = ScGetParameter(SC_PARAM_PLACE_NUM_ROWS);
+
 	/* gather list of arcs */
 	numarcnames = 0;
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 		numarcnames++;
+	numarcnames++;
 	arcnames = (char **)emalloc(numarcnames * (sizeof (char *)), el_tempcluster);
 	if (arcnames == 0) return;
 	numarcnames = 0;
+	arcnames[numarcnames++] = _("NOT SELECTED");
 	horizindex = vertindex = 0;
-	aphoriz = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC);
-	apvert = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_VERT_ARC);
 	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 	{
 		arcnames[numarcnames] = ap->protoname;
@@ -1687,19 +1708,18 @@ void sc_optionsdlog(void)
 	DiaSetPopup(4, numarcnames, arcnames);
 	DiaSetPopupEntry(3, vertindex);
 	DiaSetPopupEntry(4, horizindex);
-
-	DiaSetText(8, latoa(ScGetParameter(SC_PARAM_MAKE_L1_WIDTH)));
-	DiaSetText(10, latoa(ScGetParameter(SC_PARAM_MAKE_L2_WIDTH)));
-	DiaSetText(12, latoa(ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH)));
-	DiaSetText(14, latoa(ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH)));
-	DiaSetText(16, latoa(ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE)));
-	DiaSetText(18, latoa(ScGetParameter(SC_PARAM_MAKE_PWELL_OFFSET)));
-	DiaSetText(20, latoa(ScGetParameter(SC_PARAM_MAKE_VIA_SIZE)));
-	DiaSetText(22, latoa(ScGetParameter(SC_PARAM_MAKE_MIN_SPACING)));
-	DiaSetText(24, latoa(ScGetParameter(SC_PARAM_ROUTE_FEEDTHRU_SIZE)));
-	DiaSetText(26, latoa(ScGetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST)));
-	DiaSetText(28, latoa(ScGetParameter(SC_PARAM_ROUTE_ACTIVE_DIST)));
-	sprintf(numstring, "%ld", ScGetParameter(SC_PARAM_PLACE_NUM_ROWS));
+	DiaSetText(8, latoa(l1width));
+	DiaSetText(10, latoa(l2width));
+	DiaSetText(12, latoa(pwrwidth));
+	DiaSetText(14, latoa(mainpwrwidth));
+	DiaSetText(16, latoa(pwellsize));
+	DiaSetText(18, latoa(pwelloffset));
+	DiaSetText(20, latoa(viasize));
+	DiaSetText(22, latoa(minspacing));
+	DiaSetText(24, latoa(feedthrusize));
+	DiaSetText(26, latoa(portxmindist));
+	DiaSetText(28, latoa(activedist));
+	sprintf(numstring, "%ld", numrows);
 	DiaSetText(30, numstring);
 
 	/* loop until done */
@@ -1712,21 +1732,38 @@ void sc_optionsdlog(void)
 	if (itemHit != CANCEL)
 	{
 		i = DiaGetPopupEntry(3);
-		ScSetParameter(SC_PARAM_MAKE_VERT_ARC, (INTBIG)getarcproto(arcnames[i]));
+		if (i == 0) ap = NOARCPROTO; else
+			ap = getarcproto(arcnames[i]);
+		if (ap != apvert) ScSetParameter(SC_PARAM_MAKE_VERT_ARC, (INTBIG)ap);
 		i = DiaGetPopupEntry(4);
-		ScSetParameter(SC_PARAM_MAKE_HORIZ_ARC, (INTBIG)getarcproto(arcnames[i]));
-		ScSetParameter(SC_PARAM_MAKE_L1_WIDTH, atola(DiaGetText(8)));
-		ScSetParameter(SC_PARAM_MAKE_L2_WIDTH, atola(DiaGetText(10)));
-		ScSetParameter(SC_PARAM_MAKE_PWR_WIDTH, atola(DiaGetText(12)));
-		ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH, atola(DiaGetText(14)));
-		ScSetParameter(SC_PARAM_MAKE_PWELL_SIZE, atola(DiaGetText(16)));
-		ScSetParameter(SC_PARAM_MAKE_PWELL_OFFSET, atola(DiaGetText(18)));
-		ScSetParameter(SC_PARAM_MAKE_VIA_SIZE, atola(DiaGetText(20)));
-		ScSetParameter(SC_PARAM_MAKE_MIN_SPACING, atola(DiaGetText(22)));
-		ScSetParameter(SC_PARAM_ROUTE_FEEDTHRU_SIZE, atola(DiaGetText(24)));
-		ScSetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST, atola(DiaGetText(26)));
-		ScSetParameter(SC_PARAM_ROUTE_ACTIVE_DIST, atola(DiaGetText(28)));
-		ScSetParameter(SC_PARAM_PLACE_NUM_ROWS, atoi(DiaGetText(30)));
+		if (i == 0) ap = NOARCPROTO; else
+			ap = getarcproto(arcnames[i]);
+		if (ap != aphoriz) ScSetParameter(SC_PARAM_MAKE_HORIZ_ARC, (INTBIG)ap);
+
+		i = atola(DiaGetText(8));
+		if (i != l1width) ScSetParameter(SC_PARAM_MAKE_L1_WIDTH, i);
+		i = atola(DiaGetText(10));
+		if (i != l2width) ScSetParameter(SC_PARAM_MAKE_L2_WIDTH, i);
+		i = atola(DiaGetText(12));
+		if (i != pwrwidth) ScSetParameter(SC_PARAM_MAKE_PWR_WIDTH, i);
+		i = atola(DiaGetText(14));
+		if (i != mainpwrwidth) ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH, i);
+		i = atola(DiaGetText(16));
+		if (i != pwellsize) ScSetParameter(SC_PARAM_MAKE_PWELL_SIZE, i);
+		i = atola(DiaGetText(18));
+		if (i != pwelloffset) ScSetParameter(SC_PARAM_MAKE_PWELL_OFFSET, i);
+		i = atola(DiaGetText(20));
+		if (i != viasize) ScSetParameter(SC_PARAM_MAKE_VIA_SIZE, i);
+		i = atola(DiaGetText(22));
+		if (i != minspacing) ScSetParameter(SC_PARAM_MAKE_MIN_SPACING, i);
+		i = atola(DiaGetText(24));
+		if (i != feedthrusize) ScSetParameter(SC_PARAM_ROUTE_FEEDTHRU_SIZE, i);
+		i = atola(DiaGetText(26));
+		if (i != portxmindist) ScSetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST, i);
+		i = atola(DiaGetText(28));
+		if (i != activedist) ScSetParameter(SC_PARAM_ROUTE_ACTIVE_DIST, i);
+		i = atoi(DiaGetText(30));
+		if (i != numrows) ScSetParameter(SC_PARAM_PLACE_NUM_ROWS, i);
 	}
 	efree((char *)arcnames);
 	DiaDoneDialog();
