@@ -75,7 +75,7 @@ int Sc_export(int count, char *pars[])
 	if (port == (SCNIPORT *)NULL)
 		return(Sc_seterrmsg(SC_EXPORTPORTNOFIND, pars[1], pars[0]));
 
-	/* check for export port name */
+	/* check for export name */
 	if (count < 3)
 		return(Sc_seterrmsg(SC_EXPORTNONAME));
 
@@ -108,7 +108,7 @@ int Sc_export(int count, char *pars[])
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	newnptr->number = sc_curcell->max_node_num++;
 	*searchnptr = newnptr;
-	niport = (SCNIPORT *)emalloc( sizeof(SCNIPORT), sc_aid->cluster);
+	niport = (SCNIPORT *)emalloc(sizeof(SCNIPORT), sc_aid->cluster);
 	if (niport == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	niport->port = (char *)NULL;
@@ -117,7 +117,7 @@ int Sc_export(int count, char *pars[])
 	newnptr->ports = niport;
 
 	/* add to export port list */
-	newport = (SCPORT *)emalloc( sizeof(SCPORT), sc_aid->cluster);
+	newport = (SCPORT *)emalloc(sizeof(SCPORT), sc_aid->cluster);
 	if (newport == 0)
 		return(Sc_seterrmsg(SC_NOMEMORY));
 	niport->port = (char *)newport;
@@ -168,7 +168,7 @@ int Sc_verify(void)
 	int		err;
 
 	if (sc_cells == NULL)
-		return( Sc_seterrmsg(SC_VERIFY_NO_CELLS) );
+		return(Sc_seterrmsg(SC_VERIFY_NO_CELLS));
 	for (cell = sc_cells; cell; cell = cell->next)
 	{
 		if ((err = Sc_verify_cell(cell)))
@@ -202,9 +202,9 @@ int Sc_verify_cell(SCCELL *cell)
 		return(SC_NOERROR);
 	if (cell->niroot == NULL)
 	{
-		ttyputmsg("WARNING - Cell '%s' has no instance list, execute 'EXTRACT'",
+		ttyputmsg(_("WARNING - Cell '%s' has no instance list, execute 'EXTRACT'"),
 			cell->name);
-		ttyputmsg("            command before verifying.");
+		ttyputmsg(_("            command before verifying."));
 		return(SC_NOERROR);
 	}
 /*  for (inst = cell->niroot; inst; inst = inst->next)
@@ -254,9 +254,9 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 	/* check for unique name */
 	for (enode2 = enode->next; enode2; enode2 = enode2->next)
 	{
-		if ( namesame(enode->name, enode2->name) == 0)
+		if (namesame(enode->name, enode2->name) == 0)
 		{
-			ttyputmsg("WARNING - node name '%s' is not unique in cell '%s'",
+			ttyputmsg(_("WARNING - node name '%s' is not unique in cell '%s'"),
 				enode->name, cell_name);
 		}
 	}
@@ -265,9 +265,9 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 	power = ground = 0;
 
 	/* check for special power or ground node */
-	if ( namesame(enode->name, "power") == 0 )
+	if (namesame(enode->name, "power") == 0)
 		power++;
-	if ( namesame(enode->name, "ground") == 0 )
+	if (namesame(enode->name, "ground") == 0)
 		ground++;
 
 	for (eport = enode->firstport; eport; eport = eport->next)
@@ -298,7 +298,7 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 				}
 				break;
 			default:
-				ttyputmsg("WARNING - instance '%s' in cell '%s' has an invalid type.",
+				ttyputmsg(_("WARNING - instance '%s' in cell '%s' has an invalid type."),
 					eport->node->name, cell_name);
 				break;
 		}
@@ -327,14 +327,14 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 	/* check for power-ground short */
 	if (power && ground)
 	{
-		ttyputmsg("ERROR - power to ground shorted on node '%s' in cell '%s'.",
+		ttyputmsg(_("ERROR - power to ground shorted on node '%s' in cell '%s'."),
 			enode->name, cell_name);
 	}
 
 	/* check for only single driving source */
 	if (num_output > 1)
 	{
-		ttyputmsg("WARNING - %d outputs tied together in cell '%s' on node '%s'.",
+		ttyputmsg(_("WARNING - %d outputs tied together in cell '%s' on node '%s'."),
 			num_output, cell_name, enode->name);
 		for (eport = enode->firstport; eport; eport = eport->next)
 		{
@@ -371,21 +371,21 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 			}
 			if (port_type == SCOUTPORT)
 			{
-				ttyputmsg("    Instance '%s' port '%s'.", eport->node->name,
+				ttyputmsg(_("    Instance '%s' port '%s'."), eport->node->name,
 					port_name);
 			}
 		}
 		if (power)
-			ttyputmsg("    Also to POWER.");
+			ttyputmsg(_("    Also to POWER."));
 		if (ground)
-			ttyputmsg("    Also to GROUND.");
+			ttyputmsg(_("    Also to GROUND."));
 	} else if (num_output == 1)
 	{
 		if (power)
-			ttyputmsg("WARNING - output port tied to power in cell '%s' on node '%s'.",
+			ttyputmsg(_("WARNING - output port tied to power in cell '%s' on node '%s'."),
 				cell_name, enode->name);
 		if (ground)
-			ttyputmsg("WARNING - output port tied to ground in cell '%s' on node '%s'.",
+			ttyputmsg(_("WARNING - output port tied to ground in cell '%s' on node '%s'."),
 				cell_name, enode->name);
 		if (power || ground)
 		{
@@ -424,7 +424,7 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 				}
 				if (port_type == SCOUTPORT)
 				{
-					ttyputmsg("    Instance '%s' port '%s'.", eport->node->name,
+					ttyputmsg(_("    Instance '%s' port '%s'."), eport->node->name,
 						port_name);
 					break;
 				}
@@ -433,7 +433,7 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 	}
 	else if (!num_bidirect && !power && !ground)
 	{
-		ttyputmsg("WARNING - undriven input node '%s' in cell '%s'.",
+		ttyputmsg(_("WARNING - undriven input node '%s' in cell '%s'."),
 			enode->name, cell_name);
 		for (eport = enode->firstport; eport; eport = eport->next)
 		{
@@ -469,7 +469,7 @@ int Sc_verify_ext_node(SCEXTNODE *enode, char *cell_name)
 					break;
 			}
 			if (port_type == SCINPORT)
-				ttyputmsg("    Instance '%s' port '%s'.", eport->node->name,
+				ttyputmsg(_("    Instance '%s' port '%s'."), eport->node->name,
 					port_name);
 		}
 	}
