@@ -39,14 +39,14 @@
 
 static char *sc_makerblerb[] =
 {
-	"*********** QUISC MAKER MODULE - VERSION 1.03",
+	N_("*********** QUISC MAKER MODULE - VERSION 1.03"),
 	" ",
-	"    o  Determination of final position",
-	"    o  Include squeezing rows in vertical direction",
-	"    o  Squeeze tracks together if nonadjacent via",
-	"    o  Creating ties to power and ground",
-	"    o  Routing Power and Ground buses",
-	"    o  Creation in VLSI Layout Tool's database",
+	N_("    o  Determination of final position"),
+	N_("    o  Include squeezing rows in vertical direction"),
+	N_("    o  Squeeze tracks together if nonadjacent via"),
+	N_("    o  Creating ties to power and ground"),
+	N_("    o  Routing Power and Ground buses"),
+	N_("    o  Creation in VLSI Layout Tool's database"),
 	"----------------------------------------------------------",
 	0
 } ;
@@ -103,39 +103,39 @@ int Sc_maker(int count, char *pars[])
 		l = strlen(pars[0]);
 		l = maxi(l, 2);
 		if (namesamen(pars[0], "set-control", l) == 0)
-			return( Sc_maker_set_control(count - 1, &pars[1]) );
+			return(Sc_maker_set_control(count - 1, &pars[1]));
 		if (namesamen(pars[0], "show-control", l) == 0)
 		{
 			Sc_maker_show_control();
 			return(SC_NOERROR);
 		}
-		if ( namesamen(pars[0], "information", l) == 0)
+		if (namesamen(pars[0], "information", l) == 0)
 		{
 		} else
 		{
-			return( Sc_seterrmsg(SC_MAKE_XCMD, pars[0]) );
+			return(Sc_seterrmsg(SC_MAKE_XCMD, pars[0]));
 		}
 	}
 
 	for (i = 0; sc_makerblerb[i]; i++)
-		ttyputverbose(sc_makerblerb[i]);
+		ttyputverbose(_(sc_makerblerb[i]));
 
 	/* check if working in a cell */
 	if (sc_curcell == NULL)
-		return( Sc_seterrmsg(SC_NOCELL) );
+		return(Sc_seterrmsg(SC_NOCELL));
 
 	/* check if placement structure exists */
 	if (sc_curcell->placement == NULL)
-		return( Sc_seterrmsg(SC_CELL_NO_PLACE, sc_curcell->name) );
+		return(Sc_seterrmsg(SC_CELL_NO_PLACE, sc_curcell->name));
 
 	/* check if route structure exists */
 	if (sc_curcell->route == NULL)
-		return( Sc_seterrmsg(SC_CELL_NO_ROUTE, sc_curcell->name) );
+		return(Sc_seterrmsg(SC_CELL_NO_ROUTE, sc_curcell->name));
 
 	if (count)
 	{
 		/* information about the cell */
-		return( Sc_maker_create_info(sc_curcell) );
+		return(Sc_maker_create_info(sc_curcell));
 	}
 
 	/* show controlling parameters */
@@ -143,20 +143,20 @@ int Sc_maker(int count, char *pars[])
 		Sc_maker_show_control();
 
 	(void)Sc_cpu_time(TIME_RESET);
-	ttyputmsg("Starting MAKER...");
+	ttyputmsg(_("Starting MAKER..."));
 
 	/* set up make structure */
 	if ((err = Sc_maker_set_up(sc_curcell, &make_data)))
 		return(err);
 
 	/* create actual layout */
-	ttyputmsg("Creating facet %s", make_data->cell->name);
+	ttyputmsg(_("Creating facet %s"), make_data->cell->name);
 	if ((err = Sc_maker_create_layout(make_data)))
 		return(err);
 
 	Sc_free_maker_data(make_data);
 
-	ttyputmsg("Done (time = %s seconds)", Sc_cpu_time(TIME_ABS));
+	ttyputmsg(_("Done (time = %s seconds)"), Sc_cpu_time(TIME_ABS));
 
 	return(SC_NOERROR);
 }
@@ -281,10 +281,10 @@ int Sc_maker_set_control(int count, char *pars[])
 					ScSetParameter(SC_PARAM_MAKE_PWELL_OFFSET, atoi(pars[numcmd]));
 				continue;
 			}
-			return( Sc_seterrmsg(SC_MAKE_SET_XCMD, pars[numcmd]) );
+			return(Sc_seterrmsg(SC_MAKE_SET_XCMD, pars[numcmd]));
 		}
 	} else
-		return( Sc_seterrmsg(SC_MAKE_SET_NOCMD) );
+		return(Sc_seterrmsg(SC_MAKE_SET_NOCMD));
 
 	Sc_maker_show_control();
 	return(SC_NOERROR);
@@ -304,29 +304,29 @@ void Sc_maker_show_control(void)
 {
 	char *str1;
 
-	ttyputverbose("************ MAKER CONTROL STRUCTURE");
-	if (sc_makerverbose) str1 = "TRUE"; else
-		str1 = "FALSE";
-	ttyputverbose("Verbose output           =  %s", str1);
-	ttyputverbose("Minimum metal spacing    =  %d",
+	ttyputverbose(_("************ MAKER CONTROL STRUCTURE"));
+	if (sc_makerverbose) str1 = _("TRUE"); else
+		str1 = _("FALSE");
+	ttyputverbose(_("Verbose output           =  %s"), str1);
+	ttyputverbose(_("Minimum metal spacing    =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_MIN_SPACING));
-	ttyputverbose("Via Size                 =  %d",
+	ttyputverbose(_("Via Size                 =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_VIA_SIZE));
-	ttyputverbose("Horizontal (layer 1) arc =  '%s'",
+	ttyputverbose(_("Horizontal (layer 1) arc =  '%s'"),
 		describearcproto((ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC)));
-	ttyputverbose("Vertical (layer 2) arc   =  '%s'",
+	ttyputverbose(_("Vertical (layer 2) arc   =  '%s'"),
 		describearcproto((ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_VERT_ARC)));
-	ttyputverbose("Layer 1 Track width      =  %d",
+	ttyputverbose(_("Layer 1 Track width      =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_L1_WIDTH));
-	ttyputverbose("Layer 2 Track width      =  %d",
+	ttyputverbose(_("Layer 2 Track width      =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_L2_WIDTH));
-	ttyputverbose("Power Track width        =  %d",
+	ttyputverbose(_("Power Track width        =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH));
-	ttyputverbose("Main Power Bus width     =  %d",
+	ttyputverbose(_("Main Power Bus width     =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH));
-	ttyputverbose("P-well size (0 for none) =  %d",
+	ttyputverbose(_("P-well size (0 for none) =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE));
-	ttyputverbose("P-well offset (bottom)   =  %d",
+	ttyputverbose(_("P-well offset (bottom)   =  %d"),
 		ScGetParameter(SC_PARAM_MAKE_PWELL_OFFSET));
 }
 
@@ -360,9 +360,9 @@ int Sc_maker_create_info(SCCELL *cell)
 	int num_channels, num_tracks, track_length;
 
 	info = NULL;
-	info = (SCMAKERINFO *)emalloc( sizeof(SCMAKERINFO), sc_aid->cluster);
+	info = (SCMAKERINFO *)emalloc(sizeof(SCMAKERINFO), sc_aid->cluster);
 	if (info == 0)
-		return( Sc_seterrmsg(SC_NOMEMORY) );
+		return(Sc_seterrmsg(SC_NOMEMORY));
 
 	/* go through rows of placed cells and create maker information */
 	/* count number of leaf cells, feed throughs, etc. */
@@ -435,25 +435,25 @@ int Sc_maker_create_info(SCCELL *cell)
 	info->num_tracks = num_tracks;
 	info->track_length = track_length;
 
-	ttyputmsg("************ MAKER INFORMATION");
-	ttyputmsg("Size:");
-	ttyputmsg("    X size             = %10d  (microns)", info->x_size / 2000);
-	ttyputmsg("    Y size             = %10d  (microns)", info->y_size / 2000);
-	ttyputmsg("    Area               = %10d  (square microns)", info->area);
+	ttyputmsg(_("************ MAKER INFORMATION"));
+	ttyputmsg(_("Size:"));
+	ttyputmsg(_("    X size             = %10d  (microns)"), info->x_size / 2000);
+	ttyputmsg(_("    Y size             = %10d  (microns)"), info->y_size / 2000);
+	ttyputmsg(_("    Area               = %10d  (square microns)"), info->area);
 	if (sc_makerverbose)
 	{
-		ttyputmsg("Limits (in microns):");
-		ttyputmsg("    Minimum X position =  %d", info->min_x / 2000);
-		ttyputmsg("    Maximim X position =  %d", info->max_x / 2000);
-		ttyputmsg("    Minimum Y position =  %d", info->min_y / 2000);
-		ttyputmsg("    Maximim Y position =  %d", info->max_y / 2000);
-		ttyputmsg("Numbers of Elements:");
-		ttyputmsg("    Base Cells         =  %d", info->num_leaf_cells);
-		ttyputmsg("    Feed Throughs      =  %d", info->num_feeds);
-		ttyputmsg("    Rows of cells      =  %d", info->num_rows);
-		ttyputmsg("    Routing Channels   =  %d", info->num_channels);
-		ttyputmsg("    Routing Tracks     =  %d", info->num_tracks);
-		ttyputmsg("    Total Track Length =  %d  (microns)",
+		ttyputmsg(_("Limits (in microns):"));
+		ttyputmsg(_("    Minimum X position =  %d"), info->min_x / 2000);
+		ttyputmsg(_("    Maximim X position =  %d"), info->max_x / 2000);
+		ttyputmsg(_("    Minimum Y position =  %d"), info->min_y / 2000);
+		ttyputmsg(_("    Maximim Y position =  %d"), info->max_y / 2000);
+		ttyputmsg(_("Numbers of Elements:"));
+		ttyputmsg(_("    Base Cells         =  %d"), info->num_leaf_cells);
+		ttyputmsg(_("    Feed Throughs      =  %d"), info->num_feeds);
+		ttyputmsg(_("    Rows of cells      =  %d"), info->num_rows);
+		ttyputmsg(_("    Routing Channels   =  %d"), info->num_channels);
+		ttyputmsg(_("    Routing Tracks     =  %d"), info->num_tracks);
+		ttyputmsg(_("    Total Track Length =  %d  (microns)"),
 			info->track_length / 2000);
 	}
 
@@ -504,9 +504,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 	int			deltay;
 
 	/* create top level data structure */
-	data = (SCMAKERDATA *)emalloc( sizeof(SCMAKERDATA), sc_aid->cluster);
+	data = (SCMAKERDATA *)emalloc(sizeof(SCMAKERDATA), sc_aid->cluster);
 	if (data == 0)
-		return( Sc_seterrmsg(SC_NOMEMORY) );
+		return(Sc_seterrmsg(SC_NOMEMORY));
 	data->cell = cell;
 	data->rows = NULL;
 	data->channels = NULL;
@@ -529,9 +529,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 	{
 
 		/* create Maker Channel structute */
-		mchan = (SCMAKERCHANNEL *)emalloc( sizeof(SCMAKERCHANNEL), sc_aid->cluster);
+		mchan = (SCMAKERCHANNEL *)emalloc(sizeof(SCMAKERCHANNEL), sc_aid->cluster);
 		if (mchan == 0)
-			return( Sc_seterrmsg(SC_NOMEMORY) );
+			return(Sc_seterrmsg(SC_NOMEMORY));
 		mchan->number = chan->number;
 		mchan->tracks = NULL;
 		mchan->num_tracks = 0;
@@ -553,9 +553,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 		ypos = 0;
 		for (track = chan->tracks; track; track = track->next)
 		{
-			mtrack = (SCMAKERTRACK *)emalloc( sizeof(SCMAKERTRACK), sc_aid->cluster);
+			mtrack = (SCMAKERTRACK *)emalloc(sizeof(SCMAKERTRACK), sc_aid->cluster);
 			if (mtrack == 0)
-				return( Sc_seterrmsg(SC_NOMEMORY) );
+				return(Sc_seterrmsg(SC_NOMEMORY));
 			mtrack->number = track->number;
 			mtrack->nodes = NULL;
 			mtrack->track = track;
@@ -585,7 +585,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				tr2_port = tr2_mem->node->firstport;
 				while (tr1_port && tr2_port)
 				{
-					if ( abs(tr1_port->xpos - tr2_port->xpos) <
+					if (abs(tr1_port->xpos - tr2_port->xpos) <
 						max_track_to_track)
 					{
 						deltay = max_track_to_track;
@@ -626,9 +626,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 	for (row = cell->placement->rows; row; row = row->next)
 	{
 		/* create maker row data structure */
-		mrow = (SCMAKERROW *)emalloc( sizeof(SCMAKERROW), sc_aid->cluster);
+		mrow = (SCMAKERROW *)emalloc(sizeof(SCMAKERROW), sc_aid->cluster);
 		if (mrow == 0)
-			return( Sc_seterrmsg(SC_NOMEMORY) );
+			return(Sc_seterrmsg(SC_NOMEMORY));
 		mrow->number = row->row_num;
 		mrow->members = NULL;
 		mrow->minx = HUGEINT;
@@ -667,9 +667,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 			if (place->cell->type != SCLEAFCELL &&
 				place->cell->type != SCFEEDCELL &&
 				place->cell->type != SCLATERALFEED) continue;
-			minst = (SCMAKERINST *)emalloc( sizeof(SCMAKERINST), sc_aid->cluster);
+			minst = (SCMAKERINST *)emalloc(sizeof(SCMAKERINST), sc_aid->cluster);
 			if (minst == 0)
-				return( Sc_seterrmsg(SC_NOMEMORY) );
+				return(Sc_seterrmsg(SC_NOMEMORY));
 			minst->place = place;
 			minst->row = mrow;
 			minst->xpos = place->xpos;
@@ -684,7 +684,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				{
 					power_port = (SCMAKERPOWERPORT *)emalloc(sizeof(SCMAKERPOWERPORT), sc_aid->cluster);
 					if (power_port == 0)
-						return( Sc_seterrmsg(SC_NOMEMORY) );
+						return(Sc_seterrmsg(SC_NOMEMORY));
 					power_port->inst = minst;
 					power_port->port = iport;
 					if (mrow->number % 2)
@@ -706,7 +706,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 						plist = (SCMAKERPOWER *)emalloc(sizeof(SCMAKERPOWER), sc_aid->cluster);
 						if (plist == 0)
 						{
-							return( Sc_seterrmsg(SC_NOMEMORY) );
+							return(Sc_seterrmsg(SC_NOMEMORY));
 						}
 						plist->ports = NULL;
 						plist->ypos = port_ypos;
@@ -758,7 +758,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				{
 					power_port = (SCMAKERPOWERPORT *)emalloc(sizeof(SCMAKERPOWERPORT), sc_aid->cluster);
 					if (power_port == 0)
-						return( Sc_seterrmsg(SC_NOMEMORY) );
+						return(Sc_seterrmsg(SC_NOMEMORY));
 					power_port->inst = minst;
 					power_port->port = iport;
 					if (mrow->number % 2)
@@ -780,7 +780,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 					{
 						plist = (SCMAKERPOWER *)emalloc(sizeof(SCMAKERPOWER), sc_aid->cluster);
 						if (plist == 0)
-							return( Sc_seterrmsg(SC_NOMEMORY) );
+							return(Sc_seterrmsg(SC_NOMEMORY));
 						plist->ports = NULL;
 						plist->ypos = port_ypos;
 						last_plist = NULL;
@@ -834,7 +834,7 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				minst->ysize = Sc_leaf_port_ypos(rport->port->port);
 			} else
 			{
-				ttyputmsg("ERROR - unknown cell type in maker set up");
+				ttyputmsg(_("ERROR - unknown cell type in maker set up"));
 				minst->ysize = 0;
 			}
 			minst->instance = NULL;
@@ -880,9 +880,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 			mtrack->ypos = ypos;
 			for (mem = mtrack->track->nodes; mem; mem = mem->next)
 			{
-				mnode = (SCMAKERNODE *)emalloc( sizeof(SCMAKERNODE), sc_aid->cluster);
+				mnode = (SCMAKERNODE *)emalloc(sizeof(SCMAKERNODE), sc_aid->cluster);
 				if (mnode == 0)
-					return( Sc_seterrmsg(SC_NOMEMORY) );
+					return(Sc_seterrmsg(SC_NOMEMORY));
 				mnode->vias = NULL;
 				mnode->next = mtrack->nodes;
 				mtrack->nodes = mnode;
@@ -890,9 +890,9 @@ int Sc_maker_set_up(SCCELL *cell, SCMAKERDATA **make_data)
 				for (chport = mem->node->firstport; chport;
 					chport = chport->next)
 				{
-					mvia = (SCMAKERVIA *)emalloc( sizeof(SCMAKERVIA), sc_aid->cluster);
+					mvia = (SCMAKERVIA *)emalloc(sizeof(SCMAKERVIA), sc_aid->cluster);
 					if (mvia == 0)
-						return( Sc_seterrmsg(SC_NOMEMORY) );
+						return(Sc_seterrmsg(SC_NOMEMORY));
 					mvia->xpos = chport->xpos;
 					mvia->chport = chport;
 					mvia->instance = NULL;
@@ -982,8 +982,8 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 		ScGetParameter(SC_PARAM_MAKE_MIN_SPACING);
 
 	/* create new cell */
-	if ( (bcell = Sc_create_leaf_facet(data->cell->name)) == NULL)
-		return( Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_CELL, data->cell->name) );
+	if ((bcell = Sc_create_leaf_facet(data->cell->name)) == NULL)
+		return(Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_CELL, data->cell->name));
 
 	if ((err = Sc_setup_for_maker((ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC),
 		(ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_VERT_ARC)))) return(err);
@@ -1007,32 +1007,32 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			node = inst->place->cell;
 			if (node->type == SCLEAFCELL)
 			{
-				if ( (binst = Sc_create_leaf_instance(node->name, node->np,
+				if ((binst = Sc_create_leaf_instance(node->name, node->np,
 					inst->xpos, inst->xpos + inst->xsize,
 					inst->ypos, inst->ypos + inst->ysize,
 					transpose, rotation, bcell)) == NULL)
-						return( Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_INST,
-							node->name) );
+						return(Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_INST,
+							node->name));
 				inst->instance = binst;
 			} else if (node->type == SCFEEDCELL)
 			{
 				/* feed through node */
-				if ( (binst = Sc_create_layer2_node(inst->xpos +
+				if ((binst = Sc_create_layer2_node(inst->xpos +
 					(inst->xsize >> 1), inst->ypos + inst->ysize +
 					(ScGetParameter(SC_PARAM_MAKE_L2_WIDTH) >> 1),
 					ScGetParameter(SC_PARAM_MAKE_L2_WIDTH),
 					ScGetParameter(SC_PARAM_MAKE_L2_WIDTH), bcell))
 					== NULL)
 				{
-					return( Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_FEED) );
+					return(Sc_seterrmsg(SC_MAKER_NOCREATE_LEAF_FEED));
 				}
 				inst->instance = binst;
 			} else if (node->type == SCLATERALFEED)
 			{
 				/* lateral feed node */
-				if ( (binst = Sc_create_via(inst->xpos + (inst->xsize >> 1),
+				if ((binst = Sc_create_via(inst->xpos + (inst->xsize >> 1),
 					inst->ypos + inst->ysize, bcell)) == NULL)
-						return( Sc_seterrmsg(SC_MAKER_NOCREATE_VIA) );
+						return(Sc_seterrmsg(SC_MAKER_NOCREATE_VIA));
 				inst->instance = binst;
 			}
 		}
@@ -1049,12 +1049,12 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 				{
 					if (via->flags & SCVIAPOWER)
 					{
-						if ( (binst = Sc_create_layer1_node(via->xpos,
+						if ((binst = Sc_create_layer1_node(via->xpos,
 							track->ypos, ScGetParameter(SC_PARAM_MAKE_L1_WIDTH),
 							ScGetParameter(SC_PARAM_MAKE_L1_WIDTH), bcell))
 							== NULL)
 						{
-							return( Sc_seterrmsg(SC_MAKER_NOCREATE_VIA) );
+							return(Sc_seterrmsg(SC_MAKER_NOCREATE_VIA));
 						}
 						via->instance = binst;
 
@@ -1066,7 +1066,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							ScGetParameter(SC_PARAM_MAKE_L1_WIDTH),
 							bcell) == NULL)
 						{
-							return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2) );
+							return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2));
 						}
 						continue;
 					}
@@ -1074,9 +1074,9 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 					/* create a via if next via (if it exists) is farther */
 					/* than the track to track spacing, else create a */
 					/* layer2 node */
-					if (via->next && !(via->next->flags & SCVIAPOWER) )
+					if (via->next && !(via->next->flags & SCVIAPOWER))
 					{
-						if ( abs(via->next->xpos - via->xpos) <
+						if (abs(via->next->xpos - via->xpos) <
 							track_to_track)
 						{
 							if (via->flags & SCVIAEXPORT)
@@ -1090,20 +1090,20 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 					}
 					if (via->flags & SCVIASPECIAL)
 					{
-						if ( (binst = Sc_create_layer2_node(via->xpos,
+						if ((binst = Sc_create_layer2_node(via->xpos,
 							track->ypos, ScGetParameter(SC_PARAM_MAKE_L2_WIDTH),
 							ScGetParameter(SC_PARAM_MAKE_L2_WIDTH), bcell))
 							== NULL)
 						{
-							return( Sc_seterrmsg(
-								SC_MAKER_NOCREATE_LEAF_FEED) );
+							return(Sc_seterrmsg(
+								SC_MAKER_NOCREATE_LEAF_FEED));
 						}
 					} else
 					{
-						if ( (binst = Sc_create_via(via->xpos, track->ypos,
+						if ((binst = Sc_create_via(via->xpos, track->ypos,
 							bcell)) == NULL)
 						{
-							return( Sc_seterrmsg(SC_MAKER_NOCREATE_VIA) );
+							return(Sc_seterrmsg(SC_MAKER_NOCREATE_VIA));
 						}
 					}
 					via->instance = binst;
@@ -1118,7 +1118,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							via->instance, (char *)NULL,
 							ScGetParameter(SC_PARAM_MAKE_L2_WIDTH), bcell) == NULL)
 						{
-							return( Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2) );
+							return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2));
 						}
 					} else if (node->type == SCFEEDCELL ||
 						node->type == SCLATERALFEED)
@@ -1128,7 +1128,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							(char *)NULL, via->instance, (char *)NULL,
 							ScGetParameter(SC_PARAM_MAKE_L2_WIDTH), bcell) == NULL)
 						{
-							return( Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2) );
+							return(Sc_seterrmsg(SC_MAKER_NOCREATE_LAYER2));
 						}
 					}
 				}
@@ -1149,7 +1149,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 					{
 						if (via->flags & SCVIASPECIAL)
 						{
-							if ( abs(via->next->xpos - via->xpos) < track_to_track)
+							if (abs(via->next->xpos - via->xpos) < track_to_track)
 							{
 								if (Sc_create_track_layer2(via->instance,
 									(char *)NULL, via->next->instance,
@@ -1162,7 +1162,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							}
 						} else
 						{
-							if ( !(via->flags & SCVIAPOWER) &&
+							if (!(via->flags & SCVIAPOWER) &&
 								!(via->next->flags & SCVIAPOWER) &&
 								(via->next->xpos - via->xpos) <
 								track_to_track)
@@ -1248,8 +1248,8 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 							via->xport->xport->name, via->xport->xport->bits
 							& SCPORTTYPE, bcell) == NULL)
 						{
-							return( Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT,
-								via->xport->xport->name) );
+							return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT,
+								via->xport->xport->name));
 						}
 					}
 				}
@@ -1267,11 +1267,11 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 		ypos = plist->ypos;
 
 		/* create main power bus node */
-		if ( (binst = Sc_create_layer1_node(xpos, ypos,
+		if ((binst = Sc_create_layer1_node(xpos, ypos,
 			ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH),
 			ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH), bcell)) == NULL)
 		{
-			return( Sc_seterrmsg(SC_MAKER_NOCREATE_VIA) );
+			return(Sc_seterrmsg(SC_MAKER_NOCREATE_VIA));
 		}
 		if (lastpower)
 		{
@@ -1322,11 +1322,11 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 		ypos = plist->ypos;
 
 		/* create main ground bus node */
-		if ( (binst = Sc_create_layer1_node(xpos, ypos,
+		if ((binst = Sc_create_layer1_node(xpos, ypos,
 			ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH),
 			ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH), bcell)) == NULL)
 		{
-			return( Sc_seterrmsg(SC_MAKER_NOCREATE_VIA) );
+			return(Sc_seterrmsg(SC_MAKER_NOCREATE_VIA));
 		}
 		if (lastground)
 		{
@@ -1342,7 +1342,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 			if (Sc_create_export_port(binst, (char *)NULL, "gnd", SCGNDPORT,
 				bcell) == NULL)
 			{
-				return( Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, "gnd") );
+				return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, "gnd"));
 			}
 		}
 		lastground = (SCMAKERINST *)binst;
@@ -1378,7 +1378,7 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 		if (Sc_create_export_port((char *)lastpower, (char *)NULL, "vdd",
 			SCPWRPORT, bcell) == NULL)
 		{
-			return( Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, "vdd") );
+			return(Sc_seterrmsg(SC_MAKER_NOCREATE_XPORT, "vdd"));
 		}
 	}
 
@@ -1409,10 +1409,10 @@ int Sc_maker_create_layout(SCMAKERDATA *data)
 				xsize = (lastinst->xpos + (lastinst->xsize >> 1)) -
 					(firstinst->xpos + (firstinst->xsize >> 1));
 				ysize = ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE);
-				if ( (binst = Sc_create_pwell(xpos, ypos, xsize, ysize, bcell))
+				if ((binst = Sc_create_pwell(xpos, ypos, xsize, ysize, bcell))
 					== NULL)
 				{
-					return( Sc_seterrmsg(SC_NOCREATE_PWELL) );
+					return(Sc_seterrmsg(SC_NOCREATE_PWELL));
 				}
 			}
 		}
