@@ -147,7 +147,7 @@ int Sc_simset(int count, char *pars[])
 	{
 		if (cell->siminfo)
 		{
-			if ((fp = xcreate(SCSIMFILE, FILETYPESCSIM, "Simulation File", 0)) == NULL)
+			if ((fp = xcreate(SCSIMFILE, sc_filetypescsim, _("Simulation File"), 0)) == NULL)
 				return(Sc_seterrmsg(SC_SIMSETFERROR));
 			for (simline = (SCSIM *)cell->siminfo; simline; simline = simline->next)
 				xprintf(fp, "%s\n", simline->model);
@@ -158,7 +158,7 @@ int Sc_simset(int count, char *pars[])
 		/* write out simulation information for leafcell if it exists */
 		if ((simlist = Sc_leaf_facet_sim_info(leafcell)))
 		{
-			if ((fp = xcreate(SCSIMFILE, FILETYPESCSIM, "Simulation File", 0)) == NULL)
+			if ((fp = xcreate(SCSIMFILE, sc_filetypescsim, _("Simulation File"), 0)) == NULL)
 				return(Sc_seterrmsg(SC_SIMSETFERROR));
 			for (i = 0; simlist[i]; i++)
 				xprintf(fp, "%s\n", simlist[i]);
@@ -167,7 +167,7 @@ int Sc_simset(int count, char *pars[])
 	}
 
 	/* get lines */
-	if ((fp = xopen(SCSIMFILE, FILETYPESCSIM, "", &filename)) == NULL)
+	if ((fp = xopen(SCSIMFILE, sc_filetypescsim, "", &filename)) == NULL)
 		return(Sc_seterrmsg(SC_SIMSETFERROR));
 	oldline = NULL;
 	startline = NULL;
@@ -258,12 +258,12 @@ int Sc_simshow(int count, char *pars[])
 	{
 		if ((leafcell = Sc_find_leaf_facet(pars[0])) == NULL)
 			return(Sc_seterrmsg(SC_CELLNOFIND, pars[0]));
-		ttyputmsg("%s SIMULATION Model for leaf cell %s:", simhdr, pars[0]);
+		ttyputmsg(_("%s SIMULATION Model for leaf cell %s:"), simhdr, pars[0]);
 		if ((simlist = Sc_leaf_facet_sim_info(leafcell)))
 		{
 			for (i = 0; simlist[i]; i++)
 			{
-				if ( *(simlist[i]) )
+				if (*(simlist[i]))
 				{
 					ttyputmsg(simlist[i]);
 				} else
@@ -274,10 +274,10 @@ int Sc_simshow(int count, char *pars[])
 		}
 	} else
 	{
-		ttyputmsg("%s SIMULATION Model for cell %s:", simhdr, pars[0]);
+		ttyputmsg(_("%s SIMULATION Model for cell %s:"), simhdr, pars[0]);
 		for (simline = cell->siminfo; simline; simline = simline->next)
 		{
-			if ( *(simline->model) )
+			if (*(simline->model))
 			{
 				ttyputmsg(simline->model);
 			} else
@@ -334,7 +334,7 @@ int Sc_simwrite(int count, char *pars[])
 		}
 	}
 
-	if ((fp = xcreate(outfile, FILETYPESCSIM, "Simulation File", 0)) == NULL)
+	if ((fp = xcreate(outfile, sc_filetypescsim, _("Simulation File"), 0)) == NULL)
 		return(Sc_seterrmsg(SC_SIMWRITEFOPEN, outfile));
 	tsec = getcurrenttime();
 	strtime = timetostring(tsec);
@@ -429,7 +429,7 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 	{
 		for (simline = cell->siminfo; simline; simline = simline->next)
 		{
-			if ( *(simline->model) )
+			if (*(simline->model))
 			{
 				ttyputmsg(simline->model);
 			} else
@@ -487,13 +487,13 @@ int Sc_simwrite_model(SCCELL *cell, char *name, FILE *fp)
 	}
 
 	/* print instances of cells */
-	if ( !(cell->siminfo) )
+	if (!(cell->siminfo))
 	{
 		if ((err = Sc_simwrite_cell_instances(cell, fp)))
 			return(err);
 	}
 
-	if (sc_sim_format == SC_SILOS_FORMAT )
+	if (sc_sim_format == SC_SILOS_FORMAT)
 	{
 		Sc_fprintf_80(fp, ".EOM\n\n");
 	} else
@@ -515,20 +515,20 @@ int Sc_simwrite_subelements(SCNITREE *nptr, FILE *fp)
 {
 	int		err;
 
-	for ( ; nptr; nptr = nptr->next)
+	for (; nptr; nptr = nptr->next)
 	{
 		switch (nptr->type)
 		{
 			case SCCOMPLEXCELL:
-				if ( !(((SCCELL *)(nptr->np))->bits & SCSIMWRITESEEN) )
+				if (!(((SCCELL *)(nptr->np))->bits & SCSIMWRITESEEN))
 				{
-					if ((err = Sc_simwrite_model( ((SCCELL *)(nptr->np)),
+					if ((err = Sc_simwrite_model(((SCCELL *)(nptr->np)),
 						((SCCELL *)(nptr->np))->name, fp)))
 							return(err);
 				}
 				break;
 			case SCLEAFCELL:
-				if ( !(Sc_leaf_facet_bits(nptr->np) & SCSIMWRITESEEN) )
+				if (!(Sc_leaf_facet_bits(nptr->np) & SCSIMWRITESEEN))
 				{
 					if ((err = Sc_simwrite_gate(nptr->np, fp)))
 						return(err);
