@@ -130,7 +130,7 @@ void simals_init_display(void)
 
 	if (simals_mainproto == NONODEPROTO)
 	{
-		ttyputerr("No facet to simulate");
+		ttyputerr(_("No facet to simulate"));
 		return;
 	}
 
@@ -144,7 +144,7 @@ void simals_init_display(void)
 	if (cellptr != 0) simals_levelptr = cellptr;
 	if (simals_levelptr == 0)
 	{
-		ttyputerr("No simulation to resume");
+		ttyputerr(_("No simulation to resume"));
 		return;
 	}
 	if (simals_set_current_level() != 0) return;
@@ -225,7 +225,7 @@ void simals_com_comp(INTSML count, char *par[10])
 		simals_order_command((INTSML)(count-1), &par[1]);
 		return;
 	}
-	ttyputmsg("Unknown ALS command: %s", pp);
+	ttyputbadusage("tellaid simulation als");
 }
 
 /*
@@ -257,7 +257,7 @@ char *simals_alloc_mem(INTBIG size)
 #endif
 	if (ptr == 0)
 	{
-		ttyputmsg("ERROR: Memory Allocation Error");
+		ttyputmsg(_("ERROR: Memory Allocation Error"));
 		return(0);
 	}
 	for(i=0; i<size; i++) ptr[i] = 0;
@@ -363,7 +363,7 @@ INTSML simals_get_string(char *sp)
 
 		if (strlen(line) > 255)
 		{
-			ttyputerr("ERROR: Input record too large.  Make them smaller");
+			ttyputerr(_("ERROR: Input record too large.  Make them smaller"));
 			return(1);
 		}
 		if (simals_fragment_line(line) != 0) return(1);
@@ -706,12 +706,12 @@ INTSML simals_read_net_desc(NODEPROTO *np)
 	extern AIDENTRY *vhdl_aid;
 
 	simals_mainproto = np;
-	if (askaid(vhdl_aid, "begin-netlist-input", (INTBIG)np, FILETYPEALS, (INTBIG)&intended) != 0)
+	if (askaid(vhdl_aid, "begin-netlist-input", (INTBIG)np, sim_filetypeals, (INTBIG)&intended) != 0)
 	{
-		ttyputerr("Cannot read %s", intended);
+		ttyputerr(_("Cannot read %s"), intended);
 		return(1);
 	}
-	ttyputmsg("Simulating netlist in %s", intended);
+	ttyputmsg(_("Simulating netlist in %s"), intended);
 
 	simals_instptr[0] = -1;
 	i_ptr = 0;
@@ -732,7 +732,7 @@ INTSML simals_read_net_desc(NODEPROTO *np)
 			continue;
 		}
 
-		ttyputerr("ERROR: String '%s' invalid (expecting gate, function, or model)", s1);
+		ttyputerr(_("ERROR: String '%s' invalid (expecting gate, function, or model)"), s1);
 		(void)askaid(vhdl_aid, "end-input");
 		return(1);
 	}
@@ -762,7 +762,7 @@ INTSML simals_parse_struct_header(char flag)
 	i = simals_get_name(s1);
 	if (i)
 	{
-		ttyputerr("Structure declaration: EOF unexpectedly found");
+		ttyputerr(_("Structure declaration: EOF unexpectedly found"));
 		return(1);
 	}
 
@@ -790,7 +790,7 @@ INTSML simals_parse_struct_header(char flag)
 		simals_modptr2 = *modptr1;
 		if (! strcmp(simals_modptr2->name, s1))
 		{
-			ttyputerr("ERROR: Structure %s already defined", s1);
+			ttyputerr(_("ERROR: Structure %s already defined"), s1);
 			return(1);
 		}
 		modptr1 = &simals_modptr2->next;
@@ -799,12 +799,12 @@ INTSML simals_parse_struct_header(char flag)
 	i = simals_get_string(s1);
 	if (i)
 	{
-		ttyputerr("Structure declaration: EOF unexpectedly found");
+		ttyputerr(_("Structure declaration: EOF unexpectedly found"));
 		return(1);
 	}
 	if (s1[0] != '(')
 	{
-		ttyputerr("Structure declaration: Expecting to find '(' in place of string '%s'", s1);
+		ttyputerr(_("Structure declaration: Expecting to find '(' in place of string '%s'"), s1);
 		return(1);
 	}
 
@@ -813,7 +813,7 @@ INTSML simals_parse_struct_header(char flag)
 		i = simals_get_name(s1);
 		if (i)
 		{
-			ttyputerr("Structure declaration: EOF unexpectedly found");
+			ttyputerr(_("Structure declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		if (s1[0] == ')') break;
@@ -836,7 +836,7 @@ INTSML simals_parse_struct_header(char flag)
 			simals_exptr2 = *exptr1;
 			if (! strcmp(simals_exptr2->node_name, s1))
 			{
-				ttyputerr("Node %s specified more than once in argument list", s1);
+				ttyputerr(_("Node %s specified more than once in argument list"), s1);
 				return(1);
 			}
 			exptr1 = &simals_exptr2->next;
@@ -855,7 +855,7 @@ INTSML simals_parse_struct_header(char flag)
 			if (simals_parse_model() != 0) return(1);
 			return(0);
 	}
-	ttyputerr("Error in parser: invalid structure type");
+	ttyputerr(_("Error in parser: invalid structure type"));
 	return(1);
 }
 
@@ -944,7 +944,7 @@ INTSML simals_parse_gate(void)
 			i = simals_get_int(&j);
 			if (i)
 			{
-				ttyputerr("Priority declaration: EOF unexpectedly found");
+				ttyputerr(_("Priority declaration: EOF unexpectedly found"));
 				return(1);
 			}
 			simals_modptr2->priority = (INTSML)j;
@@ -963,7 +963,7 @@ INTSML simals_parse_gate(void)
 			continue;
 		}
 
-		ttyputerr("ERROR: String '%s' invalid syntax", s1);
+		ttyputerr(_("ERROR: String '%s' invalid syntax"), s1);
 		return(1);
 	}
 	return(0);
@@ -1006,7 +1006,7 @@ INTSML simals_parse_node(void)
 		i = simals_get_string(s1);
 		if (i)
 		{
-			ttyputerr("Node declaration: EOF unexpectedly found");
+			ttyputerr(_("Node declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		switch (s1[0])
@@ -1022,7 +1022,7 @@ INTSML simals_parse_node(void)
 			case '%':
 				break;
 			default:
-				ttyputerr("Gate declaration: Invalid Operator '%s'", s1);
+				ttyputerr(_("Gate declaration: Invalid Operator '%s'"), s1);
 				return(1);
 		}
 		simals_ioptr2->operatr = s1[0];
@@ -1030,7 +1030,7 @@ INTSML simals_parse_node(void)
 		i = simals_get_string(s1);
 		if (i)
 		{
-			ttyputerr("Node declaration: EOF unexpectedly found");
+			ttyputerr(_("Node declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		if (! (strcmp(s1, "L") && strcmp(s1, "X") && strcmp(s1, "H")))
@@ -1044,7 +1044,7 @@ INTSML simals_parse_node(void)
 				i = simals_get_int((INTBIG *)&simals_ioptr2->operand);
 				if (i)
 				{
-					ttyputerr("Node declaration: EOF unexpectedly found");
+					ttyputerr(_("Node declaration: EOF unexpectedly found"));
 					return(1);
 				}
 			} else
@@ -1052,7 +1052,7 @@ INTSML simals_parse_node(void)
 				i = simals_get_name(s1);
 				if (i)
 				{
-					ttyputerr("Node declaration: EOF unexpectedly found");
+					ttyputerr(_("Node declaration: EOF unexpectedly found"));
 					return(1);
 				}
 				simals_ioptr2->operand = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
@@ -1071,7 +1071,7 @@ INTSML simals_parse_node(void)
 		i = simals_get_int(&(j));
 		if (i)
 		{
-			ttyputerr("Node declaration: EOF unexpectedly found");
+			ttyputerr(_("Node declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		simals_ioptr2->strength = (INTSML)j;
@@ -1124,26 +1124,26 @@ INTSML simals_parse_timing(void)
 		i = simals_get_string(s1);
 		if (i)
 		{
-			ttyputerr("Timing declaration: EOF unexpectedly found");
+			ttyputerr(_("Timing declaration: EOF unexpectedly found"));
 			return(1);
 		}
 
 		i = simals_get_string(s2);
 		if (i)
 		{
-			ttyputerr("Timing declaration: EOF unexpectedly found");
+			ttyputerr(_("Timing declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		if (s2[0] != '=')
 		{
-			ttyputerr("Timing declaration: Invalid Operator '%s' (expecting '=')", s2);
+			ttyputerr(_("Timing declaration: Invalid Operator '%s' (expecting '=')"), s2);
 			return(1);
 		}
 
 		i = simals_get_float(&value);
 		if (i)
 		{
-			ttyputerr("Timing declaration: EOF unexpectedly found");
+			ttyputerr(_("Timing declaration: EOF unexpectedly found"));
 			return(1);
 		}
 
@@ -1166,7 +1166,7 @@ INTSML simals_parse_timing(void)
 				if (value > 0.0) simals_modptr2->priority = 2;
 				break;
 			default:
-				ttyputerr("Invalid timing mode '%s'", s1);
+				ttyputerr(_("Invalid timing mode '%s'"), s1);
 				return(1);
 		}
 
@@ -1193,15 +1193,15 @@ INTSML simals_parse_delay(void)
 	i = simals_get_string(s1);
 	if (i)
 	{
-		ttyputerr("Timing declaration: EOF unexpectedly found");
+		ttyputerr(_("Timing declaration: EOF unexpectedly found"));
 		return(1);
 	}
 
-	if (   strcmp(s1, "01") && strcmp(s1, "10") && strcmp(s1, "OZ") && strcmp(s1, "Z1")
+	if (strcmp(s1, "01") && strcmp(s1, "10") && strcmp(s1, "OZ") && strcmp(s1, "Z1")
 		&& strcmp(s1, "1Z") && strcmp(s1, "Z0") && strcmp(s1, "0X") && strcmp(s1, "X1")
 		&& strcmp(s1, "1X") && strcmp(s1, "X0") && strcmp(s1, "XZ") && strcmp(s1, "ZX"))
 	{
-		ttyputerr("Invalid delay transition name '%s'", s1);
+		ttyputerr(_("Invalid delay transition name '%s'"), s1);
 		return(1);
 	}
 	else
@@ -1227,19 +1227,19 @@ INTSML simals_parse_fanout(void)
 	i = simals_get_string(s1);
 	if (i)
 	{
-		ttyputerr("Fanout declaration: EOF unexpectedly found");
+		ttyputerr(_("Fanout declaration: EOF unexpectedly found"));
 		return(1);
 	}
 	if (s1[0] != '=')
 	{
-		ttyputerr("Fanout declaration: Invalid Operator '%s' (expecting '=')", s1);
+		ttyputerr(_("Fanout declaration: Invalid Operator '%s' (expecting '=')"), s1);
 		return(1);
 	}
 
 	i = simals_get_string(s1);
 	if (i)
 	{
-		ttyputerr("Fanout declaration: EOF unexpectedly found");
+		ttyputerr(_("Fanout declaration: EOF unexpectedly found"));
 		return(1);
 	}
 
@@ -1255,7 +1255,7 @@ INTSML simals_parse_fanout(void)
 		return(0);
 	}
 
-	ttyputerr("Fanout declaration: Invalid option '%s'", s1);
+	ttyputerr(_("Fanout declaration: Invalid option '%s'"), s1);
 	return(1);
 }
 
@@ -1293,19 +1293,19 @@ INTSML simals_parse_load(void)
 		i = simals_get_string(s2);
 		if (i)
 		{
-			ttyputerr("Load declaration: EOF unexpectedly found");
+			ttyputerr(_("Load declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		if (s2[0] != '=')
 		{
-			ttyputerr("Load declaration: Invalid Operator '%s' (expecting '=')", s2);
+			ttyputerr(_("Load declaration: Invalid Operator '%s' (expecting '=')"), s2);
 			return(1);
 		}
 
 		i = simals_get_float(&load);
 		if (i)
 		{
-			ttyputerr("Load declaration: EOF unexpectedly found");
+			ttyputerr(_("Load declaration: EOF unexpectedly found"));
 			return(1);
 		}
 
@@ -1380,7 +1380,7 @@ INTSML simals_parse_model(void)
 			simals_conptr2 = *conptr1;
 			if (! strcmp(simals_conptr2->inst_name, s1))
 			{
-				ttyputerr("ERROR: Instance name '%s' defined more than once", s1);
+				ttyputerr(_("ERROR: Instance name '%s' defined more than once"), s1);
 				return(1);
 			}
 			conptr1 = &simals_conptr2->next;
@@ -1389,7 +1389,7 @@ INTSML simals_parse_model(void)
 		i = simals_get_name(s1);
 		if (i)
 		{
-			ttyputerr("Model declaration: EOF unexpectedly found");
+			ttyputerr(_("Model declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		simals_conptr2->model_name = simals_alloc_mem((INTBIG)(strlen(s1) + 1));
@@ -1400,12 +1400,12 @@ INTSML simals_parse_model(void)
 		i = simals_get_string(s1);
 		if (i)
 		{
-			ttyputerr("Model declaration: EOF unexpectedly found");
+			ttyputerr(_("Model declaration: EOF unexpectedly found"));
 			return(1);
 		}
 		if (s1[0] != '(')
 		{
-			ttyputerr("Model declaration: Expecting to find '(' in place of string '%s'", s1);
+			ttyputerr(_("Model declaration: Expecting to find '(' in place of string '%s'"), s1);
 			return(1);
 		}
 
@@ -1415,7 +1415,7 @@ INTSML simals_parse_model(void)
 			i = simals_get_name(s1);
 			if (i)
 			{
-				ttyputerr("Model declaration: EOF unexpectedly found");
+				ttyputerr(_("Model declaration: EOF unexpectedly found"));
 				return(1);
 			}
 			if (s1[0] == ')') break;
@@ -1467,13 +1467,13 @@ INTSML simals_parse_function(void)
 	while (1)
 	{
 		i = simals_get_string(s1);
-		if (i || ( ! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
+		if (i || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION") && strcmp(s1, "MODEL"))))
 		{
 			--i_ptr;
 			break;
 		}
 
-		if ( ! strcmp(s1, "I"))
+		if (!strcmp(s1, "I"))
 		{
 			exptr1 = &funchead->inptr;
 			for (simals_exptr2 = funchead->inptr; simals_exptr2;
@@ -1485,13 +1485,13 @@ INTSML simals_parse_function(void)
 			continue;
 		}
 
-		if ( ! strcmp(s1, "O"))
+		if (!strcmp(s1, "O"))
 		{
 			if (simals_parse_func_output() != 0) return(1);
 			continue;
 		}
 
-		if ( ! strcmp(s1, "T"))
+		if (!strcmp(s1, "T"))
 		{
 			if (simals_parse_timing() != 0) return(1);
 			funchead->delta = simals_delta_def;
@@ -1502,25 +1502,25 @@ INTSML simals_parse_function(void)
 			continue;
 		}
 
-		if ( ! strcmp(s1, "LOAD"))
+		if (!strcmp(s1, "LOAD"))
 		{
 			if (simals_parse_load() != 0) return(1);
 			continue;
 		}
 
-		if ( ! strcmp(s1, "PRIORITY"))
+		if (!strcmp(s1, "PRIORITY"))
 		{
 			i = simals_get_int(&j);
 			if (i)
 			{
-				ttyputerr("Priority declaration: EOF unexpectedly found");
+				ttyputerr(_("Priority declaration: EOF unexpectedly found"));
 				return(1);
 			}
 			simals_modptr2->priority = (INTSML)j;
 			continue;
 		}
 
-		if ( ! strcmp(s1, "SET"))
+		if (!strcmp(s1, "SET"))
 		{
 			simals_ioptr1 = (char**) &(simals_modptr2->setptr);
 			for (simals_ioptr2 = simals_modptr2->setptr; simals_ioptr2;
@@ -1532,7 +1532,7 @@ INTSML simals_parse_function(void)
 			continue;
 		}
 
-		ttyputerr("ERROR: String '%s' invalid syntax", s1);
+		ttyputerr(_("ERROR: String '%s' invalid syntax"), s1);
 		return(1);
 	}
 	return(0);
@@ -1553,7 +1553,7 @@ INTSML simals_parse_func_input(EXPORT **exptr1)
 	while (1)
 	{
 		i = simals_get_name(s1);
-		if (i || ( ! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
+		if (i || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
 			&& strcmp(s1, "MODEL") && strcmp(s1, "I") && strcmp(s1, "O")
 			&& strcmp(s1, "T") && strcmp(s1, "FANOUT") && strcmp(s1, "LOAD")
 			&& strcmp(s1, "PRIORITY") && strcmp(s1, "SET"))))
@@ -1589,7 +1589,7 @@ INTSML simals_parse_func_output(void)
 	while (1)
 	{
 		i = simals_get_name(s1);
-		if (i || ( ! (strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
+		if (i || (!(strcmp(s1, "GATE") && strcmp(s1, "FUNCTION")
 			&& strcmp(s1, "MODEL") && strcmp(s1, "I") && strcmp(s1, "O")
 			&& strcmp(s1, "T") && strcmp(s1, "FANOUT") && strcmp(s1, "LOAD")
 			&& strcmp(s1, "PRIORITY") && strcmp(s1, "SET"))))
@@ -1600,12 +1600,12 @@ INTSML simals_parse_func_output(void)
 
 		for (simals_exptr2 = simals_modptr2->exptr; 1; simals_exptr2 = simals_exptr2->next)
 		{
-			if ( ! simals_exptr2)
+			if (!simals_exptr2)
 			{
-				ttyputerr("ERROR: Unable to find node %s in port list", s1);
+				ttyputerr(_("ERROR: Unable to find node %s in port list"), s1);
 				return(1);
 			}
-			if ( ! strcmp(s1, simals_exptr2->node_name))
+			if (!strcmp(s1, simals_exptr2->node_name))
 			{
 				simals_exptr2->nodeptr = (NODEPTR)1;
 				break;
