@@ -234,7 +234,7 @@ INTSML simals_process_connect_list(CONPTR cellhead, CONPTR conhead)
 
 			if (! simals_exptr2)
 			{
-				ttyputerr("Insufficient parameters declared for model '%s' in netlist",
+				ttyputerr(_("Insufficient parameters declared for model '%s' in netlist"),
 					conhead->model_name);
 				return(1);
 			}
@@ -255,7 +255,7 @@ INTSML simals_process_connect_list(CONPTR cellhead, CONPTR conhead)
 				xrefptr2 = *xrefptr1;
 				if (! strcmp(xrefptr2->node_name, simals_exptr2->node_name))
 				{
-					ttyputerr("Node '%s' in model '%s' connected more than once",
+					ttyputerr(_("Node '%s' in model '%s' connected more than once"),
 						simals_exptr2->node_name, conhead->model_name);
 					return(1);
 				}
@@ -296,7 +296,7 @@ MODPTR  simals_find_model(char *model_name)
 	{
 		if (modhead == 0)
 		{
-			ttyputerr("ERROR: Model '%s' not found, simulation aborted", propername);
+			ttyputerr(_("ERROR: Model '%s' not found, simulation aborted"), propername);
 			return(0);
 		}
 		if (! strcmp(modhead->name, propername)) return(modhead);
