@@ -69,7 +69,7 @@ char *sim_window_nextdsignals(void)
 }
 
 static COMCOMP sim_window_pickdtrace = {NOKEYWORD, sim_window_topofdsignals,
-	sim_window_nextdsignals, NOPARAMS, NOBACKUP, 0, " \t", "pick a signal to display", ""};
+	sim_window_nextdsignals, NOPARAMS, NOBACKUP, 0, " \t", N_("pick a signal to display"), ""};
 
 /*
  * The character handler for the waveform window of ALS simulation
@@ -119,7 +119,7 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 
 		/* add trace */
 		case 'a':
-			i = ttygetparam("Signal to add", &sim_window_pickdtrace, 3, par);
+			i = ttygetparam(_("Signal to add"), &sim_window_pickdtrace, 3, par);
 			if (i == 0) return(0);
 
 			/* find the signal */
@@ -208,7 +208,7 @@ INTSML simals_charhandlerwave(WINDOWPART *w, INTSML chr)
 	highsig = sim_window_gethighlighttrace();
 	if (highsig == 0)
 	{
-		ttyputerr("Select a signal name first");
+		ttyputerr(_("Select a signal name first"));
 		return(0);
 	}
 
@@ -306,7 +306,7 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 	REGISTER VARIABLE *var;
 	REGISTER INTSML strength;
 	REGISTER NETWORK *net;
-	char *par[30], *pt, line[100];
+	char *par[30], *pt;
 	float endtime;
 	NODEPTR nodehead;
 	LINKPTR sethead;
@@ -363,17 +363,14 @@ INTSML simals_charhandlerschem(WINDOWPART *w, INTSML chr)
 	net = net_gethighlightednet(0, 0);
 	if (net == NONETWORK) return(0);
 	if (net->namecount > 0) pt = net->netname; else
-	{
-		(void)sprintf(line, "NET%ld", (INTBIG)net);
-		pt = line;
-	}
+		pt = describenetwork(net);
 	sim_window_sethighlighttrace(sim_window_findtrace(pt));
 
 	/* get waveform trace and make changes */
 	highsig = sim_window_gethighlighttrace();
 	if (highsig == 0)
 	{
-		ttyputerr("Select a signal name first");
+		ttyputerr(_("Select a signal name first"));
 		return(0);
 	}
 
@@ -430,33 +427,33 @@ void simals_helpwindow(INTSML waveform)
 	active = sim_window_isactive(&np);
 
 	if (waveform != 0)
-		ttyputmsg("These keys may be typed in the ALS Waveform window:"); else
-			ttyputmsg("These keys may be typed in the ALS Schematic window:");
+		ttyputmsg(_("These keys may be typed in the ALS Waveform window:")); else
+			ttyputmsg(_("These keys may be typed in the ALS Schematic window:"));
 	if (active != 0)
 	{
-		ttyputmsg("L,0 Set signal low (gate strength)");
-		ttyputmsg("WL  Set signal weak low (node strength)");
-		ttyputmsg("SL  Set signal strong low (power strength)");
-		ttyputmsg("H,1 Set signal high (gate strength)");
-		ttyputmsg("WH  Set signal weak high (node strength)");
-		ttyputmsg("SH  Set signal strong high (power strength)");
-		ttyputmsg(" X  Set signal undefined (gate strength)");
-		ttyputmsg("WX  Set signal weak undefined (node strength)");
-		ttyputmsg("SX  Set signal strong undefined (power strength)");
-		ttyputmsg(" C  Set signal to be a clock");
-		ttyputmsg(" E  Delete all vectors on signal");
-		ttyputmsg(" I  Print information about signal");
-		ttyputmsg(" U  Update display (resimulate)");
+		ttyputinstruction("L,0", 4, _("Set signal low (gate strength)"));
+		ttyputinstruction("WL",  4, _("Set signal weak low (node strength)"));
+		ttyputinstruction("SL",  4, _("Set signal strong low (power strength)"));
+		ttyputinstruction("H,1", 4, _("Set signal high (gate strength)"));
+		ttyputinstruction("WH",  4, _("Set signal weak high (node strength)"));
+		ttyputinstruction("SH",  4, _("Set signal strong high (power strength)"));
+		ttyputinstruction(" X",  4, _("Set signal undefined (gate strength)"));
+		ttyputinstruction("WX",  4, _("Set signal weak undefined (node strength)"));
+		ttyputinstruction("SX",  4, _("Set signal strong undefined (power strength)"));
+		ttyputinstruction(" C",  4, _("Set signal to be a clock"));
+		ttyputinstruction(" E",  4, _("Delete all vectors on signal"));
+		ttyputinstruction(" I",  4, _("Print information about signal"));
+		ttyputinstruction(" U",  4, _("Update display (resimulate)"));
 	}
 
 	if (waveform != 0)
 	{
 		if (active != 0)
 		{
-			ttyputmsg(" A  Add signal to simulation window");
-			ttyputmsg(" R  Remove signal from the window");
+			ttyputinstruction(" A", 4, _("Add signal to simulation window"));
+			ttyputinstruction(" R", 4, _("Remove signal from the window"));
 		}
-		ttyputmsg(" P  Preserve snapshot of simulation window in database");
+		ttyputinstruction(" P", 4, _("Preserve snapshot of simulation window in database"));
 	}
 }
 
