@@ -140,7 +140,7 @@ float simals_initialize_simulator(INTSML force)
 		sim_window_gettimerange(&tmin, &tmax);
 		while (simals_linkfront && (simals_linkfront->time <= tmax))
 		{
-			if (stopping("Simulation")) break;
+			if (stopping(STOPREASONSIMULATE)) break;
 			if (simals_fire_event() != 0) break;
 			if (simals_chekroot)
 			{
@@ -153,7 +153,7 @@ float simals_initialize_simulator(INTSML force)
 		sim_window_redraw();
 		sim_window_updatelayoutwindow();
 		sim_windowconvertengineeringnotation(simals_time_abs, s1);
-		ttyputverbose("Simulation completed at time %s", s1);
+		ttyputverbose(_("Simulation completed at time %s"), s1);
 	}
 
 	return(simals_time_abs);
@@ -215,7 +215,7 @@ INTSML simals_fire_event(void)
 				|| (stathead->sched_strength != linkhead->strength)) break;
 			stathead->sched_op = 0;
 
-			/* ttyputmsg("Fire: $N%ld", stathead->nodeptr->num); */
+			/* ttyputmsg(_("Fire: $N%ld"), stathead->nodeptr->num); */
 			operatr = linkhead->operatr;
 			if (operatr < 128)
 			{
@@ -248,7 +248,7 @@ INTSML simals_fire_event(void)
 					state = stathead->nodeptr->sum_state % operand;
 					break;
 				default:
-					ttyputerr("Invalid arithmetic operator: %c", operatr);
+					ttyputerr(_("Invalid arithmetic operator: %c"), operatr);
 					return(1);
 			}
 
@@ -264,7 +264,7 @@ INTSML simals_fire_event(void)
 			if (linkhead->state == nodehead->new_state && linkhead->strength == nodehead->new_strength)
 				break;
 
-			/* ttyputmsg("Fire: $N%ld", nodehead->num);*/
+			/* ttyputmsg(_("Fire: $N%ld"), nodehead->num);*/
 			nodehead->new_state = linkhead->state;
 			nodehead->new_strength = linkhead->strength;
 			simals_create_check_list(nodehead);
@@ -433,7 +433,7 @@ INTSML simals_schedule_new_events(void)
 						if (iohead->nodeptr->sum_state <= operand) flag = 0;
 						break;
 					default:
-						ttyputerr("Invalid logical operator: %c", operatr);
+						ttyputerr(_("Invalid logical operator: %c"), operatr);
 						return(1);
 				}
 
@@ -663,7 +663,7 @@ void simals_insert_link_list(LINKPTR linkhead)
 	LINKPTR linkptr2, linkptr3;
 
 	/* if (linkhead->type == 'G')
-		ttyputmsg("Schedule: $N%ld", ((STATPTR) linkhead->ptr)->nodeptr->num); */
+		ttyputmsg(_("Schedule: $N%ld"), ((STATPTR) linkhead->ptr)->nodeptr->num); */
 
 	linkptr1 = (char**) &simals_linkback;
 	linkptr2 = simals_linkback;
