@@ -81,7 +81,6 @@ void sim_fasthenryinit(void)
 void sim_writefasthenrynetlist(NODEPROTO *np)
 {
 	char name[100], *truename, *args[30], txtpoles[20], *path;
-	extern AIDENTRY *net_aid;
 	FILE *io;
 	UINTBIG cdate, rdate;
 	float startfreq, endfreq;
@@ -91,9 +90,9 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the simulation command");
+		ttyputerr(_("...now reissue the simulation command"));
 		return;
 	}
 
@@ -104,10 +103,10 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	/* first write the "inp" file */
 	(void)strcpy(name, np->cell->cellname);
 	(void)strcat(name, ".inp");
-	io = xcreate(name, FILETYPEFASTHENRY, "FastHenry File", &truename);
+	io = xcreate(name, sim_filetypefasthenry, _("FastHenry File"), &truename);
 	if (io == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
 	xprintf(io, "* FastHenry for facet %s\n", describenodeproto(np));
@@ -146,7 +145,7 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 	/* clean up */
 	xprintf(io, "\n.end\n");
 	xclose(io);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 
 	/* generate invocation for fasthenry */
 	argc = 0;
@@ -169,12 +168,12 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 			if (i != 0) (void)addtoinfstr(' ');
 			(void)addstringtoinfstr(args[i]);
 		}
-		ttyputmsg("*** Now run: %s", returninfstr());
+		ttyputmsg(_("*** Now run: %s"), returninfstr());
 
 		sim_process = efork();
 		if (sim_process == 1)
 		{
-			ttyputmsg("Run FastHenry directly please");
+			ttyputmsg(_("Run FastHenry directly please"));
 			return;
 		}
 		if (sim_process == 0)
@@ -182,7 +181,7 @@ void sim_writefasthenrynetlist(NODEPROTO *np)
 			path = egetenv("ELECTRIC_FASTHENRYLOC");
 			if (path == NULL) path = FASTHENRYLOC;
 			eexec(path, args);
-			ttyputerr("Cannot run %s", path);
+			ttyputerr(_("Cannot run %s"), path);
 			exit(1);
 		}
 	}
@@ -203,7 +202,6 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	REGISTER INTBIG nodezval, zval, x1, y1, z1, x2, y2, z2, wid, thatend;
 	float xf, yf, zf, wf, hf;
 	char *nname, *n1name, *n2name, *groupname;
-	extern AIDENTRY *net_aid;
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER VARIABLE *var;
 	float startfreq, endfreq;
@@ -217,7 +215,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	/* stop if requested */
 	if (el_pleasestop != 0)
 	{
-		stopping("FastHenry deck generation");
+		stopping(STOPREASONDECK);
 		return(0);
 	}
 
@@ -247,7 +245,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 			if (found != 0)
 			{
 				if (zval != nodezval)
-					ttyputerr("Warning: inconsistent z value at node %s",
+					ttyputerr(_("Warning: inconsistent z value at node %s"),
 						describenodeinst(ni));
 			}
 			nodezval = zval;
@@ -325,7 +323,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 		pp->temp1 = 0;
 
-	/* look at every exported port in the facet */
+	/* look at every export in the facet */
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
 		if (pp->temp1 != 0) continue;
@@ -344,7 +342,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 		opp = sim_fasthenryfindotherport(ai, thatend);
 		if (opp == NOPORTPROTO)
 		{
-			ttyputerr("Warning: trace on port %s has no other end exported",
+			ttyputerr(_("Warning: trace on port %s has no other end that is an export"),
 				pp->protoname);
 			continue;
 		}
@@ -360,7 +358,7 @@ INTSML sim_writefhfacet(NODEPROTO *np, FILE *io)
 		if (ai->temp1 != 0) continue;
 		var = getvalkey((INTBIG)ai, VARCINST, VSTRING, sim_fasthenrygroupnamekey);
 		if (var = NOVARIABLE) continue;
-		ttyputerr("Warning: arc %s is not on a measured trace", describearcinst(ai));
+		ttyputerr(_("Warning: arc %s is not on a measured trace"), describearcinst(ai));
 	}
 	return(backannotate);
 }
@@ -409,7 +407,7 @@ void sim_fasthenrygetoptions(INTBIG *options, float *startfreq, float *endfreq,
 	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenryseglimitkey);
 	if (var != NOVARIABLE) *seglenlimit = var->addr; else *seglenlimit = 0;
 	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenrythicknesskey);
-	if (var != NOVARIABLE) *thickness = var->addr; else *thickness = 2*el_curtech->deflambda;
+	if (var != NOVARIABLE) *thickness = var->addr; else *thickness = 2*el_curlib->lambda[el_curtech->techindex];
 	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenrywidthsubdivkey);
 	if (var != NOVARIABLE) *widsubdiv = var->addr; else *widsubdiv = 1;
 	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_fasthenryheightsubdivkey);
@@ -421,7 +419,7 @@ char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubd
 	INTBIG *defz)
 {
 	REGISTER VARIABLE *var;
-	REGISTER INTSML total, i;
+	REGISTER INTBIG total, i;
 	INTBIG lheight, lthickness;
 	static POLYGON *poly = NOPOLYGON;
 
@@ -443,7 +441,7 @@ char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubd
 		shapearcpoly(ai, i, poly);
 		if (get3dfactors(ai->proto->tech, poly->layer, &lheight, &lthickness) != 0)
 			continue;
-		*defz = lheight * ai->proto->tech->deflambda;
+		*defz = lheight * lambdaofarc(ai);
 		break;
 	}
 	var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryzheadkey);
@@ -470,32 +468,32 @@ char *sim_fasthenrygetarcoptions(ARCINST *ai, INTBIG *thickness, INTBIG *widsubd
 /* Simulation: FastHenry Options */
 DIALOGITEM sim_fasthenrydialogitems[] =
 {
- /*  1 */ {0, {164,392,188,472}, BUTTON, "OK"},
- /*  2 */ {0, {164,12,188,92}, BUTTON, "Cancel"},
- /*  3 */ {0, {32,20,48,140}, MESSAGE, "Frequency start:"},
+ /*  1 */ {0, {164,392,188,472}, BUTTON, N_("OK")},
+ /*  2 */ {0, {164,12,188,92}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {32,20,48,140}, MESSAGE, N_("Frequency start:")},
  /*  4 */ {0, {32,144,48,200}, EDITTEXT, ""},
- /*  5 */ {0, {56,20,72,140}, MESSAGE, "Frequency end:"},
+ /*  5 */ {0, {56,20,72,140}, MESSAGE, N_("Frequency end:")},
  /*  6 */ {0, {56,144,72,200}, EDITTEXT, ""},
- /*  7 */ {0, {80,20,96,140}, MESSAGE, "Runs per decade:"},
+ /*  7 */ {0, {80,20,96,140}, MESSAGE, N_("Runs per decade:")},
  /*  8 */ {0, {80,144,96,200}, EDITTEXT, ""},
- /*  9 */ {0, {8,8,24,200}, CHECK, "Use single frequency"},
- /* 10 */ {0, {128,20,144,140}, MESSAGE, "Number of poles:"},
+ /*  9 */ {0, {8,8,24,200}, CHECK, N_("Use single frequency")},
+ /* 10 */ {0, {128,20,144,140}, MESSAGE, N_("Number of poles:")},
  /* 11 */ {0, {128,144,144,200}, EDITTEXT, ""},
- /* 12 */ {0, {104,8,120,200}, CHECK, "Make multipole subcircuit"},
- /* 13 */ {0, {104,232,120,420}, CHECK, "Make PostScript view"},
- /* 14 */ {0, {76,232,92,420}, MESSAGE, "Maximum segment length:"},
+ /* 12 */ {0, {104,8,120,200}, CHECK, N_("Make multipole subcircuit")},
+ /* 13 */ {0, {104,232,120,420}, CHECK, N_("Make PostScript view")},
+ /* 14 */ {0, {76,232,92,420}, MESSAGE, N_("Maximum segment length:")},
  /* 15 */ {0, {76,424,92,480}, EDITTEXT, ""},
- /* 16 */ {0, {28,232,44,420}, MESSAGE, "Default width subdivisions:"},
+ /* 16 */ {0, {28,232,44,420}, MESSAGE, N_("Default width subdivisions:")},
  /* 17 */ {0, {28,424,44,480}, EDITTEXT, ""},
- /* 18 */ {0, {52,232,68,420}, MESSAGE, "Default height subdivisions:"},
+ /* 18 */ {0, {52,232,68,420}, MESSAGE, N_("Default height subdivisions:")},
  /* 19 */ {0, {52,424,68,480}, EDITTEXT, ""},
- /* 20 */ {0, {128,232,144,420}, CHECK, "Make SPICE subcircuit"},
- /* 21 */ {0, {4,232,20,420}, MESSAGE, "Default thickness:"},
+ /* 20 */ {0, {128,232,144,420}, CHECK, N_("Make SPICE subcircuit")},
+ /* 21 */ {0, {4,232,20,420}, MESSAGE, N_("Default thickness:")},
  /* 22 */ {0, {4,424,20,480}, EDITTEXT, ""},
  /* 23 */ {0, {176,140,192,344}, POPUP, ""},
- /* 24 */ {0, {156,176,172,320}, MESSAGE, "After writing deck:"}
+ /* 24 */ {0, {156,176,172,320}, MESSAGE, N_("After writing deck:")}
 };
-DIALOG sim_fasthenrydialog = {{75,75,276,564}, "FastHenry Options", 24, sim_fasthenrydialogitems};
+DIALOG sim_fasthenrydialog = {{75,75,276,564}, N_("FastHenry Options"), 0, 24, sim_fasthenrydialogitems};
 
 /*
  * special case for the "FastHenry options" dialog
@@ -519,12 +517,14 @@ DIALOG sim_fasthenrydialog = {{75,75,276,564}, "FastHenry Options", 24, sim_fast
  */
 void sim_fasthenrydlog(void)
 {
-	REGISTER INTBIG itemHit, value, canexecute;
+	REGISTER INTBIG itemHit, value, canexecute, i;
 	float fvalue;
-	char line[30];
-	static char *exechoices[] = {"Nothing run", "Run FastHenry", "Run FastHenry Multiprocessing"};
+	char line[30], *newlang[5];
+	static char *exechoices[] = {N_("Nothing run"), N_("Run FastHenry"),
+		N_("Run FastHenry Multiprocessing")};
 	float startfreq, endfreq;
-	INTBIG options, runsperdecade, numpoles, seglenlimit, thickness, widsubdiv, heisubdiv;
+	INTBIG options, runsperdecade, numpoles, seglenlimit, thickness,
+		widsubdiv, heisubdiv;
 
 	/* get all parameters */
 	sim_fasthenrygetoptions(&options, &startfreq, &endfreq, &runsperdecade, &numpoles,
@@ -534,7 +534,7 @@ void sim_fasthenrydlog(void)
 	if (DiaInitDialog(&sim_fasthenrydialog) != 0) return;
 
 	/* set popup */
-	DiaSetPopup(23, 3, exechoices);
+	for(i=0; i<3; i++) newlang[i] = _(exechoices[i]);   DiaSetPopup(23, 3, newlang);
 	canexecute = graphicshas(CANRUNPROCESS);
 	if (canexecute != 0)
 	{
@@ -634,33 +634,42 @@ void sim_fasthenrydlog(void)
 	if (itemHit == OK)
 	{
 		/* save options */
-		options = 0;
-		if (DiaGetControl(9) != 0) options |= FHUSESINGLEFREQ;
-		if (DiaGetControl(12) != 0) options |= FHMAKEMULTIPOLECKT;
-		if (DiaGetControl(13) != 0) options |= FHMAKEPOSTSCRIPTVIEW;
-		if (DiaGetControl(20) != 0) options |= FHMAKESPICESUBCKT;
-		value = DiaGetPopupEntry(23);
-		if (value == 1) options |= FHEXECUTERUNFH; else
-			if (value == 2) options |= FHEXECUTERUNFHMUL;
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrystatekey, options, VINTEGER);
+		value = 0;
+		if (DiaGetControl(9) != 0) value |= FHUSESINGLEFREQ;
+		if (DiaGetControl(12) != 0) value |= FHMAKEMULTIPOLECKT;
+		if (DiaGetControl(13) != 0) value |= FHMAKEPOSTSCRIPTVIEW;
+		if (DiaGetControl(20) != 0) value |= FHMAKESPICESUBCKT;
+		i = DiaGetPopupEntry(23);
+		if (i == 1) value |= FHEXECUTERUNFH; else
+			if (i == 2) value |= FHEXECUTERUNFHMUL;
+		if (value != options)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrystatekey, value, VINTEGER);
 
 		/* save other limits */
 		fvalue = (float)atof(DiaGetText(4));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryfreqstartkey, castint(fvalue), VFLOAT);
+		if (fvalue != startfreq)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryfreqstartkey, castint(fvalue), VFLOAT);
 		fvalue = (float)atof(DiaGetText(6));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryfreqendkey, castint(fvalue), VFLOAT);
+		if (fvalue != endfreq)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryfreqendkey, castint(fvalue), VFLOAT);
 		value = atoi(DiaGetText(8));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryrunsperdecadekey, value, VINTEGER);
+		if (value != runsperdecade)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryrunsperdecadekey, value, VINTEGER);
 		value = atola(DiaGetText(15));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryseglimitkey, value, VINTEGER);
+		if (value != seglenlimit)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryseglimitkey, value, VINTEGER);
 		value = atola(DiaGetText(22));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrythicknesskey, value, VINTEGER);
+		if (value != thickness)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrythicknesskey, value, VINTEGER);
 		value = atoi(DiaGetText(17));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrywidthsubdivkey, value, VINTEGER);
+		if (value != widsubdiv)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrywidthsubdivkey, value, VINTEGER);
 		value = atoi(DiaGetText(19));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryheightsubdivkey, value, VINTEGER);
+		if (value != heisubdiv)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenryheightsubdivkey, value, VINTEGER);
 		value = atoi(DiaGetText(11));
-		(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrynumpoleskey, value, VINTEGER);
+		if (value != numpoles)
+			(void)setvalkey((INTBIG)sim_aid, VAID, sim_fasthenrynumpoleskey, value, VINTEGER);
 	}
 	DiaDoneDialog();
 }
@@ -668,40 +677,40 @@ void sim_fasthenrydlog(void)
 /* Simulation: FastHenry Arc */
 DIALOGITEM sim_fasthenryarcdialogitems[] =
 {
- /*  1 */ {0, {88,236,112,316}, BUTTON, "OK"},
- /*  2 */ {0, {40,236,64,316}, BUTTON, "Cancel"},
- /*  3 */ {0, {32,8,48,132}, MESSAGE, "Thickness:"},
+ /*  1 */ {0, {88,236,112,316}, BUTTON, N_("OK")},
+ /*  2 */ {0, {40,236,64,316}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {32,8,48,132}, MESSAGE, N_("Thickness:")},
  /*  4 */ {0, {32,136,48,216}, EDITTEXT, ""},
- /*  5 */ {0, {56,8,72,132}, MESSAGE, "Width:"},
+ /*  5 */ {0, {56,8,72,132}, MESSAGE, N_("Width:")},
  /*  6 */ {0, {56,136,72,216}, MESSAGE, ""},
- /*  7 */ {0, {80,8,96,180}, MESSAGE, "Width subdivisions:"},
+ /*  7 */ {0, {80,8,96,180}, MESSAGE, N_("Width subdivisions:")},
  /*  8 */ {0, {80,184,96,216}, EDITTEXT, ""},
- /*  9 */ {0, {104,8,120,180}, MESSAGE, "Height subdivisions:"},
+ /*  9 */ {0, {104,8,120,180}, MESSAGE, N_("Height subdivisions:")},
  /* 10 */ {0, {104,184,120,216}, EDITTEXT, ""},
- /* 11 */ {0, {232,8,248,36}, MESSAGE, "X:"},
+ /* 11 */ {0, {232,8,248,36}, MESSAGE, N_("X:")},
  /* 12 */ {0, {232,40,248,136}, MESSAGE, ""},
- /* 13 */ {0, {204,8,220,144}, MESSAGE, "Head of arc is at:"},
- /* 14 */ {0, {256,8,272,36}, MESSAGE, "Y:"},
+ /* 13 */ {0, {204,8,220,144}, MESSAGE, N_("Head of arc is at:")},
+ /* 14 */ {0, {256,8,272,36}, MESSAGE, N_("Y:")},
  /* 15 */ {0, {256,40,272,136}, MESSAGE, ""},
- /* 16 */ {0, {280,8,296,36}, MESSAGE, "Z:"},
+ /* 16 */ {0, {280,8,296,36}, MESSAGE, N_("Z:")},
  /* 17 */ {0, {280,40,296,132}, EDITTEXT, ""},
- /* 18 */ {0, {232,180,248,208}, MESSAGE, "X:"},
+ /* 18 */ {0, {232,180,248,208}, MESSAGE, N_("X:")},
  /* 19 */ {0, {232,212,248,308}, MESSAGE, ""},
- /* 20 */ {0, {204,180,220,316}, MESSAGE, "Tail of arc is at:"},
- /* 21 */ {0, {256,180,272,208}, MESSAGE, "Y:"},
+ /* 20 */ {0, {204,180,220,316}, MESSAGE, N_("Tail of arc is at:")},
+ /* 21 */ {0, {256,180,272,208}, MESSAGE, N_("Y:")},
  /* 22 */ {0, {256,212,272,308}, MESSAGE, ""},
- /* 23 */ {0, {280,180,296,208}, MESSAGE, "Z:"},
+ /* 23 */ {0, {280,180,296,208}, MESSAGE, N_("Z:")},
  /* 24 */ {0, {280,212,296,304}, EDITTEXT, ""},
- /* 25 */ {0, {144,8,160,108}, MESSAGE, "Group name:"},
+ /* 25 */ {0, {144,8,160,108}, MESSAGE, N_("Group name:")},
  /* 26 */ {0, {144,112,160,316}, POPUP, ""},
- /* 27 */ {0, {168,80,184,176}, BUTTON, "New Group"},
+ /* 27 */ {0, {168,80,184,176}, BUTTON, N_("New Group")},
  /* 28 */ {0, {132,8,133,316}, DIVIDELINE, ""},
- /* 29 */ {0, {192,8,193,316}, DIVIDELINE, "item"},
- /* 30 */ {0, {8,8,24,316}, CHECK, "Include this arc in FastHenry analysis"},
- /* 31 */ {0, {304,88,320,168}, MESSAGE, "Default Z:"},
+ /* 29 */ {0, {192,8,193,316}, DIVIDELINE, ""},
+ /* 30 */ {0, {8,8,24,316}, CHECK, N_("Include this arc in FastHenry analysis")},
+ /* 31 */ {0, {304,88,320,168}, MESSAGE, N_("Default Z:")},
  /* 32 */ {0, {304,172,320,268}, MESSAGE, ""}
 };
-DIALOG sim_fasthenryarcdialog = {{75,75,404,401}, "FastHenry Arc Properties", 32, sim_fasthenryarcdialogitems};
+DIALOG sim_fasthenryarcdialog = {{75,75,404,401}, N_("FastHenry Arc Properties"), 0, 32, sim_fasthenryarcdialogitems};
 
 /*
  * special case for the "FastHenry arc" dialog
@@ -730,12 +739,11 @@ DIALOG sim_fasthenryarcdialog = {{75,75,404,401}, "FastHenry Arc Properties", 32
  */
 void sim_fasthenryarcdlog(void)
 {
-	REGISTER INTBIG itemHit, value, groupnamesize, i, which;
+	REGISTER INTBIG itemHit, value, groupnamesize, i, which, val;
 	REGISTER ARCINST *ai, *oai;
 	REGISTER VARIABLE *var;
 	char line[60], *groupname, *pt, **groupnames, **newgroupnames, *newname;
 	float startfreq, endfreq;
-	extern AIDENTRY *us_aid;
 	INTBIG options, runsperdecade, numpoles, seglenlimit, thickness, defthickness,
 		widsubdiv, defwidsubdiv, heisubdiv, defheisubdiv, z_head, z_tail, defz;
 	INTSML zhover, ztover;
@@ -744,7 +752,7 @@ void sim_fasthenryarcdlog(void)
 	ai = (ARCINST *)askaid(us_aid, "get-arc");
 	if (ai == NOARCINST)
 	{
-		ttyputerr("Select an arc first");
+		ttyputerr(_("Select an arc first"));
 		return;
 	}
 
@@ -781,7 +789,7 @@ void sim_fasthenryarcdlog(void)
 	if (groupnamesize == 0)
 	{
 		groupnames = (char **)emalloc((sizeof (char *)), sim_aid->cluster);
-		(void)allocstring(&groupnames[0], "Group 1", sim_aid->cluster);
+		(void)allocstring(&groupnames[0], _("Group 1"), sim_aid->cluster);
 		groupnamesize++;
 	}
 	DiaSetPopup(26, groupnamesize, groupnames);
@@ -795,19 +803,19 @@ void sim_fasthenryarcdlog(void)
 	}
 
 	/* show arc parameters */
-	sprintf(line, "Thickness (%s):", latoa(defthickness));   DiaSetText(3, line);
+	sprintf(line, _("Thickness (%s):"), latoa(defthickness));   DiaSetText(3, line);
 	if (thickness >= 0)
 		DiaSetText(4, latoa(thickness));
 	DiaSetText(6, latoa(ai->width));
 
 	/* show subdivision overrides */
-	sprintf(line, "Width subdivisions (%ld):", defwidsubdiv);   DiaSetText(7, line);
+	sprintf(line, _("Width subdivisions (%ld):"), defwidsubdiv);   DiaSetText(7, line);
 	if (widsubdiv > 0)
 	{
 		sprintf(line, "%ld", widsubdiv);
 		DiaSetText(8, line);
 	}
-	sprintf(line, "Height subdivisions (%ld):", defheisubdiv);   DiaSetText(9, line);
+	sprintf(line, _("Height subdivisions (%ld):"), defheisubdiv);   DiaSetText(9, line);
 	if (heisubdiv > 0)
 	{
 		sprintf(line, "%ld", heisubdiv);
@@ -902,7 +910,7 @@ void sim_fasthenryarcdlog(void)
 		}
 		if (itemHit == 27)		/* new group name */
 		{
-			newname = ttygetline("New group name:");
+			newname = ttygetline(_("New group name:"));
 			if (newname == 0 || *newname == 0) continue;
 			for(i=0; i<groupnamesize; i++)
 				if (namesame(groupnames[i], newname) == 0) break;
@@ -926,56 +934,84 @@ void sim_fasthenryarcdlog(void)
 	if (itemHit == OK)
 	{
 		startobjectchange((INTBIG)ai, VARCINST);
+		var = getvalkey((INTBIG)ai, VARCINST, VSTRING, sim_fasthenrygroupnamekey);
 		if (DiaGetControl(30) != 0)
 		{
 			/* active in FastHenry */
 			i = DiaGetPopupEntry(26);
 			groupname = groupnames[i];
-			setvalkey((INTBIG)ai, VARCINST, sim_fasthenrygroupnamekey, (INTBIG)groupname, VSTRING|VDISPLAY);
+			if (var == NOVARIABLE || strcmp(groupname, (char *)var->addr) != 0)
+				setvalkey((INTBIG)ai, VARCINST, sim_fasthenrygroupnamekey, (INTBIG)groupname,
+					VSTRING|VDISPLAY);
 		} else
 		{
-			if (getvalkey((INTBIG)ai, VARCINST, VSTRING, sim_fasthenrygroupnamekey) != NOVARIABLE)
+			if (var != NOVARIABLE)
 				delvalkey((INTBIG)ai, VARCINST, sim_fasthenrygroupnamekey);
 		}
 
 		/* save thickness */
 		pt = DiaGetText(4);
+		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenrythicknesskey);
 		if (*pt != 0)
-			setvalkey((INTBIG)ai, VARCINST, sim_fasthenrythicknesskey, atola(pt), VINTEGER); else
 		{
-			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenrythicknesskey) != NOVARIABLE)
+			val = atola(pt);
+			if (var == NOVARIABLE || val != var->addr)
+				setvalkey((INTBIG)ai, VARCINST, sim_fasthenrythicknesskey, val, VINTEGER);
+		} else
+		{
+			if (var != NOVARIABLE)
 				delvalkey((INTBIG)ai, VARCINST, sim_fasthenrythicknesskey);
 		}
 
 		/* save width and height subdivisions */
 		pt = DiaGetText(8);
+		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenrywidthsubdivkey);
 		if (*pt != 0)
-			setvalkey((INTBIG)ai, VARCINST, sim_fasthenrywidthsubdivkey, atoi(pt), VINTEGER); else
 		{
-			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenrywidthsubdivkey) != NOVARIABLE)
+			val = atoi(pt);
+			if (var == NOVARIABLE || val != var->addr)
+				setvalkey((INTBIG)ai, VARCINST, sim_fasthenrywidthsubdivkey, val, VINTEGER);
+		} else
+		{
+			if (var != NOVARIABLE)
 				delvalkey((INTBIG)ai, VARCINST, sim_fasthenrywidthsubdivkey);
 		}
 		pt = DiaGetText(10);
+		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryheightsubdivkey);
 		if (*pt != 0)
-			setvalkey((INTBIG)ai, VARCINST, sim_fasthenryheightsubdivkey, atoi(pt), VINTEGER); else
 		{
-			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryheightsubdivkey) != NOVARIABLE)
+			val = atoi(pt);
+			if (var == NOVARIABLE || val != var->addr)
+				setvalkey((INTBIG)ai, VARCINST, sim_fasthenryheightsubdivkey, val, VINTEGER);
+		} else
+		{
+			if (var != NOVARIABLE)
 				delvalkey((INTBIG)ai, VARCINST, sim_fasthenryheightsubdivkey);
 		}
 
 		/* save z overrides */
 		pt = DiaGetText(17);
+		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryzheadkey);
 		if (*pt != 0)
-			setvalkey((INTBIG)ai, VARCINST, sim_fasthenryzheadkey, atola(pt), VINTEGER); else
 		{
-			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryzheadkey) != NOVARIABLE)
+			val = atola(pt);
+			if (var == NOVARIABLE || val != var->addr)
+				setvalkey((INTBIG)ai, VARCINST, sim_fasthenryzheadkey, val, VINTEGER);
+		} else
+		{
+			if (var != NOVARIABLE)
 				delvalkey((INTBIG)ai, VARCINST, sim_fasthenryzheadkey);
 		}
 		pt = DiaGetText(24);
+		var = getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryztailkey);
 		if (*pt != 0)
-			setvalkey((INTBIG)ai, VARCINST, sim_fasthenryztailkey, atola(pt), VINTEGER); else
 		{
-			if (getvalkey((INTBIG)ai, VARCINST, VINTEGER, sim_fasthenryztailkey) != NOVARIABLE)
+			val = atola(pt);
+			if (var == NOVARIABLE || val != var->addr)
+				setvalkey((INTBIG)ai, VARCINST, sim_fasthenryztailkey, val, VINTEGER);
+		} else
+		{
+			if (var != NOVARIABLE)
 				delvalkey((INTBIG)ai, VARCINST, sim_fasthenryztailkey);
 		}
 		endobjectchange((INTBIG)ai, VARCINST);
