@@ -151,16 +151,16 @@ void sim_spice_execute(char *infile, char *outfile)
 		/* parsing output into simulation window: make sure none is active */
 		if (sim_window_isactive(&np) != 0)
 		{
-			ttyputerr("Only one simulation window can run at a time");
-			ttyputmsg("Terminate the current one before reading SPICE output");
+			ttyputerr(_("Only one simulation window can run at a time"));
+			ttyputmsg(_("Terminate the current one before reading SPICE output"));
 			return;
 		}
 
 		/* no input deck, simply use output listing */
-		sim_streamfromsim = xopen(truepath(outfile), FILETYPESPICEOUT, "", &truename);
+		sim_streamfromsim = xopen(truepath(outfile), sim_filetypespiceout, "", &truename);
 		if (sim_streamfromsim == NULL)
 		{
-			ttyputerr("Cannot read %s", truename);
+			ttyputerr(_("Cannot read %s"), truename);
 			return;
 		}
 		sim_window_filelen = filesize(sim_streamfromsim);
@@ -175,7 +175,7 @@ void sim_spice_execute(char *infile, char *outfile)
 		sim_process = efork();
 		if (sim_process == 1)
 		{
-			ttyputmsg("Run SPICE directly please");
+			ttyputmsg(_("Run SPICE directly please"));
 			return;
 		}
 		if (sim_process == 0)
@@ -223,7 +223,7 @@ void sim_spice_execute(char *infile, char *outfile)
 			channelrestore(0, save0);
 			channelrestore(1, save1);
 			channelrestore(2, save2);
-			ttyputerr("Cannot run %s", path);
+			ttyputerr(_("Cannot run %s"), path);
 			exit(1);
 		}
 
@@ -237,10 +237,10 @@ void sim_spice_execute(char *infile, char *outfile)
 		{
 			char *truename;
 
-			outputfile = xcreate(outfile, FILETYPESPICEOUT, "SPICE Output File", &truename);
+			outputfile = xcreate(outfile, sim_filetypespiceout, _("SPICE Output File"), &truename);
 			if (outputfile == NULL)
 			{
-				if (truename != 0) ttyputerr("Cannot write SPICE output file %s", truename);
+				if (truename != 0) ttyputerr(_("Cannot write SPICE output file %s"), truename);
 			}
 		}
 	}
@@ -281,7 +281,7 @@ void sim_spice_execute(char *infile, char *outfile)
 		ptr = line;
 		for(;;)
 		{
-			if (stopping("SPICE") != 0) break;
+			if (stopping(STOPREASONSPICE)) break;
 			i = sim_getfromsimulator();
 			if (i == EOF) break;
 			if (parsemode == SIMRUNYESQ) continue;
@@ -302,11 +302,11 @@ void sim_spice_execute(char *infile, char *outfile)
 	/* clean up */
 	if (sim_window_filelen > 0) DiaDoneDialog();
 	(void)sim_spice_terminate(outputfile, outfile, infile);
-	if (stopping("SPICE") != 0) return;
+	if (stopping(STOPREASONSPICE)) return;
 
 	/* plot the list of numbers */
 	if (important < 0) return;
-	if (sim_spice_plotvalues((INTSML)important) != 0) ttyputerr("Problem making the plot");
+	if (sim_spice_plotvalues((INTSML)important) != 0) ttyputerr(_("Problem making the plot"));
 }
 
 /*
@@ -333,7 +333,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 		ptr = line;
 		for(;;)
 		{
-			if (stopping("SPICE") != 0) break;
+			if (stopping(STOPREASONSPICE)) break;
 			i = sim_getfromsimulator();
 			if (i == EOF) break;
 			*ptr = (char)i;
@@ -348,8 +348,8 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 					if (strlen(line) >= 20 && line[16] == '9' && line[17] == '0' &&
 						line[18] == '0' && line[19] == '7')
 					{
-						ttyputerr("This is an HSPICE file, not a SPICE2 file");
-						ttyputerr("Change the SPICE format and reread");
+						ttyputerr(_("This is an HSPICE file, not a SPICE2 file"));
+						ttyputerr(_("Change the SPICE format and reread"));
 						return(-1);
 					}
 				}
@@ -437,7 +437,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 		first = 1;
 		for(;;)
 		{
-			if (stopping("SPICE") != 0) break;
+			if (stopping(STOPREASONSPICE)) break;
 			i = sim_getfromsimulator();
 			if (i == EOF) break;
 			*ptr = (char)i;
@@ -453,8 +453,8 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 					if (strlen(line) >= 20 && line[16] == '9' && line[17] == '0' &&
 						line[18] == '0' && line[19] == '7')
 					{
-						ttyputerr("This is an HSPICE file, not a SPICE3 file");
-						ttyputerr("Change the SPICE format and reread");
+						ttyputerr(_("This is an HSPICE file, not a SPICE3 file"));
+						ttyputerr(_("Change the SPICE format and reread"));
 						return(-1);
 					}
 				}
@@ -479,8 +479,8 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 							numend->nextnumbers = num;
 							if (num->time <= lastt && knows == 0)
 							{
-								ttyputerr("First trace not increasing values");
-								ttyputmsg("   this should be 'time'");
+								ttyputerr(_("First trace not increasing values"));
+								ttyputmsg(_("   this should be 'time'"));
 								knows++;
 							}
 						}
@@ -489,7 +489,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 						numend = num;
 					} else
 					{
-						if (num == NONUMBERS) ttyputmsg("Line %ld of data has too many values",
+						if (num == NONUMBERS) ttyputmsg(_("Line %ld of data has too many values"),
 							sim_window_signals); else
 						{
 							if (sim_window_signals <= MAXTRACES)
@@ -505,7 +505,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 				{
 					/* advance to the next value for subsequent reads */
 					if (sim_window_signals != 0 && num != NONUMBERS)
-						ttyputmsg("Line %ld of data has too few values", sim_window_signals);
+						ttyputmsg(_("Line %ld of data has too few values"), sim_window_signals);
 					sim_window_signals++;
 					num = sim_window_numbers;
 				}
@@ -641,7 +641,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 		line[4] = 0;
 		if (strcmp(line, "$&%#") != 0)
 		{
-			ttyputerr("HSPICE header improperly terminated");
+			ttyputerr(_("HSPICE header improperly terminated"));
 			return(-1);
 		}
 
@@ -649,7 +649,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 		sim_window_numbers = numend = NONUMBERS;
 		for(;;)
 		{
-			if (stopping("SPICE") != 0) break;
+			if (stopping(STOPREASONSPICE)) break;
 			if (sim_window_filelen > 0) DiaPercent(1, sim_window_filepos*100/sim_window_filelen);
 
 			/* get the first number, see if it terminates */
@@ -659,7 +659,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 				l = sim_getfromsimulator();
 				if (l == EOF)
 				{
-					ttyputerr("EOF too soon");
+					ttyputerr(_("EOF too soon"));
 					return(0);
 				}
 				line[j] = (char)l;
@@ -683,7 +683,7 @@ INTBIG sim_spiceparseoutput(INTBIG running, FILE *outputfile, INTBIG parsemode)
 					l = sim_getfromsimulator();
 					if (l == EOF)
 					{
-						ttyputerr("EOF too soon");
+						ttyputerr(_("EOF too soon"));
 						return(0);
 					}
 					line[j] = (char)l;
@@ -706,7 +706,7 @@ void sim_spice_terminate(FILE *outputfile, char *outfile, char *infile)
 	if (outputfile != NULL)
 	{
 		xclose(outputfile);
-		ttyputverbose("%s written", outfile);
+		ttyputverbose(_("%s written"), outfile);
 	}
 	if (*infile != 0)
 	{
@@ -714,9 +714,9 @@ void sim_spice_terminate(FILE *outputfile, char *outfile, char *infile)
 		{
 			ewait(sim_process);
 			if (errno >= 0)
-				ttyputmsg("SPICE execution reports error %d", errno);
-					else ttyputmsg("SPICE execution terminated");
-		} else ttyputmsg("SPICE execution complete");
+				ttyputmsg(_("SPICE execution reports error %d"), errno);
+					else ttyputmsg(_("SPICE execution terminated"));
+		} else ttyputmsg(_("SPICE execution complete"));
 		sim_process = -1;
 	}
 }
@@ -755,7 +755,7 @@ char *sim_window_nextsignals(void)
 }
 
 static COMCOMP sim_window_picktrace = {NOKEYWORD, sim_window_topofsignals,
-	sim_window_nextsignals, NOPARAMS, NOBACKUP, 0, " \t", "pick a signal to display", ""};
+	sim_window_nextsignals, NOPARAMS, NOBACKUP, 0, " \t", N_("pick a signal to display"), ""};
 
 /*
  * routine to display the numbers in "sim_window_numbers".  For each entry of the
@@ -788,9 +788,8 @@ INTSML sim_spice_plotvalues(INTSML important)
 	if (plotnp != NONODEPROTO)
 	{
 		(void)initinfstr();
-		(void)addstringtoinfstr("Is this a simulation of facet ");
-		(void)addstringtoinfstr(describenodeproto(plotnp));
-		(void)addstringtoinfstr("? ");
+		(void)formatinfstr(_("Is this a simulation of facet %s?"),
+			describenodeproto(plotnp));
 		i = ttygetparam(returninfstr(), &us_yesnop, 3, pars);
 		if (i == 1)
 		{
@@ -801,7 +800,8 @@ INTSML sim_spice_plotvalues(INTSML important)
 	/* one final chance to pick a facet */
 	if (plotnp == NONODEPROTO)
 	{
-		i = ttygetparam("Please select a facet to associate with this plot: ", &us_showdp, 3, pars);
+		i = ttygetparam(_("Please select a facet to associate with this plot: "),
+			&us_showdp, 3, pars);
 		if (i > 0) plotnp = getnodeproto(pars[0]);
 	}
 	if (plotnp == NONODEPROTO) return(1);
@@ -912,11 +912,11 @@ INTSML sim_spice_charhandlerschem(WINDOWPART *w, INTSML chr)
 	switch (chr)
 	{
 		case '?':		/* help */
-			ttyputmsg("These keys may be typed in the SPICE Schematic window:");
-			ttyputmsg(" d    move down the hierarchy");
-			ttyputmsg(" u    move up the hierarchy");
-			ttyputmsg(" o    overlay selected network on top of current signal line");
-			ttyputmsg(" a    add selected network to simulation window");
+			ttyputmsg(_("These keys may be typed in the SPICE Schematic window:"));
+			ttyputinstruction(" d", 6, _("move down the hierarchy"));
+			ttyputinstruction(" u", 6, _("move up the hierarchy"));
+			ttyputinstruction(" o", 6, _("overlay selected network on top of current signal line"));
+			ttyputinstruction(" a", 6, _("add selected network to simulation window"));
 			return(0);
 		case 'a':		/* add trace */
 			sim_window_addhighlightednet(0);
@@ -946,17 +946,17 @@ INTSML sim_spice_charhandlerwave(WINDOWPART *w, INTSML chr)
 	switch (chr)
 	{
 		case '?':		/* help */
-			ttyputmsg("These keys may be typed in the SPICE Waveform window:");
-			ttyputmsg(" 9    show entire vertical range");
-			ttyputmsg(" 7    zoom vertical range in");
-			ttyputmsg(" 0    zoom vertical range out");
-			ttyputmsg(" 8    shift vertical range up");
-			ttyputmsg(" 2    shift vertical range down");
-			ttyputmsg(" i    show value of selected signal at main cursor");
-			ttyputmsg(" a    add signal to simulation window");
-			ttyputmsg(" o    overlay signal on top of current signal line");
-			ttyputmsg(" r    remove selected signal from simulation window");
-			ttyputmsg(" s    save snapshot of simulation window in database");
+			ttyputmsg(_("These keys may be typed in the SPICE Waveform window:"));
+			ttyputinstruction(" 9", 6, _("show entire vertical range"));
+			ttyputinstruction(" 7", 6, _("zoom vertical range in"));
+			ttyputinstruction(" 0", 6, _("zoom vertical range out"));
+			ttyputinstruction(" 8", 6, _("shift vertical range up"));
+			ttyputinstruction(" 2", 6, _("shift vertical range down"));
+			ttyputinstruction(" i", 6, _("show value of selected signal at main cursor"));
+			ttyputinstruction(" a", 6, _("add signal to simulation window"));
+			ttyputinstruction(" o", 6, _("overlay signal on top of current signal line"));
+			ttyputinstruction(" r", 6, _("remove selected signal from simulation window"));
+			ttyputinstruction(" s", 6, _("save snapshot of simulation window in database"));
 			return(0);
 		case '9':		/* show entire vertical range */
 			sim_window_getanaextents(&low, &high);
@@ -1001,13 +1001,13 @@ INTSML sim_spice_charhandlerwave(WINDOWPART *w, INTSML chr)
 			time = sim_window_getmaincursor();
 			v = sim_window_getanatracevalue(tr, time);
 			sim_windowconvertengineeringnotation(time, s2);
-			ttyputmsg("Signal %s has value %g at time %s", sim_window_gettracename(tr), v, s2);
+			ttyputmsg(_("Signal %s has value %g at time %s"), sim_window_gettracename(tr), v, s2);
 			return(0);
 		case 's':		/* save image in {simulation_snapshot} view */
 			sim_window_savegraph();
 			return(0);
 		case 'a':		/* add trace */
-			i = ttygetparam("Signal to add", &sim_window_picktrace, 3, par);
+			i = ttygetparam(_("Signal to add"), &sim_window_picktrace, 3, par);
 			if (i == 0) return(0);
 			i = (INTSML)sim_window_findsignalname(par[0]);
 			if (i < 0) return(0);
@@ -1038,7 +1038,7 @@ INTSML sim_spice_charhandlerwave(WINDOWPART *w, INTSML chr)
 			tr = sim_window_gethighlighttrace();
 			if (tr == 0) return(0);
 			thispos = sim_window_gettraceline(tr);
-			i = ttygetparam("Signal to overlay", &sim_window_picktrace, 3, par);
+			i = ttygetparam(_("Signal to overlay"), &sim_window_picktrace, 3, par);
 			if (i == 0) return(0);
 			i = (INTSML)sim_window_findsignalname(par[0]);
 			if (i < 0) return(0);
@@ -1102,37 +1102,37 @@ void sim_window_addhighlightednet(INTSML overlay)
 
 	if ((sim_window_isactive(&np) & SIMWINDOWWAVEFORM) == 0)
 	{
-		ttyputerr("Not displaying a waveform");
+		ttyputerr(_("Not displaying a waveform"));
 		return;
 	}
 
 	ai = (ARCINST *)askaid(us_aid, "get-arc");
 	if (ai == NOARCINST)
 	{
-		ttyputerr("Select an arc first");
+		ttyputerr(_("Select an arc first"));
 		return;
 	}
 	if (ai->network == NONETWORK)
 	{
-		ttyputerr("This arc has no network information");
+		ttyputerr(_("This arc has no network information"));
 		return;
 	}
 	pt = sim_spice_signalname(ai->network);
 	if (pt == 0)
 	{
-		ttyputerr("Cannot get SPICE signal for network %s", pt);
+		ttyputerr(_("Cannot get SPICE signal for network %s"), pt);
 		return;
 	}
 	i = sim_window_findsignalname(pt);
 	if (i < 0)
 	{
-		ttyputerr("Cannot find network %s in the simulation data", pt);
+		ttyputerr(_("Cannot find network %s in the simulation data"), pt);
 		return;
 	}
 
 	if (sim_window_findtrace(sim_window_signames[i]) != 0)
 	{
-		ttyputerr("Signal %s is already being displayed", sim_window_signames[i]);
+		ttyputerr(_("Signal %s is already being displayed"), sim_window_signames[i]);
 		return;
 	}
 
@@ -1296,7 +1296,7 @@ char *sim_spice_signalname(NETWORK *net)
 		varname = getvalkey((INTBIG)ni, VNODEINST, VSTRING, el_node_name);
 		if (varname == 0)
 		{
-			ttyputerr("Back annotation is missing");
+			ttyputerr(_("Back annotation is missing"));
 			return(0);
 		}
 		(void)initinfstr();
@@ -1314,7 +1314,7 @@ char *sim_spice_signalname(NETWORK *net)
 	(void)initinfstr();
 	(void)addstringtoinfstr(prevstr);
 	if (*prevstr != 0) (void)addtoinfstr('.');
-	if (net->namecount <= 0) (void)addstringtoinfstr("?"); else
+	if (net->namecount <= 0) (void)addstringtoinfstr(describenetwork(net)); else
 		(void)addstringtoinfstr(net->netname);
 	return(returninfstr());
 }
