@@ -45,7 +45,7 @@ static KEYWORD artopt[] =
 	TERMKEY
 };
 COMCOMP art_parse = {artopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, 0, " \t", "ARTWORK option", "show current option"};
+	NOBACKUP, 0, " \t", M_("ARTWORK option"), M_("show current option")};
 
 
 TECHNOLOGY *art_tech;
@@ -183,7 +183,8 @@ static TECH_NODES art_pin = {
 
 /* Box */
 static TECH_PORTS art_box_p[] = {					/* ports */
-	{art_pc_d, "box",    NOPORTPROTO, (180<<PORTANGLESH),  LEFTEDGE,  TOPEDGE, RIGHTEDGE, BOTEDGE}};
+	{art_pc_d, "box",    NOPORTPROTO, (180<<PORTANGLESH),
+		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_box_l[] = {					/* layers */
 	{LOPAQUE, -1, 4, CLOSEDRECT, BOX, art_fullbox}};
 static TECH_NODES art_box = {
@@ -196,7 +197,8 @@ static TECH_NODES art_box = {
 
 /* Crossed Box */
 static TECH_PORTS art_cbox_p[] = {					/* ports */
-	{art_pc_d, "fbox",    NOPORTPROTO, (180<<PORTANGLESH),  LEFTEDGE,  TOPEDGE, RIGHTEDGE, BOTEDGE}};
+	{art_pc_d, "fbox",    NOPORTPROTO, (180<<PORTANGLESH),
+		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_cbox_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, CROSSED, BOX, art_fullbox}};
 static TECH_NODES art_cbox = {
@@ -209,7 +211,8 @@ static TECH_NODES art_cbox = {
 
 /* Filled Box */
 static TECH_PORTS art_fbox_p[] = {					/* ports */
-	{art_pc_d, "fbox",    NOPORTPROTO, (180<<PORTANGLESH),  LEFTEDGE,  TOPEDGE, RIGHTEDGE, BOTEDGE}};
+	{art_pc_d, "fbox",    NOPORTPROTO, (180<<PORTANGLESH),
+		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_fbox_l[] = {				/* layers */
 	{LOPAQUE, -1, 4, FILLEDRECT, BOX, art_fullbox}};
 static TECH_NODES art_fbox = {
@@ -264,7 +267,8 @@ static TECH_NODES art_spline = {
 
 /* Triangle */
 static TECH_PORTS art_triangle_p[] = {				/* ports */
-	{art_pc_d, "triangle",    NOPORTPROTO, (180<<PORTANGLESH),  LEFTEDGE,  TOPEDGE, RIGHTEDGE, BOTEDGE}};
+	{art_pc_d, "triangle",    NOPORTPROTO, (180<<PORTANGLESH),
+		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_triangle_l[] = {			/* layers */
 	{LOPAQUE, -1, 3, CLOSED, POINTS, art_tri}};
 static TECH_NODES art_triangle = {
@@ -277,7 +281,8 @@ static TECH_NODES art_triangle = {
 
 /* Filled Triangle */
 static TECH_PORTS art_ftriangle_p[] = {				/* ports */
-	{art_pc_d, "ftriangle",    NOPORTPROTO, (180<<PORTANGLESH),  LEFTEDGE,  TOPEDGE, RIGHTEDGE, BOTEDGE}};
+	{art_pc_d, "ftriangle",    NOPORTPROTO, (180<<PORTANGLESH),
+		LEFTEDGE, TOPEDGE, RIGHTEDGE, BOTEDGE}};
 static TECH_POLYGON art_ftriangle_l[] = {			/* layers */
 	{LOPAQUE, -1, 3, FILLED, POINTS, art_tri}};
 static TECH_NODES art_ftriangle = {
@@ -467,8 +472,8 @@ void art_setmode(INTSML count, char *par[])
 	if (count == 0)
 	{
 		if (art_arrow.layercount == 2)
-			ttyputmsg("Artwork arrow heads are filled"); else
-				ttyputmsg("Artwork arrow heads are outlines");
+			ttyputmsg(_("Artwork arrow heads are filled")); else
+				ttyputmsg(_("Artwork arrow heads are outlines"));
 		return;
 	}
 
@@ -477,17 +482,17 @@ void art_setmode(INTSML count, char *par[])
 	{
 		/* set the arrow heads to be fancy */
 		art_setstate(art_state | ARTWORKFILLARROWHEADS);
-		ttyputverbose("Artwork arrow heads will be filled");
+		ttyputverbose(_("Artwork arrow heads will be filled"));
 		return;
 	}
 	if (namesamen(pp, "arrows-outline", l) == 0)
 	{
 		/* set the arrow heads to be simple */
 		art_setstate(art_state & ~ARTWORKFILLARROWHEADS);
-		ttyputverbose("Artwork arrow heads will be outline");
+		ttyputverbose(_("Artwork arrow heads will be outline"));
 		return;
 	}
-	ttyputerr("Unknown ARTWORK option: %s", pp);
+	ttyputbadusage("technology tell artwork");
 }
 
 INTBIG art_request(char *command, va_list ap)
@@ -523,9 +528,9 @@ void art_setstate(INTBIG newstate)
 	}
 }
 
-INTSML art_nodepolys(NODEINST *ni)
+INTBIG art_nodepolys(NODEINST *ni, INTBIG *reasonable)
 {
-	REGISTER INTSML pindex, count;
+	REGISTER INTBIG pindex, count;
 
 	pindex = ni->proto->primindex;
 
@@ -540,18 +545,20 @@ INTSML art_nodepolys(NODEINST *ni)
 	/* add in displayable variables */
 	tech_realpolys = count;
 	count += tech_displayablenvars(ni);
+	if (reasonable != 0) *reasonable = count;
 	return(count);
 }
 
-INTSML art_nodeEpolys(NODEINST *ni)
+INTBIG art_nodeEpolys(NODEINST *ni, INTBIG *reasonable)
 {
+	if (reasonable != 0) *reasonable = 0;
 	return(0);
 }
 
-void art_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
+void art_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML pindex, sty;
-	REGISTER INTBIG dist, cx, cy, sx, sy, count;
+	REGISTER INTSML sty;
+	REGISTER INTBIG pindex, dist, cx, cy, sx, sy, count;
 	REGISTER VARIABLE *var;
 	double startoffset, endangle;
 	INTBIG dummypoints[8];
@@ -574,7 +581,7 @@ void art_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			} else
 			{
 				tech_fillpoly(poly, &art_nodeprotos[pindex-1]->layerlist[box], ni,
-					art_tech->deflambda, FILLED);
+					lambdaofnode(ni), FILLED);
 
 				/* if there is arc information here, make it an arc of a circle */
 				if (startoffset != 0.0 || endangle != 0.0)
@@ -621,7 +628,7 @@ void art_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 			}
 
 			tech_fillpoly(poly, &art_nodeprotos[pindex-1]->layerlist[box], ni,
-				art_tech->deflambda, sty);
+				lambdaofnode(ni), sty);
 		}
 	}
 
@@ -633,7 +640,7 @@ void art_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 	poly->desc->bits = (INTSML)art_bits;
 }
 
-void art_shapeEnodepoly(NODEINST *ni, INTSML box, POLYGON *poly) {}
+void art_shapeEnodepoly(NODEINST *ni, INTBIG box, POLYGON *poly) {}
 
 void art_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	INTSML purpose)
@@ -648,14 +655,14 @@ void art_shapeportpoly(NODEINST *ni, PORTPROTO *pp, POLYGON *poly, XARRAY trans,
 	}
 
 	/* just use first graphic polygon as the port */
-	(void)art_nodepolys(ni);
+	(void)art_nodepolys(ni, 0);
 	art_shapenodepoly(ni, 0, poly);
 	xformpoly(poly, trans);
 }
 
-INTSML art_arcpolys(ARCINST *ai)
+INTBIG art_arcpolys(ARCINST *ai)
 {
-	REGISTER INTSML def;
+	REGISTER INTBIG def;
 
 	art_getgraphics((INTBIG)ai, VARCINST);
 
@@ -667,9 +674,9 @@ INTSML art_arcpolys(ARCINST *ai)
 	return(def);
 }
 
-void art_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void art_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML aindex;
+	REGISTER INTBIG aindex;
 	REGISTER INTBIG realwid;
 	REGISTER TECH_ARCLAY *thista;
 
@@ -683,7 +690,7 @@ void art_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 	/* handle curved arcs */
 	aindex = ai->proto->arcindex;
 	thista = &art_arcprotos[aindex]->list[0];
-	realwid = ai->width - thista->off*art_tech->deflambda/WHOLE;
+	realwid = ai->width - thista->off*lambdaofarc(ai)/WHOLE;
 	if (tech_curvedarcpiece(ai, box, poly, art_arcprotos) != 0)
 	{
 		/* standard arc: compute polygon in normal way */
@@ -741,7 +748,7 @@ void art_getgraphics(INTBIG addr, INTBIG type)
 		if (getlength(art_patternvar) != 8 ||
 			((art_patternvar->type&VTYPE) != VINTEGER && (art_patternvar->type&VTYPE) != VSHORT))
 		{
-			ttyputerr("'ART_pattern' must be an 8-member INTEGER or SHORT array");
+			ttyputerr(_("'ART_pattern' must be an 8-member INTEGER or SHORT array"));
 			art_patternvar = NOVARIABLE;
 			return;
 		}
