@@ -38,10 +38,10 @@
 #include "efunction.h"
 
 /* prototypes for local routines */
-void gem_addtailplus(POLYGON*, INTSML, INTBIG*, INTBIG*);
-void gem_addheadplus(POLYGON*, INTSML, INTBIG*, INTBIG*);
+void gem_addtailplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
+void gem_addheadplus(POLYGON*, INTSML, INTBIG*, INTBIG*, INTBIG);
 void gem_add1linebody(POLYGON*, INTBIG, INTBIG, INTBIG, INTBIG);
-void gem_addzigzagbody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG);
+void gem_addzigzagbody(POLYGON*, INTSML, INTBIG, INTBIG, INTBIG, INTBIG, INTBIG);
 
 static TECHNOLOGY *gem_tech;
 
@@ -328,11 +328,11 @@ INTSML gem_initprocess(TECHNOLOGY *tech, INTSML pass)
 	return(0);
 }
 
-void gem_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
+void gem_shapenodepoly(NODEINST *ni, INTBIG box, POLYGON *poly)
 {
 	REGISTER TECH_POLYGON *lay;
 	REGISTER VARIABLE *var;
-	REGISTER INTSML pindex;
+	REGISTER INTBIG pindex;
 	static INTBIG element = 0, event1 = 0, event2 = 0, event3 = 0, event4 = 0;
 
 	/* handle displayable variables */
@@ -344,7 +344,7 @@ void gem_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 
 	pindex = ni->proto->primindex;
 	lay = &gem_nodeprotos[pindex-1]->layerlist[box];
-	tech_fillpoly(poly, lay, ni, ni->proto->tech->deflambda, CLOSED);
+	tech_fillpoly(poly, lay, ni, lambdaofnode(ni), CLOSED);
 	poly->desc = gem_layers[poly->layer];
 
 	if (box == 0) return;
@@ -379,10 +379,10 @@ void gem_shapenodepoly(NODEINST *ni, INTSML box, POLYGON *poly)
 	if (var != NOVARIABLE) poly->string = (char *)var->addr;
 }
 
-void gem_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
+void gem_shapearcpoly(ARCINST *ai, INTBIG box, POLYGON *poly)
 {
-	REGISTER INTSML aindex, angle;
-	REGISTER INTBIG i, dist;
+	REGISTER INTSML angle;
+	REGISTER INTBIG aindex, i, dist, lambda;
 	INTBIG x1, y1, x2, y2;
 	REGISTER TECH_ARCLAY *thista;
 
@@ -399,6 +399,7 @@ void gem_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 	poly->style = thista->style;
 	poly->desc = gem_layers[poly->layer];
 	poly->count = 0;
+	lambda = lambdaofarc(ai);
 	x1 = ai->end[0].xpos;   y1 = ai->end[0].ypos;
 	x2 = ai->end[1].xpos;   y2 = ai->end[1].ypos;
 	angle = (INTSML)(((ai->userbits&AANGLE) >> AANGLESH) * 10);
@@ -420,15 +421,15 @@ void gem_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 			/* prerequisite arc has an arrow at the head */
 			gem_add1linebody(poly, x1,y1, x2,y2);
 			if ((ai->userbits&NOTEND1) == 0)
-				tech_addheadarrow(poly, angle, x2,y2);
+				tech_addheadarrow(poly, angle, x2,y2, lambda);
 			break;
 
 		case AFORK:
 			/* fork arc has an arrow at the head and a "+" at the tail */
 			if ((ai->userbits&NOTEND0) == 0)
-				gem_addtailplus(poly, angle, &x1,&y1);
+				gem_addtailplus(poly, angle, &x1,&y1, lambda);
 			if ((ai->userbits&NOTEND1) == 0)
-				tech_addheadarrow(poly, angle, x2,y2);
+				tech_addheadarrow(poly, angle, x2,y2, lambda);
 			gem_add1linebody(poly, x1,y1, x2,y2);
 			break;
 
@@ -436,15 +437,15 @@ void gem_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 			/* nondeterministic arc has an arrow and a "+" at the head */
 			if ((ai->userbits&NOTEND1) == 0)
 			{
-				gem_addheadplus(poly, angle, &x2,&y2);
-				tech_addheadarrow(poly, angle, x2,y2);
+				gem_addheadplus(poly, angle, &x2,&y2, lambda);
+				tech_addheadarrow(poly, angle, x2,y2, lambda);
 			}
 			gem_add1linebody(poly, x1,y1, x2,y2);
 			break;
 
 		case ATEMP:
 			/* temporal arc has a double-line with an arrow head */
-			dist = H0 * gem_tech->deflambda / WHOLE;
+			dist = H0 * lambda / WHOLE;
 			if ((ai->userbits&NOTEND1) == 0)
 				tech_adddoubleheadarrow(poly, angle, &x2,&y2, dist);
 			tech_add2linebody(poly, angle, x1,y1, x2,y2, dist);
@@ -452,7 +453,7 @@ void gem_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
 
 		case ACAUSE:
 			/* causal arc has zig-zag body */
-			gem_addzigzagbody(poly, angle, x1,y1, x2,y2);
+			gem_addzigzagbody(poly, angle, x1,y1, x2,y2, lambda);
 			break;
 	}
 }
@@ -461,14 +462,14 @@ void gem_shapearcpoly(ARCINST *ai, INTSML box, POLYGON *poly)
  * helper routine to add a "+" to the tail of the arc in "poly", given that
  * the arc runs to (x,y) and is at an angle of "angle" tenth-degrees
  */
-void gem_addtailplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y)
+void gem_addtailplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG lambda)
 {
 	REGISTER INTBIG sin, cos, dist, threehalfdist, twicedist;
 	REGISTER INTSML c;
 
 	c = poly->count;
 	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
-	dist = K1 * gem_tech->deflambda / WHOLE;
+	dist = K1 * lambda / WHOLE;
 	threehalfdist = dist + dist / 2;
 	twicedist = dist * 2;
 	sin = sine(angle);
@@ -488,14 +489,14 @@ void gem_addtailplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y)
  * helper routine to add a "+" to the head of the arc in "poly", given that
  * the arc runs from (x,y) and is at an angle of "angle" tenth-degrees
  */
-void gem_addheadplus(POLYGON *poly, INTSML angle, INTBIG *x,INTBIG *y)
+void gem_addheadplus(POLYGON *poly, INTSML angle, INTBIG *x, INTBIG *y, INTBIG lambda)
 {
 	REGISTER INTSML c;
 	REGISTER INTBIG sin, cos, dist, threehalfdist, twicedist;
 
 	c = poly->count;
 	if (poly->limit < c+4) (void)extendpolygon(poly, (INTSML)(c+4));
-	dist = K1 * gem_tech->deflambda / WHOLE;
+	dist = K1 * lambda / WHOLE;
 	threehalfdist = dist + dist / 2;
 	twicedist = dist * 2;
 	sin = sine((INTSML)((angle+1800) % 3600));
@@ -530,7 +531,8 @@ void gem_add1linebody(POLYGON *poly, INTBIG x1, INTBIG y1, INTBIG x2, INTBIG y2)
  * helper routine to add a zig-zag body to the arc in "poly", given that
  * the arc runs from (x1,y1) to (x2,y2) and is at an angle of "angle" tenth-degrees.
  */
-void gem_addzigzagbody(POLYGON *poly, INTSML angle, INTBIG x1,INTBIG y1, INTBIG x2,INTBIG y2)
+void gem_addzigzagbody(POLYGON *poly, INTSML angle, INTBIG x1, INTBIG y1,
+	INTBIG x2, INTBIG y2, INTBIG lambda)
 {
 	REGISTER INTBIG xc, yc, dist;
 	REGISTER INTSML c;
@@ -540,7 +542,7 @@ void gem_addzigzagbody(POLYGON *poly, INTSML angle, INTBIG x1,INTBIG y1, INTBIG
 
 	c = poly->count;
 	if (poly->limit < c+6) (void)extendpolygon(poly, (INTSML)(c+6));
-	dist = K1 * gem_tech->deflambda / WHOLE;
+	dist = K1 * lambda / WHOLE;
 	poly->xv[c] = x1;   poly->yv[c] = y1;   c++;
 	poly->xv[c] = poly->xv[c+1] = xc + mult(cosine((INTSML)((angle+900) % 3600)), dist);
 	poly->yv[c] = poly->yv[c+1] = yc + mult(sine((INTSML)((angle+900) % 3600)), dist);
