@@ -164,7 +164,7 @@ TECHNOLOGY el_technologylist[] =
 {
 	/* Generic */
 	{"generic", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"Miscellaneous interconnect, constraint, and glyph",							/* description */
+	N_("Miscellaneous interconnect, constraint, and glyph"),						/* description */
 	0, gen_layers, 0, gen_arcprotos, 0, gen_nodeprotos, gen_variables,				/* tables */
 	gen_initprocess, gen_termprocess, 0, 0, 0,										/* control routines */
 	gen_nodepolys, gen_nodepolys, gen_shapenodepoly, gen_shapenodepoly, 0,			/* node routines */
@@ -175,7 +175,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECNMOS
 	/* NMOS */
 	{"nmos", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
-	"n-channel MOS (from Mead & Conway)",											/* description */
+	N_("n-channel MOS (from Mead & Conway)"),										/* description */
 	0, nmos_layers, 0, nmos_arcprotos, 0, nmos_nodeprotos, nmos_variables,			/* tables */
 	nmos_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -187,7 +187,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECCMOS
 	/* CMOS */
 	{"cmos", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
-	"Complementary MOS (from Griswold, N-Well)",									/* description */
+	N_("Complementary MOS (from Griswold, N-Well)"),								/* description */
 	0, cmos_layers, 0, cmos_arcprotos, 0, cmos_nodeprotos, cmos_variables,			/* tables */
 	cmos_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -199,7 +199,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECMOCMOS
 	/* MOSIS CMOS */
 	{"mocmos", 0, 2000,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmos_parse,NOCLUSTER,	/* info */
-	"Complementary MOS (from MOSIS, P-Well, double metal)",							/* description */
+	N_("Complementary MOS (from MOSIS, P-Well, double metal)"),						/* description */
 	0, mocmos_layers, 0, mocmos_arcprotos, 0, mocmos_nodeprotos, mocmos_variables,	/* tables */
 	mocmos_initprocess, 0, mocmos_setmode, 0, 0,									/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -210,8 +210,8 @@ TECHNOLOGY el_technologylist[] =
 
 #if TECMOCMOSSUB
 	/* MOSIS CMOS Submicron */
-	{"mocmossub", 0, 400,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmossub_parse,NOCLUSTER,		/* info */
-	"Complementary MOS (from MOSIS, Submicron, P-Well, quad metal, double poly)",	/* description */
+	{"mocmossub", 0, 400,NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&mocmossub_parse,NOCLUSTER,/* info */
+	N_("Complementary MOS (from MOSIS, Submicron, quad metal, double poly)"),		/* description */
 	0, mocmossub_layers, 0, mocmossub_arcprotos, 0, mocmossub_nodeprotos, mocmossub_variables,	/* tables */
 	mocmossub_initprocess, 0, mocmossub_setmode, mocmossub_request, 0,				/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -223,7 +223,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECMOCMOS2
 	/* MOSIS CMOS, 2 micron */
 	{"mocmos2", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"Complementary MOS (MOSIS, Orbit, P-Well, double metal, double poly)",			/* description */
+	N_("Complementary MOS (MOSIS, Orbit, P-Well, double metal, double poly)"),		/* description */
 	0, mocmos2_layers, 0, mocmos2_arcprotos, 0, mocmos2_nodeprotos, mocmos2_variables,	/* tables */
 	mocmos2_initprocess, 0, 0, 0, 0,												/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -235,7 +235,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECBICMOS
 	/* MOSIS BiCMOS */
 	{"bicmos", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"MOSIS BiCMOS (N-Well, 2u, SCE Rules)",											/* description */
+	N_("MOSIS BiCMOS (N-Well, 2u, SCE Rules)"),										/* description */
 	0, bicmos_layers, 0, bicmos_arcprotos, 0, bicmos_nodeprotos, bicmos_variables,	/* tables */
 	bicmos_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -247,7 +247,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECRCMOS
 	/* Round MOSIS CMOS */
 	{"rcmos", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
-	"Complementary MOS (round, from MOSIS, P-Well, double metal)",					/* description */
+	N_("Complementary MOS (round, from MOSIS, P-Well, double metal)"),				/* description */
 	0, rcmos_layers, 0, rcmos_arcprotos, 0, rcmos_nodeprotos, rcmos_variables,		/* tables */
 	rcmos_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -259,7 +259,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECCMOSDODN
 	/* DOD CMOS (from Gary Lambert) */
 	{"cmosdodn", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"DODCmosN, lambda rules: PWell, 1 Poly, 2 Metal",								/* description */
+	N_("DODCmosN, lambda rules: PWell, 1 Poly, 2 Metal"),							/* description */
 	0, dodcmosn_layers, 0, dodcmosn_arcprotos, 0, dodcmosn_nodeprotos, dodcmosn_variables,	/* tables */
  	dodcmosn_initprocess, 0, 0, 0, 0,												/* control routines */
 	0, 0, dodcmosn_shapenodepoly, 0, 0,												/* node routines */
@@ -271,7 +271,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECBIPOLAR
 	/* bipolar */
 	{"bipolar", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"Self-Aligned Single Poly Bipolar",												/* description */
+	N_("Self-Aligned Single Poly Bipolar"),											/* description */
 	0, bipolar_layers, 0, bipolar_arcprotos, 0, bipolar_nodeprotos, bipolar_variables,	/* tables */
 	bipolar_initprocess, 0, 0, 0, 0,												/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -282,7 +282,7 @@ TECHNOLOGY el_technologylist[] =
 
 	/* Schematic capture */
 	{"schematic", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&sch_parse,NOCLUSTER,/* info */
-	"Schematic Capture",															/* description */
+	N_("Schematic Capture"),														/* description */
 	0, sch_layers, 0, sch_arcprotos, 0, sch_nodeprotos, sch_variables,				/* tables */
 	sch_initprocess, sch_termprocess, sch_setmode, sch_request, 0,					/* control routines */
 	sch_nodepolys, sch_nodeEpolys, sch_shapenodepoly, sch_shapeEnodepoly, 0,		/* node routines */
@@ -293,7 +293,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECFPGA
 	/* FPGA */
 	{"fpga", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&fpga_parse,NOCLUSTER,	/* info */
-	"FPGA Building-Blocks",															/* description */
+	N_("FPGA Building-Blocks"),														/* description */
 	0, fpga_layers, 0, fpga_arcprotos, 0, fpga_nodeprotos, fpga_variables,			/* tables */
 	fpga_initprocess, fpga_termprocess, fpga_setmode, 0, 0,							/* control routines */
 	fpga_nodepolys, fpga_nodeEpolys, fpga_shapenodepoly, fpga_shapeEnodepoly, 0,	/* node routines */
@@ -305,7 +305,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECPCB
 	/* Printed Circuit Board */
 	{"pcb", 0, 2540000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"Eight-Layer Printed Circuit Board",											/* description */
+	N_("Eight-Layer Printed Circuit Board"),										/* description */
 	0, pcb_layers, 0, pcb_arcprotos, 0, pcb_nodeprotos, pcb_variables,				/* tables */
 	pcb_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
@@ -315,8 +315,8 @@ TECHNOLOGY el_technologylist[] =
 #endif
 
 	/* Artwork */
-	{"artwork", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&art_parse,NOCLUSTER,	/* info */
-	"General Purpose Sketchpad Facility",											/* description */
+	{"artwork", 0, 4000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,&art_parse,NOCLUSTER,	/* info */
+	N_("General Purpose Sketchpad Facility"),										/* description */
 	0, art_layers, 0, art_arcprotos, 0, art_nodeprotos, art_variables,				/* tables */
 	art_initprocess, 0, art_setmode, art_request, 0,								/* control routines */
 	art_nodepolys, art_nodeEpolys, art_shapenodepoly, art_shapeEnodepoly, 0,		/* node routines */
@@ -327,7 +327,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECGEM
 	/* Gem Planning */
 	{"gem", 0, 2000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,		/* info */
-	"Group Element Model (from Lansky)",											/* description */
+	N_("Group Element Model (from Lansky)"),										/* description */
 	0, gem_layers, 0, gem_arcprotos, 0, gem_nodeprotos, gem_variables,				/* tables */
 	gem_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, gem_shapenodepoly, 0, 0,													/* node routines */
@@ -339,7 +339,7 @@ TECHNOLOGY el_technologylist[] =
 #if TECEFIDO
 	/* Digital Filter */
 	{"efido", 0, 20000, NONODEPROTO,NOARCPROTO,NOVARIABLE,0,NOCOMCOMP,NOCLUSTER,	/* info */
-	"Digital Filter Facility (from Kroeker)",										/* description */
+	N_("Digital Filter Facility (from Kroeker)"),									/* description */
 	0, efido_layers, 0, efido_arcprotos, 0, efido_nodeprotos, efido_variables,		/* tables */
 	efido_initprocess, 0, 0, 0, 0,													/* control routines */
 	0, 0, 0, 0, 0,																	/* node routines */
