@@ -44,7 +44,6 @@ ARCINST *us_onebend(NODEINST*, PORTPROTO*, NODEINST*, PORTPROTO*, ARCPROTO*, INT
 ARCINST *us_twobend(NODEINST*, PORTPROTO*, NODEINST*, PORTPROTO*, ARCPROTO*, INTBIG, INTBIG,
 	INTBIG, ARCINST**, ARCINST**);
 INTBIG us_widestarcinst(ARCPROTO*, NODEINST*, PORTPROTO*);
-NODEINST *us_getnodeonarcinst(GEOM**, PORTPROTO**, GEOM*, PORTPROTO*, INTBIG, INTBIG);
 INTBIG us_portdistance(NODEINST*, PORTPROTO*, INTBIG, INTBIG, INTBIG*, INTBIG*, INTBIG, INTSML);
 INTSML us_fitportangle(NODEINST*, PORTPROTO*, INTSML, INTSML);
 INTBIG us_figurearcwidth(ARCPROTO *typ, INTBIG wid, NODEINST *ni1, PORTPROTO *pp1,
@@ -82,7 +81,7 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 	/* error check */
 	if (fromgeom == togeom && fromgeom->entrytype != OBJNODEINST)
 	{
-		us_abortcommand("Cannot run from arc to itself");
+		us_abortcommand(_("Cannot run from arc to itself"));
 		return(NOARCINST);
 	}
 
@@ -126,14 +125,14 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 	fromnodeinst = us_getnodeonarcinst(&fromgeom, &frompp, togeom, topp, prefx, prefy);
 	if (fromnodeinst == NONODEINST)
 	{
-		us_abortcommand("Cannot create splitting pin");
+		us_abortcommand(_("Cannot create splitting pin"));
 		return(NOARCINST);
 	}
 
 	tonodeinst = us_getnodeonarcinst(&togeom, &topp, fromgeom, frompp, prefx, prefy);
 	if (tonodeinst == NONODEINST)
 	{
-		us_abortcommand("Cannot create splitting pin");
+		us_abortcommand(_("Cannot create splitting pin"));
 		return(NOARCINST);
 	}
 
@@ -149,9 +148,8 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 	if (fromnodeinst == tonodeinst && frompp == topp)
 	{
 		(void)initinfstr();
-		(void)addstringtoinfstr("Are you sure you want to run an arc from node ");
-		(void)addstringtoinfstr(describenodeinst(fromnodeinst));
-		(void)addstringtoinfstr(" to itself?");
+		(void)formatinfstr(_("Are you sure you want to run an arc from node %s to itself?"),
+			describenodeinst(fromnodeinst));
 		ans = ttygetparam(returninfstr(), &us_noyesp, 1, result);
 		if (ans <= 0 || (result[0][0] != 'y' && result[0][0] != 'Y')) return(NOARCINST);
 	}
@@ -187,7 +185,7 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 	/* if no common ports, don't run the arcinst */
 	if (t == 0)
 	{
-		us_abortcommand("Cannot find arc that connects %s to %s", geomname(fromgeom),
+		us_abortcommand(_("Cannot find arc that connects %s to %s"), geomname(fromgeom),
 			geomname(togeom));
 		return(NOARCINST);
 	}
@@ -238,7 +236,7 @@ ARCINST *aconnect(GEOM *fromgeom, PORTPROTO *frompp, GEOM *togeom, PORTPROTO *to
 			if (newai != NOARCINST) return(newai);
 		}
 	}
-	us_abortcommand("There is no way to connect these objects");
+	us_abortcommand(_("There is no way to connect these objects"));
 	return(NOARCINST);
 }
 
@@ -250,7 +248,7 @@ TECHNOLOGY *us_gettech(NODEINST *ni, PORTPROTO *pp)
 	for(;;)
 	{
 		if (ni->proto->primindex != 0) break;
-		if (pp == NOPORTPROTO) return(whattech(ni->proto));
+		if (pp == NOPORTPROTO) break;
 		ni = pp->subnodeinst;
 		pp = pp->subportproto;
 	}
@@ -650,7 +648,7 @@ ARCINST *us_directarcinst(NODEINST *fromnodeinst, PORTPROTO *fromppt,
 	{
 		ai = us_runarcinst(fromnodeinst, fromportproto, bestfx, bestfy, 
 			tonodeinst, toportproto, besttx, bestty, typ, wid);
-		if (ai != NOARCINST) ttyputmsg("Created 1 %s arc", typ->protoname);
+		if (ai != NOARCINST) ttyputmsg(_("Created 1 %s arc"), typ->protoname);
 		return(ai);
 	}
 
@@ -779,7 +777,7 @@ ARCINST *us_onebend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 		ft = getpinproto(typ);
 		if (ft == NONODEPROTO)
 		{
-			us_abortcommand("No pin for %s arcs", describearcproto(typ));
+			us_abortcommand(_("No pin for %s arcs"), describearcproto(typ));
 			return(NOARCINST);
 		}
 
@@ -826,7 +824,7 @@ ARCINST *us_onebend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 		ni = newnodeinst(ft, lx,hx, ly,hy, 0, 0, fromnodeinst->parent);
 		if (ni == NONODEINST)
 		{
-			us_abortcommand("Cannot create connecting pin");
+			us_abortcommand(_("Cannot create connecting pin"));
 			return(NOARCINST);
 		}
 		endobjectchange((INTBIG)ni, VNODEINST);
@@ -839,7 +837,7 @@ ARCINST *us_onebend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 		ai2 = us_runarcinst(ni, fpt, bestxi, bestyi, tonodeinst, toportproto,
 			besttx, bestty, typ, wid);
 		if (ai2 == NOARCINST) return(NOARCINST);
-		ttyputmsg("Created 2 %s arcs", typ->protoname);
+		ttyputmsg(_("Created 2 %s arcs"), typ->protoname);
 		if (abs(bestfx-bestxi)+abs(bestfy-bestyi) > abs(bestxi-besttx)+abs(bestyi-bestty))
 		{
 			*alt = ai2;
@@ -931,10 +929,10 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 	 */
 	if (((fromportproto->userbits&PORTARANGE) >> PORTARANGESH) != 180)
 	{
-		i = us_bottomrecurse(fromnodeinst, fromportproto, 0);
+		i = us_bottomrecurse(fromnodeinst, fromportproto);
 	} else if (((toportproto->userbits&PORTARANGE) >> PORTARANGESH) != 180)
 	{
-		i = us_bottomrecurse(tonodeinst, toportproto, 0);
+		i = us_bottomrecurse(tonodeinst, toportproto);
 	} else if ((prefy > bestfy && prefy > bestty) || (prefy < bestfy && prefy < bestty))
 	{
 		/* jog is horizontal if prefy is above or below both ports */
@@ -963,7 +961,7 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 	ft = getpinproto(typ);
 	if (ft == NONODEPROTO)
 	{
-		us_abortcommand("No pin for %s arcs", describearcproto(typ));
+		us_abortcommand(_("No pin for %s arcs"), describearcproto(typ));
 		return(NOARCINST);
 	}
 	defaultnodesize(ft, &pxs, &pys);
@@ -974,7 +972,7 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 	ni1 = newnodeinst(ft, lx,hx, ly,hy, 0, 0, fromnodeinst->parent);
 	if (ni1 == NONODEINST)
 	{
-		us_abortcommand("Cannot create first connecting pin");
+		us_abortcommand(_("Cannot create first connecting pin"));
 		return(NOARCINST);
 	}
 	endobjectchange((INTBIG)ni1, VNODEINST);
@@ -983,7 +981,7 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 	ni2 = newnodeinst(ft, lx,hx, ly,hy, 0, 0, fromnodeinst->parent);
 	if (ni2 == NONODEINST)
 	{
-		us_abortcommand("Cannot create second connecting pin");
+		us_abortcommand(_("Cannot create second connecting pin"));
 		return(NOARCINST);
 	}
 	endobjectchange((INTBIG)ni2, VNODEINST);
@@ -997,7 +995,7 @@ ARCINST *us_twobend(NODEINST *fromnodeinst, PORTPROTO *fromppt, NODEINST *tonode
 	if (ai == NOARCINST) return(NOARCINST);
 	*alt2 = us_runarcinst(ni2,fpt, xi2,yi2, tonodeinst, toportproto, besttx, bestty, typ, wid);
 	if (*alt2 == NOARCINST) return(NOARCINST);
-	ttyputmsg("Created 3 %s arcs", typ->protoname);
+	ttyputmsg(_("Created 3 %s arcs"), typ->protoname);
 	return(ai);
 }
 
@@ -1026,7 +1024,7 @@ ARCINST *us_runarcinst(NODEINST *fromnodeinst, PORTPROTO *fromportproto, INTBIG
 		tonodeinst, toportproto, tox, toy, fromnodeinst->parent);
 	if (ai == NOARCINST)
 	{
-		us_abortcommand("Problem creating the arc");
+		us_abortcommand(_("Problem creating the arc"));
 		return(NOARCINST);
 	}
 	ai->changed = 0;
@@ -1295,21 +1293,21 @@ NODEINST *us_getnodeonarcinst(GEOM **ipos, PORTPROTO **ipp, GEOM *othergeom,
 	ni = newnodeinst(np, lx,hx, ly,hy, 0, 0, pnt);
 	if (ni == NONODEINST)
 	{
-		ttyputerr("Cannot create splitting pin");
+		ttyputerr(_("Cannot create splitting pin"));
 		return(NONODEINST);
 	}
 	endobjectchange((INTBIG)ni, VNODEINST);
 
 	/* delete the old arcinst */
 	startobjectchange((INTBIG)ai, VARCINST);
-	if (killarcinst(ai)) ttyputerr("Error deleting original arc");
+	if (killarcinst(ai)) ttyputerr(_("Error deleting original arc"));
 
 	/* create the two new arcinsts */
 	ar1 = newarcinst(ap, wid, bits1, fno, fpt, fendx, fendy, ni, pt1, prefx, prefy, pnt);
 	ar2 = newarcinst(ap, wid, bits2, ni, pt1, prefx, prefy, tno, tpt, tendx, tendy, pnt);
 	if (ar1 == NOARCINST || ar2 == NOARCINST)
 	{
-		ttyputerr("Error creating the split arc parts");
+		ttyputerr(_("Error creating the split arc parts"));
 		return(ni);
 	}
 	(void)copyvars((INTBIG)ai, VARCINST, (INTBIG)ar1, VARCINST);
@@ -1425,7 +1423,7 @@ INTSML us_fitportangle(NODEINST *ni, PORTPROTO *pp, INTSML angle, INTSML range)
 {
 	REGISTER INTSML j;
 
-	j = us_bottomrecurse(ni, pp, 0);
+	j = us_bottomrecurse(ni, pp);
 	j = (j - angle) % 3600;   if (j < 0) j += 3600;
 	if (j > 1800) j = 3600 - j;
 	if (j > range) return(1);
@@ -1436,12 +1434,12 @@ INTSML us_fitportangle(NODEINST *ni, PORTPROTO *pp, INTSML angle, INTSML range)
  * routine to recurse to the bottom (most primitive node) of a port and
  * compute the port orientation from the bottom up.
  */
-INTSML us_bottomrecurse(NODEINST *ni, PORTPROTO *pp, INTSML j)
+INTSML us_bottomrecurse(NODEINST *ni, PORTPROTO *pp)
 {
 	REGISTER INTSML k;
 
 	if (ni->proto->primindex == 0)
-		k = us_bottomrecurse(pp->subnodeinst, pp->subportproto, j); else
+		k = us_bottomrecurse(pp->subnodeinst, pp->subportproto); else
 			k = (INTSML)(((pp->userbits&PORTANGLE) >> PORTANGLESH) * 10);
 	k += ni->rotation;
 	if (ni->transpose != 0) k = 2700 - k;
