@@ -34,9 +34,8 @@
 
 void us_arc(INTSML count, char *par[])
 {
-	REGISTER INTSML i, l, negate, ang, toggle;
-	REGISTER INTBIG acx, acy, r;
-	INTBIG ix,iy, x1,y1, x2,y2, xcur, ycur;
+	REGISTER INTBIG negate, ang, toggle, acx, acy, r, j, i, l;
+	INTBIG ix, iy, x1, y1, x2, y2, xcur, ycur, dx[2], dy[2];
 	REGISTER ARCINST *ai;
 	REGISTER NODEPROTO *np;
 	REGISTER char *pp;
@@ -44,10 +43,11 @@ void us_arc(INTSML count, char *par[])
 	extern COMCOMP us_arcp, us_arcnotp, us_arcnamep, us_arctogp;
 	REGISTER VARIABLE *var;
 	REGISTER GEOM **list;
+	static POLYGON *poly = NOPOLYGON;
 
 	if (count == 0)
 	{
-		count = ttygetparam("ARC command: ", &us_arcp, MAXPARS, par);
+		count = ttygetparam(_("ARC command: "), &us_arcp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -61,7 +61,7 @@ void us_arc(INTSML count, char *par[])
 	{
 		if (count == 1)
 		{
-			count = ttygetparam("Negation option: ", &us_arcnotp, MAXPARS-1, &par[1]) + 1;
+			count = ttygetparam(_("Negation option: "), &us_arcnotp, MAXPARS-1, &par[1]) + 1;
 			if (count == 1)
 			{
 				us_abortedmsg();
@@ -76,7 +76,7 @@ void us_arc(INTSML count, char *par[])
 	{
 		if (count == 1)
 		{
-			count = ttygetparam("Toggle option: ", &us_arctogp, MAXPARS-1, &par[1]) + 1;
+			count = ttygetparam(_("Toggle option: "), &us_arctogp, MAXPARS-1, &par[1]) + 1;
 			if (count == 1)
 			{
 				us_abortedmsg();
@@ -93,7 +93,7 @@ void us_arc(INTSML count, char *par[])
 	list = us_gethighlighted(OBJARCINST);
 	if (list[0] == NOGEOM)
 	{
-		us_abortcommand("No arcs are selected");
+		us_abortcommand(_("No arcs are selected"));
 		return;
 	}
 
@@ -109,88 +109,88 @@ void us_arc(INTSML count, char *par[])
 	{
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
-			us_abortcommand("Use the layout constraint system for rigid arcs");
+			us_abortcommand(_("Use the layout constraint system for rigid arcs"));
 			(void)us_pophighlight(0);
 			return;
 		}
 		i = us_modarcbits((INTSML)((toggle != 0 ? 23 : (negate != 0 ? 1 : 0))), 0, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural("arc", i),
-			(toggle != 0 ? "toggle rigidity" : (negate != 0 ? "made un-rigid" : "made rigid")));
+		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+			(toggle != 0 ? _("toggle rigidity") : (negate != 0 ? _("made un-rigid") : _("made rigid"))));
 	} else if ((namesamen(pp, "manhattan", l) == 0 ||
 		namesamen(pp, "fixed-angle", l) == 0) && l >= 1)
 	{
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
-			us_abortcommand("Use the layout constraint system for fixed-angle arcs");
+			us_abortcommand(_("Use the layout constraint system for fixed-angle arcs"));
 			(void)us_pophighlight(0);
 			return;
 		}
 		if (namesamen(pp, "manhattan", l) == 0)
-			ttyputmsg("It is now proper to use 'arc fixed-angle' instead of 'arc manhattan'");
+			ttyputmsg(_("It is now proper to use 'arc fixed-angle' instead of 'arc manhattan'"));
 		i = us_modarcbits((INTSML)((toggle != 0 ? 24 : (negate != 0 ? 3 : 2))), 0, "", list);
 		if (i >= 0)
-			ttyputverbose("%d %s %s", i, makeplural("arc", i), (toggle != 0 ? "toggle fixed-angle" :
-				(negate != 0 ? "made not fixed-angle" : "made fixed-angle")));
+			ttyputverbose("%d %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle fixed-angle") :
+				(negate != 0 ? _("made not fixed-angle") : _("made fixed-angle"))));
 	} else if (namesamen(pp, "slide", l) == 0 && l >= 2)
 	{
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
-			us_abortcommand("Use the layout constraint system for slidable arcs");
+			us_abortcommand(_("Use the layout constraint system for slidable arcs"));
 			(void)us_pophighlight(0);
 			return;
 		}
 		i = us_modarcbits((INTSML)((toggle != 0 ? 25 : (negate != 0 ? 5 : 4))), 0, "", list);
 		if (i >= 0)
-			ttyputverbose("%d %s %s", i, makeplural("arc", i), (toggle != 0 ? "toggle slidability" :
-				(negate != 0 ? "can not slide in ports" : "can slide in ports")));
+			ttyputverbose("%d %s %s", i, makeplural(_("arc"), i), (toggle != 0 ? _("toggle slidability") :
+				(negate != 0 ? _("can not slide in ports") : _("can slide in ports"))));
 	} else if (namesamen(pp, "temp-rigid", l) == 0 && l >= 1)
 	{
 		if (namesame(el_curconstraint->conname, "layout") != 0)
 		{
-			us_abortcommand("Use the layout constraint system for rigid arcs");
+			us_abortcommand(_("Use the layout constraint system for rigid arcs"));
 			(void)us_pophighlight(0);
 			return;
 		}
 		i = us_modarcbits((INTSML)((negate != 0 ? 7 : 6)), 0, "", list);
-		if (i >= 0) ttyputverbose("%d %s made temporarily %srigid", i, makeplural("arc", i),
-			(negate!=0 ? "un-" : ""));
+		if (i >= 0) ttyputverbose(_("%d %s made temporarily %srigid"), i, makeplural(_("arc"), i),
+			(negate!=0 ? _("un-") : ""));
 	} else if (namesamen(pp, "ends-extend", l) == 0 && l >= 1)
 	{
 		i = us_modarcbits((INTSML)((toggle != 0 ? 26 : (negate != 0 ? 9 : 8))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural("arc", i),
-			(toggle != 0 ? "toggle end extension" :
-				(negate != 0 ? "given no end extension" : "given full end extension")));
+		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+			(toggle != 0 ? _("toggle end extension") :
+				(negate != 0 ? _("given no end extension") : _("given full end extension"))));
 	} else if (namesamen(pp, "directional", l) == 0 && l >= 1)
 	{
 		i = us_modarcbits((INTSML)((toggle != 0 ? 27 : (negate != 0 ? 11: 10))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural("arc", i),
-			(toggle != 0 ? "toggle directionality" :
-				(negate != 0 ? "given no direction" : "given direction")));
+		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+			(toggle != 0 ? _("toggle directionality") :
+				(negate != 0 ? _("given no direction") : _("given direction"))));
 	} else if (namesamen(pp, "negated", l) == 0 && l >= 2)
 	{
 		i = us_modarcbits((INTSML)((toggle != 0 ? 28 : (negate != 0 ? 13 : 12))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural("arc", i),
-			(toggle != 0 ? "toggle negation" : (negate != 0 ? "not negated" : "negated")));
+		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+			(toggle != 0 ? _("toggle negation") : (negate != 0 ? _("not negated") : _("negated"))));
 	} else if (namesamen(pp, "skip-tail", l) == 0 && l >= 6)
 	{
 		i = us_modarcbits((INTSML)((toggle != 0 ? 29 : (negate != 0 ? 15 : 14))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural("arc", i),
-			(toggle != 0 ? "toggle tail use" : (negate!=0 ? "use tail" : "do not use tail")));
+		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+			(toggle != 0 ? _("toggle tail use") : (negate!=0 ? _("use tail") : _("do not use tail"))));
 	} else if (namesamen(pp, "skip-head", l) == 0 && l >= 6)
 	{
 		i = us_modarcbits((INTSML)((toggle != 0 ? 30 : (negate != 0 ? 17 : 16))), 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural("arc", i),
-			(toggle != 0 ? "toggle head use" : (negate!=0 ? "use head" : "do not use head")));
+		if (i >= 0) ttyputverbose("%d %s %s", i, makeplural(_("arc"), i),
+			(toggle != 0 ? _("toggle head use") : (negate!=0 ? _("use head") : _("do not use head"))));
 	} else if (namesamen(pp, "reverse", l) == 0 && l >= 2)
 	{
-		if (negate != 0) ttyputerr("'arc reverse' is a relative notion, 'not' ignored");
+		if (negate != 0) ttyputerr(_("'arc reverse' is a relative notion, 'not' ignored"));
 		i = us_modarcbits(18, 1, "", list);
-		if (i >= 0) ttyputverbose("%d %s direction reversed", i, makeplural("arc", i));
+		if (i >= 0) ttyputverbose(_("%d %s direction reversed"), i, makeplural(_("arc"), i));
 	} else if (namesamen(pp, "constraint", l) == 0 && l >= 2)
 	{
 		if (namesame(el_curconstraint->conname, "linear") != 0)
 		{
-			us_abortcommand("First switch to the linear inequalities constraint system");
+			us_abortcommand(_("First switch to the linear inequalities constraint system"));
 			(void)us_pophighlight(0);
 			return;
 		}
@@ -208,7 +208,7 @@ void us_arc(INTSML count, char *par[])
 	{
 		if (list[0]->entrytype != OBJARCINST || list[1] != NOGEOM)
 		{
-			us_abortcommand("Select only one arc when naming");
+			us_abortcommand(_("Select only one arc when naming"));
 			(void)us_pophighlight(0);
 			return;
 		}
@@ -218,7 +218,7 @@ void us_arc(INTSML count, char *par[])
 		{
 			if (count < 2)
 			{
-				count = ttygetparam("ARC name: ", &us_arcnamep, MAXPARS-1, &par[1]) + 1;
+				count = ttygetparam(_("ARC name: "), &us_arcnamep, MAXPARS-1, &par[1]) + 1;
 				if (count == 1)
 				{
 					us_abortedmsg();
@@ -233,26 +233,26 @@ void us_arc(INTSML count, char *par[])
 			if (net != NONETWORK)
 			{
 				if (ai->network == net)
-					ttyputmsg("Network %s is already on this arc", describenetwork(net));
-			} else ttyputverbose("Network %s defined", pp);
+					ttyputmsg(_("Network %s is already on this arc"), describenetwork(net));
+			} else ttyputverbose(_("Network %s defined"), pp);
 			us_setarcname(ai, pp);
 		} else
 		{
 			var = getvalkey((INTBIG)ai, VARCINST, VSTRING, el_arc_name);
 			if (var == NOVARIABLE)
 			{
-				us_abortcommand("This arc has no name");
+				us_abortcommand(_("This arc has no name"));
 				(void)us_pophighlight(0);
 				return;
 			}
 			if (var != NOVARIABLE) us_setarcname(ai, (char *)0);
-			ttyputverbose("Arc name removed");
+			ttyputverbose(_("Arc name removed"));
 		}
 	} else if (namesamen(pp, "center", l) == 0 && l >= 2)
 	{
 		if (list[0]->entrytype != OBJARCINST || list[1] != NOGEOM)
 		{
-			us_abortcommand("Select only one arc when changing curvature");
+			us_abortcommand(_("Select only one arc when changing curvature"));
 			(void)us_pophighlight(0);
 			return;
 		}
@@ -261,7 +261,7 @@ void us_arc(INTSML count, char *par[])
 		/* make sure the arc can handle it */
 		if ((ai->proto->userbits&CANCURVE) == 0 && negate == 0)
 		{
-			us_abortcommand("This arc cannot curve");
+			us_abortcommand(_("This arc cannot curve"));
 			(void)us_pophighlight(0);
 			return;
 		}
@@ -295,11 +295,38 @@ void us_arc(INTSML count, char *par[])
 
 		/* restore highlighting */
 		endobjectchange((INTBIG)ai, VARCINST);
+	} else if (namesamen(pp, "shorten", l) == 0 && l >= 2)
+	{
+		/* get the necessary polygon */
+		if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
+
+		l = 0;
+		for(i=0; list[i] != NOGEOM; i++)
+		{
+			ai = list[i]->entryaddr.ai;
+			for(j=0; j<2; j++)
+			{
+				shapeportpoly(ai->end[j].nodeinst, ai->end[j].portarcinst->proto,
+					poly, 0);
+				ix = ai->end[1-j].xpos;   iy = ai->end[1-j].ypos;
+				closestpoint(poly, &ix, &iy);
+				dx[j] = ix - ai->end[j].xpos;
+				dy[j] = iy - ai->end[j].ypos;
+			}
+			if (dx[0] != 0 || dy[0] != 0 || dx[1] != 0 || dy[1] != 0)
+			{
+				startobjectchange((INTBIG)ai, VARCINST);
+				modifyarcinst(ai, 0, dx[0], dy[0], dx[1], dy[1]);
+				endobjectchange((INTBIG)ai, VARCINST);
+				l++;
+			}
+		}
+		ttyputmsg("Shortened %d %s", l, makeplural(_("arc"), l));
 	} else if (namesamen(pp, "curve", l) == 0 && l >= 2)
 	{
 		if (list[0]->entrytype != OBJARCINST || list[1] != NOGEOM)
 		{
-			us_abortcommand("Select only one arc when changing curvature");
+			us_abortcommand(_("Select only one arc when changing curvature"));
 			(void)us_pophighlight(0);
 			return;
 		}
@@ -308,7 +335,7 @@ void us_arc(INTSML count, char *par[])
 		/* make sure the arc can handle it */
 		if ((ai->proto->userbits&CANCURVE) == 0 && negate == 0)
 		{
-			us_abortcommand("This arc cannot curve");
+			us_abortcommand(_("This arc cannot curve"));
 			(void)us_pophighlight(0);
 			return;
 		}
@@ -353,7 +380,7 @@ void us_arc(INTSML count, char *par[])
 
 		/* highlight the new arc */
 		endobjectchange((INTBIG)ai, VARCINST);
-	} else us_abortcommand("Bad ARC option: %s", pp);
+	} else ttyputbadusage("arc");
 
 	/* clean-up */
 	(void)us_pophighlight(1);
@@ -387,7 +414,7 @@ void us_array(INTSML count, char *par[])
 	list = us_gethighlighted(OBJNODEINST|OBJARCINST);
 	if (list[0] == NOGEOM)
 	{
-		us_abortcommand("Must select circuitry before arraying it");
+		us_abortcommand(_("Must select circuitry before arraying it"));
 		return;
 	}
 	np = geomparent(list[0]);
@@ -423,7 +450,7 @@ void us_array(INTSML count, char *par[])
 	/* get the X extent of the array */
 	if (count == 0)
 	{
-		us_abortcommand("Usage: array XREP[f][s] [YREP[f][s] [XOVRLP [YOVRLP [no-names][diagonal]]]]");
+		ttyputusage("array XREP[f][s] [YREP[f][s] [XOVRLP [YOVRLP [no-names][diagonal]]]]");
 		return;
 	}
 	pt1 = par[0];
@@ -450,12 +477,12 @@ void us_array(INTSML count, char *par[])
 	/* check for nonsense */
 	if (xsize <= 1 && ysize <= 1)
 	{
-		us_abortcommand("One dimension of the array must be greater than 1");
+		us_abortcommand(_("One dimension of the array must be greater than 1"));
 		return;
 	}
 	if (diagonal != 0 && xsize != 1 && ysize != 1)
 	{
-		us_abortcommand("Diagonal arrays need one dimension to be 1");
+		us_abortcommand(_("Diagonal arrays need one dimension to be 1"));
 		return;
 	}
 
@@ -491,8 +518,8 @@ void us_array(INTSML count, char *par[])
 	{
 		nodelist = (NODEINST **)emalloc(nodecount * (sizeof (NODEINST *)), el_tempcluster);
 		if (nodelist == 0) return;
-		for(ni = np->firstnodeinst, i=0; ni != NONODEINST; ni = ni->nextnodeinst)
-			if (ni->temp1 != 0) nodelist[i++] = ni;
+		for(ni = np->firstnodeinst, i=nodecount-1; ni != NONODEINST; ni = ni->nextnodeinst)
+			if (ni->temp1 != 0) nodelist[i--] = ni;
 	}
 	if (arccount > 0)
 	{
@@ -566,7 +593,7 @@ void us_array(INTSML count, char *par[])
 	}
 	if (x < xsize)
 	{
-		us_abortcommand("Array is too wide...place elements closer or use fewer");
+		us_abortcommand(_("Array is too wide...place elements closer or use fewer"));
 		if (nodecount > 0) efree((char *)nodelist);
 		if (arccount > 0) efree((char *)arclist);
 		return;
@@ -586,7 +613,7 @@ void us_array(INTSML count, char *par[])
 	}
 	if (y < ysize)
 	{
-		us_abortcommand("Array is too tall...place elements closer or use fewer");
+		us_abortcommand(_("Array is too tall...place elements closer or use fewer"));
 		if (nodecount > 0) efree((char *)nodelist);
 		if (arccount > 0) efree((char *)arclist);
 		return;
@@ -599,7 +626,7 @@ void us_array(INTSML count, char *par[])
 	/* create the array */
 	for(x=0; x<xsize; x++) for(y=0; y<ysize; y++)
 	{
-		if (stopping("Array") != 0) break;
+		if (stopping(STOPREASONARRAY)) break;
 		if (x == 0 && y == 0) continue;
 
 		/* first replicate the nodes */
@@ -635,7 +662,7 @@ void us_array(INTSML count, char *par[])
 			newno = newnodeinst(ni->proto, plx, phx, ply, phy, tr, ro, np);
 			if (newno == NONODEINST)
 			{
-				ttyputerr("Problem creating array nodes");
+				ttyputerr(_("Problem creating array nodes"));
 				if (nodecount > 0) efree((char *)nodelist);
 				if (arccount > 0) efree((char *)arclist);
 				(void)us_pophighlight(0);
@@ -663,7 +690,7 @@ void us_array(INTSML count, char *par[])
 				if (var != NOVARIABLE && ni->proto->primindex == 0)
 				{
 					var->textdescript = us_setdescriptoffset(var->textdescript,
-						0, (ni->highy-ni->lowy) / el_curtech->deflambda);
+						0, (ni->highy-ni->lowy) / el_curlib->lambda[el_curtech->techindex]);
 				}
 			}
 
@@ -676,7 +703,7 @@ void us_array(INTSML count, char *par[])
 					pp = newportproto(np, newno, pe->proto, portname);
 					if (pp == NOPORTPROTO)
 					{
-						us_abortcommand("Cannot create port %s", portname);
+						us_abortcommand(_("Cannot create port %s"), portname);
 						return;
 					}
 					pp->userbits = pe->exportproto->userbits;
@@ -724,7 +751,7 @@ void us_array(INTSML count, char *par[])
 				cx0+xoff0, cy0+yoff0, ni1, ai->end[1].portarcinst->proto, cx1+xoff1, cy1+yoff1, np);
 			if (newai == NOARCINST)
 			{
-				ttyputerr("Problem creating array arcs");
+				ttyputerr(_("Problem creating array arcs"));
 				if (nodecount > 0) efree((char *)nodelist);
 				if (arccount > 0) efree((char *)arclist);
 				(void)us_pophighlight(0);
@@ -774,7 +801,7 @@ void us_array(INTSML count, char *par[])
 			if (var != NOVARIABLE && ni->proto->primindex == 0)
 			{
 				var->textdescript = us_setdescriptoffset(var->textdescript,
-					0, (ni->highy-ni->lowy) / el_curtech->deflambda);
+					0, (ni->highy-ni->lowy) / el_curlib->lambda[el_curtech->techindex]);
 			}
 			endobjectchange((INTBIG)ni, VNODEINST);
 		}
@@ -823,7 +850,7 @@ void us_bind(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		count = ttygetparam("BIND option: ", &us_bindp, MAXPARS, par);
+		count = ttygetparam(_("BIND option: "), &us_bindp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -838,7 +865,7 @@ void us_bind(INTSML count, char *par[])
 		negated = 1;
 		if (count <= 1)
 		{
-			us_abortcommand("Usage: bind not verbose");
+			ttyputusage("bind not verbose");
 			return;
 		}
 		l = strlen(pp = par[1]);
@@ -849,11 +876,11 @@ void us_bind(INTSML count, char *par[])
 		if (negated == 0)
 		{
 			us_aid->aidstate |= ECHOBIND;
-			ttyputverbose("Key/menu/button commands echoed");
+			ttyputverbose(_("Key/menu/button commands echoed"));
 		} else
 		{
 			us_aid->aidstate &= ~ECHOBIND;
-			ttyputverbose("Key/menu/button commands not echoed");
+			ttyputverbose(_("Key/menu/button commands not echoed"));
 		}
 		return;
 	}
@@ -862,13 +889,13 @@ void us_bind(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: bind get LETTER OBJECT");
+			ttyputusage("bind get LETTER OBJECT");
 			return;
 		}
 		letter = par[1];
 		if (!isalpha(*letter) || letter[1] != 0)
 		{
-			us_abortcommand("A single letter must be used, not '%s'", letter);
+			us_abortcommand(_("A single letter must be used, not '%s'"), letter);
 			return;
 		}
 
@@ -877,7 +904,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 4)
 			{
-				us_abortcommand("Usage: bind get LETTER button BUTTON");
+				ttyputusage("bind get LETTER button BUTTON");
 				return;
 			}
 			pp = par[3];
@@ -894,7 +921,7 @@ void us_bind(INTSML count, char *par[])
 			}
 			if (j < important)
 			{
-				us_abortcommand("Button %s unknown", pp);
+				us_abortcommand(_("Button %s unknown"), pp);
 				return;
 			}
 			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_buttons);
@@ -910,7 +937,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 4)
 			{
-				us_abortcommand("Usage: bind get LETTER key KEY");
+				ttyputusage("bind get LETTER key KEY");
 				return;
 			}
 			pp = par[3];
@@ -928,14 +955,14 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 5)
 			{
-				us_abortcommand("Usage: bind get LETTER menu ROW COLUMN");
+				ttyputusage("bind get LETTER menu ROW COLUMN");
 				return;
 			}
 			y = (INTSML)myatoi(pp = par[3]);
 			x = (INTSML)myatoi(pp = par[4]);
 			if (x < 0 || y < 0 || x >= us_menux || y >= us_menuy)
 			{
-				us_abortcommand("Index of menu entry out of range");
+				us_abortcommand(_("Index of menu entry out of range"));
 				return;
 			}
 			var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
@@ -954,19 +981,19 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 5)
 			{
-				us_abortcommand("Usage: bind get LETTER popup MENU ENTRY");
+				ttyputusage("bind get LETTER popup MENU ENTRY");
 				return;
 			}
 			pm = us_getpopupmenu(par[3]);
 			if (pm == NOPOPUPMENU)
 			{
-				us_abortcommand("No popup menu called %s", par[3]);
+				us_abortcommand(_("No popup menu called %s"), par[3]);
 				return;
 			}
 			popup = myatoi(par[4]) + 1;
 			if (popup <= 0 || popup > pm->total)
 			{
-				us_abortcommand("Popup menu entry must be from 0 to %d", pm->total-1);
+				us_abortcommand(_("Popup menu entry must be from 0 to %d"), pm->total-1);
 				return;
 			}
 			rb = pm->list[popup-1].response;
@@ -983,7 +1010,7 @@ void us_bind(INTSML count, char *par[])
 				(INTBIG)pp, VSTRING|VDONTSAVE);
 			return;
 		}
-		us_abortcommand("Usage: bind get LETTER key|button|menu|popup ENTRY");
+		ttyputusage("bind get LETTER key|button|menu|popup ENTRY");
 		return;
 	}
 
@@ -991,7 +1018,7 @@ void us_bind(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			count = ttygetparam("Key, Menu, Button, or Popup: ", &us_bindsetp, MAXPARS-1, &par[1])+1;
+			count = ttygetparam(_("Key, Menu, Button, or Popup: "), &us_bindsetp, MAXPARS-1, &par[1])+1;
 			if (count == 1)
 			{
 				us_abortedmsg();
@@ -1011,7 +1038,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 3)
 			{
-				count = ttygetparam("Button name: ", &us_bindbuttonp, MAXPARS-2, &par[2])+2;
+				count = ttygetparam(_("Button name: "), &us_bindbuttonp, MAXPARS-2, &par[2])+2;
 				if (count == 2)
 				{
 					us_abortedmsg();
@@ -1032,7 +1059,7 @@ void us_bind(INTSML count, char *par[])
 			}
 			if (j < important)
 			{
-				us_abortcommand("Button %s unknown", pp);
+				us_abortcommand(_("Button %s unknown"), pp);
 				return;
 			}
 			important = 3;
@@ -1042,7 +1069,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 3)
 			{
-				count = ttygetparam("Key name: ", &us_bindkeyp, MAXPARS-2, &par[2])+2;
+				count = ttygetparam(_("Key name: "), &us_bindkeyp, MAXPARS-2, &par[2])+2;
 				if (count == 2)
 				{
 					us_abortedmsg();
@@ -1063,7 +1090,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (count < 3)
 			{
-				count = ttygetparam("Popup menu name: ", &us_bindpopnp, MAXPARS-2, &par[2])+2;
+				count = ttygetparam(_("Popup menu name: "), &us_bindpopnp, MAXPARS-2, &par[2])+2;
 				if (count == 2)
 				{
 					us_abortedmsg();
@@ -1074,7 +1101,7 @@ void us_bind(INTSML count, char *par[])
 			pm = us_getpopupmenu(popname);
 			if (pm == NOPOPUPMENU)
 			{
-				us_abortcommand("No popup menu called %s", par[2]);
+				us_abortcommand(_("No popup menu called %s"), par[2]);
 				return;
 			}
 			(void)initinfstr();
@@ -1092,7 +1119,7 @@ void us_bind(INTSML count, char *par[])
 
 			if (count < 4)
 			{
-				count = ttygetparam("Popup menu entry: ", &us_bindpoprep, MAXPARS-3, &par[3])+3;
+				count = ttygetparam(_("Popup menu entry: "), &us_bindpoprep, MAXPARS-3, &par[3])+3;
 				if (count == 3)
 				{
 					us_abortedmsg();
@@ -1102,7 +1129,7 @@ void us_bind(INTSML count, char *par[])
 			popup = myatoi(par[3]) + 1;
 			if (popup <= 0 || popup > pm->total)
 			{
-				us_abortcommand("Popup menu entry must be from 0 to %d", pm->total-1);
+				us_abortcommand(_("Popup menu entry must be from 0 to %d"), pm->total-1);
 				return;
 			}
 			if (pp[0] == 'i') popup = -popup;
@@ -1119,7 +1146,7 @@ void us_bind(INTSML count, char *par[])
 					nodeglyph = getnodeproto(par[3]);
 					if (nodeglyph == NONODEPROTO)
 					{
-						us_abortcommand("Cannot find %s", par[3]);
+						us_abortcommand(_("Cannot find %s"), par[3]);
 						return;
 					}
 					count -= 2;
@@ -1153,7 +1180,7 @@ void us_bind(INTSML count, char *par[])
 			/* get the menu row number */
 			if (count < 3)
 			{
-				count = ttygetparam("Menu row: ", &us_bindmenuryp, MAXPARS-2, &par[2]) + 2;
+				count = ttygetparam(_("Menu row: "), &us_bindmenuryp, MAXPARS-2, &par[2]) + 2;
 				if (count == 2)
 				{
 					us_abortedmsg();
@@ -1163,7 +1190,7 @@ void us_bind(INTSML count, char *par[])
 			y = (INTSML)myatoi(pp = par[2]);
 			if (count < 4)
 			{
-				count = ttygetparam("Menu column: ", &us_bindmenuxp, MAXPARS+3, &par[3])+3;
+				count = ttygetparam(_("Menu column: "), &us_bindmenuxp, MAXPARS+3, &par[3])+3;
 				if (count == 3)
 				{
 					us_abortedmsg();
@@ -1189,7 +1216,7 @@ void us_bind(INTSML count, char *par[])
 			/* check validity */
 			if (x < 0 || y < 0 || x >= us_menux || y >= us_menuy)
 			{
-				us_abortcommand("Index of menu entry out of range");
+				us_abortcommand(_("Index of menu entry out of range"));
 				return;
 			}
 			varkey = us_binding_menu;
@@ -1201,12 +1228,12 @@ void us_bind(INTSML count, char *par[])
 
 		if (important == 0)
 		{
-			us_abortcommand("Usage: bind set key|button|menu|[input-]popup COMMAND");
+			ttyputusage("bind set key|button|menu|[input-]popup COMMAND");
 			return;
 		}
 
 		if (count <= important)
-			count = ttygetparam("Command: ", &us_userp, (INTSML)(MAXPARS-important),
+			count = ttygetparam(_("Command: "), &us_userp, (INTSML)(MAXPARS-important),
 				&par[important]) + important;
 		(void)initinfstr();
 		for(i=important; i<count; i++)
@@ -1227,7 +1254,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (key != 0 && us_islasteval(key))
 			{
-				us_abortcommand("Cannot un-bind the last 'tellaid user' key");
+				us_abortcommand(_("Cannot un-bind the last 'tellaid user' key"));
 				return;
 			}
 			(void)initinfstr();
@@ -1266,7 +1293,7 @@ void us_bind(INTSML count, char *par[])
 		{
 			if (key != 0 && us_islasteval(key))
 			{
-				us_abortcommand("Cannot re-bind the last 'tellaid user' key");
+				us_abortcommand(_("Cannot re-bind the last 'tellaid user' key"));
 				return;
 			}
 		}
@@ -1338,5 +1365,5 @@ void us_bind(INTSML count, char *par[])
 		return;
 	}
 
-	us_abortcommand("Bad BIND argument: %s", par[0]);
+	ttyputbadusage("bind");
 }
