@@ -64,9 +64,9 @@ struct
 void us_window(INTSML count, char *par[])
 {
 	REGISTER WINDOWPART *w, *oldw, *nextw, *neww;
-	REGISTER INTBIG i, dist, curwx, curwy, size, x, y, diffx, diffy;
+	REGISTER INTBIG i, dist, curwx, curwy, size, x, y, diffx, diffy, lambda;
 	REGISTER INTSML l, nogood, splitkey, lineno, startper, endper;
-	INTBIG lx, hx, ly, hy, xcur, ycur, schx, schy, windowView[8];
+	INTBIG lx, hx, ly, hy, xcur, ycur, windowView[8];
 	static POLYGON *poly = NOPOLYGON;
 	REGISTER STATUSFIELD *sf, **whichstatus;
 	char *newpar[4], *fieldname;
@@ -85,7 +85,7 @@ void us_window(INTSML count, char *par[])
 
 	if (count == 0)
 	{
-		count = ttygetparam("Window configuration: ", &us_windowp, MAXPARS, par);
+		count = ttygetparam(_("Window configuration: "), &us_windowp, MAXPARS, par);
 		if (count == 0)
 		{
 			us_abortedmsg();
@@ -94,7 +94,34 @@ void us_window(INTSML count, char *par[])
 	}
 	l = (INTSML)strlen(pp = par[0]);
 
-	if (namesamen(pp, "all-displayed", l) == 0 && l >= 1)
+	if (namesamen(pp, "adjust", l) == 0 && l >= 2)
+	{
+		if (count == 1)
+		{
+			ttyputusage("window adjust STYLE");
+			return;
+		}
+		l = (INTSML)strlen(pp = par[1]);
+		if (namesamen(pp, "horizontal-tile", l) == 0)
+		{
+			adjustwindowframe(0);
+			return;
+		}
+		if (namesamen(pp, "vertical-tile", l) == 0)
+		{
+			adjustwindowframe(1);
+			return;
+		}
+		if (namesamen(pp, "cascade", l) == 0)
+		{
+			adjustwindowframe(2);
+			return;
+		}
+		ttyputusage("window adjust (horizontal-tile | vertical-tile | cascade)");
+		return;
+	}
+
+	if (namesamen(pp, "all-displayed", l) == 0 && l >= 2)
 	{
 		if (us_needwindow()) return;
 
@@ -156,7 +183,7 @@ void us_window(INTSML count, char *par[])
 		np = us_getareabounds(&lx, &hx, &ly, &hy);
 		if (np == NONODEPROTO)
 		{
-			us_abortcommand("Outline an area");
+			us_abortcommand(_("Outline an area"));
 			return;
 		}
 
@@ -167,7 +194,7 @@ void us_window(INTSML count, char *par[])
 					break;
 			if (w == NOWINDOWPART)
 			{
-				us_abortcommand("Cannot find an editing window with highlighted objects");
+				us_abortcommand(_("Cannot find an editing window with highlighted objects"));
 				return;
 			}
 		}
@@ -175,7 +202,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot manipulate a nonstandard window */
 		if ((w->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only pan circuit editing windows");
+			us_abortcommand(_("Can only pan circuit editing windows"));
 			return;
 		}
 
@@ -188,15 +215,6 @@ void us_window(INTSML count, char *par[])
 		lx = x - curwx/2;      ly = y - curwy/2;
 		hx = lx + curwx;       hy = ly + curwy;
 
-		/* limit schematic windows to their normal extent */
-		if (framesize(&schx, &schy, np) == 0)
-		{
-			if (lx < -schx/2) { lx = -schx/2;   hx = lx + curwx; }
-			if (hx >  schx/2) { hx =  schx/2;   lx = hx - curwx; }
-			if (ly < -schy/2) { ly = -schy/2;   hy = ly + curwy; }
-			if (hy >  schy/2) { hy =  schy/2;   ly = hy - curwy; }
-		}
-
 		/* save and erase highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
@@ -222,7 +240,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot manipulate a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only pan circuit editing windows");
+			us_abortcommand(_("Can only pan circuit editing windows"));
 			return;
 		}
 
@@ -231,19 +249,9 @@ void us_window(INTSML count, char *par[])
 		/* pre-compute current window size */
 		curwx = el_curwindowpart->screenhx - el_curwindowpart->screenlx;
 		curwy = el_curwindowpart->screenhy - el_curwindowpart->screenly;
-
 		lx = xcur - curwx/2;   ly = ycur - curwy/2;
 		hx = lx + curwx;       hy = ly + curwy;
 
-		/* limit schematic windows to their normal extent */
-		if (framesize(&schx, &schy, np) == 0)
-		{
-			if (lx < -schx/2) { lx = -schx/2;   hx = lx + curwx; }
-			if (hx >  schx/2) { hx =  schx/2;   lx = hx - curwx; }
-			if (ly < -schy/2) { ly = -schy/2;   hy = ly + curwy; }
-			if (hy >  schy/2) { hy =  schy/2;   ly = hy - curwy; }
-		}
-
 		/* save and erase highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
@@ -284,7 +292,7 @@ void us_window(INTSML count, char *par[])
 				if (wf->floating == 0) i++;
 			if (i <= 1)
 			{
-				ttyputerr("Sorry, cannot delete the last window");
+				ttyputerr(_("Sorry, cannot delete the last window"));
 				return;
 			}
 		}
@@ -293,7 +301,7 @@ void us_window(INTSML count, char *par[])
 		wf = getwindowframe(0);
 		if (wf == NOWINDOWFRAME)
 		{
-			us_abortcommand("No current window to delete");
+			us_abortcommand(_("No current window to delete"));
 			return;
 		}
 
@@ -356,7 +364,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot pan a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only pan circuit editing windows");
+			us_abortcommand(_("Can only pan circuit editing windows"));
 			return;
 		}
 
@@ -379,13 +387,13 @@ void us_window(INTSML count, char *par[])
 				(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~INTERACTIVE, VINTEGER);
 			else
 			{
-				us_abortcommand("Usage: window dragging on|off");
+				ttyputusage("window dragging on|off");
 				return;
 			}
 		}
 		if ((us_aid->aidstate&INTERACTIVE) == 0)
-			ttyputverbose("Cursor-based commands will act immediately"); else
-				ttyputverbose("Cursor-based commands will drag their objects");
+			ttyputverbose(_("Cursor-based commands will act immediately")); else
+				ttyputverbose(_("Cursor-based commands will drag their objects"));
 		return;
 	}
 
@@ -398,7 +406,7 @@ void us_window(INTSML count, char *par[])
 			if ((w->state&WINDOWTYPE) == EXPLORERWINDOW) break;
 		if (w != NOWINDOWPART)
 		{
-			/* if the explorer shares a window, delete it */
+			/* the explorer is up, delete it */
 			el_curwindowpart = w;
 			us_killcurrentwindow(1);
 			return;
@@ -411,7 +419,7 @@ void us_window(INTSML count, char *par[])
 			w = us_wantnewwindow(0);
 			if (w == NOWINDOWPART)
 			{
-				us_abortcommand("Cannot create new window frame");
+				us_abortcommand(_("Cannot create new window frame"));
 				return;
 			}
 		}
@@ -466,7 +474,7 @@ void us_window(INTSML count, char *par[])
 		np = us_getareabounds(&lx, &hx, &ly, &hy);
 		if (np == NONODEPROTO)
 		{
-			us_abortcommand("Outline an area");
+			us_abortcommand(_("Outline an area"));
 			return;
 		}
 
@@ -477,7 +485,7 @@ void us_window(INTSML count, char *par[])
 					break;
 			if (w == NOWINDOWPART)
 			{
-				us_abortcommand("Cannot find an editing window with highlighted objects");
+				us_abortcommand(_("Cannot find an editing window with highlighted objects"));
 				return;
 			}
 		}
@@ -485,32 +493,23 @@ void us_window(INTSML count, char *par[])
 		/* cannot manipulate a nonstandard window */
 		if ((w->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only adjust circuit editing windows");
+			us_abortcommand(_("Can only adjust circuit editing windows"));
 			return;
 		}
 
 		if (lx == hx && ly == hy)
 		{
-			lx -= el_curtech->deflambda;
-			hx += el_curtech->deflambda;
-			ly -= el_curtech->deflambda;
-			hy += el_curtech->deflambda;
+			lambda = lambdaoffacet(np);
+			lx -= lambda;
+			hx += lambda;
+			ly -= lambda;
+			hy += lambda;
 		}
 
 		/* pre-compute current window size */
 		curwx = w->screenhx - w->screenlx;
 		curwy = w->screenhy - w->screenly;
 
-		/* limit schematic windows to their normal extent */
-		i = framesize(&schx, &schy, np);
-		if (i == 0)
-		{
-			if (lx < -schx/2) lx = -schx/2;
-			if (hx > schx/2) hx = schx/2;
-			if (ly < -schy/2) ly = -schy/2;
-			if (hy > schy/2) hy = schy/2;
-		}
-
 		/* save and erase highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
@@ -518,31 +517,6 @@ void us_window(INTSML count, char *par[])
 		/* make sure the new window has square pixels */
 		us_squarescreen(w, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
 
-		/* make sure squaring didn't push extent of schematic frame */
-		if (i == 0)
-		{
-			if (lx < -schx/2)
-			{
-				hx -= schx/2 + lx;
-				lx = -schx/2;
-			}
-			if (hx > schx/2)
-			{
-				lx -= hx - schx/2;
-				hx = schx/2;
-			}
-			if (ly < -schy/2)
-			{
-				hy -= schy/2 + ly;
-				ly = -schy/2;
-			}
-			if (hy > schy/2)
-			{
-				ly -= hy - schy/2;
-				hy = schy/2;
-			}
-		}
-
 		startobjectchange((INTBIG)w, VWINDOWPART);
 		(void)setval((INTBIG)w, VWINDOWPART, "screenlx", lx, VINTEGER);
 		(void)setval((INTBIG)w, VWINDOWPART, "screenhx", hx, VINTEGER);
@@ -582,16 +556,18 @@ void us_window(INTSML count, char *par[])
 		/* cannot zoom a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only zoom circuit editing windows");
+			us_abortcommand(_("Can only zoom circuit editing windows"));
 			return;
 		}
 
-		if (us_needfacet() == NONODEPROTO) return;
+		np = us_needfacet();
+		if (np == NONODEPROTO) return;
+		lambda = lambdaoffacet(np);
 		if (count >= 2) dist = atola(par[1]); else
-			dist = 2 * el_curtech->deflambda;
+			dist = 2 * lambda;
 		if (dist == 0)
 		{
-			us_abortcommand("Must zoom by a nonzero amount");
+			us_abortcommand(_("Must zoom by a nonzero amount"));
 			return;
 		}
 
@@ -600,9 +576,9 @@ void us_window(INTSML count, char *par[])
 		us_clearhighlightcount();
 
 		diffx = muldiv(el_curwindowpart->screenhx - el_curwindowpart->screenlx,
-			el_curtech->deflambda, dist);
+			lambda, dist);
 		diffy = muldiv(el_curwindowpart->screenhy - el_curwindowpart->screenly,
-			el_curtech->deflambda, dist);
+			lambda, dist);
 		lx = el_curwindowpart->screenlx;   hx = el_curwindowpart->screenhx;
 		ly = el_curwindowpart->screenly;   hy = el_curwindowpart->screenhy;
 		lx = (hx+lx-diffx)/2;   hx = lx + diffx;
@@ -664,7 +640,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot pan a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only pan circuit editing windows");
+			us_abortcommand(_("Can only pan circuit editing windows"));
 			return;
 		}
 
@@ -682,7 +658,7 @@ void us_window(INTSML count, char *par[])
 		for(i = 0, w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart) i++;
 		if (i <= 1)
 		{
-			us_abortcommand("Must be multiple windows to match them");
+			us_abortcommand(_("Must be multiple windows to match them"));
 			return;
 		}
 
@@ -695,7 +671,7 @@ void us_window(INTSML count, char *par[])
 		{
 			if (count < 2)
 			{
-				count = ttygetparam("Other window to match: ", &us_windowmp, MAXPARS-1, &par[1]) + 1;
+				count = ttygetparam(_("Other window to match: "), &us_windowmp, MAXPARS-1, &par[1]) + 1;
 				if (count == 1)
 				{
 					us_abortedmsg();
@@ -714,28 +690,28 @@ void us_window(INTSML count, char *par[])
 			}
 			if (w == NOWINDOWPART)
 			{
-				us_abortcommand("No window named '%s'", win);
+				us_abortcommand(_("No window named '%s'"), win);
 				return;
 			}
 		}
 
 		if (w == el_curwindowpart)
 		{
-			us_abortcommand("Choose a window other than the current one to match");
+			us_abortcommand(_("Choose a window other than the current one to match"));
 			return;
 		}
 
 		/* cannot match if they are editing the same thing */
 		if ((w->state&WINDOWTYPE) != (el_curwindowpart->state&WINDOWTYPE))
 		{
-			us_abortcommand("Can only match windows that edit the same thing");
+			us_abortcommand(_("Can only match windows that edit the same thing"));
 			return;
 		}
 
 		/* cannot match if they are not normal display windows */
 		if ((w->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only match normal editing windows");
+			us_abortcommand(_("Can only match normal editing windows"));
 			return;
 		}
 
@@ -772,17 +748,17 @@ void us_window(INTSML count, char *par[])
 	{
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only measure distance in an edit window");
+			us_abortcommand(_("Can only measure distance in an edit window"));
 			return;
 		}
 		if (el_curwindowpart->curnodeproto == NONODEPROTO)
 		{
-			us_abortcommand("No facet in this window to measure");
+			us_abortcommand(_("No facet in this window to measure"));
 			return;
 		}
 		us_clearhighlightcount();
-		ttyputmsg("Type ENTER when done measuring distances");
-		ttyputmsg("Type 'x' to set a new starting point");
+		ttyputmsg(_("Type ENTER when done measuring distances"));
+		ttyputmsg(_("Type 'x' to set a new starting point"));
 		us_distanceinit();
 		for(;;)
 		{
@@ -798,7 +774,7 @@ void us_window(INTSML count, char *par[])
 		if (us_needwindow()) return;
 		if (count <= 1)
 		{
-			us_abortcommand("Usage: window name VIEWNAME");
+			ttyputusage("window name VIEWNAME");
 			return;
 		}
 		(void)initinfstr();
@@ -807,7 +783,7 @@ void us_window(INTSML count, char *par[])
 		var = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, returninfstr());
 		if (var == NOVARIABLE)
 		{
-			us_abortcommand("Cannot find saved window view '%s'", par[1]);
+			us_abortcommand(_("Cannot find saved window view '%s'"), par[1]);
 			return;
 		}
 
@@ -847,7 +823,7 @@ void us_window(INTSML count, char *par[])
 		w = us_wantnewwindow(0);
 		if (w == NOWINDOWPART)
 		{
-			us_abortcommand("Cannot create new window frame");
+			us_abortcommand(_("Cannot create new window frame"));
 			return;
 		}
 		return;
@@ -857,14 +833,14 @@ void us_window(INTSML count, char *par[])
 	{
 		if (count < 2)
 		{
-			us_abortcommand("Usage: window normal-cursor CURSORNAME");
+			ttyputusage("window normal-cursor CURSORNAME");
 			return;
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "standard", l) == 0) setnormalcursor(NORMALCURSOR); else
 			if (namesamen(pp, "pen", l) == 0) setnormalcursor(PENCURSOR); else
 				if (namesamen(pp, "tee", l) == 0) setnormalcursor(TECHCURSOR); else
-					us_abortcommand("Bad window cursor option: %s", pp);
+					ttyputbadusage("window cursor");
 		return;
 	}
 
@@ -894,17 +870,18 @@ void us_window(INTSML count, char *par[])
 		/* cannot zoom a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only zoom circuit editing windows");
+			us_abortcommand(_("Can only zoom circuit editing windows"));
 			return;
 		}
 
 		np = us_needfacet();
 		if (np == NONODEPROTO) return;
+		lambda = lambdaoffacet(np);
 		if (count >= 2) dist = atola(par[1]); else
-			dist = 2 * el_curtech->deflambda;
+			dist = 2 * lambda;
 		if (dist == 0)
 		{
-			us_abortcommand("Must zoom by a nonzero amount");
+			us_abortcommand(_("Must zoom by a nonzero amount"));
 			return;
 		}
 
@@ -914,47 +891,12 @@ void us_window(INTSML count, char *par[])
 
 		lx = el_curwindowpart->screenlx;   hx = el_curwindowpart->screenhx;
 		ly = el_curwindowpart->screenly;   hy = el_curwindowpart->screenhy;
-		i = muldiv(el_curwindowpart->screenhx - el_curwindowpart->screenlx, dist, el_curtech->deflambda);
+		i = muldiv(el_curwindowpart->screenhx - el_curwindowpart->screenlx, dist, lambda);
 		lx = (lx+hx-i)/2;   hx = lx + i;
-		i = muldiv(el_curwindowpart->screenhy - el_curwindowpart->screenly, dist, el_curtech->deflambda);
+		i = muldiv(el_curwindowpart->screenhy - el_curwindowpart->screenly, dist, lambda);
 		ly = (ly+hy-i)/2;   hy = ly + i;
-
-		/* limit schematic windows to their normal extent */
-		i = framesize(&schx, &schy, np);
-		if (i == 0)
-		{
-			if (lx < -schx/2) lx = -schx/2;
-			if (hx > schx/2) hx = schx/2;
-			if (ly < -schy/2) ly = -schy/2;
-			if (hy > schy/2) hy = schy/2;
-		}
 		us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
 
-		/* make sure squaring didn't push extent of schematic frame */
-		if (i == 0)
-		{
-			if (lx < -schx/2)
-			{
-				hx -= schx/2 + lx;
-				lx = -schx/2;
-			}
-			if (hx > schx/2)
-			{
-				lx -= hx - schx/2;
-				hx = schx/2;
-			}
-			if (ly < -schy/2)
-			{
-				hy -= schy/2 + ly;
-				ly = -schy/2;
-			}
-			if (hy > schy/2)
-			{
-				ly -= hy - schy/2;
-				hy = schy/2;
-			}
-		}
-
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", lx, VINTEGER);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenhx", hx, VINTEGER);
@@ -982,19 +924,19 @@ void us_window(INTSML count, char *par[])
 				us_state |= NONOVERLAPPABLEDISPLAY;
 			} else
 			{
-				us_abortcommand("Usage: window overlappable-display [on|off]");
+				ttyputusage("window overlappable-display [on|off]");
 				return;
 			}
 		}
 		if ((us_state&NONOVERLAPPABLEDISPLAY) != 0)
-			ttyputverbose("Overlappable layers will not be handled"); else
-				ttyputverbose("Overlappable layers will be drawn properly");
+			ttyputverbose(_("Overlappable layers will not be handled")); else
+				ttyputverbose(_("Overlappable layers will be drawn properly"));
 		return;
 	}
 
 	if (namesamen(pp, "overview", l) == 0 && l >= 5)
 	{
-		ttyputerr("Cannot make an overview window yet");
+		ttyputerr(_("Cannot make an overview window yet"));
 		return;
 	}
 
@@ -1003,7 +945,7 @@ void us_window(INTSML count, char *par[])
 		np = us_getareabounds(&lx, &hx, &ly, &hy);
 		if (np == NONODEPROTO)
 		{
-			us_abortcommand("Enclose an area to be peeked");
+			us_abortcommand(_("Enclose an area to be peeked"));
 			return;
 		}
 
@@ -1014,7 +956,7 @@ void us_window(INTSML count, char *par[])
 					break;
 			if (w == NOWINDOWPART)
 			{
-				us_abortcommand("Cannot find an editing window with highlighted objects");
+				us_abortcommand(_("Cannot find an editing window with highlighted objects"));
 				return;
 			}
 		}
@@ -1074,7 +1016,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot pan a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only pan circuit editing windows");
+			us_abortcommand(_("Can only pan circuit editing windows"));
 			return;
 		}
 
@@ -1091,7 +1033,7 @@ void us_window(INTSML count, char *par[])
 		if (us_needwindow()) return;
 		if (count <= 1)
 		{
-			us_abortcommand("Usage: window save VIEWNAME");
+			ttyputusage("window save VIEWNAME");
 			return;
 		}
 		windowView[0] = el_curwindowpart->screenlx;
@@ -1107,7 +1049,7 @@ void us_window(INTSML count, char *par[])
 		(void)addstringtoinfstr(par[1]);
 		(void)setval((INTBIG)us_aid, VAID, returninfstr(), (INTBIG)windowView,
 			VINTEGER|VISARRAY|(8<<VLENGTHSH)|VDONTSAVE);
-		ttyputverbose("Window view %s saved", par[1]);
+		ttyputverbose(_("Window view %s saved"), par[1]);
 		return;
 	}
 
@@ -1121,7 +1063,7 @@ void us_window(INTSML count, char *par[])
 			if (namesamen(pp, "horizontal", l) == 0 && l >= 1) splitkey = 1; else
 				if (namesamen(pp, "vertical", l) == 0 && l >= 1) splitkey = 2; else
 			{
-				us_abortcommand("Usage: window split horizontal|vertical");
+				ttyputusage("window split horizontal|vertical");
 				return;
 			}
 		}
@@ -1141,8 +1083,8 @@ void us_window(INTSML count, char *par[])
 				sf = *us_statusfields[i].fieldaddr;
 				if (sf == 0) continue;
 				if (sf->line == 0)
-					ttyputmsg("Window title has %s", us_statusfields[i].fieldaddr); else
-						ttyputmsg("Line %d from %3d%% to %3d%% is %s", sf->line, sf->startper,
+					ttyputmsg(_("Window title has %s"), us_statusfields[i].fieldaddr); else
+						ttyputmsg(_("Line %d from %3d%% to %3d%% is %s"), sf->line, sf->startper,
 							sf->endper, us_statusfields[i].fieldaddr);
 			}
 			return;
@@ -1153,30 +1095,30 @@ void us_window(INTSML count, char *par[])
 			if (count < 3)
 			{
 				if ((us_state&NONPERSISTENTCURNODE) != 0)
-					ttyputmsg("Current node displayed temporarily"); else
-						ttyputmsg("Current node display is persistent");
+					ttyputmsg(_("Current node displayed temporarily")); else
+						ttyputmsg(_("Current node display is persistent"));
 				return;
 			}
 			l = strlen(pp = par[2]);
 			if (namesamen(pp, "persistent", l) == 0)
 			{
 				us_state &= ~NONPERSISTENTCURNODE;
-				ttyputverbose("Current node display is persistent");
+				ttyputverbose(_("Current node display is persistent"));
 				return;
 			}
 			if (namesamen(pp, "temporary", l) == 0)
 			{
 				us_state |= NONPERSISTENTCURNODE;
-				ttyputverbose("Current node displayed temporarily");
+				ttyputverbose(_("Current node displayed temporarily"));
 				return;
 			}
-			us_abortcommand("Usage: find current-node [persistent|temporary]");
+			ttyputusage("window status-bar current-node [persistent|temporary]");
 			return;
 		}
 
 		if (count < 3)
 		{
-			us_abortcommand("Usage: window status-bar %s FIELD...", pp);
+			ttyputusage("window status-bar COMMAND FIELD...");
 			return;
 		}
 
@@ -1191,7 +1133,7 @@ void us_window(INTSML count, char *par[])
 		}
 		if (us_statusfields[i].keyword == 0)
 		{
-			us_abortcommand("Unknown status-bar location: %s", pp);
+			us_abortcommand(_("Unknown status-bar location: %s"), pp);
 			return;
 		}
 
@@ -1208,25 +1150,25 @@ void us_window(INTSML count, char *par[])
 		{
 			if (count < 6)
 			{
-				us_abortcommand("Usage: window status-bar add FIELD LINE STARTPER ENDPER [TITLE]");
+				ttyputusage("window status-bar add FIELD LINE STARTPER ENDPER [TITLE]");
 				return;
 			}
 			lineno = atoi(par[3]);
 			if (lineno < 0 || lineno > ttynumstatuslines())
 			{
-				us_abortcommand("Line number must range from 0 to %d", ttynumstatuslines());
+				us_abortcommand(_("Line number must range from 0 to %d"), ttynumstatuslines());
 				return;
 			}
 			startper = atoi(par[4]);
 			if (startper < 0 || startper > 100)
 			{
-				us_abortcommand("Starting percentage must range from 0 to 100");
+				us_abortcommand(_("Starting percentage must range from 0 to 100"));
 				return;
 			}
 			endper = atoi(par[5]);
 			if (endper <= startper || endper > 100)
 			{
-				us_abortcommand("Ending percentage must range from %d to 100", startper+1);
+				us_abortcommand(_("Ending percentage must range from %d to 100"), startper+1);
 				return;
 			}
 			if (count == 7) fieldname = par[6]; else fieldname = "";
@@ -1235,7 +1177,7 @@ void us_window(INTSML count, char *par[])
 			us_redostatus(NOWINDOWFRAME);
 			return;
 		}
-		us_abortcommand("Usage: window status-bar [add | delete]");
+		ttyputusage("window status-bar [add | delete]");
 		return;
 	}
 
@@ -1265,16 +1207,16 @@ void us_window(INTSML count, char *par[])
 				endobjectchange((INTBIG)us_aid, VAID);
 			} else
 			{
-				us_abortcommand("Usage: window tiny-facets draw|(hash-out [LAMBDAPERPIXEL])");
+				ttyputusage("window tiny-facets draw|(hash-out [LAMBDAPERPIXEL])");
 				return;
 			}
 		}
 		if ((us_useroptions&DRAWTINYFACETS) != 0)
 		{
-			ttyputverbose("Tiny facets will be drawn");
+			ttyputverbose(_("Tiny facets will be drawn"));
 		} else
 		{
-			ttyputverbose("Tiny facets will be hashed-out after %s lambda per pixel",
+			ttyputverbose(_("Tiny facets will be hashed-out after %s lambda per pixel"),
 				frtoa(us_tinyratio));
 		}
 		return;
@@ -1288,7 +1230,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot manipulate a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only adjust circuit editing windows");
+			us_abortcommand(_("Can only adjust circuit editing windows"));
 			return;
 		}
 
@@ -1299,7 +1241,7 @@ void us_window(INTSML count, char *par[])
 		var = getval((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_commandvarname('T'));
 		if (var == NOVARIABLE)
 		{
-			us_abortcommand("Issue an outline before zooming into that area");
+			us_abortcommand(_("Issue an outline before zooming into that area"));
 			return;
 		}
 		size = getlength(var) / 2;
@@ -1321,20 +1263,10 @@ void us_window(INTSML count, char *par[])
 		}
 		if (nogood != 0)
 		{
-			us_abortcommand("Outline not inside window");
+			us_abortcommand(_("Outline not inside window"));
 			return;
 		}
 
-		/* limit schematic windows to their normal extent */
-		i = framesize(&schx, &schy, np);
-		if (i == 0)
-		{
-			if (lx < -schx/2) lx = -schx/2;
-			if (hx > schx/2) hx = schx/2;
-			if (ly < -schy/2) ly = -schy/2;
-			if (hy > schy/2) hy = schy/2;
-		}
-
 		/* save and erase highlighting */
 		us_pushhighlight();
 		us_clearhighlightcount();
@@ -1342,31 +1274,6 @@ void us_window(INTSML count, char *par[])
 		/* set the new window size */
 		us_squarescreen(el_curwindowpart, NOWINDOWPART, 0, &lx, &hx, &ly, &hy);
 
-		/* make sure squaring didn't push extent of schematic frame */
-		if (i == 0)
-		{
-			if (lx < -schx/2)
-			{
-				hx -= schx/2 + lx;
-				lx = -schx/2;
-			}
-			if (hx > schx/2)
-			{
-				lx -= hx - schx/2;
-				hx = schx/2;
-			}
-			if (ly < -schy/2)
-			{
-				hy -= schy/2 + ly;
-				ly = -schy/2;
-			}
-			if (hy > schy/2)
-			{
-				ly -= hy - schy/2;
-				hy = schy/2;
-			}
-		}
-
 		startobjectchange((INTBIG)el_curwindowpart, VWINDOWPART);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenlx", lx, VINTEGER);
 		(void)setval((INTBIG)el_curwindowpart, VWINDOWPART, "screenhx", hx, VINTEGER);
@@ -1406,7 +1313,7 @@ void us_window(INTSML count, char *par[])
 		/* cannot pan a nonstandard window */
 		if ((el_curwindowpart->state&WINDOWTYPE) != DISPWINDOW)
 		{
-			us_abortcommand("Can only pan circuit editing windows");
+			us_abortcommand(_("Can only pan circuit editing windows"));
 			return;
 		}
 
@@ -1422,7 +1329,7 @@ void us_window(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			count = ttygetparam("Window to use: ", &us_windowup, MAXPARS-1, &par[1]) + 1;
+			count = ttygetparam(_("Window to use: "), &us_windowup, MAXPARS-1, &par[1]) + 1;
 			if (count == 1)
 			{
 				us_abortedmsg();
@@ -1440,7 +1347,7 @@ void us_window(INTSML count, char *par[])
 		}
 		if (w == NOWINDOWPART)
 		{
-			us_abortcommand("No window named '%s'", par[1]);
+			us_abortcommand(_("No window named '%s'"), par[1]);
 			return;
 		}
 		(void)setvalkey((INTBIG)us_aid, VAID, us_current_window, (INTBIG)w, VWINDOWPART|VDONTSAVE);
@@ -1459,13 +1366,13 @@ void us_window(INTSML count, char *par[])
 				(void)setval((INTBIG)us_aid, VAID, "aidstate", us_aid->aidstate & ~INTEGRAL, VINTEGER);
 			else
 			{
-				us_abortcommand("Usage: window zoom-scale integral|nonintegral");
+				ttyputusage("window zoom-scale integral|nonintegral");
 				return;
 			}
 		}
 		if ((us_aid->aidstate&INTEGRAL) == 0)
-			ttyputverbose("Window scaling will be continuous"); else
-				ttyputverbose("Window scaling will force integral pixel alignment");
+			ttyputverbose(_("Window scaling will be continuous")); else
+				ttyputverbose(_("Window scaling will force integral pixel alignment"));
 		return;
 	}
 
@@ -1475,7 +1382,7 @@ void us_window(INTSML count, char *par[])
 
 		if (strcmp(el_curwindowpart->location, "entire") == 0)
 		{
-			ttyputmsg("Already displaying only one window");
+			ttyputmsg(_("Already displaying only one window"));
 			return;
 		}
 
@@ -1493,7 +1400,7 @@ void us_window(INTSML count, char *par[])
 		neww = newwindowpart("entire", oldw);
 		if (neww == NOWINDOWPART)
 		{
-			ttyputerr("No memory for windows");
+			ttyputnomemory();
 			return;
 		}
 
@@ -1529,7 +1436,7 @@ void us_window(INTSML count, char *par[])
 		w = el_curwindowpart;
 		if (count < 2)
 		{
-			us_abortcommand("Usage: window 3-dimensional OPTION");
+			ttyputusage("window 3-dimensional OPTION");
 			return;
 		}
 
@@ -1538,12 +1445,12 @@ void us_window(INTSML count, char *par[])
 		{
 			if ((w->state&WINDOWTYPE) == DISP3DWINDOW)
 			{
-				ttyputmsg("Window already shown in 3 dimensions");
+				ttyputmsg(_("Window already shown in 3 dimensions"));
 				return;
 			}
 			if ((w->state&WINDOWTYPE) != DISPWINDOW)
 			{
-				us_abortcommand("Cannot view this window in 3 dimensions");
+				us_abortcommand(_("Cannot view this window in 3 dimensions"));
 				return;
 			}
 
@@ -1565,12 +1472,12 @@ void us_window(INTSML count, char *par[])
 		{
 			if ((w->state&WINDOWTYPE) == DISPWINDOW)
 			{
-				ttyputmsg("Window already shown in 2 dimensions");
+				ttyputmsg(_("Window already shown in 2 dimensions"));
 				return;
 			}
 			if ((w->state&WINDOWTYPE) != DISP3DWINDOW)
 			{
-				us_abortcommand("Cannot view this window in 2 dimensions");
+				us_abortcommand(_("Cannot view this window in 2 dimensions"));
 				return;
 			}
 
@@ -1608,7 +1515,7 @@ void us_window(INTSML count, char *par[])
 		}
 	}
 
-	us_abortcommand("Bad WINDOW option: %s", par[0]);
+	ttyputbadusage("window");
 }
 
 void us_yanknode(INTSML count, char *par[])
@@ -1621,7 +1528,7 @@ void us_yanknode(INTSML count, char *par[])
 	list = us_gethighlighted(OBJNODEINST);
 	if (list[0] == NOGEOM)
 	{
-		us_abortcommand("Must highlight facet(s) to be yanked");
+		us_abortcommand(_("Must highlight facet(s) to be yanked"));
 		return;
 	}
 
@@ -1643,5 +1550,5 @@ void us_yanknode(INTSML count, char *par[])
 		found++;
 	}
 
-	if (found == 0) us_abortcommand("Can only yank facets");
+	if (found == 0) us_abortcommand(_("Can only yank facets"));
 }
