@@ -67,13 +67,13 @@ void us_dumpfields(char***, INTSML, INTSML, FILE*, char*);
 
 /*
  * this routine converts facet "oldfacet" to one of technology "newtech".
- * Returns the address of the new facet
+ * Returns the address of the new facet (NONODEPROTO on error).
  */
 NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 {
 	NODEPROTO *newfacet, *np;
 	NODEPROTO *(*localconversion)(NODEPROTO*, TECHNOLOGY*);
-	REGISTER TECHNOLOGY *oldtech;
+	REGISTER TECHNOLOGY *oldtech, *tech;
 	REGISTER ARCINST *ai;
 	REGISTER LIBRARY *lib;
 	VARIABLE *var;
@@ -81,8 +81,8 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 	/* cannot convert text-only views */
 	if ((oldfacet->cellview->viewstate&TEXTVIEW) != 0)
 	{
-		ttyputerr("Cannot convert textual views: only layout and schematic");
-		return(0);
+		ttyputerr(_("Cannot convert textual views: only layout and schematic"));
+		return(NONODEPROTO);
 	}
 
 	/* separate code if converting to the schematic technology */
@@ -129,7 +129,12 @@ NODEPROTO *us_convertfacet(NODEPROTO *oldfacet, TECHNOLOGY *newtech)
 	} else
 	{
 		/* do general conversion between technologies */
-		oldtech = whattech(oldfacet);
+		oldtech = oldfacet->tech;
+
+		/* reset flag that primitive cannot be converted */
+		for(tech = el_technologies; tech != NOTECHNOLOGY; tech = tech->nexttechnology)
+			for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
+				np->temp1 = 0;
 		newfacet = us_tran_makelayoutfacets(oldfacet, oldfacet->cell->cellname,
 			oldtech, newtech, el_layoutview);
 	}
@@ -158,8 +163,8 @@ NODEPROTO *us_tran_linkage(char *newfacetname, VIEW *newfacetview, NODEPROTO *fa
 	}
 	newfacet = newnodeproto(facetname, facet->cell->lib);
 	if (newfacet == NONODEPROTO)
-		ttyputmsg("Could not create facet: %s", facetname); else
-			ttyputmsg("Creating new facet: %s", facetname);
+		ttyputmsg(_("Could not create facet: %s"), facetname); else
+			ttyputmsg(_("Creating new facet: %s"), facetname);
 	return(newfacet);
 }
 
@@ -173,7 +178,7 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 	REGISTER PORTPROTO *pp, *pp2;
 	REGISTER PORTARCINST *pi;
 	INTSML type, rotate, trans;
-	INTBIG len, wid, vartype;
+	INTBIG len, wid, vartype, lambda;
 	char ttype[30];
 
 	/*
@@ -252,8 +257,9 @@ void us_tran_logmakenodes(NODEPROTO *facet, NODEPROTO *newfacet, TECHNOLOGY *new
 				transistorsize(ni, &len, &wid);
 				if (len >= 0 && wid >= 0)
 				{
-					len /= ni->proto->tech->deflambda;
-					wid /= ni->proto->tech->deflambda;
+					lambda = lambdaofnode(ni);
+					len /= lambda;
+					wid /= lambda;
 					if (type == NPTRAPMOS || type == NPTRANMOS || type == NPTRADMOS)
 						(void)sprintf(ttype, "%ld/%ld", wid, len); else
 							(void)sprintf(ttype, "%ld", len*wid);
@@ -301,10 +307,9 @@ NODEINST *us_tran_logmakenode(NODEPROTO *prim, NODEINST *orig, INTSML trn, INTSM
 	REGISTER NODEINST *newni;
 	REGISTER TECHNOLOGY *oldtech;
 
-	scaleu = newtech->deflambda;
-	if (orig->proto->primindex == 0) oldtech = whattech(orig->proto); else
-		oldtech = orig->proto->tech;
-	scaled = oldtech->deflambda;
+	scaleu = el_curlib->lambda[newtech->techindex];
+	oldtech = orig->proto->tech;
+	scaled = el_curlib->lambda[oldtech->techindex];
 	cx = muldiv((orig->lowx+orig->highx)/2, scaleu, scaled) - (prim->highx-prim->lowx)/2;
 	cy = muldiv((orig->lowy+orig->highy)/2, scaleu, scaled) - (prim->highy-prim->lowy)/2;
 	defaultnodesize(prim, &sx, &sy);
@@ -574,8 +579,8 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 	if (poly2 == NOPOLYGON) poly2 = allocstaticpolygon(4, us_aid->cluster);
 
 	/* get lambda values */
-	oldlambda = oldtech->deflambda;
-	newlambda = newtech->deflambda;
+	oldlambda = el_curlib->lambda[oldtech->techindex];
+	newlambda = el_curlib->lambda[newtech->techindex];
 
 	/* first convert the nodes */
 	for(ni = oldfacet->firstnodeinst; ni != NONODEINST; ni = ni->nextnodeinst)
@@ -587,7 +592,7 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 				if (newnp->cellview == nview) break;
 			if (newnp != NONODEPROTO)
 			{
-				ttyputerr("No equivalent facet for %s", describenodeproto(ni->proto));
+				ttyputerr(_("No equivalent facet for %s"), describenodeproto(ni->proto));
 				continue;
 			}
 			us_tranplacenode(ni, newnp, newfacet, oldtech, newtech);
@@ -687,18 +692,18 @@ INTSML us_tran_makelayoutparts(NODEPROTO *oldfacet, NODEPROTO *newfacet,
 		if (newarcinst(newap, newwid, newbits, end1, schempp1, x1, y1,
 			end2, schempp2, x2, y2, newfacet) == NOARCINST)
 		{
-			ttyputmsg("Facet %s: can't run arc from node %s port %s at (%s,%s)",
+			ttyputmsg(_("Facet %s: can't run arc from node %s port %s at (%s,%s)"),
 				describenodeproto(newfacet), describenodeinst(end1),
 					schempp1->protoname, latoa(x1), latoa(y1));
-			ttyputmsg("   to node %s port %s at (%s,%s)", describenodeinst(end2),
+			ttyputmsg(_("   to node %s port %s at (%s,%s)"), describenodeinst(end2),
 				schempp2->protoname, latoa(x2), latoa(y2));
 		}
 	}
 
 	/* print warning if arcs were made nonmanhattan */
 	if (badarcs != 0)
-		ttyputmsg("WARNING: %d %s made not-fixed-angle in facet %s", badarcs,
-			makeplural("arc", badarcs), describenodeproto(newfacet));
+		ttyputmsg(_("WARNING: %d %s made not-fixed-angle in facet %s"), badarcs,
+			makeplural(_("arc"), badarcs), describenodeproto(newfacet));
 	return(univarcs);
 }
 
@@ -715,17 +720,22 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 	REGISTER PORTPROTO *pp, *pp2;
 	REGISTER VARIABLE *var;
 
-	newlambda = newtech->deflambda;
-	oldlambda = oldtech->deflambda;
+	oldlambda = el_curlib->lambda[oldtech->techindex];
+	newlambda = el_curlib->lambda[newtech->techindex];
 
 	/* scale edge offsets if this is a primitive */
 	trn = ni->transpose;
 	if (ni->proto->primindex != 0)
 	{
+		/* get offsets for new node type */
+		nodeprotosizeoffset(newnp, &nlx, &nly, &nhx, &nhy);
+
 		/* special case for schematic transistors: get size from description */
 		if (((ni->proto->userbits&NFUNCTION) >> NFUNCTIONSH) == NPTRANS)
 		{
 			transistorsize(ni, &bx, &by);
+			if (bx < 0) bx = newnp->highx - newnp->lowx - nlx - nhx;
+			if (by < 0) by = newnp->highy - newnp->lowy - nly - nhy;
 			lx = (ni->lowx + ni->highx - bx) / 2;
 			hx = (ni->lowx + ni->highx + bx) / 2;
 			ly = (ni->lowy + ni->highy - by) / 2;
@@ -733,8 +743,8 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 			trn = 1 - trn;
 
 			/* compute scaled size for new node */
-			newsx = muldiv(hx - lx, newlambda, el_curtech->deflambda);
-			newsy = muldiv(hy - ly, newlambda, el_curtech->deflambda);
+			newsx = muldiv(hx - lx, newlambda, oldlambda);
+			newsy = muldiv(hy - ly, newlambda, oldlambda);
 		} else
 		{
 			/* compute true bounds of old node */
@@ -751,9 +761,6 @@ void us_tranplacenode(NODEINST *ni, NODEPROTO *newnp, NODEPROTO *newfacet,
 		x1 = muldiv((hx + lx) / 2, newlambda, oldlambda);
 		y1 = muldiv((hy + ly) / 2, newlambda, oldlambda);
 
-		/* get offsets for new node type */
-		nodeprotosizeoffset(newnp, &nlx, &nly, &nhx, &nhy);
-
 		/* compute bounds of the new node */
 		newlx = x1 - newsx/2 - nlx;   newhx = newlx + newsx + nlx + nhx;
 		newly = y1 - newsy/2 - nly;   newhy = newly + newsy + nly + nhy;
@@ -847,7 +854,7 @@ PORTPROTO *us_convport(NODEINST *ni, NODEINST *newni, PORTPROTO *oldpp)
 	if (oldfun == NPCAPAC && newfun == NPCAPAC) return(newni->proto->firstportproto);
 
 	/* association has failed: assume the first port */
-	ttyputmsg("No port association between %s, port %s and %s",
+	ttyputmsg(_("No port association between %s, port %s and %s"),
 		describenodeproto(ni->proto), oldpp->protoname,
 			describenodeproto(newni->proto));
 	return(newni->proto->firstportproto);
@@ -871,7 +878,7 @@ ARCPROTO *us_figurenewaproto(ARCPROTO *oldap, TECHNOLOGY *newtech)
 		if ((INTBIG)((ap->userbits&AFUNCTION) >> AFUNCTIONSH) == type) break;
 	if (ap == NOARCPROTO)
 	{
-		ttyputmsg("No equivalent arc for %s", describearcproto(oldap));
+		ttyputmsg(_("No equivalent arc for %s"), describearcproto(oldap));
 		return(oldap);
 	}
 	return(ap);
@@ -883,7 +890,7 @@ ARCPROTO *us_figurenewaproto(ARCPROTO *oldap, TECHNOLOGY *newtech)
  */
 NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 {
-	REGISTER INTSML type, i, j, k;
+	REGISTER INTBIG type, i, j, k;
 	REGISTER ARCPROTO *ap, *oap;
 	REGISTER INTBIG important, funct;
 	REGISTER NODEPROTO *np, *rnp, *oldnp;
@@ -903,7 +910,7 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 	if (type == NPNODE)
 	{
 		/* get the polygon describing the first box of the old node */
-		(void)nodepolys(oldni);
+		(void)nodepolys(oldni, 0);
 		shapenodepoly(oldni, 0, poly);
 		important = LFTYPE | LFPSEUDO | LFNONELEC;
 		funct = layerfunction(oldnp->tech, poly->layer) & important;
@@ -914,7 +921,7 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 			if (((np->userbits&NFUNCTION) >> NFUNCTIONSH) != NPNODE) continue;
 			ni = dummynode();
 			ni->proto = np;
-			(void)nodepolys(ni);
+			(void)nodepolys(ni, 0);
 			shapenodepoly(ni, 0, poly);
 			if ((layerfunction(newtech, poly->layer)&important) == funct)
 				return(np);
@@ -962,7 +969,11 @@ NODEPROTO *us_figurenewnproto(NODEINST *oldni, TECHNOLOGY *newtech)
 	/* give up if it still cannot be determined */
 	if (i != 1)
 	{
-		ttyputmsg("No equivalent node for %s", describenodeproto(oldnp));
+		if (oldnp->temp1 == 0)
+			ttyputmsg(_("Node %s (function %s) has no equivalent in the %s technology"),
+				describenodeproto(oldnp), nodefunctionname((INTSML)type, oldni),
+					newtech->techname);
+		oldnp->temp1 = 1;
 		return(oldnp);
 	}
 	return(rnp);
@@ -983,8 +994,9 @@ void us_printtechnology(TECHNOLOGY *tech)
 	REGISTER char **names, **colors, **styles, **cifs, **gdss,
 		**funcs, **layers, **layersizes, **extensions, **angles, **wipes, **ports,
 		**portsizes, **portangles, **connections;
-	REGISTER INTSML i, j, k, l, m, tot, base, saveunit;
-	REGISTER INTBIG func, area, bits;
+	REGISTER INTBIG i, j, k, l, m, tot, base;
+	REGISTER INTSML saveunit;
+	REGISTER INTBIG func, area, bits, lambda;
 	INTBIG lx, hx, ly, hy;
 	REGISTER ARCINST *ai;
 	REGISTER ARCPROTO *ap;
@@ -997,7 +1009,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	REGISTER TECH_NODES *nodestr;
 	TECH_POLYGON *lay;
 	static POLYGON *poly = NOPOLYGON;
-	extern INTSML tech_realpolys;
+	extern INTBIG tech_realpolys;
 
 	/* get polygon */
 	if (poly == NOPOLYGON) poly = allocstaticpolygon(4, us_aid->cluster);
@@ -1006,13 +1018,13 @@ void us_printtechnology(TECHNOLOGY *tech)
 	(void)addstringtoinfstr(tech->techname);
 	(void)addstringtoinfstr(".doc");
 	name = returninfstr();
-	f = xcreate(name, FILETYPETEXT, "Technology Documentation File", &truename);
+	f = xcreate(name, el_filetypetext, _("Technology Documentation File"), &truename);
 	if (f == NULL)
 	{
-		if (truename != 0) us_abortcommand("Cannot write %s", truename);
+		if (truename != 0) us_abortcommand(_("Cannot write %s"), truename);
 		return;
 	}
-	ttyputverbose("Writing: %s", name);
+	ttyputverbose(_("Writing: %s"), name);
 
 	/****************************** dump layers ******************************/
 
@@ -1042,7 +1054,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	/* compute each layer */
 	for(i=0; i<tech->layercount; i++)
 	{
-		(void)allocstring(&names[i+1], layername(tech, i), el_tempcluster);
+		(void)allocstring(&names[i+1], layername(tech, (INTSML)i), el_tempcluster);
 
 		gra = tech->layers[i];
 		if (ecolorname(gra->col, &fieldname, &colorsymbol) != 0) fieldname = "?";
@@ -1162,7 +1174,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 			if (tech->shapearcpoly != 0) (*(tech->shapearcpoly))(ai, k, poly); else
 			{
 				arclay = &tech->arcprotos[ap->arcindex]->list[k];
-				makearcpoly(ai->length, defaultarcwidth(ap)-arclay->off*tech->deflambda/WHOLE,
+				makearcpoly(ai->length, defaultarcwidth(ap)-arclay->off*lambdaofarc(ai)/WHOLE,
 					ai, poly, arclay->style);
 				poly->layer = arclay->lay;
 			}
@@ -1188,7 +1200,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	fields[0] = names;        fields[1] = layers;   fields[2] = layersizes;
 	fields[3] = extensions;   fields[4] = angles;   fields[5] = wipes;
 	fields[6] = funcs;
-	us_dumpfields(fields, 7, tot, f, "ARCS");
+	us_dumpfields(fields, 7, (INTSML)tot, f, "ARCS");
 	for(i=0; i<tot; i++)
 	{
 		efree(names[i]);
@@ -1215,7 +1227,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	for(np = tech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		ni->proto = np;
-		if (tech->nodepolys != 0) j = (*(tech->nodepolys))(ni); else
+		if (tech->nodepolys != 0) j = (*(tech->nodepolys))(ni, 0); else
 			j = tech->nodeprotos[np->primindex-1]->layercount;
 		l = 0;
 		for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
@@ -1261,21 +1273,22 @@ void us_printtechnology(TECHNOLOGY *tech)
 		ni->proto = np;
 		ni->lowx = np->lowx;   ni->highx = np->highx;
 		ni->lowy = np->lowy;   ni->highy = np->highy;
-		if (tech->nodepolys != 0) j = (*(tech->nodepolys))(ni); else
+		if (tech->nodepolys != 0) j = (*(tech->nodepolys))(ni, 0); else
 			tech_realpolys = j = tech->nodeprotos[np->primindex-1]->layercount;
 		for(k=0; k<j; k++)
 		{
 			if (tech->shapenodepoly != 0) (*(tech->shapenodepoly))(ni, k, poly); else
 			{
 				nodestr = tech->nodeprotos[np->primindex-1];
+				lambda = el_curlib->lambda[tech->techindex];
 				if (nodestr->special == SERPTRANS)
 				{
-					tech_filltrans(poly, &lay, nodestr->gra, ni, tech->deflambda, k,
-						(TECH_PORTS *)0);
+					tech_filltrans(poly, &lay, nodestr->gra, ni,
+						lambda, k, (TECH_PORTS *)0);
 				} else
 				{
 					lay = &nodestr->layerlist[k];
-					tech_fillpoly(poly, lay, ni, tech->deflambda, FILLED);
+					tech_fillpoly(poly, lay, ni, lambda, FILLED);
 				}
 			}
 			(void)allocstring(&layers[tot], layername(tech, poly->layer), el_tempcluster);
@@ -1341,7 +1354,7 @@ void us_printtechnology(TECHNOLOGY *tech)
 	fields[0] = names;        fields[1] = funcs;    fields[2] = layers;
 	fields[3] = layersizes;   fields[4] = ports;    fields[5] = portsizes;
 	fields[6] = portangles;   fields[7] = connections;
-	us_dumpfields(fields, 8, tot, f, "NODES");
+	us_dumpfields(fields, 8, (INTSML)tot, f, "NODES");
 	for(i=0; i<tot; i++)
 	{
 		efree(names[i]);
