@@ -35,10 +35,6 @@
 #include "usrtrack.h"
 #include "edialogs.h"
 
-#define	DELETECHAR    010				/* the Delete character */
-#define	BSCHAR       0177				/* the Backspace character */
-#define	ESCCHAR       033				/* the Escape character */
-
 #define	THUMBSIZE   16					/* width of the thumb area in scroll slider */
 #define	HEADERLINES  2					/* number of lines of text at top of editor */
 #define	LEFTINDENT   4					/* space between left edge and text */
@@ -214,15 +210,15 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 		if (e->maxlines <= 0) e->maxlines = 1;
 		e->mostchars = e->screenchars;
 		e->formerline = (char *)emalloc(e->mostchars+1, us_aid->cluster);
-		if (e->formerline == 0) ttyputerr("No memory for save buffer");
+		if (e->formerline == 0) ttyputnomemory();
 		e->textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_aid->cluster);
-		if (e->textarray == 0) ttyputerr("No memory for text");
+		if (e->textarray == 0) ttyputnomemory();
 		e->maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_aid->cluster);
-		if (e->maxchars == 0) ttyputerr("No memory for characters");
+		if (e->maxchars == 0) ttyputnomemory();
 		for(i=0; i<e->maxlines; i++)
 		{
 			e->textarray[i] = (char *)emalloc(DEFAULTWID, us_aid->cluster);
-			if (e->textarray[i] == 0) ttyputerr("No memory for line");
+			if (e->textarray[i] == 0) ttyputnomemory();
 			e->maxchars[i] = DEFAULTWID;
 		}
 	} else
@@ -251,6 +247,14 @@ WINDOWPART *us_editpacmakeeditor(WINDOWPART *oriwin, char *header, INTSML *chars
 	return(win);
 }
 
+/*
+ * routine to free all memory associated with this module (at exit time)
+ */
+void us_freeedpacmemory(void)
+{
+	if (us_editpacbuffer != 0) efree(us_editpacbuffer);
+}
+
 /*
  * routine to free all memory associated with this editor
  */
@@ -395,7 +399,7 @@ void us_editpacdeleteline(WINDOWPART *win, INTBIG lindex)
 	us_editpacbeginwork(win);
 
 	/* fake the deletion character */
-	(void)us_editpacimplementchar(win, DELETECHAR, 0);
+	(void)us_editpacimplementchar(win, DELETEKEY, 0);
 
 	/* send out pending changes */
 	us_editpacshipchanges(win);
@@ -475,20 +479,20 @@ void us_editpacwritetextfile(WINDOWPART *win, char *file)
 	/* find the last line */
 	if (e->linecount <= 0)
 	{
-		ttyputerr("File is empty");
+		ttyputerr(_("File is empty"));
 		return;
 	}
 
-	f = xcreate(file, FILETYPETEXT, "Text File", &truename);
+	f = xcreate(file, el_filetypetext, _("Text File"), &truename);
 	if (f == NULL)
 	{
-		if (truename != 0) ttyputerr("Cannot write %s", truename);
+		if (truename != 0) ttyputerr(_("Cannot write %s"), truename);
 		return;
 	}
 
 	for(i = 0; i < e->linecount; i++) xprintf(f, "%s\n", e->textarray[i]);
 	xclose(f);
-	ttyputmsg("%s written", truename);
+	ttyputmsg(_("%s written"), truename);
 }
 
 /*
@@ -507,10 +511,10 @@ void us_editpacreadtextfile(WINDOWPART *win, char *file)
 	if (e == NOEDITOR) return;
 
 	/* get the file */
-	f = xopen(file, FILETYPETEXT, "", &filename);
+	f = xopen(file, el_filetypetext, "", &filename);
 	if (f == NULL)
 	{
-		ttyputerr("Cannot read %s", file);
+		ttyputerr(_("Cannot read %s"), file);
 		return;
 	}
 	filelength = filesize(f);
@@ -523,12 +527,10 @@ void us_editpacreadtextfile(WINDOWPART *win, char *file)
 		}
 		DiaPercent(1, 0);
 		(void)initinfstr();
-		(void)addstringtoinfstr("Reading ");
-		(void)addstringtoinfstr(file);
-		(void)addstringtoinfstr("...");
+		(void)formatinfstr(_("Reading %s..."), file);
 		DiaSetText(2, returninfstr());
 	} else
-		ttyputmsg("Reading %s", file);
+		ttyputmsg(_("Reading %s"), file);
 
 	e->state |= EGRAPHICSOFF;
 	for(i=0; i<e->maxlines; i++) e->textarray[i][0] = 0;
@@ -573,7 +575,7 @@ void us_editpacreadtextfile(WINDOWPART *win, char *file)
 	if (filelength > 0)
 	{
 		DiaPercent(1, 100);
-		DiaSetText(2, "Cleaning up...");
+		DiaSetText(2, _("Cleaning up..."));
 	}
 	(*win->changehandler)(win, REPLACEALLTEXT, "", (char *)e->textarray, e->linecount);
 	if (filelength > 0) DiaDoneDialog();
@@ -641,7 +643,7 @@ INTSML us_editpacgotchar(WINDOWPART *win, INTSML i)
 	us_editpacinvertselection(win);
 	if (us_editpacimplementchar(win, i, 1) != 0) return(1);
 	us_editpacinvertselection(win);
-	setactivity("Text Editing");
+	setactivity(_("Text Editing"));
 	return(0);
 }
 
@@ -658,7 +660,7 @@ void us_editpaccut(WINDOWPART *win)
 	/* remove the selection from the edit buffer */
 	screensettextsize(win, us_editpacfont);
 	us_editpacinvertselection(win);
-	(void)us_editpacimplementchar(win, DELETECHAR, 1);
+	(void)us_editpacimplementchar(win, DELETEKEY, 1);
 	us_editpacinvertselection(win);
 }
 
@@ -747,7 +749,7 @@ void us_editpacundo(WINDOWPART *win)
 	e->curline = us_editpacundonewcurline;    e->curchar = us_editpacundonewcurchar;
 	e->endline = us_editpacundonewendline;    e->endchar = us_editpacundonewendchar;
 	us_editpacbeginwork(win);
-	if (savebuffer[0] == 0) (void)us_editpacimplementchar(win, DELETECHAR, 1); else
+	if (savebuffer[0] == 0) (void)us_editpacimplementchar(win, DELETEKEY, 1); else
 		for(i=0; savebuffer[i] != 0; i++)
 			(void)us_editpacimplementchar(win, savebuffer[i], 1);
 	us_editpacinvertselection(win);
@@ -1291,7 +1293,7 @@ INTSML us_editpacimplementchar(WINDOWPART *win, INTSML i, INTSML fromuser)
 	if (e == NOEDITOR) return(1);
 
 	/* ESCAPE quits the editor */
-	if (i == ESCCHAR) return(1);
+	if (i == ESCKEY) return(1);
 
 	if (i == LEFTARROWKEY)
 	{
@@ -1368,7 +1370,7 @@ INTSML us_editpacimplementchar(WINDOWPART *win, INTSML i, INTSML fromuser)
 	}
 
 	/* if delete key hit and nothing selected, set to erase previous character */
-	if (i == DELETECHAR || i == BSCHAR)
+	if (i == DELETEKEY || i == BACKSPACEKEY)
 	{
 		if (e->curline == e->endline && e->curchar == e->endchar)
 		{
@@ -1398,7 +1400,7 @@ INTSML us_editpacimplementchar(WINDOWPART *win, INTSML i, INTSML fromuser)
 	/* mark a dirty edit buffer */
 	e->dirty = 1;
 	us_editpacamtyping(e);
-	if (i == DELETECHAR || i == BSCHAR) us_editpactypeddelete(e);
+	if (i == DELETEKEY || i == BACKSPACEKEY) us_editpactypeddelete(e);
 
 	/* remove the selected characters */
 	us_editpacremoveselection(win);
@@ -1407,7 +1409,7 @@ INTSML us_editpacimplementchar(WINDOWPART *win, INTSML i, INTSML fromuser)
 	e->charposition = e->endchar;
 
 	/* ignore delete or backspace characters */
-	if (i == DELETECHAR || i == BSCHAR) return(0);
+	if (i == DELETEKEY || i == BACKSPACEKEY) return(0);
 
 	/* self-insert of normal characters */
 	if (i == '\t') i = ' ';
@@ -1770,14 +1772,14 @@ void us_editpacsetheader(WINDOWPART *win, char *header)
 	e->horizfactor = 0;
 	us_editpactext(win, header, 0, -2);
 	if ((win->state&WINDOWTYPE) == POPTEXTWINDOW)
-		us_editpactext(win, "Type RETURN when done", 0, -1); else
+		us_editpactext(win, _("Point-and-Click editor: type RETURN when done"), 0, -1); else
 	{
 		if (strcmp(win->location, "entire") != 0)
-			us_editpactext(win, "Type ESC when done", 0, -1); else
+			us_editpactext(win, _("Point-and-Click editor: type ESC when done"), 0, -1); else
 		{
 			if (graphicshas(CANUSEFRAMES) != 0)
-				us_editpactext(win, "Close the window when done", 0, -1); else
-					us_editpactext(win, "This facet is purely textual", 0, -1);
+				us_editpactext(win, _("Point-and-Click editor: close the window when done"), 0, -1); else
+					us_editpactext(win, _("Point-and-Click editor: text-only facet"), 0, -1);
 		}
 	}
 	e->horizfactor = formerhf;
@@ -2043,9 +2045,9 @@ void us_editpacaddmorelines(EDITOR *e)
 
 	/* allocate new arrays */
 	maxchars = (INTSML *)emalloc((e->maxlines * SIZEOFINTSML), us_aid->cluster);
-	if (maxchars == 0) ttyputerr("No memory for line lengths");
+	if (maxchars == 0) ttyputnomemory();
 	textarray = (char **)emalloc((e->maxlines * (sizeof (char *))), us_aid->cluster);
-	if (textarray == 0) ttyputerr("No memory for line pointers");
+	if (textarray == 0) ttyputnomemory();
 
 	/* copy old information */
 	for(i=0; i<e->maxlines; i++)
@@ -2053,7 +2055,7 @@ void us_editpacaddmorelines(EDITOR *e)
 		if (i >= oldlines)
 		{
 			textarray[i] = (char *)emalloc(DEFAULTWID, us_aid->cluster);
-			if (textarray[i] == 0) ttyputerr("No memory for line");
+			if (textarray[i] == 0) ttyputnomemory();
 			textarray[i][0] = 0;
 			maxchars[i] = DEFAULTWID;
 		} else
@@ -2138,7 +2140,7 @@ void us_editpacinvertrectframe(WINDOWPART *win, INTSML x, INTSML y)
  */
 void us_editpactext(WINDOWPART *win, char *str, INTSML x, INTSML y)
 {
-	INTSML xpos, len, diff, save;
+	INTSML xpos, len, diff, i, clip;
 	REGISTER EDITOR *e;
 
 	e = win->editor;
@@ -2164,9 +2166,10 @@ void us_editpactext(WINDOWPART *win, char *str, INTSML x, INTSML y)
 
 	if (len + x - e->horizfactor > e->screenchars)
 	{
-		save = str[e->screenchars + e->horizfactor - x];
-		str[e->screenchars + e->horizfactor - x] = 0;
-	} else save = 0;
+		(void)initinfstr();
+		clip = e->screenchars + e->horizfactor - x;
+		for(i=0; i<clip; i++) (void)addtoinfstr(str[i]);
+		str = returninfstr();
+	}
 	screendrawtext(win, (INTSML)(xpos + e->offx), (INTSML)(e->revy-(y+1)*us_thei), str, &us_menutext);
-	if (save != 0) str[e->screenchars + e->horizfactor - x] = (char)save;
 }
