@@ -52,12 +52,11 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	REGISTER char **drclist, *lay, *dxf, **sequence, **varnames, *fname;
 	REGISTER INTBIG i, j, k, l, total, e, xs, ys, oldlam, *newmap, *mapptr,
 		drccount, drcindex, tcon, func, serp, gds, nodexpos, portdescript, bits,
-		drcminwid, height3d, thick3d;
+		drcminwid, height3d, thick3d, lambda, min2x, min2y;
 	REGISTER INTSML first;
 	INTBIG lx, hx, ly, hy, xpos[4], ypos[4], xsc[4], ysc[4], lxo, hxo, lyo, hyo,
 		lxp, hxp, lyp, hyp;
 	REGISTER NODEPROTO *np, **nplist, *pnp, **aplist;
-	REGISTER TECH_COLORMAP *colmap;
 	float spires, spicap, spiecap;
 	REGISTER VARIABLE *var, *var2, *var3, *var5, *var6, *var7, *var8, *var9,
 		*var10, *var11, *varred, *vargreen, *varblue;
@@ -68,15 +67,16 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	REGISTER CELL *c;
 	REGISTER GRAPHICS *desc;
 	static POLYGON *poly = NOPOLYGON;
-	extern AIDENTRY *net_aid;
 	REGISTER TECH_POLYGON *ll;
+	REGISTER TECH_NODES *techn;
+	REGISTER TECH_COLORMAP *colmap;
 
 	/* make sure network tool is on */
 	if ((net_aid->aidstate&AIDON) == 0)
 	{
-		ttyputerr("Network tool must be running...turning it on");
+		ttyputerr(_("Network tool must be running...turning it on"));
 		aidturnon(net_aid, 0);
-		ttyputerr("...now reissue the technology editing command");
+		ttyputerr(_("...now reissue the technology editing command"));
 		return(NOLIBRARY);
 	}
 
@@ -86,15 +86,21 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	lib = newlibrary(tech->techname, tech->techname);
 	if (lib == NOLIBRARY)
 	{
-		ttyputerr("Cannot create library %s", tech->techname);
+		ttyputerr(_("Cannot create library %s"), tech->techname);
 		return(NOLIBRARY);
 	}
-	ttyputmsg("Created library %s...", tech->techname);
+	ttyputmsg(_("Created library %s..."), tech->techname);
 
 	/* create the information node */
 	np = newnodeproto("factors", lib);
 	if (np == NONODEPROTO) return(NOLIBRARY);
-	us_tecedmakeinfo(np, tech->deflambda, tech->techdescript);
+
+	/* modify this technology's lambda value to match the current one */
+	oldlam = lib->lambda[tech->techindex];
+	lambda = lib->lambda[art_tech->techindex];
+	lib->lambda[tech->techindex] = lambda;
+
+	us_tecedmakeinfo(np, lambda, tech->techdescript);
 
 	/* copy any miscellaneous variables and make a list of their names */
 	j = 0;
@@ -124,12 +130,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	nplist = (NODEPROTO **)emalloc((total * (sizeof (NODEPROTO *))), el_tempcluster);
 	if (nplist == 0) return(NOLIBRARY);
 
-	/* modify this technology's lambda value to match the current one */
-	oldlam = tech->deflambda;
-	tech->deflambda = art_tech->deflambda;
-
 	/* create the layer nodes */
-	ttyputmsg("Creating the layers...");
+	ttyputmsg(_("Creating the layers..."));
 	var2 = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_cif_layer_names");
 	var3 = getval((INTBIG)tech, VTECHNOLOGY, VINTEGER|VISARRAY, "IO_gds_layer_numbers");
 	var8 = getval((INTBIG)tech, VTECHNOLOGY, VSTRING|VISARRAY, "IO_dxf_layer_names");
@@ -151,7 +153,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
 			if (namesame(fname, c->cellname) == 0)
 		{
-			ttyputerr("Warning: multiple layers named '%s'", fname);
+			ttyputerr(_("Warning: multiple layers named '%s'"), fname);
 			break;
 		}
 
@@ -204,7 +206,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	efree((char *)sequence);
 
 	/* create the color map information */
-	ttyputmsg("Adding color map and design rules...");
+	ttyputmsg(_("Adding color map and design rules..."));
 	var2 = getval((INTBIG)tech, VTECHNOLOGY, VCHAR|VISARRAY, "USER_color_map");
 	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
 	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
@@ -310,7 +312,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	}
 
 	/* create the arc nodes */
-	ttyputmsg("Creating the arcs...");
+	ttyputmsg(_("Creating the arcs..."));
 	total = 0;
 	for(ap = tech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
 	{
@@ -323,7 +325,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
 			if (namesame(fname, c->cellname) == 0)
 		{
-			ttyputerr("Warning: multiple arcs named '%s'", fname);
+			ttyputerr(_("Warning: multiple arcs named '%s'"), fname);
 			break;
 		}
 
@@ -340,12 +342,12 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		/* now create the arc layers */
 		ai = dummyarc();
 		ai->proto = ap;
-		ai->width = defaultarcwidth(ap) * tech->deflambda / oldlam;
-		ai->end[0].xpos = -60000;
-		ai->end[0].ypos = -10000;
-		ai->end[1].xpos = -30000;
-		ai->end[1].ypos = -10000;
-		ai->length = 30000;
+		ai->width = defaultarcwidth(ap);
+		ai->end[0].xpos = -90000 * oldlam / lambda;
+		ai->end[0].ypos = -10000 * oldlam / lambda;
+		ai->end[1].xpos = -60000 * oldlam / lambda;
+		ai->end[1].ypos = -10000 * oldlam / lambda;
+		ai->length = computedistance(ai->end[0].xpos, ai->end[0].ypos, ai->end[1].xpos, ai->end[1].ypos);
 		j = arcpolys(ai);
 		for(i=0; i<j; i++)
 		{
@@ -354,6 +356,13 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 			desc = tech->layers[poly->layer];
 			if (desc->bits == LAYERN) continue;
 
+			/* scale the arc geometry appropriately */
+			for(k=0; k<poly->count; k++)
+			{
+				poly->xv[k] = poly->xv[k] * lambda / oldlam;
+				poly->yv[k] = poly->yv[k] * lambda / oldlam;
+			}
+
 			/* create the node to describe this layer */
 			ni = us_tecedplacegeom(poly, np);
 			if (ni == NONODEINST) continue;
@@ -363,8 +372,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 			(void)setval((INTBIG)ni, VNODEINST, "EDTEC_layer", (INTBIG)nplist[poly->layer], VNODEPROTO);
 			(void)setval((INTBIG)ni, VNODEINST, "EDTEC_option", LAYERPATCH, VINTEGER);
 		}
-		i = (defaultarcwidth(ap) * tech->deflambda/oldlam - arcwidthoffset(ai)) / 2;
-		ni = newnodeinst(art_boxprim, -60000-i, -30000+i, -10000-i, -10000+i, 0, 0, np);
+		i = (defaultarcwidth(ap) - arcwidthoffset(ai)) / 2 * lambda/oldlam;
+		ni = newnodeinst(art_boxprim, -90000-i, -60000+i, -10000-i, -10000+i, 0, 0, np);
 		if (ni == NONODEINST) return(NOLIBRARY);
 		(void)setvalkey((INTBIG)ni, VNODEINST, art_colorkey, HIGHLIT, VINTEGER);
 		(void)setval((INTBIG)ni, VNODEINST, "EDTEC_layer", (INTBIG)NONODEPROTO, VNODEPROTO);
@@ -383,7 +392,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	efree((char *)sequence);
 
 	/* create the node nodes */
-	ttyputmsg("Creating the nodes...");
+	ttyputmsg(_("Creating the nodes..."));
 	portdescript = defaulttextdescript(NOGEOM);
 	total = 0;
 	for(pnp = tech->firstnodeproto; pnp != NONODEPROTO; pnp = pnp->nextnodeproto)
@@ -394,8 +403,8 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		/* create the node layers */
 		oni = dummynode();
 		oni->proto = pnp;
-		xs = (pnp->highx - pnp->lowx) * 2 * tech->deflambda / oldlam;
-		ys = (pnp->highy - pnp->lowy) * 2 * tech->deflambda / oldlam;
+		xs = (pnp->highx - pnp->lowx) * 2;
+		ys = (pnp->highy - pnp->lowy) * 2;
 		if (xs < 5000) xs = 5000;
 		if (ys < 5000) ys = 5000;
 		nodexpos = -xs*2;
@@ -408,12 +417,24 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 		ypos[2] = -10000 - ys;
 		ypos[3] = -10000 - ys;
 		nodesizeoffset(oni, &lxp, &lyp, &hxp, &hyp);
-		xs = (pnp->highx - pnp->lowx) * tech->deflambda / oldlam - lxp - hxp;
-		ys = (pnp->highy - pnp->lowy) * tech->deflambda / oldlam - lyp - hyp;
-		xsc[0] = 1;   ysc[0] = 1;
-		xsc[1] = 2;   ysc[1] = 1;
-		xsc[2] = 1;   ysc[2] = 2;
-		xsc[3] = 2;   ysc[3] = 2;
+		xs = (pnp->highx - pnp->lowx) - lxp - hxp;
+		ys = (pnp->highy - pnp->lowy) - lyp - hyp;
+		xsc[0] = xs*1;   ysc[0] = ys*1;
+		xsc[1] = xs*2;   ysc[1] = ys*1;
+		xsc[2] = xs*1;   ysc[2] = ys*2;
+		xsc[3] = xs*2;   ysc[3] = ys*2;
+
+		/* for multicut contacts, make large size be just right for 2 cuts */
+		techn = tech->nodeprotos[pnp->primindex-1];
+		if (techn->special == MULTICUT)
+		{
+			min2x = (techn->f1*2 + techn->f3*2 + techn->f4) * oldlam / WHOLE;
+			min2y = (techn->f2*2 + techn->f3*2 + techn->f4) * oldlam / WHOLE;
+			xsc[1] = min2x;
+			xsc[3] = min2x;
+			ysc[2] = min2y;
+			ysc[3] = min2y;
+		}
 		for(e=0; e<4; e++)
 		{
 			/* do not create node if main example had no polygons */
@@ -421,20 +442,26 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 
 			/* square nodes have only two examples */
 			if ((pnp->userbits&NSQUARE) != 0 && (e == 1 || e == 2)) continue;
-			oni->lowx  = xpos[e] - xs*xsc[e]/2 - lxp;
-			oni->lowy  = ypos[e] - ys*ysc[e]/2 - lyp;
-			oni->highx = xpos[e] + xs*xsc[e]/2 + hxp;
-			oni->highy = ypos[e] + ys*ysc[e]/2 + hyp;
+			oni->lowx  = xpos[e] - xsc[e]/2 - lxp;
+			oni->lowy  = ypos[e] - ysc[e]/2 - lyp;
+			oni->highx = xpos[e] + xsc[e]/2 + hxp;
+			oni->highy = ypos[e] + ysc[e]/2 + hyp;
 
 			/* place the layers */
-			j = nodepolys(oni);
+			j = nodepolys(oni, 0);
 			for(i=0; i<j; i++)
 			{
-				shapenodepoly(oni, (INTSML)i, poly);
+				shapenodepoly(oni, i, poly);
 				if (poly->layer < 0) continue;
 				desc = tech->layers[poly->layer];
 				if (desc->bits == LAYERN) continue;
 
+				for(k=0; k<poly->count; k++)
+				{
+					poly->xv[k] = poly->xv[k] * lambda / oldlam;
+					poly->yv[k] = poly->yv[k] * lambda / oldlam;
+				}
+
 				/* create the node facet on the first valid layer */
 				if (first != 0)
 				{
@@ -448,7 +475,7 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 					for(c = lib->firstcell; c != NOCELL; c = c->nextcell)
 						if (namesame(fname, c->cellname) == 0)
 					{
-						ttyputerr("Warning: multiple nodes named '%s'", fname);
+						ttyputerr(_("Warning: multiple nodes named '%s'"), fname);
 						break;
 					}
 
@@ -487,8 +514,11 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 			if (first != 0) continue;
 
 			/* create the highlight node */
-			ni = newnodeinst(art_boxprim, xpos[e]-xs*xsc[e]/2, xpos[e]+xs*xsc[e]/2,
-				ypos[e]-ys*ysc[e]/2, ypos[e]+ys*ysc[e]/2, 0, 0, np);
+			lx = (xpos[e]-xsc[e]/2) * lambda / oldlam;
+			hx = (xpos[e]+xsc[e]/2) * lambda / oldlam;
+			ly = (ypos[e]-ysc[e]/2) * lambda / oldlam;
+			hy = (ypos[e]+ysc[e]/2) * lambda / oldlam;
+			ni = newnodeinst(art_boxprim, lx, hx, ly, hy, 0, 0, np);
 			if (ni == NONODEINST) return(NOLIBRARY);
 			(void)setvalkey((INTBIG)ni, VNODEINST, art_colorkey, HIGHLIT, VINTEGER);
 			(void)setval((INTBIG)ni, VNODEINST, "EDTEC_layer", (INTBIG)NONODEPROTO, VNODEPROTO);
@@ -502,6 +532,10 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 				{
 					lx = hx = xpos[0] + ((INTBIG *)var->addr)[0];
 					ly = hy = ypos[0] + ((INTBIG *)var->addr)[1];
+					lx = lx * lambda / oldlam;
+					hx = hx * lambda / oldlam;
+					ly = ly * lambda / oldlam;
+					hy = hy * lambda / oldlam;
 					nodeprotosizeoffset(gen_facetcenterprim, &lxo, &lyo, &hxo, &hyo);
 					ni = newnodeinst(gen_facetcenterprim, lx-lxo, hx+hxo, ly-lyo, hy+hyo, 0, 0, np);
 					if (ni == NONODEINST) return(NOLIBRARY);
@@ -513,6 +547,10 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 			{
 				shapeportpoly(oni, pp, poly, 0);
 				getbbox(poly, &lx, &hx, &ly, &hy);
+				lx = lx * lambda / oldlam;
+				hx = hx * lambda / oldlam;
+				ly = ly * lambda / oldlam;
+				hy = hy * lambda / oldlam;
 				nodeprotosizeoffset(gen_portprim, &lxo, &lyo, &hxo, &hyo);
 				ni = newnodeinst(gen_portprim, lx-lxo, hx+hxo, ly-lyo, hy+hyo, 0, 0, np);
 				if (ni == NONODEINST) return(NOLIBRARY);
@@ -576,9 +614,9 @@ LIBRARY *us_tecedmakelibfromtech(TECHNOLOGY *tech)
 	efree((char *)sequence);
 
 	/* clean up */
-	ttyputmsg("Done.");
+	ttyputmsg(_("Done."));
 	efree((char *)nplist);
-	tech->deflambda = oldlam;
+	lib->lambda[tech->techindex] = oldlam;
 	return(lib);
 }
 
