@@ -56,8 +56,8 @@ void us_graphfacets(void)
 	graphnp = newnodeproto("FacetStructure", el_curlib);
 	if (graphnp == NONODEPROTO) return;
 	if (graphnp->lastversion != NONODEPROTO)
-		ttyputverbose("Creating new version of facet: FacetStructure"); else
-			ttyputverbose("Creating facet: FacetStructure");
+		ttyputverbose(_("Creating new version of facet: FacetStructure")); else
+			ttyputverbose(_("Creating facet: FacetStructure"));
 
 	/* clear flags on all of the facets */
 	for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
@@ -109,7 +109,7 @@ void us_graphfacets(void)
 	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
 	{
 		if (np->temp1 >= 0) continue;
-		ttyputmsg("Warning: facet %s not found in hierarchy", describenodeproto(np));
+		ttyputmsg(_("Warning: facet %s not found in hierarchy"), describenodeproto(np));
 		np->temp1 = 0;
 	}
 
@@ -138,8 +138,7 @@ void us_graphfacets(void)
 	if (ni == NONODEINST) return;
 	endobjectchange((INTBIG)ni, VNODEINST);
 	(void)initinfstr();
-	(void)addstringtoinfstr("Structure of library ");
-	(void)addstringtoinfstr(el_curlib->libname);
+	(void)formatinfstr(_("Structure of library %s"), el_curlib->libname);
 	(void)setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)returninfstr(),
 		VSTRING|VDISPLAY);
 
@@ -277,8 +276,8 @@ void us_illustratecommandset(void)
 	graphnp = newnodeproto("CommandStructure", el_curlib);
 	if (graphnp == NONODEPROTO) return;
 	if (graphnp->lastversion != NONODEPROTO)
-		ttyputmsg("Creating new version of facet: CommandStructure"); else
-			ttyputmsg("Creating facet: CommandStructure");
+		ttyputmsg(_("Creating new version of facet: CommandStructure")); else
+			ttyputmsg(_("Creating facet: CommandStructure"));
 
 	us_maxillustratedepth = 0;
 	us_maxcommandentries = 0;
@@ -295,7 +294,7 @@ void us_illustratecommandset(void)
 		us_comilllist[i] = us_illustratecommand(us_lcommand[i].name, 0,NOCOMILL);
 	}
 
-	ttyputmsg("%d entries in command graph", us_maxcommandentries);
+	ttyputmsg(_("%d entries in command graph"), us_maxcommandentries);
 
 	/* count the breadth information */
 	j = 0;
@@ -307,7 +306,7 @@ void us_illustratecommandset(void)
 		gen_invispinprim->highx-gen_invispinprim->lowx-YCOMSCALE, 0, 0, graphnp);
 	if (ni == NONODEINST) return;
 	endobjectchange((INTBIG)ni, VNODEINST);
-	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)"Structure of commands",
+	var = setvalkey((INTBIG)ni, VNODEINST, art_messagekey, (INTBIG)_("Structure of commands"),
 		VSTRING|VDISPLAY);
 	if (var != NOVARIABLE) var->textdescript = TXT20P << VTSIZESH;
 
@@ -465,3 +464,75 @@ COMILL *us_illustratecommand(char *name, INTSML depth, COMILL *thisci)
 	}
 	return(ci);
 }
+
+/****************************** PULLDOWN MENU DUMPING ******************************/
+
+/* prototypes for local routines */
+void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix);
+
+/*
+ * Routine to dump the pulldown menus to an indented text file.
+ */
+void us_dumppulldownmenus(void)
+{
+	FILE *io;
+	char *truename;
+	REGISTER INTBIG i;
+	REGISTER POPUPMENU *pm;
+
+	io = xcreate("pulldowns.txt", el_filetypetext, _("Menu dump file"), &truename);
+	if (io == NULL) return;
+
+	xprintf(io, _("Pulldown menus in Electric as of %s\n"),
+		timetostring(getcurrenttime()));
+	for(i=0; i<us_pulldownmenucount; i++)
+	{
+		pm = us_pulldowns[i];
+		xprintf(io, "\n");
+		us_dumppulldownmenu(io, pm, pm->header, "");
+	}
+
+	xclose(io);
+	ttyputmsg(_("Pulldown menus dumped to %s"), truename);
+}
+
+void us_dumppulldownmenu(FILE *io, POPUPMENU *pm, char *name, char *prefix)
+{
+	REGISTER POPUPMENUITEM *mi;
+	REGISTER USERCOM *uc;
+	REGISTER INTBIG i, j, k;
+	char comname[300], subprefix[50];
+
+	for(k=j=0; name[k] != 0; k++)
+		if (name[k] != '&') comname[j++] = name[k];
+	comname[j] = 0;
+
+	xprintf(io, "%s%s:\n", prefix, comname);
+	for(i=0; i<pm->total; i++)
+	{
+		mi = &pm->list[i];
+		uc = mi->response;
+		if (uc->active < 0)
+		{
+			xprintf(io, "%s    ----------\n", prefix);
+			continue;
+		}
+
+		for(k=j=0; mi->attribute[k] != 0; k++)
+		{
+			if (mi->attribute[k] == '&') continue;
+			if (mi->attribute[k] == '/') break;
+			comname[j++] = mi->attribute[k];
+		}
+		comname[j] = 0;
+
+		if (uc->menu != NOPOPUPMENU)
+		{
+			strcpy(subprefix, prefix);
+			strcat(subprefix, "    ");
+			us_dumppulldownmenu(io, uc->menu, comname, subprefix);
+			continue;
+		}
+		xprintf(io, "%s    %s\n", prefix, comname);
+	}
+}
