@@ -33,6 +33,7 @@
 #include "usr.h"
 #include "efunction.h"
 #include "tecart.h"
+#include "tecschem.h"
 
 extern GRAPHICS us_ebox, us_nmbox, us_box;
 
@@ -163,7 +164,7 @@ void us_drawmenu(INTSML scaletofit, WINDOWFRAME *mw)
 void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 {
 	REGISTER INTBIG i, scaleu, scaled, x1, y1, lowx, lowy, highx, highy, xl,
-		yl, xh, yh, ofun, fun;
+		yl, xh, yh, ofun, fun, lambda;
 	REGISTER NODEINST *nodeinst;
 	REGISTER ARCINST *arcinst;
 	REGISTER NODEPROTO *tnp;
@@ -172,8 +173,9 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	REGISTER char *pt;
 	VARIABLE colorvar[2];
 	WINDOWPART ww;
+	XARRAY trans;
 	char line[100];
-	INTSML swid, shei;
+	INTSML swid, shei, pangle;
 	INTBIG pxs, pys;
 	static POLYGON *poly = NOPOLYGON;
 	WINDOWFRAME *menuframe;
@@ -187,7 +189,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	colorvar[0].type = VINTEGER;
 	colorvar[0].addr = el_colmengly;
 
-	if (stopping("Menu")) return;
+	if (stopping(STOPREASONDISPLAY)) return;
 	if ((us_aid->aidstate&MENUON) == 0) return;
 
 	/* parse the menu entry string */
@@ -200,6 +202,7 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	ww.screenlx = ww.screenly = ww.uselx = ww.usely = 0;
 	ww.screenhx = ww.usehx = swid-1;   ww.screenhy = ww.usehy = shei-1;
 	ww.frame = menuframe;
+	ww.curnodeproto = NONODEPROTO;
 	ww.state = DISPWINDOW;
 	computewindowscale(&ww);
 
@@ -214,10 +217,20 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 	if (commandbinding.nodeglyph != NONODEPROTO || commandbinding.arcglyph != NOARCPROTO)
 	{
 		/* graphics will be drawn: draw an outline of background color */
-		maketruerectpoly(xl+1, xh-1, yl+1, yh-1, poly);
 		poly->desc = &us_box;
 		us_box.col = commandbinding.backgroundcolor;
 		poly->style = CLOSEDRECT;
+		if (commandbinding.arcglyph != NOARCPROTO &&
+			commandbinding.arcglyph == us_curarcproto)
+		{
+			maketruerectpoly(xl+2, xh-2, yl+2, yh-2, poly);
+			(void)us_showpoly(poly, &ww);
+			maketruerectpoly(xl+3, xh-3, yl+3, yh-3, poly);
+			(void)us_showpoly(poly, &ww);
+			maketruerectpoly(xl+4, xh-4, yl+4, yh-4, poly);
+			(void)us_showpoly(poly, &ww);
+		}
+		maketruerectpoly(xl+1, xh-1, yl+1, yh-1, poly);
 	} else
 	{
 		/* text will be drawn: fill the entry with background color */
@@ -252,15 +265,34 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 			/* build the dummy nodeinst for menu display */
 			tech = commandbinding.nodeglyph->tech;
 			if (tech == NOTECHNOLOGY) tech = el_curtech;
+			lambda = el_curlib->lambda[tech->techindex];
 			nodeinst = dummynode();
 			nodeinst->proto = commandbinding.nodeglyph;
+			pangle = us_getplacementangle(nodeinst->proto);
+			nodeinst->rotation = pangle % 3600;
+			nodeinst->transpose = pangle / 3600;
 			defaultnodesize(commandbinding.nodeglyph, &pxs, &pys);
 			nodeinst->userbits |= NEXPAND;
-			lowx  = nodeinst->lowx  = -pxs / 2;
+			lowx = nodeinst->lowx  = -pxs / 2;
 			highx = nodeinst->highx = nodeinst->lowx + pxs;
-			lowy  = nodeinst->lowy  = -pys / 2;
+			lowy = nodeinst->lowy  = -pys / 2;
 			highy = nodeinst->highy = nodeinst->lowy + pys;
 
+			/*
+			 * Special hack: the Schematic Transistor does not fill its bounding box
+			 * but stops 1 lambda short of the top.  To center it in the menu square,
+			 * that amount is rotated and the node is shifted thusly.
+			 */
+			if (nodeinst->proto == sch_transistorprim)
+			{
+				makerot(nodeinst, trans);
+				xform(0, el_curlib->lambda[sch_tech->techindex]/2, &pxs, &pys, trans);
+				nodeinst->lowx += pxs;
+				nodeinst->highx += pxs;
+				nodeinst->lowy += pys;
+				nodeinst->highy += pys;
+			}
+
 			/* fake the variable "ART_color" to be the glyph color */
 			nodeinst->firstvar = &colorvar[0];
 			nodeinst->numvar = 1;
@@ -284,13 +316,14 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 		{
 			/* build dummy display arcinst for menu */
 			tech = commandbinding.arcglyph->tech;
+			lambda = el_curlib->lambda[tech->techindex];
 			arcinst = dummyarc();
 			arcinst->proto = commandbinding.arcglyph;
-			arcinst->length = MENUARCLENGTH * commandbinding.arcglyph->tech->deflambda;
+			arcinst->length = MENUARCLENGTH * lambda;
 			arcinst->width = defaultarcwidth(commandbinding.arcglyph);
-			arcinst->end[0].xpos = -MENUARCLENGTH*commandbinding.arcglyph->tech->deflambda/2;
+			arcinst->end[0].xpos = -MENUARCLENGTH*lambda/2;
 			arcinst->end[0].ypos = arcinst->end[1].ypos = 0;
-			arcinst->end[1].xpos = MENUARCLENGTH*commandbinding.arcglyph->tech->deflambda/2;
+			arcinst->end[1].xpos = MENUARCLENGTH*lambda/2;
 			lowx = -(arcinst->width+arcinst->length)/2;  highx = -lowx;
 			lowy = -arcinst->width / 2;                  highy = -lowy;
 
@@ -327,13 +360,13 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 			if (ofun == NPPIN)
 			{
 				for(tap = tech->firstarcproto; tap != NOARCPROTO; tap = tap->nextarcproto)
-					scaled = maxi(scaled, MENUARCLENGTH*tech->deflambda + defaultarcwidth(tap));
+					scaled = maxi(scaled, MENUARCLENGTH*lambda + defaultarcwidth(tap));
 			}
 		} else if (commandbinding.arcglyph != NOARCPROTO)
 		{
 			/* make all arcs be the same scale */
 			for(tap = tech->firstarcproto; tap != NOARCPROTO; tap = tap->nextarcproto)
-				scaled = maxi(scaled, MENUARCLENGTH*tech->deflambda + defaultarcwidth(tap));
+				scaled = maxi(scaled, MENUARCLENGTH*lambda + defaultarcwidth(tap));
 
 			/* and make them the same scale as the pins */
 			for(tnp = tech->firstnodeproto; tnp != NONODEPROTO; tnp = tnp->nextnodeproto)
@@ -368,8 +401,9 @@ void us_drawmenuentry(INTBIG x, INTBIG y, char *str)
 		if (commandbinding.nodeglyph != NONODEPROTO)
 		{
 			begintraversehierarchy();
-			if (us_drawnodeinst(nodeinst, LAYERA, el_matid, 1, &ww) == 2)
-				(void)us_drawnodeinst(nodeinst, LAYERA, el_matid, 2, &ww);
+			makerot(nodeinst, trans);
+			if (us_drawnodeinst(nodeinst, LAYERA, trans, 1, &ww) == 2)
+				(void)us_drawnodeinst(nodeinst, LAYERA, trans, 2, &ww);
 		} else if (commandbinding.arcglyph != NOARCPROTO)
 		{
 			if (us_drawarcinst(arcinst, LAYERA, el_matid, 1, &ww) == 2)
