@@ -66,12 +66,12 @@ INTSML   us_pathisind;					/* pointer into the current keyword list */
 /* List Dialog */
 DIALOGITEM us_listdialogitems[] =
 {
- /*  1 */ {0, {160,216,184,280}, BUTTON, "OK"},
- /*  2 */ {0, {96,216,120,280}, BUTTON, "Cancel"},
+ /*  1 */ {0, {160,216,184,280}, BUTTON, N_("OK")},
+ /*  2 */ {0, {96,216,120,280}, BUTTON, N_("Cancel")},
  /*  3 */ {0, {56,8,200,206}, SCROLL, ""},
  /*  4 */ {0, {8,8,54,275}, MESSAGE, ""}
 };
-DIALOG us_listdialog = {{50,75,259,369}, "", 4, us_listdialogitems};
+DIALOG us_listdialog = {{50,75,259,369}, "", 0, 4, us_listdialogitems};
 
 /* prototypes for local routines */
 INTSML us_addusercom(USERCOM*, char*);
@@ -280,7 +280,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 	us_state &= ~COMMANDFAILED;
 
 	/* stop if interrupted */
-	if (stopping("Execution")) return;
+	if (stopping(STOPREASONEXECUTE)) return;
 
 	/* see if the status display should be cleared */
 	if ((us_state&DIDINPUT) != 0)
@@ -319,7 +319,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 		 * little hack lets the command be executed but may cause all
 		 * kinds of hell in other places.
 		 */
-		ttyputerr("No memory for command execution!");
+		ttyputnomemory();
 		uc = item;
 	}
 
@@ -368,7 +368,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 			i += addtoinfstr('-');
 			i += addstringtoinfstr(ucnew->comname);
 			i += us_appendargs(ucnew);
-			if (i != 0) ttyputerr("Memory low!");
+			if (i != 0) ttyputnomemory();
 			ttyputmsg("%s", returninfstr());
 		}
 
@@ -389,7 +389,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 				us_domacro(ucnew->comname, ucnew->count, ucnew->word);
 			}
 		}
-	} else ttyputmsg("(command not executed)");
+	} else ttyputmsg(_("(command not executed)"));
 	if (ucnew != uc && ucnew != NOUSERCOM) us_freeusercom(ucnew);
 
 	/* save the command in a macro if requested */
@@ -398,7 +398,7 @@ void us_execute(USERCOM *item, INTBIG print, INTSML macro, INTSML fromuser)
 		var = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
 		if (var != NOVARIABLE)
 			if (us_addusercom(uc, (char *)var->addr) != 0)
-				ttyputerr("No memory to save macro command");
+				ttyputnomemory();
 	}
 
 	/* if command had an error, set flag to not save it */
@@ -607,7 +607,7 @@ USERCOM *us_fleshcommand(USERCOM *uc)
 				pp++;
 				if (*pp == 0)
 				{
-					ttyputerr("HEY! '^' at end of line");
+					ttyputerr(_("HEY! '^' at end of line"));
 					break;
 				}
 				chr = *pp;
@@ -629,7 +629,7 @@ USERCOM *us_fleshcommand(USERCOM *uc)
 		if (allocstring(&ucnew->word[j], returninfstr(), us_aid->cluster) != 0) i++;
 		efree(tmpstring);
 	}
-	if (i != 0) ttyputerr("Memory low!");
+	if (i != 0) ttyputnomemory();
 	return(ucnew);
 }
 
@@ -1078,7 +1078,7 @@ void us_dopopupmenu(POPUPMENU *pm)
 			mi->value = (char *)emalloc((mi->maxlen+1), el_tempcluster);
 			if (mi->value == 0)
 			{
-				ttyputerr("No memory");
+				ttyputnomemory();
 				return;
 			}
 			(void)strcpy(mi->value, "*");
@@ -1141,7 +1141,7 @@ void us_domacro(char *mac, INTSML count, char *pp[])
 	varbuilding = getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding);
 	if (varbuilding != NOVARIABLE && namesame((char *)varbuilding->addr, mac) == 0)
 	{
-		us_abortcommand("End macro definitions before executing them");
+		us_abortcommand(_("End macro definitions before executing them"));
 		return;
 	}
 
@@ -1149,7 +1149,7 @@ void us_domacro(char *mac, INTSML count, char *pp[])
 	varmacro = us_getmacro(mac);
 	if (varmacro == NOVARIABLE || (len = (INTSML)getlength(varmacro)) < 4)
 	{
-		us_abortcommand("Cannot find macro '%s'", mac);
+		us_abortcommand(_("Cannot find macro '%s'"), mac);
 		return;
 	}
 	varmacroaddr = (char **)varmacro->addr;
@@ -1221,18 +1221,18 @@ void us_unknowncommand(void)
 
 	if ((us_aid->aidstate&NOKEYLOCK) != 0) return;
 	i = ttyquiet(0);
-	ttyputmsg("Single-key commands will be ignored until the next RETURN");
+	ttyputmsg(_("Single-key commands will be ignored until the next RETURN"));
 	(void)ttyquiet(i);
 	us_state |= SKIPKEYS;
 }
 
 void us_abortedmsg(void)
 {
-	if ((us_aid->aidstate & JUSTTHEFACTS) == 0) us_abortcommand("Aborted"); else
+	if ((us_aid->aidstate & JUSTTHEFACTS) == 0) us_abortcommand(_("Aborted")); else
 	{
 		us_state |= COMMANDFAILED;
 		if (getvalkey((INTBIG)us_aid, VAID, VSTRING, us_macrobuilding) != NOVARIABLE)
-			ttyputmsg("Command ignored from macro definition");
+			ttyputmsg(_("Command ignored from macro definition"));
 		us_unknowncommand();
 	}
 }
@@ -1269,7 +1269,7 @@ void us_docommands(FILE *infile, INTSML verbose, char *headerstring)
 	/* loop through the command file */
 	for(;;)
 	{
-		if (stopping("Command file") != 0) break;
+		if (stopping(STOPREASONCOMFILE)) break;
 		if (xfgets(line, MAXLINE, infile)) break;
 		pp = line;   while (*pp == ' ' || *pp == '\t') pp++;
 		if (namesamen(pp, headerstring, headercount) != 0) continue;
@@ -1306,10 +1306,13 @@ void us_docommands(FILE *infile, INTSML verbose, char *headerstring)
  */
 INTSML us_parsecommand(char *pp, char *build[])
 {
-	REGISTER char *ppsave, c;
-	REGISTER INTSML count, inquote;
+	REGISTER char *ppsave, c, *tstart, *tend, *ch, *initstring;
+	char tempbuf[300];
+	REGISTER INTSML count;
+	REGISTER INTBIG inquote, tp;
 
 	/* parse the line into up to MAXPARS fields (command plus parameters) */
+	initstring = pp;
 	for(count=0; count<MAXPARS; count++)
 	{
 		/* skip the delimiters before the keyword */
@@ -1321,16 +1324,69 @@ INTSML us_parsecommand(char *pp, char *build[])
 
 		/* scan to the end of the keyword (considering quotation) */
 		inquote = 0;
+		tstart = tend = 0;
 		for(;;)
 		{
-			if (*pp == '"') inquote = 1 - inquote;
 			if (*pp == 0) break;
+			if (inquote == 0)
+			{
+				if (*pp == '"') inquote = 1; else
+				{
+					if (pp[0] == 'N' && pp[1] == '_' && pp[2] == '(' && pp[3] == '"')
+					{
+						inquote = 1;
+						tstart = pp;
+						pp += 3;
+					}
+				}
+			} else
+			{
+				if (*pp == '"')
+				{
+					inquote = 0;
+					if (tstart != 0 && pp[1] == ')')
+					{
+						tend = pp;
+						pp++;
+					}
+				}
+			}
 			if (inquote == 0 && (*pp == ' ' || *pp == '\t')) break;
 			pp++;
 		}
 
+		if (inquote != 0 || (tstart != 0 && tend == 0))
+			ttyputerr(_("Unbalanced quote in commandfile line '%s'"), initstring);
+
 		/* save the keyword */
 		c = *pp;   *pp = 0;
+		if (tstart != 0 && tend != 0)
+		{
+#if 0
+			(void)initinfstr();
+			(void)addtoinfstr('"');
+			for(ch = ppsave; ch != tstart; ch++) (void)addtoinfstr(*ch);
+			tstart += 4;
+			*tend = 0;
+			(void)addstringtoinfstr(_(tstart));
+			*tend = '"';
+			for(ch = tend+2; *ch != 0; ch++) (void)addtoinfstr(*ch);
+			(void)addtoinfstr('"');
+			ppsave = returninfstr();
+#else
+			tp = 0;
+			tempbuf[tp++] = '"';
+			for(ch = ppsave; ch != tstart; ch++) tempbuf[tp++] = *ch;
+			tstart += 4;
+			*tend = 0;
+			for(ch = _(tstart); *ch != 0; ch++) tempbuf[tp++] = *ch;
+			*tend = '"';
+			for(ch = tend+2; *ch != 0; ch++) tempbuf[tp++] = *ch;
+			tempbuf[tp++] = '"';
+			tempbuf[tp] = 0;
+			ppsave = tempbuf;
+#endif
+		}
 		if (count > us_parsemaxownbuild)
 		{
 			(void)allocstring(&us_parseownbuild[count], ppsave, us_aid->cluster);
@@ -1408,7 +1464,7 @@ USERCOM *us_makecommand(char *line)
 	count = us_parsecommand(line, build);
 	if (count <= 0) return(NOUSERCOM);
 	uc = us_buildcommand(count, build);
-	if (uc == NOUSERCOM) ttyputerr("No memory for command");
+	if (uc == NOUSERCOM) ttyputnomemory();
 	return(uc);
 }
 
@@ -1517,8 +1573,8 @@ COMCOMP *us_getcomcompfromkeyword(char *keyword)
 
 INTSML us_specialparse(char *prompt, COMCOMP *parameter, INTSML keycount, char *paramstart[])
 {
-	INTBIG itemHit;
-	INTSML filetype, multiplefiles;
+	INTBIG filetype, itemHit;
+	INTSML multiplefiles;
 	REGISTER char *pt, *next;
 	DIALOGHOOK *dh;
 	extern COMCOMP us_arrayxp, us_quitp, us_editfacetp, us_spreaddp, us_artlookp,
@@ -1533,7 +1589,7 @@ INTSML us_specialparse(char *prompt, COMCOMP *parameter, INTSML keycount, char *
 		us_nodetcaip, us_bindgkeyp, us_sizep, us_sizewp, us_defnodep, us_showup,
 		us_librarykp, us_findobjap, us_window3dp, us_gridp, us_technologytp,
 		us_renamecp, us_findnnamep, us_findexportp, us_noyesalwaysp, us_varop,
-		us_copyfacetdp;
+		us_copyfacetdp, us_findnodep, us_technologycnnp, us_showep, us_purelayerp;
 
 	for(dh = us_firstdialoghook; dh != NODIALOGHOOK; dh = dh->nextdialoghook)
 		if (parameter == dh->getlinecomp)
@@ -1541,66 +1597,71 @@ INTSML us_specialparse(char *prompt, COMCOMP *parameter, INTSML keycount, char *
 		(*dh->routine)();
 		return(0);
 	}
-	if (parameter == &us_window3dp)           return(us_3ddepthdlog(paramstart));
-	if (parameter == &us_gridalip)            return(us_alignmentdlog(paramstart));
-	if (parameter == &us_nodetcaip)           return(us_annularringdlog(paramstart));
+
+	if (parameter == &us_window3dp)           return(us_3ddepthdlog());
+	if (parameter == &us_showep)              return(us_aboutdlog());
+	if (parameter == &us_gridalip)            return(us_alignmentdlog());
+	if (parameter == &us_nodetcaip)           return(us_annularringdlog());
 	if (parameter == &us_sizewp)              return(us_arcsizedlog(paramstart));
 	if (parameter == &us_technologycnsp)      return(us_areadlog(prompt, paramstart, 0));
 	if (parameter == &us_arrayxp)             return(us_arraydlog(paramstart));
-	if (parameter == &us_artlookp)            return(us_artlookdlog(paramstart));
-	if (parameter == &us_varop)               return(us_attributesdlog(paramstart));
+	if (parameter == &us_artlookp)            return(us_artlookdlog());
+	if (parameter == &us_varop)               return(us_attributesdlog());
 	if (parameter == &us_technologyclscp)     return(us_capacitancedlog(paramstart, 0));
-	if (parameter == &us_copyfacetp)          return(us_copyfacetdlog(prompt, paramstart));
+	if (parameter == &us_copyfacetp)          return(us_copyfacetdlog(prompt));
 	if (parameter == &us_createxp)            return(us_createtodlog(paramstart));
-	if (parameter == &us_defarcsp)            return(us_defarcdlog(paramstart));
-	if (parameter == &us_defnodexsp)          return(us_defnodedlog(paramstart));
-	if (parameter == &us_textdsp)             return(us_deftextdlog(prompt, paramstart));
-	if (parameter == &us_technologyedlp)      return(us_dependentlibdlog(paramstart));
-	if (parameter == &us_editfacetp)          return(us_editfacetdlog(prompt, paramstart));
-	if (parameter == &us_defnodep)            return(us_facetdlog(paramstart));
+	if (parameter == &us_defarcsp)            return(us_defarcdlog());
+	if (parameter == &us_defnodexsp)          return(us_defnodedlog());
+	if (parameter == &us_textdsp)             return(us_deftextdlog(prompt));
+	if (parameter == &us_technologyedlp)      return(us_dependentlibdlog());
+	if (parameter == &us_editfacetp)          return(us_editfacetdlog(prompt));
+	if (parameter == &us_defnodep)            return(us_facetdlog());
 	if (parameter == &us_showdp)              return(us_facetlist(prompt, paramstart, 1));
 	if (parameter == &us_showup)              return(us_facetlist(prompt, paramstart, 0));
-	if (parameter == &us_viewfp)              return(us_frameoptionsdlog(paramstart));
+	if (parameter == &us_viewfp)              return(us_frameoptionsdlog());
 	if (parameter == &us_technologyclsp)      return(us_gaindlog(prompt, paramstart, 0));
-	if (parameter == &us_gridp)               return(us_griddlog(paramstart));
-	if (parameter == &us_helpp)               return(us_helpdlog(prompt, paramstart));
-	if (parameter == &us_colorhighp)          return(us_highlayerlog(paramstart));
-	if (parameter == &us_copyfacetdp)         return(us_iconstyledlog(paramstart));
+	if (parameter == &us_gridp)               return(us_griddlog());
+	if (parameter == &us_helpp)               return(us_helpdlog(prompt));
+	if (parameter == &us_colorhighp)          return(us_highlayerlog());
+	if (parameter == &us_copyfacetdp)         return(us_iconstyledlog());
 	if (parameter == &us_technologyclsecp)    return(us_inductancedlog(paramstart, 0));
-	if (parameter == &us_lambdachp)           return(us_lambdadlog(paramstart));
-	if (parameter == &us_librarydp)           return(us_librarypathdlog(paramstart));
+	if (parameter == &us_lambdachp)           return(us_lambdadlog());
+	if (parameter == &us_librarydp)           return(us_librarypathdlog());
+	if (parameter == &us_technologycnnp)      return(us_libtotechnologydlog());
 	if (parameter == &us_menup)               return(us_menudlog(paramstart));
 	if (parameter == &us_viewn1p)             return(us_newviewdlog(paramstart));
 	if (parameter == &us_sizep)               return(us_nodesizedlog(paramstart));
 	if (parameter == &us_noyesp)              return(us_noyesdlog(prompt, paramstart));
 	if (parameter == &us_noyesalwaysp)        return(us_noyesalwaysdlog(prompt, paramstart));
-	if (parameter == &us_librarykp)           return(us_oldlibrarydlog(paramstart));
-	if (parameter == &us_librarywp)           return(us_optionsavingdlog(paramstart));
-	if (parameter == &us_colorpvaluep)        return(us_patterndlog(paramstart));
-	if (parameter == &us_nodetptlp)           return(us_placetextdlog(paramstart));
-	if (parameter == &us_librarywriteformatp) return(us_plotoptionsdlog(paramstart));
-	if (parameter == &us_portlp)              return(us_portdisplaydlog(paramstart));
+	if (parameter == &us_librarykp)           return(us_oldlibrarydlog());
+	if (parameter == &us_librarywp)           return(us_optionsavingdlog());
+	if (parameter == &us_colorpvaluep)        return(us_patterndlog());
+	if (parameter == &us_nodetptlp)           return(us_placetextdlog());
+	if (parameter == &us_librarywriteformatp) return(us_plotoptionsdlog());
+	if (parameter == &us_portlp)              return(us_portdisplaydlog());
 	if (parameter == &us_portep)              return(us_portdlog(paramstart));
-	if (parameter == &us_bindgkeyp)           return(us_quickkeydlog(paramstart));
+	if (parameter == &us_bindgkeyp)           return(us_quickkeydlog());
 	if (parameter == &us_quitp)               return(us_quitdlog(prompt, paramstart));
-	if (parameter == &us_renamecp)            return(us_renamedlog(paramstart));
-	if (parameter == &us_replacep)            return(us_replacedlog(paramstart));
+	if (parameter == &us_renamecp)            return(us_renamedlog());
+	if (parameter == &us_replacep)            return(us_replacedlog());
 	if (parameter == &us_technologyclsrp)     return(us_resistancedlog(prompt, paramstart, 0));
-	if (parameter == &us_findobjap)           return(us_selectoptdlog(paramstart));
-	if (parameter == &us_findnnamep)          return(us_selectportnetdlog(paramstart, 0));
-	if (parameter == &us_findexportp)         return(us_selectportnetdlog(paramstart, 1));
-	if (parameter == &us_showp)               return(us_showdlog(paramstart, 0));
-	if (parameter == &us_showop)              return(us_showdlog(paramstart, 1));
+	if (parameter == &us_findobjap)           return(us_selectoptdlog());
+	if (parameter == &us_findnnamep)          return(us_selectportnodenetdlog(0));
+	if (parameter == &us_findexportp)         return(us_selectportnodenetdlog(1));
+	if (parameter == &us_findnodep)           return(us_selectportnodenetdlog(2));
+	if (parameter == &us_showp)               return(us_showdlog(0));
+	if (parameter == &us_showop)              return(us_showdlog(1));
 	if (parameter == &us_spreaddp)            return(us_spreaddlog(paramstart));
 	if (parameter == &us_technologyup)        return(us_technologydlog(prompt, paramstart));
-	if (parameter == &us_technologytp)        return(us_techoptdlog(paramstart));
-	if (parameter == &us_technologyctdp)      return(us_techvarsdlog(paramstart));
-	if (parameter == &us_nodetp)              return(us_tracedlog(paramstart));
-	if (parameter == &us_varvep)              return(us_variablesdlog(paramstart));
+	if (parameter == &us_technologytp)        return(us_techoptdlog());
+	if (parameter == &us_technologyctdp)      return(us_techvarsdlog());
+	if (parameter == &us_nodetp)              return(us_tracedlog());
+	if (parameter == &us_purelayerp)          return(us_purelayernodedlog(paramstart));
+	if (parameter == &us_varvep)              return(us_variablesdlog());
 	if (parameter == &us_technologyclip)      return(us_vccsdlog(paramstart, 0));
-	if (parameter == &us_visiblelayersp)      return(us_visiblelayersdlog(prompt, paramstart));
+	if (parameter == &us_visiblelayersp)      return(us_visiblelayersdlog(prompt));
 	if (parameter == &us_technologyclgp)      return(us_widlendlog(paramstart, 0));
-	if (parameter == &us_windowrnamep)        return(us_windowviewdlog(paramstart));
+	if (parameter == &us_windowrnamep)        return(us_windowviewdlog());
 	if (parameter == &us_yesnop)              return(us_yesnodlog(prompt, paramstart));
 	if (parameter == &us_colorwritep || parameter == &us_colorreadp)
 	{
@@ -1610,7 +1671,7 @@ INTSML us_specialparse(char *prompt, COMCOMP *parameter, INTSML keycount, char *
 		prompt = returninfstr();
 
 		/* file dialog prompts have the form "type/prompt" */
-		filetype = FILETYPETEXT;
+		filetype = el_filetypetext;
 		multiplefiles = 0;
 		for(pt = prompt; *pt != 0; pt++) if (*pt == '/') break;
 		if (*pt == '/')
@@ -1622,7 +1683,7 @@ INTSML us_specialparse(char *prompt, COMCOMP *parameter, INTSML keycount, char *
 				prompt += 6;
 			}
 			filetype = getfiletype(prompt);
-			if (filetype == 0) filetype = FILETYPETEXT;
+			if (filetype == 0) filetype = el_filetypetext;
 			*pt++ = '/';
 			prompt = pt;
 		}
@@ -1938,10 +1999,10 @@ INTSML us_pagetword(INTSML (*input)(COMCOMP**, INTSML*), void (*output)(char*),
 		if (isbreak != 0) { realc = (char)c;   c = ' '; }
 
 		/* ignore break characters at the start of a keyword */
-		if ((c == 033 || isbreak != 0) && *initialline == 0) continue;
+		if ((c == ESCKEY || isbreak != 0) && *initialline == 0) continue;
 
 		/* fill out keyword if a break character is reached */
-		if (c == 033 || isbreak != 0 || c == '\n' || c == '\r')
+		if (c == ESCKEY || isbreak != 0 || c == '\n' || c == '\r')
 		{
 			/* special case for variables */
 			if (*initialline == '$')
@@ -1974,7 +2035,7 @@ INTSML us_pagetword(INTSML (*input)(COMCOMP**, INTSML*), void (*output)(char*),
 				}
 
 				/* fill out the keyword if possible */
-				if ((nofill == 0 || c == 033) && extra != 0)
+				if ((nofill == 0 || c == ESCKEY) && extra != 0)
 				{
 					us_paambiguous[extra] = 0;
 					if (us_pacurchar+extra >= us_patruelength)
@@ -1986,7 +2047,7 @@ INTSML us_pagetword(INTSML (*input)(COMCOMP**, INTSML*), void (*output)(char*),
 
 				/* print an error bell if there is ambiguity */
 				if (i == 0) bst = -1;
-				if (bst < 0 && c == 033)
+				if (bst < 0 && c == ESCKEY)
 				{
 					ttybeep();
 					continue;
@@ -1997,7 +2058,7 @@ INTSML us_pagetword(INTSML (*input)(COMCOMP**, INTSML*), void (*output)(char*),
 			} else bst = -1;
 
 			/* if an escape was typed, stop after filling in the keyword */
-			if (c == 033) continue;
+			if (c == ESCKEY) continue;
 
 			/* if normal break character was typed, advance to next keyword */
 			if (isbreak != 0)
