@@ -54,6 +54,7 @@ void us_addobjects(NODEPROTO*);
 INTSML us_wildmatch(char*, char*);
 void us_explainaid(INTBIG, struct explanation[]);
 void us_saveoptions(void);
+void us_drawarcmenu(ARCPROTO *ap);
 
 STATUSFIELD *us_clearstatuslines[3] = {0, 0, 0};
 
@@ -82,6 +83,7 @@ void us_freestatusmemory(void)
 	if (us_statuspart != 0) ttyfreestatusfield(us_statuspart);
 	if (us_statuspackage != 0) ttyfreestatusfield(us_statuspackage);
 	if (us_statusselection != 0) ttyfreestatusfield(us_statusselection);
+
 	lines = ttynumstatuslines();
 	for(i=0; i<lines; i++) ttyfreestatusfield(us_clearstatuslines[i]);
 
@@ -107,18 +109,18 @@ void us_initstatus(void)
 		us_statusproject = us_statusroot = us_statuspart = us_statuspackage = 0;
 		us_statusselection = 0;
 		us_statusfacet      = ttydeclarestatusfield(0,  0,   0, "");
-		us_statusnode       = ttydeclarestatusfield(1,  0,  22, "NODE: ");
-		us_statusarc        = ttydeclarestatusfield(1, 22,  44, "ARC: ");
-		us_statusfacetsize  = ttydeclarestatusfield(1, 44,  65, "SIZE: ");
-		us_statuslambda     = ttydeclarestatusfield(1, 65,  80, "LAMBDA: ");
-		us_statustechnology = ttydeclarestatusfield(1, 80, 100, "TECHNOLOGY: ");
-		us_statusxpos       = ttydeclarestatusfield(1, 67,  83, "X: ");
-		us_statusypos       = ttydeclarestatusfield(1, 83, 100, "Y: ");
+		us_statusnode       = ttydeclarestatusfield(1,  0,  22, _("NODE: "));
+		us_statusarc        = ttydeclarestatusfield(1, 22,  44, _("ARC: "));
+		us_statusfacetsize  = ttydeclarestatusfield(1, 44,  65, _("SIZE: "));
+		us_statuslambda     = ttydeclarestatusfield(1, 65,  80, _("LAMBDA: "));
+		us_statustechnology = ttydeclarestatusfield(1, 80, 100, _("TECHNOLOGY: "));
+		us_statusxpos       = ttydeclarestatusfield(1, 65,  80, _("X: "));
+		us_statusypos       = ttydeclarestatusfield(1, 80, 100, _("Y: "));
 		if (lines > 1)
 		{
-			us_statusangle     = ttydeclarestatusfield(2,  0,  25, "ANGLE: ");
-			us_statusalign     = ttydeclarestatusfield(2, 25,  50, "ALIGN: ");
-			us_statusgridsize  = ttydeclarestatusfield(2, 75, 100, "GRID: ");
+			us_statusangle     = ttydeclarestatusfield(2,  0,  25, _("ANGLE: "));
+			us_statusalign     = ttydeclarestatusfield(2, 25,  50, _("ALIGN: "));
+			us_statusgridsize  = ttydeclarestatusfield(2, 75, 100, _("GRID: "));
 		}
 	}
 }
@@ -158,7 +160,7 @@ void us_setalignment(WINDOWFRAME *frame)
 	ttysetstatusfield(frame, us_statusalign, valstring, 0);
 }
 
-/* write the current lambda value from "el_curtech->deflambda" in microns */
+/* write the current lambda value from the current library/technology in microns */
 void us_setlambda(WINDOWFRAME *frame)
 {
 	REGISTER INTSML len;
@@ -168,7 +170,7 @@ void us_setlambda(WINDOWFRAME *frame)
 	/* show nothing in X/Y mode */
 	if ((us_aid->aidstate&SHOWXY) != 0) return;
 
-	lambdainmicrons = scaletodispunit(el_curtech->deflambda, DISPUNITMIC);
+	lambdainmicrons = scaletodispunit(el_curlib->lambda[el_curtech->techindex], DISPUNITMIC);
 	(void)sprintf(hold, "%g", lambdainmicrons);
 	for(;;)
 	{
@@ -283,13 +285,51 @@ void us_showcurrentnodeproto(void)
 /* shadow changes to the current arcproto */
 void us_shadowarcproto(WINDOWFRAME *frame, ARCPROTO *ap)
 {
+	REGISTER ARCPROTO *oldap;
+
 	if (us_curarcproto == ap) return;
+
+	/* undraw the menu entry with the last arc proto in it */
+	oldap = us_curarcproto;
 	us_curarcproto = ap;
 
+	/* adjust the component menu entries */
+	if (oldap != NOARCPROTO) us_drawarcmenu(oldap);
+	if (us_curarcproto != NOARCPROTO) us_drawarcmenu(us_curarcproto);
+
 	ttysetstatusfield(frame, us_statusarc, describearcproto(ap), 1);
 	us_showcurrentarcproto();
 }
 
+/*
+ * Routine to find arcproto "ap" in the component menu and redraw that entry.
+ */
+void us_drawarcmenu(ARCPROTO *ap)
+{
+	REGISTER char *str;
+	REGISTER INTSML x, y;
+	REGISTER VARIABLE *var;
+	REGISTER ARCPROTO *pap;
+	COMMANDBINDING commandbinding;
+
+	var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
+	if (var == NOVARIABLE) return;
+	for(x=0; x<us_menux; x++)
+		for(y=0; y<us_menuy; y++)
+	{
+		if (us_menupos <= 1) str = ((char **)var->addr)[y * us_menux + x]; else
+			str = ((char **)var->addr)[x * us_menuy + y];
+		us_parsebinding(str, &commandbinding);
+		pap = commandbinding.arcglyph;
+		us_freebindingparse(&commandbinding);
+		if (pap == ap)
+		{
+			us_drawmenuentry(x, y, str);
+			return;
+		}
+	}
+}
+
 /*
  * routine to draw highlighting around the menu entry with the current
  * arc prototype
@@ -353,8 +393,6 @@ void us_setnodeangle(WINDOWFRAME *frame)
 /* write the name of the facet in window "w" */
 void us_setfacetname(WINDOWPART *w)
 {
-	REGISTER char *npname;
-	REGISTER INTSML len;
 	REGISTER EDITOR *ed;
 
 	/* do not show name of explorer window when it is split */
@@ -371,30 +409,28 @@ void us_setfacetname(WINDOWPART *w)
 			if (ed != NOEDITOR)
 			{
 				(void)addstringtoinfstr(ed->header);
-				len = strlen(ed->header);
 				break;
 			}
 		case DISPWINDOW:
 		case DISP3DWINDOW:
-			if (w->curnodeproto == NONODEPROTO) len = 0; else
+			if (w->curnodeproto != NONODEPROTO)
 			{
-				npname = describenodeproto(w->curnodeproto);
-				(void)addstringtoinfstr(npname);
-				len = strlen(npname);
+				(void)formatinfstr("%s:%s", w->curnodeproto->cell->lib->libname,
+					nldescribenodeproto(w->curnodeproto));
+				if (w->curnodeproto->cell->lib != el_curlib)
+					(void)formatinfstr(_(" - Current library: %s"), el_curlib->libname);
 			}
 			break;
 		case EXPLORERWINDOW:
-			(void)addstringtoinfstr("Facet Explorer");
+			(void)addstringtoinfstr(_("Facet Explorer"));
 			break;
 		case WAVEFORMWINDOW:
-			(void)addstringtoinfstr("Waveform");
-			len = 8;
 			if (w->curnodeproto != NONODEPROTO)
 			{
-				npname = describenodeproto(w->curnodeproto);
-				(void)addstringtoinfstr(" of ");
-				(void)addstringtoinfstr(npname);
-				len += strlen(npname) + 4;
+				(void)formatinfstr(_("Waveform of %s"), describenodeproto(w->curnodeproto));
+			} else
+			{
+				(void)addstringtoinfstr(_("Waveform"));
 			}
 			break;
 	}
@@ -506,11 +542,11 @@ void us_printmacros(void)
 	}
 	if (gotany == 0)
 	{
-		ttyputmsg("No macros defined");
+		ttyputmsg(_("No macros defined"));
 		return;
 	}
 
-	ttyputmsg("---------- Macros by Package ----------");
+	ttyputmsg(_("---------- Macros by Package ----------"));
 
 	/* now print the macros by package */
 	for(pack = us_macropacktop; ; pack = pack->nextmacropack)
@@ -518,14 +554,14 @@ void us_printmacros(void)
 		if (pack == NOMACROPACK)
 		{
 			if (keyboard == 0) break;
-			name = "Keyboard-defined";
+			name = _("Keyboard-defined");
 		} else
 		{
 			if (pack->total == 0) continue;
 			name = pack->packname;
 		}
 		(void)strcpy(line, name);
-		(void)strcat(line, " macros:");
+		(void)strcat(line, _(" macros:"));
 		len = strlen(line);
 		inter = "";
 		for(i=0; i<us_aid->numvar; i++)
@@ -570,12 +606,12 @@ void us_printmacro(VARIABLE *mac)
 	len = (INTSML)getlength(mac);
 	if (len <= 3)
 	{
-		ttyputmsg("Macro '%s' is not defined", &makename(mac->key)[11]);
+		ttyputmsg(_("Macro '%s' is not defined"), &makename(mac->key)[11]);
 		return;
 	}
 
-	ttyputmsg("Macro '%s' has %d %s", &makename(mac->key)[11], len-3,
-		makeplural("command", len-3));
+	ttyputmsg(_("Macro '%s' has %d %s"), &makename(mac->key)[11], len-3,
+		makeplural(_("command"), len-3));
 	for(j=3; j<len; j++) ttyputmsg("   %s", ((char **)mac->addr)[j]);
 }
 
@@ -614,6 +650,7 @@ struct
 	{"Constraint",   VCONSTRAINT},
 	{"General",      VGENERAL},
 	{"Window-Frame", VWINDOWFRAME},
+	{"Polygon",      VPOLYGON},
 	{NULL, 0}
 };
 
@@ -657,10 +694,10 @@ char *us_variableattributes(VARIABLE *var, INTSML aindex)
 		}
 	}
 	(void)initinfstr();
-	if ((var->type&VDONTSAVE) != 0) (void)addstringtoinfstr("Temporary ");
+	if ((var->type&VDONTSAVE) != 0) (void)addstringtoinfstr(_("Temporary "));
 	if ((var->type&VDISPLAY) != 0)
 	{
-		(void)addstringtoinfstr("Displayable(");
+		(void)addstringtoinfstr(_("Displayable("));
 		(void)addstringtoinfstr(us_describetextdescript(var->textdescript));
 		(void)addstringtoinfstr(") ");
 	}
@@ -699,7 +736,7 @@ void us_describecontents(NODEINST *ni)
 	us_addobjects(ni->proto);
 
 	/* print the totals */
-	ttyputmsg("Contents of facet %s:", describenodeproto(ni->proto));
+	ttyputmsg(_("Contents of facet %s:"), describenodeproto(ni->proto));
 	printtech = el_curtech;
 	for(curtech = el_technologies; curtech != NOTECHNOLOGY; curtech = curtech->nexttechnology)
 	{
@@ -708,20 +745,20 @@ void us_describecontents(NODEINST *ni)
 		{
 			if (curtech != printtech)
 			{
-				ttyputmsg("%s technology:", curtech->techname);
+				ttyputmsg(_("%s technology:"), curtech->techname);
 				printtech = curtech;
 			}
-			ttyputmsg("%6d nodes of prototype %s", np->temp1, describenodeproto(np));
+			ttyputmsg(_("%6d nodes of prototype %s"), np->temp1, describenodeproto(np));
 		}
 	}
 	sorted = us_sortlib(el_curlib, (char *)0, 0);
-	if (sorted == 0) ttyputerr("No memory for list"); else
+	if (sorted == 0) ttyputnomemory(); else
 	{
 		for(i = 0; sorted[i] != NONODEPROTO; i++)
 		{
 			np = sorted[i];
 			if (np->temp1 == 0) continue;
-			ttyputmsg("%6d facets of prototype %s", np->temp1, describenodeproto(np));
+			ttyputmsg(_("%6d facets of prototype %s"), np->temp1, describenodeproto(np));
 		}
 		efree((char *)sorted);
 	}
@@ -906,10 +943,10 @@ void us_printnodeaidinfo(NODEINST *ni)
 {
 	static struct explanation explain[] =
 	{
-		{DEADN,       -1,      "dead"},
-		{NEXPAND,     -1,      "expand"},
-		{WIPED,       -1,      "wiped"},
-		{NSHORT,      -1,      "short"},
+		{DEADN,       -1,      N_("dead")},
+		{NEXPAND,     -1,      N_("expand")},
+		{WIPED,       -1,      N_("wiped")},
+		{NSHORT,      -1,      N_("short")},
 		{0, -1, NULL}
 	};
 	us_explainaid(ni->userbits, explain);
@@ -920,19 +957,19 @@ void us_printarcaidinfo(ARCINST *ai)
 {
 	static struct explanation explain[] =
 	{
-		{FIXED,         -1,                 "rigid"},
-		{CANTSLIDE,     -1,                 "rigid-in-ports"},
-		{FIXANG,        -1,                 "fixed-angle"},
-		{DEADA,         -1,                 "dead"},
-		{AANGLE,        AANGLESH,           "angle"},
-		{ASHORT,        -1,                 "short"},
-		{AFUNCTION,     APBUS<<AFUNCTIONSH, "bus"},
-		{NOEXTEND,      -1,                 "ends-shortened"},
-		{ISNEGATED,     -1,                 "negated"},
-		{ISDIRECTIONAL, -1,                 "directional"},
-		{NOTEND0,       -1,                 "skip-tail"},
-		{NOTEND1,       -1,                 "skip-head"},
-		{REVERSEEND,    -1,                 "direction-reversed"},
+		{FIXED,         -1,                 N_("rigid")},
+		{CANTSLIDE,     -1,                 N_("rigid-in-ports")},
+		{FIXANG,        -1,                 N_("fixed-angle")},
+		{DEADA,         -1,                 N_("dead")},
+		{AANGLE,        AANGLESH,           N_("angle")},
+		{ASHORT,        -1,                 N_("short")},
+		{AFUNCTION,     APBUS<<AFUNCTIONSH, N_("bus")},
+		{NOEXTEND,      -1,                 N_("ends-shortened")},
+		{ISNEGATED,     -1,                 N_("negated")},
+		{ISDIRECTIONAL, -1,                 N_("directional")},
+		{NOTEND0,       -1,                 N_("skip-tail")},
+		{NOTEND1,       -1,                 N_("skip-head")},
+		{REVERSEEND,    -1,                 N_("direction-reversed")},
 		{0, -1, NULL}
 	};
 	us_explainaid(ai->userbits, explain);
@@ -946,7 +983,7 @@ void us_explainaid(INTBIG bits, struct explanation explain[])
 
 	/* print the aid bit information */
 	(void)initinfstr();
-	(void)sprintf(partial, "User state = %ld", bits);
+	(void)sprintf(partial, _("User state = %ld"), bits);
 	(void)addstringtoinfstr(partial);
 	k = 0;
 	for(j=0; explain[j].bit != 0; j++)
@@ -955,7 +992,7 @@ void us_explainaid(INTBIG bits, struct explanation explain[])
 		{
 			if (k == 0) (void)addtoinfstr('('); else
 				(void)addstringtoinfstr(", ");
-			(void)addstringtoinfstr(explain[j].name);
+			(void)addstringtoinfstr(_(explain[j].name));
 			(void)addtoinfstr('=');
 			(void)sprintf(partial, "%ld",(bits&explain[j].bit)>>explain[j].shift);
 			(void)addstringtoinfstr(partial);
@@ -964,7 +1001,7 @@ void us_explainaid(INTBIG bits, struct explanation explain[])
 		}
 		if ((bits & explain[j].bit) == 0) continue;
 		if (k == 0) (void)addtoinfstr('('); else (void)addstringtoinfstr(", ");
-		(void)addstringtoinfstr(explain[j].name);
+		(void)addstringtoinfstr(_(explain[j].name));
 		k++;
 	}
 	if (k != 0) (void)addtoinfstr(')');
@@ -999,11 +1036,11 @@ void us_chatportproto(NODEINST *ni, PORTPROTO *pp)
 	activity = us_describeportbits(pp);
 	if (*activity != 0)
 	{
-		(void)addstringtoinfstr(activity);
-		(void)addstringtoinfstr(" port ");
-	} else (void)addstringtoinfstr("Port ");
-	(void)addstringtoinfstr(pp->protoname);
-	(void)addstringtoinfstr(" connects to ");
+		(void)formatinfstr(_("%s port %s connects to "), activity, pp->protoname);
+	} else
+	{
+		(void)formatinfstr(_("Port %s connects to "), pp->protoname);
+	}
 	for(i=0; pp->connects[i] != NOARCPROTO; i++)
 	{
 		if (i != 0) (void)addstringtoinfstr(", ");
@@ -1020,28 +1057,22 @@ void us_chatportproto(NODEINST *ni, PORTPROTO *pp)
 			if (poly->xv[i] != poly->xv[i-1] || poly->yv[i] != poly->yv[i-1]) break;
 		if (i >= poly->count)
 		{
-			ttyputmsg("  Located at (%s, %s)", latoa(poly->xv[0]), latoa(poly->yv[0]));
+			ttyputmsg(_("  Located at (%s, %s)"), latoa(poly->xv[0]), latoa(poly->yv[0]));
 		} else if (isbox(poly, &lx,&hx, &ly,&hy))
 		{
-			if (lx == hx) (void)sprintf(locx, "at %s", latoa(lx)); else
-				(void)sprintf(locx, "from %s to %s", latoa(lx), latoa(hx));
-			if (ly == hy) (void)sprintf(locy, "at %s", latoa(ly)); else
-				(void)sprintf(locy, "from %s to %s", latoa(ly), latoa(hy));
-			ttyputmsg("  Located %s in X and %s in Y", locx, locy);
+			if (lx == hx) (void)sprintf(locx, _("at %s"), latoa(lx)); else
+				(void)sprintf(locx, _("from %s to %s"), latoa(lx), latoa(hx));
+			if (ly == hy) (void)sprintf(locy, _("at %s"), latoa(ly)); else
+				(void)sprintf(locy, _("from %s to %s"), latoa(ly), latoa(hy));
+			ttyputmsg(_("  Located %s in X and %s in Y"), locx, locy);
 		} else
 		{
 			(void)initinfstr();
 			for(i=0; i<poly->count; i++)
-			{
-				(void)addstringtoinfstr(" (");
-				(void)addstringtoinfstr(latoa(poly->xv[i]));
-				(void)addtoinfstr(',');
-				(void)addstringtoinfstr(latoa(poly->yv[i]));
-				(void)addtoinfstr(')');
-			}
-			ttyputmsg("  Located inside polygon%s", returninfstr());
+				(void)formatinfstr(" (%s, %s)", latoa(poly->xv[i]), latoa(poly->yv[i]));
+			ttyputmsg(_("  Located inside polygon%s"), returninfstr());
 		}
-	} else ttyputmsg("  Located at subnode %s subport %s",
+	} else ttyputmsg(_("  Located at subnode %s subport %s"),
 		describenodeinst(pp->subnodeinst), pp->subportproto->protoname);
 
 	/* talk about any arcs on this prototype */
@@ -1050,23 +1081,20 @@ void us_chatportproto(NODEINST *ni, PORTPROTO *pp)
 		if (pi->proto != pp) continue;
 		ai = pi->conarcinst;
 		if (ai->end[0].portarcinst == pi) i = 0; else i = 1;
-		ttyputmsg("  Connected at (%s,%s) to %s", latoa(ai->end[i].xpos),
+		ttyputmsg(_("  Connected at (%s,%s) to %s"), latoa(ai->end[i].xpos),
 			latoa(ai->end[i].ypos), describearcinst(ai));
 	}
 
-	/* talk about any exported ports of this prototype */
+	/* talk about any exports of this prototype */
 	for(pe=ni->firstportexpinst; pe!=NOPORTEXPINST; pe=pe->nextportexpinst)
 		if (pe->proto == pp)
 	{
 		(void)initinfstr();
-		(void)addstringtoinfstr("  Exported as ");
-		(void)addstringtoinfstr(us_describeportbits(pe->exportproto));
-		(void)addstringtoinfstr(" port '");
-		(void)addstringtoinfstr(pe->exportproto->protoname);
-		(void)addstringtoinfstr("' (label ");
-		(void)addstringtoinfstr(us_describetextdescript(pe->exportproto->textdescript));
-		if ((pe->exportproto->userbits&PORTDRAWN) != 0) (void)addstringtoinfstr(",always-drawn");
-		if ((pe->exportproto->userbits&BODYONLY) != 0) (void)addstringtoinfstr(",only-on-body");
+		(void)formatinfstr(_("  Available as %s export '%s' (label %s"),
+			us_describeportbits(pe->exportproto), pe->exportproto->protoname,
+				us_describetextdescript(pe->exportproto->textdescript));
+		if ((pe->exportproto->userbits&PORTDRAWN) != 0) (void)addstringtoinfstr(_(",always-drawn"));
+		if ((pe->exportproto->userbits&BODYONLY) != 0) (void)addstringtoinfstr(_(",only-on-body"));
 		(void)addstringtoinfstr(") ");
 		ttyputmsg("%s", returninfstr());
 	}
@@ -1076,20 +1104,20 @@ char *us_describeportbits(PORTPROTO *pp)
 {
 	switch (pp->userbits&STATEBITS)
 	{
-		case INPORT:     return("Input");
-		case OUTPORT:    return("Output");
-		case BIDIRPORT:  return("Bidirectional");
-		case PWRPORT:    return("Power");
-		case GNDPORT:    return("Ground");
-		case CLKPORT:    return("Clock");
-		case C1PORT:     return("Clock Phase 1");
-		case C2PORT:     return("Clock Phase 2");
-		case C3PORT:     return("Clock Phase 3");
-		case C4PORT:     return("Clock Phase 4");
-		case C5PORT:     return("Clock Phase 5");
-		case C6PORT:     return("Clock Phase 6");
-		case REFOUTPORT: return("Reference Output");
-		case REFINPORT:  return("Reference Input");
+		case INPORT:     return(_("Input"));
+		case OUTPORT:    return(_("Output"));
+		case BIDIRPORT:  return(_("Bidirectional"));
+		case PWRPORT:    return(_("Power"));
+		case GNDPORT:    return(_("Ground"));
+		case CLKPORT:    return(_("Clock"));
+		case C1PORT:     return(_("Clock Phase 1"));
+		case C2PORT:     return(_("Clock Phase 2"));
+		case C3PORT:     return(_("Clock Phase 3"));
+		case C4PORT:     return(_("Clock Phase 4"));
+		case C5PORT:     return(_("Clock Phase 5"));
+		case C6PORT:     return(_("Clock Phase 6"));
+		case REFOUTPORT: return(_("Reference Output"));
+		case REFINPORT:  return(_("Reference Input"));
 	}
 	return("");
 }
@@ -1127,16 +1155,16 @@ char *us_describestyle(INTBIG style)
 {
 	switch (style)
 	{
-		case VTPOSCENT:      return("centered");
-		case VTPOSBOXED:     return("boxed");
-		case VTPOSUP:        return("up");
-		case VTPOSDOWN:      return("down");
-		case VTPOSLEFT:      return("left");
-		case VTPOSRIGHT:     return("right");
-		case VTPOSUPLEFT:    return("up-left");
-		case VTPOSUPRIGHT:   return("up-right");
-		case VTPOSDOWNLEFT:  return("down-left");
-		case VTPOSDOWNRIGHT: return("down-right");
+		case VTPOSCENT:      return(_("centered"));
+		case VTPOSBOXED:     return(_("boxed"));
+		case VTPOSUP:        return(_("up"));
+		case VTPOSDOWN:      return(_("down"));
+		case VTPOSLEFT:      return(_("left"));
+		case VTPOSRIGHT:     return(_("right"));
+		case VTPOSUPLEFT:    return(_("up-left"));
+		case VTPOSUPRIGHT:   return(_("up-right"));
+		case VTPOSDOWNLEFT:  return(_("down-left"));
+		case VTPOSDOWNRIGHT: return(_("down-right"));
 	}
 	return("?");
 }
@@ -1148,18 +1176,18 @@ char *us_describefont(INTBIG font)
 {
 	switch (font)
 	{
-		case TXT4P:     return("4-point");
-		case TXT6P:     return("6-point");
-		case TXT8P:     return("8-point");
-		case TXT10P:    return("10-point");
-		case TXT12P:    return("12-point");
-		case TXT14P:    return("14-point");
-		case TXT16P:    return("16-point");
-		case TXT18P:    return("18-point");
-		case TXT20P:    return("20-point");
-		case TXTSMALL:  return("small");
-		case TXTMEDIUM: return("medium");
-		case TXTLARGE:  return("large");
+		case TXT4P:     return(_("4-point"));
+		case TXT6P:     return(_("6-point"));
+		case TXT8P:     return(_("8-point"));
+		case TXT10P:    return(_("10-point"));
+		case TXT12P:    return(_("12-point"));
+		case TXT14P:    return(_("14-point"));
+		case TXT16P:    return(_("16-point"));
+		case TXT18P:    return(_("18-point"));
+		case TXT20P:    return(_("20-point"));
+		case TXTSMALL:  return(_("small"));
+		case TXTMEDIUM: return(_("medium"));
+		case TXTLARGE:  return(_("large"));
 	}
 	return("?");
 }
@@ -1214,14 +1242,14 @@ void us_printcolorvalue(INTSML ind)
 	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
 	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE)
 	{
-		ttyputerr("Cannot get current color map");
+		ttyputerr(_("Cannot get current color map"));
 		return;
 	}
 
 	(void)initinfstr();
 	if ((ind&(LAYERH|LAYERG)) == 0)
 	{
-		(void)sprintf(line, "Entry %d", ind);
+		(void)sprintf(line, _("Entry %d"), ind);
 		(void)addstringtoinfstr(line);
 		j = 0;
 		high = el_curtech->layercount;
@@ -1236,13 +1264,13 @@ void us_printcolorvalue(INTSML ind)
 			(void)addstringtoinfstr(layername(el_curtech, i));
 		}
 		if (j != 0) (void)addtoinfstr(')');
-		(void)addstringtoinfstr(" is");
+		(void)addstringtoinfstr(_(" is"));
 	} else
 	{
-		if ((ind&LAYERG) != 0) (void)addstringtoinfstr("Grid entry is"); else
-			if ((ind&LAYERH) != 0) (void)addstringtoinfstr("Highlight entry is");
+		if ((ind&LAYERG) != 0) (void)addstringtoinfstr(_("Grid entry is")); else
+			if ((ind&LAYERH) != 0) (void)addstringtoinfstr(_("Highlight entry is"));
 	}
-	(void)sprintf(line, " color (%ld,%ld,%ld)", ((INTBIG *)varred->addr)[ind],
+	(void)sprintf(line, _(" color (%ld,%ld,%ld)"), ((INTBIG *)varred->addr)[ind],
 		((INTBIG *)vargreen->addr)[ind], ((INTBIG *)varblue->addr)[ind]);
 	(void)addstringtoinfstr(line);
 	ttyputmsg("%s", returninfstr());
@@ -1257,13 +1285,13 @@ void us_printcolorvalue(INTSML ind)
 char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 {
 	char line[40];
-	REGISTER INTSML l, i, gooddrc;
+	REGISTER INTSML l, i, gooddrc, goodncc;
 	INTSML year, month, mday, hour, minute, second;
 	REGISTER INTBIG len, total;
 	REGISTER char *pt;
 	REGISTER VARIABLE *var;
 	REGISTER NODEINST *ni;
-	REGISTER UINTBIG lastgooddate, lastchangedate;
+	REGISTER UINTBIG lastgooddate;
 
 	(void)initinfstr();
 	pt = nldescribenodeproto(np);
@@ -1283,14 +1311,14 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 	/* add the creation date */
 	if (np->creationdate == 0)
 	{
-		if (maxlen < 0) (void)addstringtoinfstr("UNRECORDED"); else
-			(void)addstringtoinfstr("     UNRECORDED     ");
+		if (maxlen < 0) (void)addstringtoinfstr(_("UNRECORDED")); else
+			(void)addstringtoinfstr(_("     UNRECORDED     "));
 	} else
 	{
 		if (maxlen < 0)
 		{
 			parsetime(np->creationdate, &year, &month, &mday, &hour, &minute, &second);
-			sprintf(line, "%4d-%02d-%02d %02d:%02d:%02d", year+1900, month, mday, hour,
+			sprintf(line, "%4d-%02d-%02d %02d:%02d:%02d", year, month, mday, hour,
 				minute, second);
 			(void)addstringtoinfstr(line);
 		} else
@@ -1298,7 +1326,7 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 			pt = timetostring(np->creationdate);
 			if (pt == NULL)
 			{
-				(void)addstringtoinfstr("     UNAVAILABLE     ");
+				(void)addstringtoinfstr(_("     UNAVAILABLE     "));
 			} else
 			{
 				for(i=4; i<=9; i++) (void)addtoinfstr(pt[i]);
@@ -1313,14 +1341,14 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 		(void)addstringtoinfstr("  ");
 	if (np->revisiondate == 0)
 	{
-		if (maxlen < 0) (void)addstringtoinfstr("UNRECORDED"); else
-			(void)addstringtoinfstr("     UNRECORDED     ");
+		if (maxlen < 0) (void)addstringtoinfstr(_("UNRECORDED")); else
+			(void)addstringtoinfstr(_("     UNRECORDED     "));
 	} else
 	{
 		if (maxlen < 0)
 		{
 			parsetime(np->revisiondate, &year, &month, &mday, &hour, &minute, &second);
-			sprintf(line, "%4d-%02d-%02d %02d:%02d:%02d", year+1900, month, mday, hour,
+			sprintf(line, "%4d-%02d-%02d %02d:%02d:%02d", year, month, mday, hour,
 				minute, second);
 			(void)addstringtoinfstr(line);
 		} else
@@ -1328,7 +1356,7 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 			pt = timetostring(np->revisiondate);
 			if (pt == NULL)
 			{
-				(void)addstringtoinfstr("     UNAVAILABLE     ");
+				(void)addstringtoinfstr(_("     UNAVAILABLE     "));
 			} else
 			{
 				for(i=4; i<=9; i++) (void)addtoinfstr(pt[i]);
@@ -1346,8 +1374,8 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING|VISARRAY, el_facet_message);
 		if (var == NOVARIABLE) len = 0; else
 			len = getlength(var);
-		if (maxlen < 0) sprintf(line, "%ld lines", len); else
-			sprintf(line, "%8ld lines   ", len);
+		if (maxlen < 0) sprintf(line, _("%ld lines"), len); else
+			sprintf(line, _("%8ld lines   "), len);
 		(void)addstringtoinfstr(line);
 	} else
 	{
@@ -1394,11 +1422,21 @@ char *us_makefacetline(NODEPROTO *np, INTSML maxlen)
 	if (var != NOVARIABLE)
 	{
 		lastgooddate = (UINTBIG)var->addr;
-		lastchangedate = np->revisiondate;
-		if (lastchangedate <= lastgooddate) gooddrc = 1;
+		if (np->revisiondate <= lastgooddate) gooddrc = 1;
 	}
 	if (gooddrc != 0) (void)addstringtoinfstr("D"); else
 		(void)addstringtoinfstr(" ");
+	if (maxlen < 0) (void)addtoinfstr('\t'); else
+		(void)addstringtoinfstr(" ");
+	goodncc = 0;
+	var = getvalkey((INTBIG)np, VNODEPROTO, VINTEGER, net_lastgoodncckey);
+	if (var != NOVARIABLE)
+	{
+		lastgooddate = (UINTBIG)var->addr;
+		if (np->revisiondate <= lastgooddate) goodncc = 1;
+	}
+	if (goodncc != 0) (void)addstringtoinfstr("N"); else
+		(void)addstringtoinfstr(" ");
 	return(returninfstr());
 }
 
@@ -1417,7 +1455,6 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 	char *par[10];
 	REGISTER LIBRARY *l;
 	extern COMCOMP us_quitp, us_yesnop;
-	extern AIDENTRY *io_aid;
 
 	i = 0;
 	for(l = el_curlib; l != NOLIBRARY; l = l->nextlibrary)
@@ -1427,18 +1464,12 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 		if ((l->userbits&(LIBCHANGEDMAJOR|LIBCHANGEDMINOR)) == 0) continue;
 
 		(void)initinfstr();
-		(void)addstringtoinfstr("Library ");
-		(void)addstringtoinfstr(l->libname);
-		(void)addstringtoinfstr(" has changed");
 		if ((l->userbits&LIBCHANGEDMAJOR) != 0)
-			(void)addstringtoinfstr(" significantly"); else
-				(void)addstringtoinfstr(" insignificantly");
-		(void)addstringtoinfstr(".  ");
+			(void)formatinfstr(_("Library %s has changed significantly.  "), l->libname); else
+				(void)formatinfstr(_("Library %s has changed insignificantly.  "), l->libname);
 		if (cancancel != 0)
 		{
-			(void)addstringtoinfstr("Save before ");
-			(void)addstringtoinfstr(action);
-			(void)addstringtoinfstr("?");
+			(void)formatinfstr(_("Save before %s?"), action);
 			count = ttygetparam(returninfstr(), &us_quitp, MAXPARS, par);
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
@@ -1449,12 +1480,12 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 				(void)askaid(io_aid, "write", (INTBIG)l, (INTBIG)"binary");
 			} else
 			{
-				ttyputverbose("Keep working");
+				ttyputverbose(_("Keep working"));
 				return(1);
 			}
 		} else
 		{
-			(void)addstringtoinfstr("save?");
+			(void)addstringtoinfstr(_("save?"));
 			count = ttygetparam(returninfstr(), &us_yesnop, MAXPARS, par);
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
@@ -1469,7 +1500,7 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 	{
 		if (cancancel != 0)
 		{
-			count = ttygetparam("Options have changed, Save?", &us_quitp, MAXPARS, par);
+			count = ttygetparam(_("Options have changed, Save?"), &us_quitp, MAXPARS, par);
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
 				/* do nothing: ignoring the option changes */
@@ -1479,12 +1510,12 @@ INTSML us_preventloss(LIBRARY *lib, char *action, INTSML cancancel)
 				us_saveoptions();
 			} else
 			{
-				ttyputverbose("Keep working");
+				ttyputverbose(_("Keep working"));
 				return(1);
 			}
 		} else
 		{
-			count = ttygetparam("Options have changed, Save?", &us_yesnop, MAXPARS, par);
+			count = ttygetparam(_("Options have changed, Save?"), &us_yesnop, MAXPARS, par);
 			if (count > 0 && namesamen(par[0], "yes", strlen(par[0])) == 0)
 			{
 				/* save the options */
@@ -1500,21 +1531,20 @@ void us_saveoptions(void)
 	REGISTER INTBIG retval;
 	REGISTER LIBRARY *l;
 	REGISTER char *libname, *libfile;
-	extern AIDENTRY *io_aid;
 
 	libname = us_tempoptionslibraryname();
 	libfile = optionsfilepath();
 	l = newlibrary(libname, libfile);
 	if (l == NOLIBRARY)
 	{
-		ttyputerr("Cannot create options library %s", libfile);
+		ttyputerr(_("Cannot create options library %s"), libfile);
 		return;
 	}
 	l->userbits |= READFROMDISK;
-	retval = askaid(io_aid, "write", (INTBIG)l, (INTBIG)"binary");
+	retval = askaid(io_aid, "write", (INTBIG)l, (INTBIG)"nobackupbinary");
 	killlibrary(l);
 	if (retval != 0)
-		ttyputerr("Could not save options library");
+		ttyputerr(_("Could not save options library"));
 }
 
 /*
@@ -1560,7 +1590,7 @@ INTSML us_getcolormapentry(char *pp, INTSML purpose)
 	{
 		if (pp[0] == 0 || pp[1] != 0)
 		{
-			us_abortcommand("Can only give one layer letter");
+			us_abortcommand(_("Can only give one layer letter"));
 			return(-1);
 		}
 		for(i=0; i<high; i++)
@@ -1568,7 +1598,7 @@ INTSML us_getcolormapentry(char *pp, INTSML purpose)
 			for(ch = us_layerletters(el_curtech, i); *ch != 0; ch++)
 				if (*ch == pp[0]) return(i);
 		}
-		us_abortcommand("Letter '%s' is not a valid layer", pp);
+		us_abortcommand(_("Letter '%s' is not a valid layer"), pp);
 		return(-1);
 	}
 
@@ -1588,7 +1618,7 @@ INTSML us_getcolormapentry(char *pp, INTSML purpose)
 			desc = el_curtech->layers[i];
 			if ((desc->bits & color) != 0)
 			{
-				us_abortcommand("No single color for the letters '%s'", pp);
+				us_abortcommand(_("No single color for the letters '%s'"), pp);
 				return(-1);
 			}
 			color |= desc->col;
@@ -1596,7 +1626,7 @@ INTSML us_getcolormapentry(char *pp, INTSML purpose)
 		}
 		if (i == high)
 		{
-			us_abortcommand("Letter '%c' is not a valid layer", *pt1);
+			us_abortcommand(_("Letter '%c' is not a valid layer"), *pt1);
 			return(-1);
 		}
 	}
@@ -1737,10 +1767,10 @@ void us_setaid(INTSML count, char *par[], INTSML state)
 
 	if (count == 0)
 	{
-		count = ttygetparam("Which aid: ", &us_onoffaidp, MAXPARS, par);
+		count = ttygetparam(_("Which aid: "), &us_onoffaidp, MAXPARS, par);
 		if (count == 0)
 		{
-			us_abortcommand("Specify an aid to control");
+			us_abortcommand(_("Specify an aid to control"));
 			return;
 		}
 	}
@@ -1750,37 +1780,37 @@ void us_setaid(INTSML count, char *par[], INTSML state)
 		if (namesame(el_aids[i].aidname, pt) == 0) break;
 	if (i >= el_maxaid)
 	{
-		us_abortcommand("No aid called %s", pt);
+		us_abortcommand(_("No aid called %s"), pt);
 		return;
 	}
 	aid = &el_aids[i];
 
 	if (aid == us_aid && state <= 1)
 	{
-		us_abortcommand("No! I won't go!");
+		us_abortcommand(_("No! I won't go!"));
 		return;
 	}
 	if ((aid->aidstate&AIDON) == 0 && state <= 1)
 	{
-		ttyputverbose("%s already off", pt);
+		ttyputverbose(_("%s already off"), pt);
 		return;
 	}
 	if ((aid->aidstate&AIDON) != 0 && state > 1)
 	{
-		ttyputverbose("%s already on", pt);
+		ttyputverbose(_("%s already on"), pt);
 		return;
 	}
-	if (state <= 1) ttyputverbose("%s turned off", aid->aidname); else
+	if (state <= 1) ttyputverbose(_("%s turned off"), aid->aidname); else
 	{
 		if ((aid->aidstate&AIDINCREMENTAL) == 0 || state == 3)
-			ttyputverbose("%s turned on", aid->aidname); else
-				ttyputmsg("%s turned on, catching up on changes...", aid->aidname);
+			ttyputverbose(_("%s turned on"), aid->aidname); else
+				ttyputmsg(_("%s turned on, catching up on changes..."), aid->aidname);
 	}
 
 	if (state <= 1) aidturnoff(aid, state); else
 	{
 		if (state == 2) aidturnon(aid, 0); else aidturnon(aid, 1);
 		if ((aid->aidstate&AIDINCREMENTAL) != 0 && state != 3)
-			ttyputmsg("...%s caught up", aid->aidname);
+			ttyputmsg(_("...%s caught up"), aid->aidname);
 	}
 }
