@@ -36,6 +36,8 @@
 #include "global.h"
 #include "efunction.h"
 #include "vhdl.h"
+#include "sim.h"
+#include "eio.h"
 #include "tecschem.h"
 #include "edialogs.h"
 
@@ -67,9 +69,9 @@ static KEYWORD vhdloutputopt[] =
 	TERMKEY
 };
 static COMCOMP vhdloutputp = {vhdloutputopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "VHDL compiler output format", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("VHDL compiler output format"), 0};
 static COMCOMP vhdllibraryp = {NOKEYWORD, topoflibs, nextlibs, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Behavioral library to use in VHDL compilation", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Behavioral library to use in VHDL compilation"), 0};
 static KEYWORD vhdlnopt[] =
 {
 	{"vhdl-on-disk",       0,{NOKEY,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -80,7 +82,7 @@ static KEYWORD vhdlnopt[] =
 	TERMKEY
 };
 static COMCOMP vhdlnp = {vhdlnopt, NOTOPLIST, NONEXTLIST, NOPARAMS,
-	NOBACKUP, INPUTOPT, " \t", "Negating action", 0};
+	NOBACKUP, INPUTOPT, " \t", M_("Negating action"), 0};
 static KEYWORD vhdlsetopt[] =
 {
 	{"output-format",      1,{&vhdloutputp,NOKEY,NOKEY,NOKEY,NOKEY}},
@@ -96,7 +98,7 @@ static KEYWORD vhdlsetopt[] =
 	TERMKEY
 };
 COMCOMP vhdl_comp = {vhdlsetopt, NOTOPLIST, NONEXTLIST, NOPARAMS, NOBACKUP,
-	0, " \t", "VHDL compiler action", 0};
+	0, " \t", M_("VHDL compiler action"), 0};
 
 char	vhdl_delimiterstr[] = "&'()*+,-./:;<=>|";
 char	vhdl_doubledelimiterstr[] = "=>..**:=/=>=<=<>";
@@ -207,19 +209,19 @@ UNRESLIST         *vhdl_unresolved_list = 0;
 /* VHDL Options */
 DIALOGITEM vhdl_optionsdialogitems[] =
 {
- /*  1 */ {0, {336,228,360,292}, BUTTON, "OK"},
- /*  2 */ {0, {300,228,324,292}, BUTTON, "Cancel"},
- /*  3 */ {0, {308,4,324,166}, CHECK, "VHDL stored in facet"},
- /*  4 */ {0, {332,4,348,179}, CHECK, "Netlist stored in facet"},
+ /*  1 */ {0, {336,228,360,292}, BUTTON, N_("OK")},
+ /*  2 */ {0, {300,228,324,292}, BUTTON, N_("Cancel")},
+ /*  3 */ {0, {308,4,324,166}, CHECK, N_("VHDL stored in facet")},
+ /*  4 */ {0, {332,4,348,179}, CHECK, N_("Netlist stored in facet")},
  /*  5 */ {0, {28,8,224,295}, SCROLL, ""},
- /*  6 */ {0, {236,4,252,179}, MESSAGE, "VHDL for primitive:"},
- /*  7 */ {0, {260,4,276,179}, MESSAGE, "VHDL for negated primitive:"},
+ /*  6 */ {0, {236,4,252,179}, MESSAGE, N_("VHDL for primitive:")},
+ /*  7 */ {0, {260,4,276,179}, MESSAGE, N_("VHDL for negated primitive:")},
  /*  8 */ {0, {236,184,252,295}, EDITTEXT, ""},
  /*  9 */ {0, {260,184,276,295}, EDITTEXT, ""},
- /* 10 */ {0, {8,8,24,183}, MESSAGE, "Schematics primitives:"},
+ /* 10 */ {0, {8,8,24,183}, MESSAGE, N_("Schematics primitives:")},
  /* 11 */ {0, {292,8,293,295}, DIVIDELINE, ""}
 };
-DIALOG vhdl_optionsdialog = {{50,75,419,379}, "VHDL Options", 11, vhdl_optionsdialogitems};
+DIALOG vhdl_optionsdialog = {{50,75,419,379}, N_("VHDL Options"), 0, 11, vhdl_optionsdialogitems};
 
 /* prototypes for local routines */
 void      vhdl_addportlist(NODEINST*, NODEPROTO*, INTSML);
@@ -249,8 +251,8 @@ void      vhdl_optionsdlog(void);
 char     *vhdl_primname(NODEINST*, INTSML*);
 INTSML    vhdl_propernetlist(NODEPROTO*, char*);
 void      vhdl_scanner(void);
-INTBIG    vhdl_startinput(NODEPROTO*, INTSML, INTSML, char**, UINTBIG*);
-INTSML    vhdl_startoutput(NODEPROTO*, INTSML, INTSML, char**);
+INTBIG    vhdl_startinput(NODEPROTO*, INTBIG, INTSML, char**, UINTBIG*);
+INTSML    vhdl_startoutput(NODEPROTO*, INTBIG, INTSML, char**);
 char      vhdl_toupper(char);
 
 void vhdl_init(INTBIG *argc, char *argv[], AIDENTRY *thisaid)
@@ -295,12 +297,12 @@ INTSML vhdl_set(INTSML count, char *par[])
 			np = getnodeproto(par[1]);
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No facet named %s", par[1]);
+				ttyputerr(_("No facet named %s"), par[1]);
 				return(1);
 			}
 			if (np->primindex != 0)
 			{
-				ttyputerr("Can only convert facets to VHDL, not primitives");
+				ttyputerr(_("Can only convert facets to VHDL, not primitives"));
 				return(1);
 			}
 		} else
@@ -308,7 +310,7 @@ INTSML vhdl_set(INTSML count, char *par[])
 			np = getcurfacet();
 			if (np == NONODEPROTO)
 			{
-				ttyputerr("No current facet");
+				ttyputerr(_("No current facet"));
 				return(1);
 			}
 		}
@@ -323,7 +325,7 @@ INTSML vhdl_set(INTSML count, char *par[])
 		np = getcurfacet();
 		if (np == NONODEPROTO)
 		{
-			ttyputerr("Must be editing a cell");
+			ttyputerr(_("Must be editing a cell"));
 			return(1);
 		}
 
@@ -335,51 +337,51 @@ INTSML vhdl_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputerr("Usage: tellaid VHDL-compiler library LIBRARY");
+			ttyputusage("tellaid vhdl-compiler library LIBRARY");
 			return(0);
 		}
 		vhdl_lib = getlibrary(par[1]);
 		if (vhdl_lib == NOLIBRARY)
 		{
-			ttyputerr("Cannot find library %s", par[1]);
+			ttyputerr(_("Cannot find library %s"), par[1]);
 			return(0);
 		}
-		ttyputverbose("Library %s will be used for behavioral descriptions", par[1]);
+		ttyputverbose(_("Library %s will be used for behavioral descriptions"), par[1]);
 		return(0);
 	}
 
 	if (namesamen(pp, "vhdl-on-disk", l) == 0)
 	{
 		setvalkey((INTBIG)vhdl_aid, VAID, vhdl_vhdlondisk, 1, VINTEGER);
-		ttyputverbose("VHDL will be kept in separate disk files");
+		ttyputverbose(_("VHDL will be kept in separate disk files"));
 		return(0);
 	}
 
 	if (namesamen(pp, "netlist-on-disk", l) == 0)
 	{
 		setvalkey((INTBIG)vhdl_aid, VAID, vhdl_netlistondisk, 1, VINTEGER);
-		ttyputverbose("Netlists will be kept in separate disk files");
+		ttyputverbose(_("Netlists will be kept in separate disk files"));
 		return(0);
 	}
 
 	if (namesamen(pp, "warn", l) == 0)
 	{
 		vhdl_warnflag = TRUE;
-		ttyputverbose("VHDL compiler will display warnings");
+		ttyputverbose(_("VHDL compiler will display warnings"));
 		return(0);
 	}
 
 	if (namesamen(pp, "external", l) == 0)
 	{
 		vhdl_externentities = TRUE;
-		ttyputverbose("VHDL compiler will allow external references");
+		ttyputverbose(_("VHDL compiler will allow external references"));
 		return(0);
 	}
 
 	if (namesamen(pp, "generate-equations", l) == 0)
 	{
 		vhdl_genequations = TRUE;
-		ttyputverbose("VHDL generation will use equations instead of logic block calls");
+		ttyputverbose(_("VHDL generation will use equations instead of logic block calls"));
 		return(0);
 	}
 
@@ -387,41 +389,41 @@ INTSML vhdl_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputerr("Usage: tellaid VHDL-compiler not OPTION");
+			ttyputusage("tellaid vhdl-compiler not OPTION");
 			return(0);
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "warn", l) == 0)
 		{
 			vhdl_warnflag = FALSE;
-			ttyputverbose("VHDL compiler will not display warnings");
+			ttyputverbose(_("VHDL compiler will not display warnings"));
 			return(0);
 		}
 		if (namesamen(pp, "external", l) == 0)
 		{
 			vhdl_externentities = FALSE;
-			ttyputverbose("VHDL compiler will not allow external references");
+			ttyputverbose(_("VHDL compiler will not allow external references"));
 			return(0);
 		}
 		if (namesamen(pp, "vhdl-on-disk", l) == 0)
 		{
 			setvalkey((INTBIG)vhdl_aid, VAID, vhdl_vhdlondisk, 0, VINTEGER);
-			ttyputverbose("VHDL will be kept in facets");
+			ttyputverbose(_("VHDL will be kept in facets"));
 			return(0);
 		}
 		if (namesamen(pp, "netlist-on-disk", l) == 0)
 		{
 			setvalkey((INTBIG)vhdl_aid, VAID, vhdl_netlistondisk, 0, VINTEGER);
-			ttyputverbose("Netlists will be kept in facets");
+			ttyputverbose(_("Netlists will be kept in facets"));
 			return(0);
 		}
 		if (namesamen(pp, "generate-equations", l) == 0)
 		{
 			vhdl_genequations = FALSE;
-			ttyputverbose("VHDL generation will use logic block calls instead of equations");
+			ttyputverbose(_("VHDL generation will use logic block calls instead of equations"));
 			return(0);
 		}
-		ttyputerr("Invalid VHDL compiler NOT option: %s", pp);
+		ttyputbadusage("tellaid vhdl-compiler not");
 		return(0);
 	}
 
@@ -429,45 +431,45 @@ INTSML vhdl_set(INTSML count, char *par[])
 	{
 		if (count <= 1)
 		{
-			ttyputerr("Usage: tellaid VHDL-compiler output FORMAT");
+			ttyputusage("tellaid vhdl-compiler output-format FORMAT");
 			return(0);
 		}
 		l = strlen(pp = par[1]);
 		if (namesamen(pp, "netlisp", l) == 0)
 		{
 			vhdl_target = TARGET_NETLISP;
-			ttyputverbose("VHDL compiles to net lisp");
+			ttyputverbose(_("VHDL compiles to net lisp"));
 			return(0);
 		}
 		if (namesamen(pp, "als", l) == 0 && l >= 1)
 		{
 			vhdl_target = TARGET_ALS;
-			ttyputverbose("VHDL compiles to ALS simulation");
+			ttyputverbose(_("VHDL compiles to ALS simulation"));
 			return(0);
 		}
 		if (namesamen(pp, "quisc", l) == 0 && l >= 3)
 		{
 			vhdl_target = TARGET_QUISC;
-			ttyputverbose("VHDL compiles to QUISC place-and-route");
+			ttyputverbose(_("VHDL compiles to QUISC place-and-route"));
 			return(0);
 		}
 		if (namesamen(pp, "silos", l) == 0)
 		{
 			vhdl_target = TARGET_SILOS;
-			ttyputverbose("VHDL compiles to SILOS simulation");
+			ttyputverbose(_("VHDL compiles to SILOS simulation"));
 			return(0);
 		}
 		if (namesamen(pp, "rsim", l) == 0)
 		{
 			vhdl_target = TARGET_RSIM;
-			ttyputverbose("VHDL compiles to RSIM simulation");
+			ttyputverbose(_("VHDL compiles to RSIM simulation"));
 			return(0);
 		}
-		ttyputerr("Invalid VHDL compiler output: %s", pp);
+		ttyputbadusage("tellaid vhdl-compiler output-format");
 		return(0);
 	}
 
-	ttyputerr("Unknown VHDL compiler option: %s", pp);
+	ttyputbadusage("tellaid vhdl-compiler");
 	return(0);
 }
 
@@ -478,7 +480,7 @@ void vhdl_slice(void)
 	np = getcurfacet();
 	if (np == NONODEPROTO)
 	{
-		ttyputerr("Must be editing a cell");
+		ttyputerr(_("Must be editing a cell"));
 		aidturnoff(vhdl_aid, 0);
 		return;
 	}
@@ -486,7 +488,7 @@ void vhdl_slice(void)
 	vhdl_compile(np);
 
 	aidturnoff(vhdl_aid, 0);
-	ttyputmsg("VHDL compiler turned off");
+	ttyputmsg(_("VHDL compiler turned off"));
 }
 
 /*
@@ -528,7 +530,7 @@ INTBIG vhdl_request(char *command, va_list ap)
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 
-		return(vhdl_startinput((NODEPROTO *)arg1, FILETYPEVHDL, vhdlondisk,
+		return(vhdl_startinput((NODEPROTO *)arg1, io_filetypevhdl, vhdlondisk,
 			(char **)arg2, &vhdldate));
 	}
 
@@ -539,7 +541,7 @@ INTBIG vhdl_request(char *command, va_list ap)
 		arg2 = va_arg(ap, INTBIG);
 		arg3 = va_arg(ap, INTBIG);
 
-		return(vhdl_startinput((NODEPROTO *)arg1, (INTSML)arg2, netlistondisk,
+		return(vhdl_startinput((NODEPROTO *)arg1, arg2, netlistondisk,
 			(char **)arg3, &netlistdate));
 	}
 
@@ -562,18 +564,26 @@ INTBIG vhdl_request(char *command, va_list ap)
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 
-		switch (arg2)
+		if (arg2 == sim_filetypequisc)
 		{
-			case FILETYPEQUISC:   view = el_netlistquiscview;   vhdl_target = TARGET_QUISC;   break;
-			case FILETYPEALS:     view = el_netlistalsview;     vhdl_target = TARGET_ALS;     break;
-			case FILETYPENETLISP: view = el_netlistnetlispview; vhdl_target = TARGET_NETLISP; break;
-			case FILETYPESILOS:   view = el_netlistsilosview;   vhdl_target = TARGET_SILOS;   break;
-			case FILETYPERSIM:    view = el_netlistrsimview;    vhdl_target = TARGET_RSIM;    break;
+			view = el_netlistquiscview;   vhdl_target = TARGET_QUISC;
+		} else if (arg2 == sim_filetypeals)
+		{
+			view = el_netlistalsview;     vhdl_target = TARGET_ALS;
+		} else if (arg2 == sim_filetypenetlisp)
+		{
+			view = el_netlistnetlispview; vhdl_target = TARGET_NETLISP;
+		} else if (arg2 == sim_filetypesilos)
+		{
+			view = el_netlistsilosview;   vhdl_target = TARGET_SILOS;
+		} else if (arg2 == sim_filetypersim)
+		{
+			view = el_netlistrsimview;    vhdl_target = TARGET_RSIM;
 		}
 
 		/* must have a valid netlist */
 		orignp = (NODEPROTO *)arg1;
-		i = vhdl_startinput(orignp, (INTSML)arg2, netlistondisk, &intended, &netlistdate);
+		i = vhdl_startinput(orignp, arg2, netlistondisk, &intended, &netlistdate);
 		vhdl_endinput();
 		if (i == 0)
 		{
@@ -581,7 +591,7 @@ INTBIG vhdl_request(char *command, va_list ap)
 			if (orignp->cellview != view)
 			{
 				/* determine date of associated VHDL */
-				if (vhdl_startinput(orignp, FILETYPEVHDL, vhdlondisk, &intended,
+				if (vhdl_startinput(orignp, io_filetypevhdl, vhdlondisk, &intended,
 					&vhdldate) == 0)
 				{
 					if (netlistdate < vhdldate) i = 1;
@@ -606,7 +616,7 @@ INTBIG vhdl_request(char *command, va_list ap)
 		if (i != 0)
 		{
 			/* no valid netlist: look for VHDL */
-			i = vhdl_startinput(orignp, FILETYPEVHDL, vhdlondisk, &intended, &vhdldate);
+			i = vhdl_startinput(orignp, io_filetypevhdl, vhdlondisk, &intended, &vhdldate);
 			vhdl_endinput();
 			if (i == 0)
 			{
@@ -643,7 +653,7 @@ INTBIG vhdl_request(char *command, va_list ap)
 		arg1 = va_arg(ap, INTBIG);
 		arg2 = va_arg(ap, INTBIG);
 
-		return((INTBIG)vhdl_startoutput((NODEPROTO *)arg1, FILETYPEVHDL, vhdlondisk,
+		return((INTBIG)vhdl_startoutput((NODEPROTO *)arg1, io_filetypevhdl, vhdlondisk,
 			(char **)arg2));
 	}
 
@@ -697,7 +707,7 @@ INTSML vhdl_morerecentcontents(NODEPROTO *np, UINTBIG dateoffile)
  * the facet with the appropriate view of "np".  Returns the name of the input source in
  * "intended" and its last modification date in "revisiondate".  Returns nonzero on error.
  */
-INTBIG vhdl_startinput(NODEPROTO *np, INTSML filetype, INTSML diskflag, char **intended,
+INTBIG vhdl_startinput(NODEPROTO *np, INTBIG filetype, INTSML diskflag, char **intended,
 	UINTBIG *revisiondate)
 {
 	REGISTER NODEPROTO *onp;
@@ -710,14 +720,24 @@ INTBIG vhdl_startinput(NODEPROTO *np, INTSML filetype, INTSML diskflag, char **i
 		return(1);
 	}
 
-	switch (filetype)
+	if (filetype == io_filetypevhdl)
 	{
-		case FILETYPEVHDL:    view = el_vhdlview;            break;
-		case FILETYPEQUISC:   view = el_netlistquiscview;    break;
-		case FILETYPEALS:     view = el_netlistalsview;      break;
-		case FILETYPENETLISP: view = el_netlistnetlispview;  break;
-		case FILETYPESILOS:   view = el_netlistsilosview;    break;
-		case FILETYPERSIM:    view = el_netlistrsimview;     break;
+		view = el_vhdlview;
+	} else if (filetype == sim_filetypequisc)
+	{
+		view = el_netlistquiscview;
+	} else if (filetype == sim_filetypeals)
+	{
+		view = el_netlistalsview;
+	} else if (filetype == sim_filetypenetlisp)
+	{
+		view = el_netlistnetlispview;
+	} else if (filetype == sim_filetypesilos)
+	{
+		view = el_netlistsilosview;
+	} else if (filetype == sim_filetypersim)
+	{
+		view = el_netlistrsimview;
 	}
 
 	vhdl_fp = 0;
@@ -794,20 +814,30 @@ INTBIG vhdl_getnextline(char *addr)
  * appropriate view of "np".  Returns the intended destination in "indended".
  * Returns 1 on error, -1 if aborted.
  */
-INTSML vhdl_startoutput(NODEPROTO *np, INTSML filetype, INTSML diskflag, char **intended)
+INTSML vhdl_startoutput(NODEPROTO *np, INTBIG filetype, INTSML diskflag, char **intended)
 {
 	REGISTER char *prompt;
 	char *truefile, *ext;
 	REGISTER VIEW *view;
 
-	switch (filetype)
+	if (filetype == io_filetypevhdl)
 	{
-		case FILETYPEVHDL:    view = el_vhdlview;            ext = "vhdl";  break;
-		case FILETYPEQUISC:   view = el_netlistquiscview;    ext = "sci";   break;
-		case FILETYPEALS:     view = el_netlistalsview;      ext = "net";   break;
-		case FILETYPENETLISP: view = el_netlistnetlispview;  ext = "net";   break;
-		case FILETYPESILOS:   view = el_netlistsilosview;    ext = "sil";   break;
-		case FILETYPERSIM:    view = el_netlistrsimview;     ext = "net";   break;
+		view = el_vhdlview;            ext = "vhdl";
+	} else if (filetype == sim_filetypequisc)
+	{
+		view = el_netlistquiscview;    ext = "sci";
+	} else if (filetype == sim_filetypeals)
+	{
+		view = el_netlistalsview;      ext = "net";
+	} else if (filetype == sim_filetypenetlisp)
+	{
+		view = el_netlistnetlispview;  ext = "net";
+	} else if (filetype == sim_filetypesilos)
+	{
+		view = el_netlistsilosview;    ext = "sil";
+	} else if (filetype == sim_filetypersim)
+	{
+		view = el_netlistrsimview;     ext = "net";
 	}
 
 	vhdl_fp = 0;
@@ -821,8 +851,8 @@ INTSML vhdl_startoutput(NODEPROTO *np, INTSML filetype, INTSML diskflag, char **
 		(void)addstringtoinfstr(".");
 		(void)addstringtoinfstr(ext);
 		*intended = returninfstr();
-		if (namesame(ext, "vhdl") == 0) prompt = "VHDL File"; else
-			prompt = "Netlist File";
+		if (namesame(ext, "vhdl") == 0) prompt = _("VHDL File"); else
+			prompt = _("Netlist File");
 		vhdl_fp = xcreate(&(*intended)[5], filetype, prompt, &truefile);
 		if (vhdl_fp == 0)
 		{
@@ -839,7 +869,7 @@ INTSML vhdl_startoutput(NODEPROTO *np, INTSML filetype, INTSML diskflag, char **
 		(void)addstringtoinfstr(view->sviewname);
 		(void)addstringtoinfstr("}");
 		*intended = returninfstr();
-		vhdl_facet = newnodeproto(&(*intended)[6], el_curlib);
+		vhdl_facet = newnodeproto(&(*intended)[6], np->cell->lib);
 		if (vhdl_facet == NONODEPROTO) return(1);
 		vhdl_stringarray = newstringarray(vhdl_aid->cluster);
 	}
@@ -862,12 +892,27 @@ INTBIG vhdl_endoutput(void)
 	return(0);
 }
 
+/*
+ * Routine to write a formatted string to the current output file.
+ */
+void vhdl_printoneline(char *fstring, ...)
+{
+	char buff[4000];
+	va_list ap;
+
+	var_start(ap, fstring);
+	(void)vsprintf(buff, fstring, ap);
+	va_end(ap);
+	if (vhdl_fp == 0) addtostringarray(vhdl_stringarray, buff); else
+		xprintf(vhdl_fp, "%s\n", buff);
+}
+
 /*
  * Routine to write a formatted string to the current output file.
  */
 void vhdl_print(char *fstring, ...)
 {
-	INTSML i;
+	INTBIG i;
 	char buff[4000], *sptr, save;
 	va_list ap;
 
@@ -932,7 +977,7 @@ void vhdl_convertfacet(NODEPROTO *np, INTSML force)
 	/* cannot make VHDL for facet with no ports */
 	if (np->firstportproto == NOPORTPROTO)
 	{
-		ttyputerr("Cannot convert facet %s to VHDL: it has no ports", describenodeproto(np));
+		ttyputerr(_("Cannot convert facet %s to VHDL: it has no ports"), describenodeproto(np));
 		return;
 	}
 
@@ -949,7 +994,7 @@ void vhdl_convertfacet(NODEPROTO *np, INTSML force)
 		if (vhdlondisk != 0)
 		{
 			/* look for the disk file */
-			f = xopen(np->cell->cellname, FILETYPEVHDL, "", &filename);
+			f = xopen(np->cell->cellname, io_filetypevhdl, "", &filename);
 			if (f != NULL)
 			{
 				xclose(f);
@@ -958,7 +1003,7 @@ void vhdl_convertfacet(NODEPROTO *np, INTSML force)
 		} else
 		{
 			/* look for the facet */
-			npvhdl = vhdlview(np);
+			npvhdl = anyview(np, el_vhdlview);
 			if (npvhdl != NONODEPROTO)
 			{
 				/* examine the VHDL to see if it really came from this facet */
@@ -981,13 +1026,13 @@ void vhdl_convertfacet(NODEPROTO *np, INTSML force)
 	}
 
 	/* begin output of VHDL */
-	i = vhdl_startoutput(np, FILETYPEVHDL, vhdlondisk, &intended);
+	i = vhdl_startoutput(np, io_filetypevhdl, vhdlondisk, &intended);
 	if (i != 0)
 	{
-		if (i > 0) ttyputerr("Cannot write %s", intended);
+		if (i > 0) ttyputerr(_("Cannot write %s"), intended);
 		return;
 	}
-	ttyputmsg("Converting layout in facet %s, writing VHDL to %s", describenodeproto(np),
+	ttyputmsg(_("Converting layout in facet %s, writing VHDL to %s"), describenodeproto(np),
 		intended);
 
 	/* recursively generate the VHDL */
@@ -996,7 +1041,7 @@ void vhdl_convertfacet(NODEPROTO *np, INTSML force)
 			onp->temp1 = 0;
 	backannotate = vhdl_generatevhdl(np);
 	if (backannotate != 0)
-		ttyputmsg("Back-annotation information has been added (library must be saved)");
+		ttyputmsg(_("Back-annotation information has been added (library must be saved)"));
 
 	/* that's it */
 	vhdl_endoutput();
@@ -1014,7 +1059,6 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	REGISTER VARIABLE *var;
 	char line[30], *pt, gotnand[MAXINPUTS+1], gotxnor[MAXINPUTS+1],
 		gotnor[MAXINPUTS+1], **componentlist;
-	extern AIDENTRY *net_aid;
 
 	/* make sure that all nodes have names on them */
 	backannotate = 0;
@@ -1025,7 +1069,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 	(void)initinfstr();
 	(void)addstringtoinfstr("-- VHDL automatically generated from facet ");
 	(void)addstringtoinfstr(describenodeproto(np));
-	vhdl_print(returninfstr());
+	vhdl_printoneline(returninfstr());
 
 	/* build the "entity" line */
 	(void)initinfstr();
@@ -1215,10 +1259,7 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 		}
 		first = 1;
 		if (net->namecount > 0) pt = net->netname; else
-		{
-			(void)sprintf(line, "NET%ld", (INTBIG)net);
-			pt = line;
-		}
+			pt = describenetwork(net);
 		if (linelen + strlen(pt) > 80)
 		{
 			vhdl_print(returninfstr());
@@ -1300,20 +1341,12 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 			(void)addstringtoinfstr(", ");
 			net = ai->network;
 			if (net->namecount > 0) vhdl_addstring(net->netname); else
-			{
-				(void)addstringtoinfstr("NET");
-				(void)sprintf(line, "%ld", (INTBIG)net);
-				(void)addstringtoinfstr(line);
-			}
+				(void)addstringtoinfstr(describenetwork(net));
 		} else
 		{
 			net = ai->network;
 			if (net->namecount > 0) vhdl_addstring(net->netname); else
-			{
-				(void)addstringtoinfstr("NET");
-				(void)sprintf(line, "%ld", (INTBIG)net);
-				(void)addstringtoinfstr(line);
-			}
+				(void)addstringtoinfstr(describenetwork(net));
 			(void)addstringtoinfstr(", ");
 			(void)sprintf(line, "PINV%ld", ai->temp1);
 			(void)addstringtoinfstr(line);
@@ -1362,18 +1395,24 @@ INTSML vhdl_generatevhdl(NODEPROTO *np)
 void vhdl_addrealports(NODEINST *ni, INTSML special)
 {
 	REGISTER INTSML first, pass;
-	REGISTER PORTPROTO *pp, *opp;
+	REGISTER PORTPROTO *pp, *opp, *cpp;
+	REGISTER NODEPROTO *np, *cnp;
 	REGISTER ARCINST *ai;
 	REGISTER PORTARCINST *pi;
 	REGISTER PORTEXPINST *pe;
 	REGISTER NETWORK *net;
 	char line[50];
 
+	np = ni->proto;
+	cnp = contentsview(np);
+	if (cnp == NONODEPROTO) cnp = np;
 	first = 0;
 	for(pass = 0; pass < 5; pass++)
 	{
-		for(pp = ni->proto->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+		for(cpp = cnp->firstportproto; cpp != NOPORTPROTO; cpp = cpp->nextportproto)
 		{
+			if (cnp == np) pp = cpp; else
+				pp = equivalentport(cnp, cpp, np);
 			if (pass == 0)
 			{
 				/* must be an input port */
@@ -1405,7 +1444,7 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 			if (special == BLOCKMOSTRAN)
 			{
 				/* ignore electrically connected ports */
-				for(opp = ni->proto->firstportproto; opp != pp; opp = opp->nextportproto)
+				for(opp = np->firstportproto; opp != pp; opp = opp->nextportproto)
 					if (opp->network == pp->network) break;
 				if (opp != pp) continue;
 			}
@@ -1461,11 +1500,7 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 					}
 					net = ai->network;
 					if (net->namecount > 0) vhdl_addstring(net->netname); else
-					{
-						(void)addstringtoinfstr("NET");
-						(void)sprintf(line, "%ld", (INTBIG)net);
-						(void)addstringtoinfstr(line);
-					}
+						(void)addstringtoinfstr(describenetwork(net));
 				}
 				continue;
 			}
@@ -1492,16 +1527,12 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 
 					net = ai->network;
 					if (net->namecount > 0) vhdl_addstring(net->netname); else
-					{
-						(void)addstringtoinfstr("NET");
-						(void)sprintf(line, "%ld", (INTBIG)net);
-						(void)addstringtoinfstr(line);
-					}
+						(void)addstringtoinfstr(describenetwork(net));
 					continue;
 				}
 			}
 
-			/* see if this is exported */
+			/* see if this is an export */
 			for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 				if (pe->proto->network == pp->network) break;
 			if (pe != NOPORTEXPINST)
@@ -1511,7 +1542,7 @@ void vhdl_addrealports(NODEINST *ni, INTSML special)
 				continue;
 			}
 
-			/* port is not connected or exported */
+			/* port is not connected or an export */
 			if (first != 0) (void)addstringtoinfstr(", ");   first = 1;
 			(void)addstringtoinfstr("open");
 		}
@@ -1755,7 +1786,7 @@ char *vhdl_primname(NODEINST *ni, INTSML *special)
 	}
 	if (*pt == 0)
 	{
-		/* if the node has an exported port with power/ground, make it that */
+		/* if the node has an export with power/ground, make it that */
 		for(pe = ni->firstportexpinst; pe != NOPORTEXPINST; pe = pe->nextportexpinst)
 		{
 			pp = pe->exportproto;
@@ -1811,6 +1842,7 @@ void vhdl_addstring(char *orig)
 void vhdl_addportlist(NODEINST *ni, NODEPROTO *np, INTSML special)
 {
 	REGISTER PORTPROTO *pp, *opp;
+	REGISTER NODEPROTO *cnp;
 	char before[10];
 
 	if (special == BLOCKFLOPTS || special == BLOCKFLOPDS)
@@ -1824,6 +1856,21 @@ void vhdl_addportlist(NODEINST *ni, NODEPROTO *np, INTSML special)
 		return;
 	}
 
+	/* if this is an icon, use the contents */
+	if (np->primindex == 0 && np->cellview == el_iconview)
+	{
+		cnp = contentsview(np);
+		if (cnp != NONODEPROTO)
+		{
+			/* make sure that the ports correspond */
+			for(pp = cnp->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				(void)equivalentport(cnp, pp, np);
+			for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
+				(void)equivalentport(np, pp, cnp);
+			np = cnp;
+		}
+	}
+
 	/* flag important ports */
 	for(pp = np->firstportproto; pp != NOPORTPROTO; pp = pp->nextportproto)
 	{
@@ -1921,19 +1968,19 @@ void vhdl_addtheseports(NODEINST *ni, NODEPROTO *np, INTBIG bits, char *before)
 void vhdl_compile(NODEPROTO *basefacet)
 {
 	char *intended, *fromintended;
-	INTBIG	i, err;
+	INTBIG	i, err, filetype;
 	REGISTER VARIABLE *var;
 	UINTBIG	netlistdate, vhdldate;
-	INTSML retval, filetype, vhdlondisk, netlistondisk;
+	INTSML retval, vhdlondisk, netlistondisk;
 
 	/* determine netlist type */
 	switch (vhdl_target)
 	{
-		case TARGET_ALS:     filetype = FILETYPEALS;      break;
-		case TARGET_NETLISP: filetype = FILETYPENETLISP;  break;
-		case TARGET_RSIM:    filetype = FILETYPERSIM;     break;
-		case TARGET_SILOS:   filetype = FILETYPESILOS;    break;
-		case TARGET_QUISC:   filetype = FILETYPEQUISC;    break;
+		case TARGET_ALS:     filetype = sim_filetypeals;     break;
+		case TARGET_NETLISP: filetype = sim_filetypenetlisp; break;
+		case TARGET_RSIM:    filetype = sim_filetypersim;    break;
+		case TARGET_SILOS:   filetype = sim_filetypesilos;   break;
+		case TARGET_QUISC:   filetype = sim_filetypequisc;   break;
 	}
 
 	var = getvalkey((INTBIG)vhdl_aid, VAID, VINTEGER, vhdl_vhdlondisk);
@@ -1952,11 +1999,11 @@ void vhdl_compile(NODEPROTO *basefacet)
 	}
 
 	/* get VHDL */
-	if (vhdl_startinput(basefacet, FILETYPEVHDL, vhdlondisk, &intended, &vhdldate) != 0)
+	if (vhdl_startinput(basefacet, io_filetypevhdl, vhdlondisk, &intended, &vhdldate) != 0)
 	{
 		/* issue error if this isn't an icon */
 		if (basefacet->cellview != el_iconview)
-			ttyputerr("Cannot find VHDL for %s", basefacet->cell->cellname);
+			ttyputerr(_("Cannot find VHDL for %s"), basefacet->cell->cellname);
 		return;
 	}
 
@@ -1985,7 +2032,7 @@ void vhdl_compile(NODEPROTO *basefacet)
 	if (!err) err = vhdl_semantic();
 	if (err)
 	{
-		ttyputmsg("ERRORS during compilation, no output produced");
+		ttyputmsg(_("ERRORS during compilation, no output produced"));
 		efree(fromintended);
 		return;
 	}
@@ -1994,10 +2041,10 @@ void vhdl_compile(NODEPROTO *basefacet)
 	retval = vhdl_startoutput(basefacet, filetype, netlistondisk, &intended);
 	if (retval != 0)
 	{
-		if (retval > 0) ttyputerr("Cannot write %s", intended);
+		if (retval > 0) ttyputerr(_("Cannot write %s"), intended);
 		return;
 	}
-	ttyputmsg("Compiling VHDL in %s, writing netlist to %s", fromintended, intended);
+	ttyputmsg(_("Compiling VHDL in %s, writing netlist to %s"), fromintended, intended);
 	efree(fromintended);
 
 	/* write output */
@@ -2645,7 +2692,7 @@ IDENTTABLE *vhdl_makeidentkey(char *string)
 	{
 		if (++count >= MAX_HASH_TRYS)
 		{
-			ttyputmsg("ERROR hashing identifier - tried %ld times", count);
+			ttyputmsg(_("ERROR hashing identifier - tried %ld times"), count);
 			return(0);
 		}
 		attempt = vhdl_identsecondhash(string, attempt);
@@ -2661,7 +2708,7 @@ Description:
 	Return the hash value for the passed string.  The first hash
 	function is:
 
-		value = ( (firstchar << 7) + (lastchar << 4) + length ) mod
+		value = ((firstchar << 7) + (lastchar << 4) + length) mod
 				IDENT_TABLE_SIZE;
 
 	Note:  lowercase letters are converted to uppercase.
@@ -2691,7 +2738,7 @@ Description:
 	Return the hash value for the passed string.  The second hash
 	function is:
 
-		value = (previous_hash +  ( (summation of characters) << 4) +
+		value = (previous_hash +  ((summation of characters) << 4) +
 				(length of string)) mod IDENT_TABLE_SIZE;
 ------------------------------------------------------------------------
 Calling Sequence:  value = vhdl_identsecondhash(string, first_hash);
@@ -2781,7 +2828,7 @@ DBINTERFACE *vhdl_findtopinterface(DBUNITS *units)
 	/* find interface with the flag bit not set */
 	for (interfacef = units->interfaces; interfacef != NULL; interfacef = interfacef->next)
 	{
-		if ( !(interfacef->flags & TOP_ENTITY_FLAG) ) break;
+		if (!(interfacef->flags & TOP_ENTITY_FLAG)) break;
 	}
 	return(interfacef);
 }
@@ -2847,8 +2894,7 @@ void vhdl_optionsdlog(void)
 	REGISTER VARIABLE *var;
 	REGISTER TECHNOLOGY *tech;
 	REGISTER NODEPROTO *np, **nplist;
-	REGISTER INTBIG i, len, vhdlondisk, netlistondisk;
-	extern AIDENTRY *vhdl_aid;
+	REGISTER INTBIG i, len, vhdlondisk, netlistondisk, technameschanged;
 
 	if (DiaInitDialog(&vhdl_optionsdialog) != 0) return;
 	var = getval((INTBIG)vhdl_aid, VAID, VINTEGER, "VHDL_vhdl_on_disk");
@@ -2904,6 +2950,7 @@ void vhdl_optionsdlog(void)
 	if (netlistondisk == 0) DiaSetControl(4, 1);
 
 	/* loop until done */
+	technameschanged = 0;
 	for(;;)
 	{
 		itemHit = DiaNextHit();
@@ -2940,10 +2987,11 @@ void vhdl_optionsdlog(void)
 			(void)addstringtoinfstr(DiaGetText(8));
 			(void)addtoinfstr('/');
 			(void)addstringtoinfstr(DiaGetText(9));
-			efree(varnames[i]);
 			pt = returninfstr();
-			varnames[i] = (char *)emalloc(strlen(pt)+1, el_tempcluster);
-			strcpy(varnames[i], pt);
+			if (strcmp(varnames[i], pt) == 0) continue;
+
+			technameschanged++;
+			(void)reallocstring(&varnames[i], pt, el_tempcluster);
 
 			(void)initinfstr();
 			(void)addstringtoinfstr(nplist[i]->primname);
@@ -2960,14 +3008,15 @@ void vhdl_optionsdlog(void)
 
 	if (itemHit != CANCEL)
 	{
-		if (DiaGetControl(3) != 0) vhdlondisk = 0; else
-			vhdlondisk = 1;
-		setval((INTBIG)vhdl_aid, VAID, "VHDL_vhdl_on_disk", vhdlondisk, VINTEGER);
-		if (DiaGetControl(4) != 0) netlistondisk = 0; else
-			netlistondisk = 1;
-		setval((INTBIG)vhdl_aid, VAID, "VHDL_netlist_on_disk", netlistondisk, VINTEGER);
-		setval((INTBIG)tech, VTECHNOLOGY, "TECH_vhdl_names", (INTBIG)varnames,
-			VSTRING|VISARRAY|(len<<VLENGTHSH));
+		if (DiaGetControl(3) != 0) i = 0; else i = 1;
+		if (i != vhdlondisk)
+			setval((INTBIG)vhdl_aid, VAID, "VHDL_vhdl_on_disk", i, VINTEGER);
+		if (DiaGetControl(4) != 0) i = 0; else i = 1;
+		if (i != netlistondisk)
+			setval((INTBIG)vhdl_aid, VAID, "VHDL_netlist_on_disk", i, VINTEGER);
+		if (technameschanged != 0)
+			setval((INTBIG)tech, VTECHNOLOGY, "TECH_vhdl_names", (INTBIG)varnames,
+				VSTRING|VISARRAY|(len<<VLENGTHSH));
 	}
 	DiaDoneDialog();
 	for(i=0; i<len; i++) efree(varnames[i]);
