@@ -39,7 +39,6 @@ extern INTBIG		vhdl_externentities, vhdl_warnflag, vhdl_target;
 extern DBUNITS		*vhdl_units;
 extern SYMBOLLIST	*vhdl_gsymbols;
 static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
-extern AIDENTRY		*vhdl_aid;
 
 /* prototypes for local routines */
 INTSML vhdl_addnetlist(LIBRARY*, char*);
@@ -104,7 +103,7 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 		"i: a=H o: z=L",
 		"t: delta=0",
 		"i: a=X o: z=X",
-		"load: in=1.0",
+		"load: a=1.0",
 		0
 	};
 	static char *buffer[] =
@@ -171,20 +170,20 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 	vhdl_ident_power = vhdl_findidentkey("power");
 
 	/* print file header */
-	vhdl_print("#*************************************************");
-	vhdl_print("#  ALS Netlist file");
-	vhdl_print("#");
+	vhdl_printoneline("#*************************************************");
+	vhdl_printoneline("#  ALS Netlist file");
+	vhdl_printoneline("#");
 	tsec = getcurrenttime();
 	strtime = timetostring(tsec);
-	vhdl_print("#  File Creation:    %s", strtime);
-	vhdl_print("#-------------------------------------------------");
+	vhdl_printoneline("#  File Creation:    %s", strtime);
+	vhdl_printoneline("#-------------------------------------------------");
 	vhdl_print("");
 
 	/* determine top level cell which must be renamed from "basenp" */
 	top_interface = vhdl_findtopinterface(vhdl_units);
 	if (top_interface == NULL)
 	{
-		ttyputmsg("ERROR - Cannot find interface to rename main.");
+		ttyputmsg(_("ERROR - Cannot find interface to rename main."));
 	} else
 	{
 		/* clear written flag on all interfaces */
@@ -196,7 +195,7 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 	}
 
 	/* print closing line of output file */
-	vhdl_print("#********* End of netlist *******************");
+	vhdl_printoneline("#********* End of netlist *******************");
 
 	/* scan unresolved references for reality inside of Electric */
 	total = 0;
@@ -296,10 +295,10 @@ void vhdl_genals(LIBRARY *lib, NODEPROTO *basenp)
 	/* print unresolved reference list if not empty */
 	if (total > 0)
 	{
-		ttyputmsg("*****  UNRESOLVED REFERENCES *****");
+		ttyputmsg(_("*****  UNRESOLVED REFERENCES *****"));
 		for (ulist = vhdl_unresolved_list; ulist != NULL; ulist = ulist->next)
 			if (ulist->numref > 0)
-				ttyputmsg("%s, %ld time(s)", ulist->interfacef->string, ulist->numref);
+				ttyputmsg(_("%s, %ld time(s)"), ulist->interfacef->string, ulist->numref);
 	}
 }
 
@@ -329,7 +328,7 @@ INTSML vhdl_addnetlist(LIBRARY *lib, char *name)
 		if (var == NOVARIABLE) continue;
 		len = getlength(var);
 		vhdl_print("");
-		for(i=0; i<len; i++) vhdl_print(((char **)var->addr)[i]);
+		for(i=0; i<len; i++) vhdl_printoneline(((char **)var->addr)[i]);
 		return(1);
 	}
 	return(0);
@@ -353,7 +352,7 @@ void vhdl_genfunction(char *name, INTSML isand, INTSML isneg, INTSML inputs)
 	(void)initinfstr();
 	(void)addstringtoinfstr("# Built-in model for ");
 	(void)addstringtoinfstr(modelname);
-	vhdl_print(returninfstr());
+	vhdl_printoneline(returninfstr());
 
 	/* write header line */
 	(void)initinfstr();
@@ -466,8 +465,8 @@ void vhdl_dumpfunction(char *name, char **model)
 	(void)initinfstr();
 	(void)addstringtoinfstr("# Built-in model for ");
 	(void)addstringtoinfstr(name);
-	vhdl_print(returninfstr());
-	for(i=0; model[i] != 0; i++) vhdl_print(model[i]);
+	vhdl_printoneline(returninfstr());
+	for(i=0; model[i] != 0; i++) vhdl_printoneline(model[i]);
 }
 
 /*
@@ -521,12 +520,12 @@ void vhdl_genals_interface(DBINTERFACE *interfacef, char *name)
 				if (vhdl_externentities)
 				{
 					if (vhdl_warnflag)
-						ttyputmsg("WARNING - interface %s not found, assumed external.",
+						ttyputmsg(_("WARNING - interface %s not found, assumed external."),
 							inst->compo->name->string);
 					vhdl_unresolved(inst->compo->name, &vhdl_unresolved_list);
 				} else
 				{
-					ttyputmsg("ERROR - interface %s not found.", inst->compo->name->string);
+					ttyputmsg(_("ERROR - interface %s not found."), inst->compo->name->string);
 				}
 				continue;
 			} else if (symbol->pointer == NULL)
