@@ -40,7 +40,6 @@ extern DBUNITS		*vhdl_units;
 extern SYMBOLLIST	*vhdl_gsymbols;
 static IDENTTABLE	*vhdl_ident_ground, *vhdl_ident_power;
 static DBINTERFACE	*vhdl_top_interface;
-extern AIDENTRY		*vhdl_aid;
 
 /* prototypes for local routines */
 void vhdl_gennet_interface(DBINTERFACE*, char*);
@@ -68,13 +67,13 @@ void vhdl_gennet(INTSML target)
 	vhdl_ident_power = vhdl_findidentkey("power");
 
 	/* print file header */
-	vhdl_print(";*************************************************");
-	vhdl_print(";  RNL Netlisp file");
-	vhdl_print(";");
+	vhdl_printoneline(";*************************************************");
+	vhdl_printoneline(";  RNL Netlisp file");
+	vhdl_printoneline(";");
 	tsec = getcurrenttime();
 	strtime = timetostring(tsec);
-	vhdl_print(";  File Creation:    %s", strtime);
-	vhdl_print(";-------------------------------------------------");
+	vhdl_printoneline(";  File Creation:    %s", strtime);
+	vhdl_printoneline(";-------------------------------------------------");
 	vhdl_print("(load \"library.net\")");
 
 	/* determine top level cell which must be renamed main */
@@ -94,15 +93,15 @@ void vhdl_gennet(INTSML target)
 	}
 
 	/* print closing line of output file */
-	vhdl_print(";********* End of netlist file *******************");
+	vhdl_printoneline(";********* End of netlist file *******************");
 
 	/* print unresolved reference list is not empty */
 	if (vhdl_unresolved_list)
 	{
-		ttyputmsg("*****  UNRESOLVED REFERENCES *****");
+		ttyputmsg(_("*****  UNRESOLVED REFERENCES *****"));
 		for (ulist = vhdl_unresolved_list; ulist != NULL; ulist = ulist->next)
 			if (ulist->numref > 0)
-				ttyputmsg("%s, %ld time(s)", ulist->interfacef->string, ulist->numref);
+				ttyputmsg(_("%s, %ld time(s)"), ulist->interfacef->string, ulist->numref);
 	}
 }
 
@@ -159,13 +158,13 @@ void vhdl_gennet_interface(DBINTERFACE *interfacef, char *name)
 				{
 					if (vhdl_warnflag)
 					{
-						ttyputmsg("WARNING - interface %s not found, assumed external.",
+						ttyputmsg(_("WARNING - interface %s not found, assumed external."),
 							inst->compo->name->string);
 					}
 					vhdl_unresolved(inst->compo->name, &vhdl_unresolved_list);
 				} else
 				{
-					ttyputmsg("ERROR - interface %s not found.", inst->compo->name->string);
+					ttyputmsg(_("ERROR - interface %s not found."), inst->compo->name->string);
 				}
 				continue;
 			} else if (symbol->pointer == NULL)
