@@ -38,7 +38,6 @@
 extern INTBIG		vhdl_externentities, vhdl_warnflag;
 extern DBUNITS		*vhdl_units;
 extern SYMBOLLIST	*vhdl_gsymbols;
-extern AIDENTRY		*vhdl_aid;
 
 #define QNODE_SNAME		0
 #define QNODE_INAME		1
@@ -101,19 +100,19 @@ void vhdl_genquisc(void)
 	vhdl_ident_power = vhdl_findidentkey("power");
 
 	/* print file header */
-	vhdl_print("!*************************************************");
-	vhdl_print("!  QUISC Command file");
-	vhdl_print("!");
+	vhdl_printoneline("!*************************************************");
+	vhdl_printoneline("!  QUISC Command file");
+	vhdl_printoneline("!");
 	tsec = getcurrenttime();
 	strtime = timetostring(tsec);
-	vhdl_print("!  File Creation:    %s", strtime);
-	vhdl_print("!-------------------------------------------------");
+	vhdl_printoneline("!  File Creation:    %s", strtime);
+	vhdl_printoneline("!-------------------------------------------------");
 	vhdl_print("");
 
 	/* determine top level cell */
 	top_interface = vhdl_findtopinterface(vhdl_units);
 	if (top_interface == NULL)
-		ttyputmsg("ERROR - Cannot find top interface."); else
+		ttyputmsg(_("ERROR - Cannot find top interface.")); else
 	{
 		/* clear written flag on all entities */
 		for (interfacef = vhdl_units->interfaces; interfacef != NULL;
@@ -122,7 +121,7 @@ void vhdl_genquisc(void)
 	}
 
 	/* print closing line of output file */
-	vhdl_print("!********* End of command file *******************");
+	vhdl_printoneline("!********* End of command file *******************");
 
 	/* scan unresolved references for reality inside of Electric */
 	total = 0;
@@ -147,10 +146,10 @@ void vhdl_genquisc(void)
 	/* print unresolved reference list */
 	if (total > 0)
 	{
-		ttyputmsg("*****  UNRESOLVED REFERENCES *****");
+		ttyputmsg(_("*****  UNRESOLVED REFERENCES *****"));
 		for (ulist = vhdl_unresolved_list; ulist != NULL; ulist = ulist->next)
 			if (ulist->numref > 0)
-				ttyputmsg("%s, %ld time(s)", ulist->interfacef->string, ulist->numref);
+				ttyputmsg(_("%s, %ld time(s)"), ulist->interfacef->string, ulist->numref);
 	}
 }
 
@@ -206,11 +205,11 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				if (vhdl_externentities)
 				{
 					if (vhdl_warnflag)
-						ttyputmsg("WARNING - interface %s not found, assumed external.",
+						ttyputmsg(_("WARNING - interface %s not found, assumed external."),
 							inst->compo->name->string);
 					vhdl_unresolved(inst->compo->name, &vhdl_unresolved_list);
 				} else
-					ttyputmsg("ERROR - interface %s not found.", inst->compo->name->string);
+					ttyputmsg(_("ERROR - interface %s not found."), inst->compo->name->string);
 				continue;
 			} else vhdl_genquisc_interface((DBINTERFACE *)symbol->pointer);
 		}
@@ -227,7 +226,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				(INTBIG)inst->compo->name->string);
 	}
 
-	/* create exported port list */
+	/* create export list */
 	qnodes = lastnode = NULL;
 	for (fport = interfacef->ports; fport != NULL; fport = fport->next)
 	{
@@ -397,7 +396,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 						}
 						break;
 					default:
-						ttyputmsg("ERROR - unknown name type on actual port.");
+						ttyputmsg(_("ERROR - unknown name type on actual port."));
 						break;
 				}
 			}
@@ -444,7 +443,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 		}
 	}
 
-	/* print out export ports */
+	/* print out exports */
 	for (newnode = qnodes; newnode; newnode = newnode->next)
 	{
 		if (newnode->flags & QNODE_EXPORT)
@@ -464,7 +463,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 				} else
 				{
 					sprintf(buff, "%s", newnode->name->string);
-					ttyputmsg("ERROR - no port to export for %s", buff);
+					ttyputmsg(_("ERROR - no export for %s"), buff);
 				}
 			} else
 			{
@@ -491,7 +490,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 					} else
 					{
 						sprintf(buff, "%s[%ld]", newnode->name->string, (INTBIG)indexc);
-						ttyputmsg("ERROR - no port to export for %s", buff);
+						ttyputmsg(_("ERROR - no export for %s"), buff);
 					}
 				}
 			}
@@ -504,7 +503,7 @@ void vhdl_genquisc_interface(DBINTERFACE *interfacef)
 	/* print out non-exported node name assignments */
 	for (newnode = qnodes; newnode; newnode = newnode->next)
 	{
-		if ( !(newnode->flags & QNODE_EXPORT) )
+		if (!(newnode->flags & QNODE_EXPORT))
 		{
 			if (newnode->name_type == QNODE_SNAME)
 			{
@@ -811,7 +810,7 @@ void vhdl_addporttonode(QPORT *port, IDENTTABLE *ident, INTBIG type, INTBIG inde
 	}
 	if (!node)
 	{
-		ttyputmsg("WARNING node %s not found.", node->name->string);
+		ttyputmsg(_("WARNING node %s not found."), node->name->string);
 	}
 }
 
