@@ -44,13 +44,10 @@ SYMBOLLIST      *vhdl_symbollists = 0;
 DBUNITS			*vhdl_units = 0;
 static char		vhdl_default_name[80];
 #ifdef VHDL50
-static INTBIG	vhdl_default_num;
-#endif
-extern AIDENTRY	*vhdl_aid;
-
-#ifndef VHDL50
-static INTBIG	vhdl_for_level = 0;
-static INTBIG	vhdl_for_tags[10];
+  static INTBIG	vhdl_default_num;
+#else
+  static INTBIG	vhdl_for_level = 0;
+  static INTBIG	vhdl_for_tags[10];
 #endif
 
 /* prototypes for local routines */
@@ -389,7 +386,7 @@ void vhdl_sempackage(PACKAGE *package)
 	/* search to see if package name is unique */
 	if (vhdl_searchsymbol((IDENTTABLE *)package->name->pointer, vhdl_gsymbols))
 	{
-		vhdl_reporterrormsg(package->name, "Symbol previously defined");
+		vhdl_reporterrormsg(package->name, _("Symbol previously defined"));
 	} else
 	{
 		dbpackage = (DBPACKAGE *)emalloc((INTBIG)sizeof(DBPACKAGE), vhdl_aid->cluster);
@@ -434,7 +431,7 @@ DBINTERFACE  *vhdl_seminterface(VINTERFACE *interfacef)
 	if (interfacef == 0) return(dbinter);
 	if (vhdl_searchsymbol((IDENTTABLE *)interfacef->name->pointer, vhdl_gsymbols))
 	{
-		vhdl_reporterrormsg(interfacef->name, "Entity previously defined");
+		vhdl_reporterrormsg(interfacef->name, _("Entity previously defined"));
 	} else
 	{
 		dbinter = (DBINTERFACE *)emalloc((INTBIG)sizeof(DBINTERFACE), vhdl_aid->cluster);
@@ -484,7 +481,7 @@ DBBODY *vhdl_sembody(BODY *body)
 	if (body == 0) return(dbbody);
 	if (vhdl_searchsymbol((IDENTTABLE *)body->name->pointer, vhdl_gsymbols))
 	{
-		vhdl_reporterrormsg(body->name, "Body previously defined");
+		vhdl_reporterrormsg(body->name, _("Body previously defined"));
 		return(dbbody);
 	}
 
@@ -504,11 +501,11 @@ DBBODY *vhdl_sembody(BODY *body)
 	if ((symbol = vhdl_searchsymbol((IDENTTABLE *)body->entity->identifier->pointer,
 		vhdl_gsymbols)) == 0)
 	{
-		vhdl_reporterrormsg((TOKENLIST *)body->entity, "Reference to undefined entity");
+		vhdl_reporterrormsg((TOKENLIST *)body->entity, _("Reference to undefined entity"));
 		return(dbbody);
 	} else if (symbol->type != SYMBOL_ENTITY)
 	{
-		vhdl_reporterrormsg((TOKENLIST *)body->entity, "Symbol is not an entity");
+		vhdl_reporterrormsg((TOKENLIST *)body->entity, _("Symbol is not an entity"));
 		return(dbbody);
 	} else
 	{
@@ -582,7 +579,7 @@ DBPORTLIST *vhdl_semformal_port_list(FPORTLIST *port)
 			case MODE_LINKAGE:
 				break;
 			default:
-				vhdl_reporterrormsg(port->names->identifier, "Unknown port mode");
+				vhdl_reporterrormsg(port->names->identifier, _("Unknown port mode"));
 				break;
 		}
 
@@ -590,7 +587,7 @@ DBPORTLIST *vhdl_semformal_port_list(FPORTLIST *port)
 		if ((symbol = vhdl_searchsymbol(vhdl_getnameident(port->type), vhdl_symbols)) == 0 ||
 			symbol->type != SYMBOL_TYPE)
 		{
-			vhdl_reporterrormsg(vhdl_getnametoken(port->type), "Unknown port mode");
+			vhdl_reporterrormsg(vhdl_getnametoken(port->type), _("Unknown port mode"));
 		}
 
 		/* check for uniqueness of port names */
@@ -598,7 +595,7 @@ DBPORTLIST *vhdl_semformal_port_list(FPORTLIST *port)
 		{
 			if (vhdl_searchfsymbol((IDENTTABLE *)names->identifier->pointer, vhdl_symbols))
 			{
-				vhdl_reporterrormsg(names->identifier, "Duplicate port name in port list");
+				vhdl_reporterrormsg(names->identifier, _("Duplicate port name in port list"));
 			} else
 			{
 				/* add to port list */
@@ -724,7 +721,7 @@ DBCOMPONENTS *vhdl_semcomponent(COMPONENT *compo)
 	if (compo == 0) return(dbcomp);
 	if (vhdl_searchfsymbol((IDENTTABLE *)compo->name->pointer, vhdl_symbols))
 	{
-		vhdl_reporterrormsg(compo->name, "Identifier previously defined");
+		vhdl_reporterrormsg(compo->name, _("Identifier previously defined"));
 		return(dbcomp);
 	}
 	dbcomp = (DBCOMPONENTS *)emalloc((INTBIG)sizeof(DBCOMPONENTS), vhdl_aid->cluster);
@@ -840,7 +837,7 @@ DBSIGNALS *vhdl_semsignal_declare(SIGNALDECLARE *signal)
 	if ((symbol = vhdl_searchsymbol((IDENTTABLE *)type, vhdl_symbols)) == 0 ||
 		symbol->type != SYMBOL_TYPE)
 	{
-		vhdl_reporterrormsg(vhdl_getnametoken(signal->subtype->type), "Bad type");
+		vhdl_reporterrormsg(vhdl_getnametoken(signal->subtype->type), _("Bad type"));
 	}
 
 	/* check each signal in signal list for uniqueness */
@@ -848,7 +845,7 @@ DBSIGNALS *vhdl_semsignal_declare(SIGNALDECLARE *signal)
 	{
 		if (vhdl_searchsymbol((IDENTTABLE *)sig->identifier->pointer, vhdl_symbols))
 		{
-			vhdl_reporterrormsg(sig->identifier, "Signal previously defined");
+			vhdl_reporterrormsg(sig->identifier, _("Signal previously defined"));
 		} else
 		{
 			newsignal = (DBSIGNALS *)emalloc((INTBIG)sizeof(DBSIGNALS), vhdl_aid->cluster);
@@ -891,7 +888,7 @@ void vhdl_semconstant_declare(CONSTANTDECLARE *constant)
 	/* check if name exists in top level of symbol tree */
 	if (vhdl_searchfsymbol((IDENTTABLE *)constant->identifier->pointer, vhdl_symbols))
 	{
-		vhdl_reporterrormsg(constant->identifier, "Symbol previously defined");
+		vhdl_reporterrormsg(constant->identifier, _("Symbol previously defined"));
 	} else
 	{
 		value = vhdl_evalexpression(constant->expression);
@@ -1004,7 +1001,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 	if (!inst->name)
 	{
 		if (vhdl_warnflag)
-			ttyputmsg("WARNING - no name for node instance, adding default");
+			ttyputmsg(_("WARNING - no name for node instance, adding default"));
 
 		/* create instance name */
 		sprintf(sbuffer, "%s_%ld", vhdl_default_name, vhdl_default_num++);
@@ -1014,7 +1011,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 	 */
 	if (vhdl_for_level > 0)
 	{
-		if (!inst->name) strcpy(sbuffer,"no_name"); else
+		if (!inst->name) strcpy(sbuffer, "no_name"); else
 			strcpy(sbuffer,((IDENTTABLE *)(inst->name->pointer))->string);
 		for (i=1; i<=vhdl_for_level; ++i)
 		{
@@ -1040,7 +1037,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 	dbinst->next = 0;
 	if (vhdl_searchsymbol(dbinst->name, vhdl_symbols))
 	{
-		vhdl_reporterrormsg(inst->name, "Instance name previously defined");
+		vhdl_reporterrormsg(inst->name, _("Instance name previously defined"));
 	} else
 	{
 		vhdl_addsymbol(dbinst->name, (INTBIG)SYMBOL_INSTANCE, (char *)dbinst, vhdl_symbols);
@@ -1051,10 +1048,10 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 	symbol = vhdl_searchsymbol((IDENTTABLE *)inst->entity->identifier->pointer, vhdl_symbols);
 	if (symbol == 0)
 	{
-		vhdl_reporterrormsg(inst->entity->identifier, "Instance references undefined component");
+		vhdl_reporterrormsg(inst->entity->identifier, _("Instance references undefined component"));
 	} else if (symbol->type != SYMBOL_COMPONENT)
 	{
-		vhdl_reporterrormsg(inst->entity->identifier, "Symbol is not a component reference");
+		vhdl_reporterrormsg(inst->entity->identifier, _("Symbol is not a component reference"));
 	} else
 	{
 		compo = (DBCOMPONENTS *)symbol->pointer;
@@ -1074,7 +1071,7 @@ DBINSTANCE *vhdl_seminstance(INSTANCE *inst)
 		if (iport_num != cport_num)
 		{
 			vhdl_reporterrormsg(vhdl_getnametoken((NAME *)inst->ports->pointer),
-				"Instance has different number of ports that component");
+				_("Instance has different number of ports that component"));
 			return((DBINSTANCE *)0);
 		}
 	}
@@ -1157,7 +1154,7 @@ DBSTATEMENTS *vhdl_semgenerate(GENERATE *gen)
 		/* check label for uniqueness */
 		if (vhdl_searchsymbol((IDENTTABLE *)gen->label->pointer, vhdl_symbols))
 		{
-			vhdl_reporterrormsg(gen->label, "Symbol previously defined");
+			vhdl_reporterrormsg(gen->label, _("Symbol previously defined"));
 		} else
 		{
 			vhdl_addsymbol((IDENTTABLE *)gen->label->pointer, (INTBIG)SYMBOL_LABEL, (char *)0,
@@ -1279,12 +1276,12 @@ void vhdl_semwith(WITH *with)
 		symbol = vhdl_searchsymbol((IDENTTABLE *)with->unit->pointer, vhdl_gsymbols);
 		if (symbol == 0)
 		{
-			vhdl_reporterrormsg(with->unit, "Symbol is undefined");
+			vhdl_reporterrormsg(with->unit, _("Symbol is undefined"));
 			continue;
 		}
 		if (symbol->type != SYMBOL_PACKAGE)
 		{
-			vhdl_reporterrormsg(with->unit, "Symbol is not a PACKAGE");
+			vhdl_reporterrormsg(with->unit, _("Symbol is not a PACKAGE"));
 		} else
 		{
 			vhdl_addsymbol(symbol->value, (INTBIG)SYMBOL_PACKAGE, symbol->pointer, vhdl_symbols);
@@ -1323,12 +1320,12 @@ void vhdl_semuse(USE *use)
 		symbol = vhdl_searchsymbol((IDENTTABLE *)use->unit->pointer, vhdl_gsymbols);
 		if (symbol == 0)
 		{
-			vhdl_reporterrormsg(use->unit, "Symbol is undefined");
+			vhdl_reporterrormsg(use->unit, _("Symbol is undefined"));
 			continue;
 		}
 		if (symbol->type != SYMBOL_PACKAGE)
 		{
-			vhdl_reporterrormsg(use->unit, "Symbol is not a PACKAGE");
+			vhdl_reporterrormsg(use->unit, _("Symbol is not a PACKAGE"));
 		} else
 		{
 			vhdl_addsymbol(symbol->value, (INTBIG)SYMBOL_PACKAGE, symbol->pointer, vhdl_symbols);
@@ -1337,12 +1334,12 @@ void vhdl_semuse(USE *use)
 		symbol = vhdl_searchsymbol((IDENTTABLE *)use->unit->pointer, vhdl_gsymbols);
 		if (symbol == 0)
 		{
-			vhdl_reporterrormsg(use->unit, "Symbol is undefined");
+			vhdl_reporterrormsg(use->unit, _("Symbol is undefined"));
 			continue;
 		}
 		if (symbol->type != SYMBOL_PACKAGE)
 		{
-			vhdl_reporterrormsg(use->unit, "Symbol is not a PACKAGE");
+			vhdl_reporterrormsg(use->unit, _("Symbol is not a PACKAGE"));
 		} else
 		{
 			vhdl_symbols = vhdl_pushsymbols(vhdl_symbols);
@@ -1517,7 +1514,7 @@ SYMBOLTREE *vhdl_addsymboltree(IDENTTABLE *value, INTBIG type, char *pointer, SY
 		tptr = &nptr->rptr;
 	} else
 	{
-		ttyputmsg("ERROR - symbol %s already exists", value->string);
+		ttyputmsg(_("ERROR - symbol %s already exists"), value->string);
 		return((SYMBOLTREE *)0);
 	}
 
@@ -1579,7 +1576,7 @@ SYMBOLLIST *vhdl_popsymbols(SYMBOLLIST *old_sym_list)
 
 	if (!old_sym_list)
 	{
-		ttyputmsg("ERROR - trying to pop nonexistant symbol list.");
+		ttyputmsg(_("ERROR - trying to pop nonexistant symbol list."));
 		return((SYMBOLLIST *)0);
 	}
 	new_sym_list = old_sym_list->last;
@@ -1649,7 +1646,8 @@ void vhdl_semaport_check_single_name(SINGLENAME *sname)
 			if ((symbol = vhdl_searchsymbol(ident, vhdl_symbols)) == 0 ||
 				(symbol->type != SYMBOL_FPORT && symbol->type != SYMBOL_SIGNAL))
 			{
-				vhdl_reporterrormsg(simname->identifier, "Instance port has reference to unknown port");
+				vhdl_reporterrormsg(simname->identifier,
+					_("Instance port has reference to unknown port"));
 			}
 			break;
 		case SINGLENAME_INDEXED:
@@ -1658,7 +1656,8 @@ void vhdl_semaport_check_single_name(SINGLENAME *sname)
 			if ((symbol = vhdl_searchsymbol(ident, vhdl_symbols)) == 0 ||
 				(symbol->type != SYMBOL_FPORT && symbol->type != SYMBOL_SIGNAL))
 			{
-				vhdl_reporterrormsg(vhdl_getprefixtoken(iname->prefix), "Instance port has reference to unknown port");
+				vhdl_reporterrormsg(vhdl_getprefixtoken(iname->prefix),
+					_("Instance port has reference to unknown port"));
 			}
 			break;
 		default:
@@ -1697,7 +1696,7 @@ TYPE *vhdl_parsetype(void)
 	/* should be at keyword TYPE */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_TYPE))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword TYPE");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword TYPE"));
 		vhdl_getnexttoken();
 		return(type);
 	}
@@ -1706,7 +1705,7 @@ TYPE *vhdl_parsetype(void)
 	/* should be at type identifier */
 	if (vhdl_nexttoken->token != TOKEN_IDENTIFIER)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting an identifier");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting an identifier"));
 		vhdl_getnexttoken();
 		return(type);
 	}
@@ -1716,7 +1715,7 @@ TYPE *vhdl_parsetype(void)
 	/* should be keyword IS */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_IS))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword IS");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword IS"));
 		vhdl_getnexttoken();
 		return(type);
 	}
@@ -1741,7 +1740,7 @@ TYPE *vhdl_parsetype(void)
 		pointer = vhdl_parsescalar_type();
 	} else
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Invalid type definition");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Invalid type definition"));
 		vhdl_getnexttoken();
 		return(type);
 	}
@@ -1749,7 +1748,7 @@ TYPE *vhdl_parsetype(void)
 	/* should be at semicolon */
 	if (vhdl_nexttoken->token != TOKEN_SEMICOLON)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a semicolon");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a semicolon"));
 		vhdl_getnexttoken();
 		return(type);
 	}
@@ -1795,7 +1794,7 @@ COMPOSITE *vhdl_parsecomposite_type(void)
 		pointer = vhdl_parserecord_type();
 	} else
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Invalid composite type");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Invalid composite type"));
 		vhdl_getnexttoken();
 		return(compo);
 	}
@@ -1849,7 +1848,7 @@ ARRAY *vhdl_parsearray_type(void)
 	/* should be keyword ARRAY */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_ARRAY))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword ARRAY");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword ARRAY"));
 		vhdl_getnexttoken();
 		return(array);
 	}
@@ -1859,7 +1858,7 @@ ARRAY *vhdl_parsearray_type(void)
 	/* should be left bracket */
 	if (vhdl_nexttoken->token != TOKEN_LEFTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a left bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a left bracket"));
 		vhdl_getnexttoken();
 		return(array);
 	}
@@ -1885,7 +1884,7 @@ ARRAY *vhdl_parsearray_type(void)
 	/* should be at right bracket */
 	if (vhdl_nexttoken->token != TOKEN_RIGHTBRACKET)
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting a right bracket");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting a right bracket"));
 		vhdl_getnexttoken();
 		return(array);
 	}
@@ -1894,7 +1893,7 @@ ARRAY *vhdl_parsearray_type(void)
 	/* should be at keyword OF */
 	if (!vhdl_keysame(vhdl_nexttoken, (INTBIG)KEY_OF))
 	{
-		vhdl_reporterrormsg(vhdl_nexttoken, "Expecting keyword OF");
+		vhdl_reporterrormsg(vhdl_nexttoken, _("Expecting keyword OF"));
 		vhdl_getnexttoken();
 		return(array);
 	}
@@ -1937,7 +1936,7 @@ void vhdl_semtype_declare(TYPE *type)
 	/* check that type name is distict */
 	if (vhdl_searchsymbol((IDENTTABLE *)type->identifier->pointer, vhdl_symbols))
 	{
-		vhdl_reporterrormsg(type->identifier, "Identifier previously defined");
+		vhdl_reporterrormsg(type->identifier, _("Identifier previously defined"));
 		return;
 	}
 
@@ -2198,7 +2197,7 @@ DBTYPE *vhdl_semtype_mark(NAME *name)
 	if ((symbol = vhdl_searchsymbol(vhdl_getnameident(name), vhdl_symbols)) == NULL ||
 		symbol->type != SYMBOL_TYPE)
 	{
-		vhdl_reporterrormsg(vhdl_getnametoken(name), "Bad type");
+		vhdl_reporterrormsg(vhdl_getnametoken(name), _("Bad type"));
 	} else
 	{
 		dbtype = (DBTYPE *)symbol->pointer;
